/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=568240;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function xM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=0,U=0,V=0,W=0,X=E(0),Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=E(0),Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=E(0),Ya=0;fa=fb-32|0;fb=fa;ha=fa+28|0;x[ha>>2]=48884;x[ha>>2]=48784;e=mB(fa+20|0);d=mB(fa+12|0);ia=b;oa=c;pa=x[e>>2];Ea=y[e+4|0];qa=x[d>>2];Fa=y[d+4|0];b=0;L=fb-96|0;fb=L;d=a;ra=a+24604|0;a=ra;a:{if(!x[a+16>>2]){break a}c=x[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=L+80|0;VR(a,9133,13070,220,45);b=fb-48|0;fb=b;c=rc(b+24|0,18361);x[31721]=0;O(890,b+12|0,17437);e=x[31721];x[31721]=0;b:{c:{d:{e:{if((e|0)!=1){x[31721]=0;S(2,b+36|0,c|0,b+12|0);e=x[31721];x[31721]=0;if((e|0)==1){break e}x[31721]=0;S(891,a|0,1,b+36|0);a=x[31721];x[31721]=0;if((a|0)!=1){break b}a=N()|0;tb(b+36|0);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0}sa=d+8204|0;ta=d+397452|0;ua=d+397448|0;da=d+393352|0;J=d+397456|0;$=d+12|0;Ga=d+1074376|0;Ha=d+1298424|0;Ia=d+1074365|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!ia|a&512)){h:{if(x[d+1074380>>2]){break h}ma=d;b=a|512;i:{if(a&256){break i}o=fb-48|0;fb=o;G=fb-32|0;fb=G;j=d+1074312|0;h=d+1074992|0;l=d+1298264|0;i=d+1074424|0;n=d+484360|0;m=d+1074448|0;q=d+1074376|0;a=x[d+1074392>>2];C=d+480188|0;K=d+480180|0;s=d+484376|0;M=d+484348|0;U=d+480210|0;P=d+484364|0;j:{k:while(1){l:{a=a+1|0;x[d+1074392>>2]=a;if(Hl(q)>>>0>a>>>0){break l}pT(G+30|0,x[K>>2],z[C>>1],q,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{r=x[d+480208>>2];if(r&32){t=x[M>>2];H=x[d+484344>>2];c=z[d+1074446>>1];break p}c=65535;R=Wb(x[d+484360>>2],y[s|0]);u=x[R>>2];T=x[R+4>>2];e=Yc(u,T);a=z[d+1074448>>1];if(e>>>0>a>>>0){c=z[Zb(u,a)>>1]}w[d+1074446>>1]=c;q:{r:{b=c&65535;H=x[d+484344>>2];t=x[M>>2];I=aj(H,t);if(b>>>0>=I>>>0){break r}b=Vb(H,b);if(Ib(x[b>>2],x[b+4>>2])){break r}b=0;break q}b=1}while(1){s:{t:{u:{g=d;if(b){v:{w:{x:{b=c&65535;if(b>>>0>=I>>>0){c=a&65535;if(!((b|0)!=65535&e>>>0>c>>>0)){f=z[R+28>>1];if(f){b=Yc(u,T);break w}if(!(a&65535)|c>>>0>e>>>0){break x}while(1){f=c;a=a-1|0;b=a&65535;if(!b){break x}c=f-1|0;if(z[Zb(u,b)>>1]!=65535){continue}break}b=e;break w}a=a+1|0;w[m>>1]=a;c=a&65535;break v}w[d+1074450>>1]=a;break p}b=e;f=0}a=f;w[d+1074448>>1]=a;r=r&-524289;x[d+480208>>2]=r;while(1){c=a&65535;if(c>>>0>=b>>>0){break o}if(z[Zb(u,c)>>1]==65534){a=a+1|0;w[m>>1]=a;continue}break}if(!_i(R,a&65535)){break o}}if(c>>>0<e>>>0){break u}c=65535}else{c=65534}w[g+1074446>>1]=c;break t}c=z[Zb(u,c)>>1];w[d+1074446>>1]=c;if(c>>>0>=I>>>0){break t}b=Vb(H,c);if(!Ib(x[b>>2],x[b+4>>2])){break s}}b=1;continue}b=0;continue}}b=c&65535;if(!Ge(H,t,b)){break n}a=x[i>>2];if(a>>>0>=A[Vb(H,b)+12>>2]){x[i>>2]=0;a=0}if(r&32?x[d+480272>>2]!=-1:0){break m}if(!Gu(l,z[m>>1],a,vq(G+20|0,h),y[G+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Go(l,1);Gu(l,z[m>>1],x[i>>2],vq(G+20|0,h),y[G+30|0]);break m}if(!(y[U|0]&64)){break o}a=0;if(!Fu(l,m,i)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;c=Kj(x[d+484360>>2],x[P>>2])-1|0;b=y[s|0];if((c|0)<=(b|0)){_j(n,0);break o}_j(n,b+1&255);Go(l,1)}while(1)if((a|0)==256){MR(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Wb(x[d+484360>>2],y[s|0]);e=x[c>>2];if(Yc(e,x[c+4>>2])>>>0>a>>>0){Va=d,Wa=z[Zb(e,a)>>1],w[Va+1074446>>1]=Wa}Gu(l,a,b,vq(G+20|0,h),y[G+30|0]);if(!Ge(x[d+484344>>2],x[M>>2],z[d+1074446>>1])){break n}break m}else{Ko((D(a,872)+d|0)+1074992|0,d,a&65535,134217728);a=a+1|0;continue}}Go(l,1)}a=0;break j}oT(d,q,(x[d+480208>>2]&32)>>>5|0);a=Vb(x[d+484344>>2],z[d+1074446>>1]);c=jd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=h+D(z[C>>1],872)|0;a=h;while(1){if((a|0)==(e|0)){y:{z:{a=x[d+484344>>2];b=z[d+1074446>>1];if(vn(a,x[d+484348>>2],b)){a=Vb(a,b);b=x[a+16>>2];a=x[a+20>>2];if(lT(b,a)){break z}}x[d+1074408>>2]=x[d+480216>>2];a=x[d+480220>>2];break y}x[d+1074408>>2]=b}x[d+1074412>>2]=a;if(!y[G+30|0]){break l}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue k}Kb(G+20|0,j,82);A:{if(!Hb(x[x[G+20>>2]>>2],x[G+24>>2])|y[a+805|0]!=1){break A}b=y[c+3|0];if((b|0)!=2&(b|0)!=3){break A}Va=a,Wa=uh(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Va+700>>2]=Wa}Kb(G+20|0,j,91);B:{if(!Hb(x[x[G+20>>2]>>2],x[G+24>>2])){break B}if(Sc(y[c|0])){break B}b=y[a+788|0];if(!Sc(b)|y[a+791|0]!=19){break B}f=y[a+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break B}Va=a,Wa=uh(d,b,w[a+772>>1],0),x[Va+700>>2]=Wa}Kb(G+20|0,j,118);C:{if(!Hb(x[x[G+20>>2]>>2],x[G+24>>2])){break C}if(Sc(y[c|0])|!(y[a+89|0]&2)){break C}b=x[a+708>>2];if(!b){break C}if(!Sc(y[a+788|0])){break C}if(!Il(y[a+790|0],y[a+791|0])){break C}x[a+700>>2]=b}Kb(G+20|0,j,92);D:{if(!Hb(x[x[G+20>>2]>>2],x[G+24>>2])){break D}Kb(G+12|0,j,5);if(Hb(x[x[G+12>>2]>>2],x[G+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break D}v[G+20|0]=1;Va=d,Wa=D(y[af(G+20|0,a+793|0)|0],1e4),x[Va+1074420>>2]=Wa}b=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+788|0]=b;v[a+789|0]=b>>>8;v[a+790|0]=b>>>16;v[a+791|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8;v[a+792|0]=b;v[a+793|0]=b>>>8;b=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=b;x[a+88>>2]=x[a+88>>2]&-393217;Kb(G+20|0,j,21);if(!Hb(x[x[G+20>>2]>>2],x[G+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;c=c+6|0;a=a+872|0;continue}}break}b=x[d+1074416>>2];if(!b){x[d+1074416>>2]=1;b=1}a=x[d+480208>>2];e=x[d+1074392>>2];E:{F:{if(e){c=a&-4097;x[d+480208>>2]=c;f=x[d+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break E}if(Hl(q)>>>0<=e>>>0){break E}if(!((e>>>0)%(x[d+1074400>>2]+b>>>0)|0)){break F}break E}c=a&-528385}x[d+480208>>2]=c|4096}n=0;i=fb-16|0;fb=i;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;ba=d+1075809|0;s=d+1074312|0;T=d+906300|0;C=d+1074376|0;Y=d+480188|0;I=d+480208|0;Z=d+480209|0;M=d+480180|0;ea=d+480210|0;aa=d+480190|0;P=d+480192|0;while(1){if(z[Y>>1]<=n>>>0){G:{if(!(y[d+480209|0]&16)){break G}if(!dT(d,C,Wb(x[d+484360>>2],y[d+484376|0]),1)){break G}a=d+480208|0;x[a>>2]=x[a>>2]|524288}fb=i+16|0}else{q=D(n,872)+d|0;l=q+1075785|0;b=y[l|0];j=q+1075784|0;r=y[j|0];W=q+1075781|0;c=y[W|0];a=x[d+1074392>>2];e=x[d+1074400>>2];f=x[d+1074416>>2];V=q+1075782|0;g=y[V|0];m=q+1075783|0;H=y[m|0];h=Il(g,H);t=q+1075843|0;v[t|0]=x[I>>2]>>>12&1|y[t|0]&254;k=(a>>>0)%(e+f>>>0)|0;K=q+1075780|0;f=y[K|0];H:{I:{J:{if((f|0)==252){e=Hj(g,r);u=Hj(H,b);f=252;a=c-1|0;if((a&255)>>>0>249){break J}if(!x[sd(T,a)>>2]){break J}a=x[sd(T,a)>>2];ib[x[x[a>>2]+44>>2]](a,e,E(E(u>>>0)/E(999)));f=y[K|0]}if((f&255)==251){break I}}if(B[q+1075852>>2]==E(0)|H){break H}}u=x[I>>2]&4096;K:{if(!u){e=y[q+1075862|0];break K}e=y[W|0];v[q+1075862|0]=e}if((e-1&255)>>>0>249){break H}a=e-1|0;if(!x[sd(T,a)>>2]){break H}L:{if(!u){f=z[q+1075860>>1];break L}f=bB(y[V|0],y[j|0]);w[q+1075860>>1]=f;X=E(E(bB(y[m|0],y[l|0])>>>0)/E(999));B[q+1075856>>2]=X;e=x[sd(T,a)>>2];Va=q+1075852|0,Xa=E(E(X-E(ib[x[x[e>>2]+48>>2]](e,f)))/E(Hl(C)>>>0)),B[Va>>2]=Xa}e=x[d+1074392>>2];l=Hl(C);a=x[sd(T,a)>>2];e=(l|0)==(e+1|0);ib[x[x[a>>2]+(e?44:108)>>2]](a,f,B[(e?q+1075856|0:q+1075852|0)>>2]);f=y[K|0]}l=q+1074992|0;if(VS(f&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Ig(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[l+788|0]=c;v[l+789|0]=c>>>8;v[l+790|0]=c>>>16;v[l+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[l+792|0]=a;v[l+793|0]=a>>>8;fb=b+16|0;H=0;r=0;g=0;c=0;h=0;b=0}M:{if(!(y[Z|0]&16)){wS(d,l);break M}if(!c){break M}x[q+1075752>>2]=0}N:{O:{if((H|0)==33){Kb(i+8|0,s,30);f=b>>>4|0;OA(d,n&65535,f+(b&15)|0,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break O}f=0;if((H-19&255)>>>0>1){break O}P:{if(!(!(x[M>>2]&16777250)|b)){b=y[q+1075825|0];break P}v[q+1075825|0]=b}a=b&240;if((a|0)==208){a=b&15;if(!a){a=x[M>>2];if(a&16777248){f=1;break O}if((a|0)!=2){break O}break N}if(a>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Kb(i+8|0,s,14);f=a;if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break O}if(!c){break N}v[q+1075795|0]=c;break N}f=a;break O}if(!(x[I>>2]&4096)|(a|0)!=224){break O}a=x[M>>2];if(x[d+1074396>>2]?a&16777250:0){break O}e=b&15;if(!(a&2?e:1)){break O}x[d+1074396>>2]=e+1}e=x[M>>2]==16&(H|0)==19&(b&240)==208;R=e?0:f;Q:{if(!R|y[K|0]!=255|y[V|0]!=2){break Q}Kb(i+8|0,s,74);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Q}v[V|0]=0}U=b&15;a=x[d+1074392>>2];Kb(i+8|0,s,72);R:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){u=0;if(R>>>0>=A[d+1074416>>2]){break R}}Kb(i+8|0,s,88);u=(k|0)==(R|0)|(a|0)==(R|0);if(!(!R|!Hb(x[x[i+8>>2]>>2],x[i+12>>2]))){break R}u=(a|0)==(R|0)}Kb(i+8|0,s,44);b=e?U|144:b;S:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){a=y[t|0];break S}a=y[t|0]&-2|(k|0)==(R|0)}v[t|0]=a&253;Kb(i+8|0,s,66);e=(!R|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)&h;T:{U:{V:{if(!(x[d+1074392>>2]|(!(y[ea|0]&32)|!c))){x[q+1075652>>2]=0;if(u){h=y[K|0];break V}if(!Pi(x[l+8>>2],x[l+12>>2])){break T}v[q+1075795|0]=c;if(z[aa>>1]<c>>>0){break T}a=D(c,104)+d|0;x[q+1075680>>2]=z[a+484410>>1];w[q+1075764>>1]=v[a+484417|0];break T}if(!u){break T}h=y[K|0];if(!c){break U}}v[q+1075795|0]=c}W:{X:{a=h&255;if(!Sc(a)){break X}Kb(i+8|0,s,67);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break X}f=w[q+1075762>>1];Y:{if(!c|e){break Y}k=cr(d,a,c);if(!k){break Y}f=v[qi(d,k)+36|0]}h=(a+f|0)-132>>>0>=4294967176?h:0;break W}if(!(x[M>>2]&25165856)){break W}f=z[P>>1];if(!f){break W}if(a){a=Sc(a)}else{a=1}if(!a){break W}a=c;Z:{if(!a){a=y[q+1075796|0];if(!a){break Z}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=f>>>0:0){break W}h=0}c=0}if(!((H|0)!=25|b)){Kb(i+8|0,s,55);a=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);c=a?0:c;h=a?0:h}Kb(i+8|0,s,65);j=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);m=1;if(!(x[M>>2]&16777248)){Kb(i+8|0,s,107);m=Hb(x[x[i+8>>2]>>2],x[i+12>>2])}f=(c|0)!=0;a=h&255;ca=!a;Kb(i+8|0,s,85);_:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break _}if(Pi(x[l+8>>2],x[l+12>>2])){break _}k=x[q+1075096>>2];if(k){if(ge(x[k>>2],x[k+20>>2])){break _}}m=1}ca=f&ca;k=f&j;$:{aa:{ba:{ca:{da:{ea:{if(!(x[M>>2]&1048580)){break ea}fa:{if((a|0)!=255){break fa}if(!(!((g|0)==1|c)&(H|0)!=13)){Kb(i+8|0,s,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break fa}}f=x[q+1075648>>2];if(v[f+60|0]&1?f:0){break fa}x[q+1075680>>2]=0;a=q+1075080|0;x[a>>2]=x[a>>2]|2097152;ga:{if(!(x[I>>2]&4096)){break ga}Kb(i+8|0,s,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ga}x[a>>2]=x[a>>2]|4096}c=0;h=0;a=0;f=0;j=1;if(k){break aa}break $}Kb(i+8|0,s,59);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[I>>2]&4096){break ea}ha:{if(!a){h=y[q+1075789|0]-y[q+1075762|0]|0;break ha}if(a>>>0>250){m=0;k=1;h=0;break ha}ia:{if(c){break ia}Kb(i+8|0,s,98);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ia}c=0;break ha}m=1;k=1}f=h;e=0;break da}f=0;if(!ca){break ca}}Kb(i+8|0,s,65);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ba}h=f;f=1}a=h;j=1;if(k){break aa}break $}h=f;f=1;j=k}ja:{ka:{if(!z[P>>1]){if(z[aa>>1]<c>>>0){break ja}a=(D(c,104)+d|0)+484380|0;break ka}a=x[q+1075096>>2];if(!a){break ja}}la:{if(w[a+34>>1]<0){break la}if(x[M>>2]==2){if(!ge(x[a>>2],x[a+20>>2])){break la}}x[q+1075680>>2]=z[a+30>>1];k=q+1075080|0;x[k>>2]=x[k>>2]|2097152}if(!j){break ja}Gq(l,z[a+28>>1],d)}a=h}Kb(i+8|0,s,71);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){v[q+1075831|0]=32}ma:{if(!z[P>>1]){break ma}Kb(i+8|0,s,100);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break ma}if(Sc(a&255)){break ma}h=x[I>>2];na:{if(e){if(h&8){break na}break ma}if(!(h&4)){break ma}}Xm(l);x[q+1075688>>2]=65536;h=q+1075080|0;x[h>>2]=x[h>>2]|2097152}if(f){Kb(i+8|0,s,11);oa:{pa:{qa:{if(!(Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[M>>2]==268435456)){h=z[P>>1];break qa}Kb(i+8|0,s,87);f=0;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){f=Pi(x[l+8>>2],x[l+12>>2])^1}h=z[P>>1];ra:{if(h){if(c>>>0>h>>>0){break pa}if(x[q+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break ra}break pa}if((f^-1)&x[q+1075096>>2]==((D(c,104)+d|0)+484380|0)){break oa}}a=y[q+1075789|0]}if(!(h&65535)){break oa}}if(!(x[M>>2]&1048588)){break oa}Xm(l);v[q+1075810|0]=0;x[q+1075748>>2]=0;x[q+1075688>>2]=65536;f=q+1075080|0;x[f>>2]=x[f>>2]&-2101249|2097152;Kb(i+8|0,s,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break oa}x[f>>2]=x[f>>2]&-2049}c=m?c:0}h=a&255;sa:{if(h>>>0<251){break sa}Kb(i+8|0,s,50);ta:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break ta}f=cr(d,y[q+1075791|0],c);if(!f){break ta}f=D(f,104)+d|0;if(w[f+484414>>1]<0){break ta}x[q+1075680>>2]=z[f+484410>>1]}Kb(i+8|0,s,100);if(Va=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Wa=0,Ya=x[I>>2]&4,Ya?Va:Wa){break sa}c=0}k=Sc(h);if(k){v[q+1075794|0]=a;v[q+1075791|0]=a;if(!e){xS(d,n&65535,c,h,0)}UU(l)}ua:{va:{wa:{xa:{ya:{if(c){f=q+1075096|0;j=x[f>>2];Fo(d,l,c,e,1,1);a=x[f>>2];za:{if(!a|!(y[a+35|0]&2)){break za}m=x[d+1298300>>2];if(!yd(m)){break za}AB(m,n&65535,a+68|0)}Aa:{Ba:{if(x[M>>2]==1){if(!e){break Ba}Kb(i+8|0,s,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ba}break Aa}Kb(i+8|0,s,50);if((k|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)!=1){break Aa}}v[q+1075795|0]=0}Kb(i+8|0,s,42);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!k|(j|0)==x[f>>2]){break xa}break ya}if(x[M>>2]&16777248){a=0;if(k&(j|0)!=x[f>>2]){break wa}}Kb(i+8|0,s,107);Ca:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|(!(k^1|e)|(j|0)==x[f>>2])){break Ca}a=q+1075068|0;if(A[a>>2]>=A[l+4>>2]){break Ca}x[a>>2]=0;break xa}Kb(i+8|0,s,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break xa}if(!Pi(x[l+8>>2],x[l+12>>2])){break ya}break xa}if(!h){a=e;break ua}f=0;j=q+1075795|0;a=y[j|0];if(!(!a|k^1)){Fo(d,l,a,e,!(x[q+1075096>>2]?1:x[q+1075648>>2]),!(x[M>>2]&1048580));v[j|0]=0;f=1}a=e;break va}x[l>>2]=0;x[l+4>>2]=0}a=e}f=0;if(!h){break ua}}e=x[q+1075096>>2];Da:{if(!e|!(y[e+35|0]&2)){break Da}k=x[d+1298300>>2];if(!yd(k)){break Da}if(!f){if(yS(k,n&65535)){break Da}}AB(k,n&65535,e+68|0)}e=n&65535;Bu(d,l,h,a,!(x[M>>2]&1048580),0,e);iT(x[M>>2],z[Y>>1],C,e);if(!(!(x[M>>2]&1048580)|(!a|!c))){c=q+1075080|0;x[c>>2]=x[c>>2]|2097152;Xm(l);v[q+1075810|0]=0;x[q+1075748>>2]=0}if(!(x[q+1075080>>2]&512)){break ua}if(!yd(x[d+1298300>>2])){break ua}if(h>>>0<=253){if((h|0)!=253){break ua}Kb(i+8|0,s,99);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ua}}Kb(i+8|0,s,110);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){BB(x[d+1298300>>2],e,0,1,0)}zk(x[d+1298300>>2],e)}Ea:{Fa:{switch(g-1|0){case 0:r=r>>>0>=64?64:r;x[q+1075680>>2]=r<<2;c=q+1075080|0;x[c>>2]=x[c>>2]|2097152;break Ea;case 1:break Fa;default:break Ea}}Ym(d,l,r,6)}if(z[P>>1]){vS(d,n&65535)}e=a}Kb(i+8|0,s,77);if(Va=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Wa=0,Ya=x[((n<<5)+d|0)+480280>>2]&1024,Ya?Va:Wa){break N}a=x[d+1074392>>2];Kb(i+8|0,s,75);f=a>>>0>=R>>>0;Ga:{Ha:{Ia:{Ja:{if(!R|!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ja}c=x[d+1074392>>2];if(!c){break Ia}f=1;if((c|0)!=(R|0)){break Ja}f=!y[W|0]&(g|0)!=11}a=g;if(!f|a>>>0<3){break Ia}if((a|0)==11){a=i+8|0;fB(a,d,y[K+3|0],y[K+4|0],R);a=y[Ye(a)|0];NA(d,n&65535,z[i+8>>1]);if(a){break Ha}g=11;break Ia}Kb(i+8|0,s,62);Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|r)){r=0;g=0;Ra:{switch(a-8|0){case 0:break Qa;case 1:break Ra;default:break Ia}}if(y[Z|0]&16){break Ia}x[q+1075684>>2]=0;break Ia}Kb(i+8|0,s,41);Sa:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Sa}if(r){v[q+1075826|0]=r;break Sa}r=y[q+1075826|0]}Ta:{switch(a-3|0){case 0:case 1:Ua:{Va:{if(r){break Va}Kb(i+8|0,s,41);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Va}r=y[q+1075826|0];if(r){break Ua}r=0;break Ia}v[q+1075826|0]=r}Do(d,l,((a|0)==3?r<<4:r)&255);break Ia;case 2:if((R|0)!=x[d+1074392>>2]){Kb(i+8|0,s,41);g=5;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ia}}Kb(i+8|0,s,41);Co(d,l,r,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=5;break Ia;case 3:if((R|0)!=x[d+1074392>>2]){Kb(i+8|0,s,41);g=6;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ia}}Kb(i+8|0,s,41);Bo(d,l,r,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=6;break Ia;case 11:break Ka;case 12:break La;case 10:break Ma;case 9:break Na;case 7:break Oa;case 6:break Pa;case 5:break Qa;case 4:break Ta;default:break Ia}}Kb(i+8|0,s,53);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){v[q+1075815|0]=r&15;g=7;break Ia}Gl(l,r<<4);g=7;break Ia}Gl(l,r);g=8;break Ia}Kb(i+8|0,s,62);MA(d,l,r,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);g=9;break Ia}Kb(i+8|0,s,62);MA(d,l,r<<4&240,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);g=10;break Ia}g=12;Kb(i+8|0,s,12);uS(d,n&65535,r<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break Ia}Kb(i+8|0,s,12);tS(d,n&65535,r<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=13;break Ia}g=15;if(!u){break Ia}a=x[q+1075096>>2];if(!a|r>>>0>9){break Ia}Wa:{if(!r){c=x[q+1075656>>2];break Wa}c=x[xb(a+68|0,r-1|0)>>2];x[q+1075656>>2]=c}Eo(d,l,c);break Ia}g=14;if(r>>>0>1){break Ia}v[t|0]=y[t|0]&247|!r<<3}c=b;Xa:{Ya:{Za:{switch(H-1|0){case 12:if(!(y[d+480209|0]&16)){break Ha}a=D(n,872)+d|0;x[a+1075680>>2]=b>>>0>=64?256:b<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 45:if(!(y[d+480209|0]&16)){break Ha}a=D(n,872)+d|0;x[a+1075680>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 1:if(!b){c=0;if(v[d+480180|0]&1){break Ga}}uS(d,n&65535,b,0);break Ha;case 2:if(!b){c=0;if(v[d+480180|0]&1){break Ga}}tS(d,n&65535,b,0);break Ha;case 10:if(!b){c=0;if(x[d+480180>>2]==1){break Ga}}Do(d,l,b);break Ha;case 3:NA(d,n&65535,b);break Ha;case 5:if(!(!b&x[d+480180>>2]==1)){Do(d,l,b)}NA(d,n&65535,0);break Ha;case 4:Gl(l,b);break Ha;case 6:if(!(!b&x[d+480180>>2]==1)){Do(d,l,b)}Gl(l,0);break Ha;case 15:if(!(y[d+480209|0]&16)){break Ha}break Xa;case 16:Kb(i+8|0,s,5);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!(y[d+480209|0]&16)){break Ha}if(b){break Xa}break Ha}c=Ao(d,z[d+1074446>>1],x[d+1074424>>2],n&65535,0);_a:{if(!(x[d+480180>>2]&16777250)){break _a}if(c){v[(D(n,872)+d|0)+1075827|0]=c;break _a}c=y[(D(n,872)+d|0)+1075827|0]}x[i+8>>2]=D(c,1e4);uc(i+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=x[i+8>>2];x[a+12>>2]=e;b=x[d+8>>2];$a:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];Kb(a+4|0,d+1074312|0,92);if((Hb(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break $a}x[a+4>>2]=D(x[b+24>>2],1e4);Va=d+1074420|0,Wa=x[Gb(a+12|0,a+4|0)>>2],x[Va>>2]=Wa;break $a}if(y[d+480209|0]&16){break $a}f=d+1074420|0;e=(e>>>0)/1e4|0;h=D(e&15,1e4);x[f>>2]=x[f>>2]+((e&240)==16?h:0-h|0);e=x[b+20>>2];b=x[b+24>>2];Kb(a+4|0,d+1074312|0,8);wp(f,D(e,1e4),Hb(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}fb=a+16|0;break Ga;case 9:if(!u|x[d+480180>>2]==4&e){break Ha}hT(d,l,n&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ha;case 43:if(!u){break Ha}c=zua(x[(D(n,872)+d|0)+1075068>>2],0,b,0);a=hb;g=a>>>8|0;Eo(d,l,Bc((a&255)<<24|c>>>8,g));break Ha;case 0:if(x[d+1074392>>2]){break Ha}a=D(n,872)+d|0;ab:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break ab}a=x[a+1075648>>2];if(a){if(Nj(y[a+31|0])){break ab}}Kb(i+8|0,s,13);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ab}if(x[d+480180>>2]&16777248){break Ha}}if(!b){c=0;if(y[d+480180|0]&5){break Ga}v[(D(n,872)+d|0)+1075797|0]=1;break Ga}a=D(n,872)+d|0;v[a+1075798|0]=b;v[a+1075797|0]=1;break Ha;case 14:if(x[d+480180>>2]&1048580){b=b&240?b:y[(D(n,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=y[(D(n,872)+d|0)+1075799|0]&15|b}b=b|256}c=b;Kb(i+8|0,s,23);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){b=n&65535;if(c){v[(D(n,872)+d|0)+1075799|0]=c;a=c}else{a=y[(D(n,872)+d|0)+1075799|0]}LA(d,b,a&255,(g|0)==15?r+1|0:0);break Ga}bb:{if(c){v[(D(n,872)+d|0)+1075799|0]=c;break bb}c=y[(D(n,872)+d|0)+1075799|0]}LA(d,n&65535,c,(g|0)==15?r+1|0:0);break Ga;case 17:if(!(y[d+480209|0]&16)){break Ha}Kb(i+8|0,s,22);cb:{db:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!b){b=0;break db}if(y[d+480208|0]&4){break db}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;v[(D(n,872)+d|0)+1075832|0]=b;break db}Kb(i+8|0,s,71);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break cb}}a=(D(n,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(n,872)+d|0;v[a+1075797|0]=18;if(!b){c=0;break Ga}v[a+1075832|0]=b;break Ha;case 22:if(!(y[d+480209|0]&16)){break Ha}a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ga}if(a&16777250){break Ga}x[d+1074456>>2]=256;break Ga;case 23:Kb(i+8|0,s,9);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){sS(d,b,(D(n,872)+d|0)+1075809|0);break Ha}sS(d,b,ba);break Ha;case 8:if(!(y[d+480209|0]&16)){break Ha}Ym(d,l,b,8);break Ha;case 28:MA(d,l,b,1);break Ha;case 7:$S(l,b);break Ha;case 25:aT(d,l,b);break Ha;case 18:f=fb-16|0;fb=f;g=d+1074376|0;c=n&65535;h=D(c,872);e=(g+h|0)+616|0;a=b&15;eb:{fb:{switch(b>>>4|0){case 0:c=(b&1)<<14;e=z[d+480188>>1];a=0;while(1){if((a|0)==(e|0)){break eb}h=(D(a,872)+d|0)+1075080|0;x[h>>2]=(c|x[h>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break eb}}ZA(d,e,a);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break eb}uo(d,c,b|240,1);break eb;case 2:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break eb}}YA(d,e,a);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break eb}uo(d,c,0-(b|240)|0,1);break eb;case 3:c=(d+h|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((a|0)!=0)<<20;break eb;case 4:v[(d+h|0)+1075814|0]=b&7;break eb;case 5:if(!(y[d+480209|0]&16)){break eb}h=x[d+480180>>2];if(h&69206025){e=D(c,872)+d|0;a=a<<28>>24;w[e+1075764>>1]=a;h=e+1075692|0;if(!x[h>>2]){break eb}if(!Sc(y[e+1075780|0])){break eb}c=D(c,872)+d|0;Va=h,Wa=uh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Va>>2]=Wa;break eb}e=Sc(y[(D(c,872)+d|0)+1075780|0]);if((h|0)==16){if(!e){break eb}e=D(c,872)+d|0;h=x[e+1075096>>2];if(!h){break eb}v[h+37|0]=a;w[e+1075764>>1]=a;e=e+1075692|0;if(!x[e>>2]){break eb}c=D(c,872)+d|0;Va=e,Wa=uh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Va>>2]=Wa;break eb}if(!e){break eb}a=D(c,872)+d|0;c=(b<<4^-128)<<24>>24;w[a+1075764>>1]=c;e=a+1075692|0;if(!x[e>>2]){break eb}Va=e,Wa=uh(d,y[a+1075789|0],c,x[a+1075696>>2]),x[Va>>2]=Wa;break eb;case 6:if(!(y[d+480209|0]&16)){break eb}eB(d,g,c,a);break eb;case 7:v[(d+h|0)+1075817|0]=b&7;break eb;case 8:if(!(y[d+480209|0]&16)){break eb}Ym(d,e,a,4);break eb;case 9:LA(d,c,a,0);break eb;case 10:if(a){Co(d,e,a,0);break eb}if(!(x[d+480180>>2]&1048580)){break eb}Co(d,e,0,0);break eb;case 11:if(a){Bo(d,e,a,0);break eb}if(!(x[d+480180>>2]&1048580)){break eb}Bo(d,e,0,0);break eb;case 12:OA(d,c,a,0);break eb;case 15:break fb;default:break eb}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break eb}wS(d,e);break eb}v[(D(c,872)+d|0)+1075836|0]=a}fb=f+16|0;break Ha;case 19:rS(d,n&65535,b);break Ha;case 24:Kb(i+8|0,s,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(x[d+1074392>>2]!=(b|0)){break Ha}a=x[(D(n,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break Ya}if(!(!(y[W|0]|y[V|0])|b)){a=(D(n,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break Ya}a=D(n,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ya}if(y[d+480209|0]&16){break Ya}break Ha;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ha}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ha}XA(d,l,U);Kb(i+8|0,s,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}uo(d,n&65535,-224-U|0,1);break Ha}_A(d,l,U);Kb(i+8|0,s,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}uo(d,n&65535,U|224,1);break Ha}Kb(i+8|0,s,58);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}rS(d,n&65535,b);break Ha;case 34:case 35:f=(H|0)==36;if(!(f|x[d+480208>>2]&4096)){break Ha}c=n&65535;e=C+D(c,872)|0;h=e+616|0;a=eT(d,z[d+1074446>>1],x[d+1074424>>2],c);gb:{if(!f){break gb}f=Hl(C)-x[C+16>>2]|0;if((f|0)<2){break gb}g=a;a=w[(C+D(c,872)|0)+1390>>1];a=dd(((g-a|0)/(f|0)|0)+a|0)}w[e+1390>>1]=a;e=rq(d,x[e+704>>2],x[h+656>>2]);if(e){ib[x[x[e>>2]+80>>2]](e,(a<<16>>16)+32768>>>2|0,c)}break Ha;case 20:if(!(y[d+480209|0]&16)|b>>>0>64){break Ha}a=D(n,872)+d|0;x[a+1075740>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 21:h=x[d+480180>>2];f=x[d+480208>>2];a=b;hb:{if(a){v[l+816|0]=a;break hb}a=y[l+816|0]}c=a&15;e=a&255;ib:{jb:{if(!((c|0)!=15|e>>>0<16)){if(!(f&4096)){break ib}a=e>>>4|0;break jb}f=f&4096;g=e&240;if(!(!c|(g|0)!=240)){if(!f){break ib}a=0-c|0;break jb}if(f){break ib}if(c){a=0-c|0;if(!g|!(h&25690144)){break jb}break ib}if((a&255)>>>0<16){break ib}a=e>>>4|0}Va=l,Wa=Xb(a+x[l+748>>2]|0,0,64),x[Va+748>>2]=Wa}break Ha;case 26:_S(l,b);break Ha;case 29:if(!(y[d+480209|0]&16)){break Ha}a=D(n,872)+d|0;x[a+1075716>>2]=b;Kb(i+8|0,s,60);if(Va=0,Wa=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Ya=y[a+1075722|0]&4,Ya?Va:Wa){break Ha}a=D(n,872)+d|0;x[a+1075732>>2]=b;x[a+1075724>>2]=b;break Ha;case 11:cT(d,C,n&65535);break Ha;case 13:a=bT(d,C,n&65535,b);if((a|0)==-1){break Ha}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ha}w[d+1074444>>1]=z[d+1074448>>1];break Ha;case 37:case 38:case 39:case 40:SS(d,l,b,(H|0)==38|(H|0)==40,(H&254)==40);break Ha;case 41:gT(l,b);break Ha;case 42:if(x[d+1074392>>2]|U>>>0>1|b>>>0>47){break Ha}a=(b&240)==16;f=a?z[d+480188>>1]-1|0:n;c=a?0:n;a=((U|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Ha}h=((e<<5)+d|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;e=(D(e,872)+d|0)+1075080|0;x[e>>2]=a|x[e>>2]&-67108865;c=c+1|0;continue};case 44:break Za;default:break Ga}}fT(l,b);break Ha}zo(d,l);break Ha}mT(d,C,b)}c=b}Kb(i+8|0,s,78);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){XS(l,c&255)}a=y[W|0];if(!a){break N}v[q+1075796|0]=a}n=n+1|0;continue}break}a=1}fb=G+32|0;K=a&x[d+1074420>>2]!=0;kb:{if(!K){break kb}a=kT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Hd(z[d+480188>>1],1,31);lb:{if(Bd(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}l=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+30544|0]|0;break lb}l=x[d+480228>>2]}w[d+480212>>1]=0;u=d+1074312|0;U=d+1074365|0;q=d+480180|0;R=d+480210|0;C=d+480209|0;P=d+1074366|0;T=d+1074364|0;W=d+1074360|0;H=0;while(1){if((H|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break kb}g=fb-16|0;fb=g;x[g+12>>2]=d;f=d+1074478|0;c=f+(a<<1)|0;if((c|0)!=(f|0)){a=f+(b<<1)|0;mb:{b=c-f|0;if((b|0)<3){break mb}e=b>>1;b=e-2>>>1|0;while(1){if((b|0)<0){break mb}xR(f,x[g+12>>2],e,f+(b<<1)|0);b=b-1|0;continue}}e=c-f>>1;b=c;while(1){if((a|0)!=(b|0)){if(Dl(x[g+12>>2],z[b>>1],z[f>>1])){wR(b,f);xR(f,x[g+12>>2],e,f)}b=b+2|0;continue}break}b=c-f>>1;while(1){if((b|0)>1){k=z[f>>1];a=f;j=x[g+12>>2];e=0;h=b;m=b-2>>>1|0;while(1){b=e<<1;e=b|1;l=b+2|0;b=l+a|0;if((h|0)>(l|0)){i=l;l=Dl(j,z[b>>1],z[b+2>>1]);e=l?i:e;b=l?b+2|0:b}w[a>>1]=z[b>>1];a=b;if((e|0)<=(m|0)){continue}break}b=c-2|0;nb:{if((b|0)==(a|0)){w[a>>1]=k;break nb}w[a>>1]=z[b>>1];w[b>>1]=k;k=x[g+12>>2];a=a+2|0;b=a-f>>1;ob:{if((b|0)<2){break ob}e=b-2|0;b=f+(e&-2)|0;a=a-2|0;if(!Dl(k,z[b>>1],z[a>>1])){break ob}e=e>>>1|0;l=z[a>>1];while(1){pb:{j=a;a=b;w[j>>1]=z[a>>1];if(!e){break pb}b=e-1|0;e=b>>>1|0;b=f+(b&-2)|0;if(Dl(k,z[b>>1],l)){continue}}break}w[a>>1]=l}}b=h-1|0;c=c-2|0;continue}break}}fb=g+16|0}else{j=D(H,872)+d|0;t=j+1075080|0;qb:{if(!(x[t>>2]&4096)|(x[j+1075016>>2]|(x[j+1075012>>2]|x[j+1075688>>2]))){break qb}Kb(o+16|0,u,64);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break qb}x[j+1075068>>2]=0;a=j+1075084|0;x[a>>2]=0;x[a+4>>2]=0}b=z[d+480188>>1];a=x[t>>2];rb:{if(x[j+1075068>>2]|b>>>0>H>>>0?a&1024:1){if(b>>>0>H>>>0){CR(d,H&65535)}w[j+1075834>>1]=0;break rb}c=0;I=j+1075712|0;x[I>>2]=0;s=j+1075672|0;x[s>>2]=0;i=j+1075e3|0;e=i;x[e>>2]=0;x[e+4>>2]=0;x[j+1075092>>2]=0;x[o+44>>2]=1065353216;w[o+42>>1]=0;M=j+1075648|0;G=x[M>>2];x[o+36>>2]=0;g=0;k=j+1075692|0;g=x[k>>2]?x[j+1075068>>2]!=0:g;e=j+1074992|0;sb:{tb:{ub:{if(b>>>0<=H>>>0){break ub}if(y[((H<<5)+d|0)+480288|0]){break tb}if(!G){break ub}c=y[G+34|0]!=0}if((c|g)!=1){break sb}}x[o+8>>2]=x[j+1075680>>2];x[o+32>>2]=x[j+1075744>>2];Kb(o+16|0,u,28);a=o+8|0;b=Hb(x[x[o+16>>2]>>2],x[o+20>>2])?o+32|0:a;c=d+1074312|0;vb:{if(Ob(c,28)){x[b>>2]=x[b>>2]+w[e+776>>1];Ee(b,0,64);break vb}f=Ob(c,1);c=w[e+776>>1];if(f){x[b>>2]=c+x[b>>2];Ee(b,0,256);break vb}x[e+688>>2]=c+x[e+688>>2];Ee(e+688|0,0,256);x[b>>2]=x[e+688>>2];w[e+776>>1]=0}wb:{xb:{b=d+1074312|0;if(!Ob(b,28)){if(!Ob(b,1)){break xb}}x[e+684>>2]=x[e+692>>2]+w[e+778>>1];Ee(e+684|0,0,256);break wb}x[e+692>>2]=x[e+692>>2]+w[e+778>>1];Ee(e+692|0,0,256);w[e+778>>1]=0;x[e+684>>2]=x[e+692>>2]}yb:{if(!(y[e+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break yb}zb:{if(x[a>>2]<=0){if(!Ob(d+1074312|0,21)){break zb}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}b=tA(d,y[e+825|0],y[e+820|0]);Ab:{if((y[e+825|0]&3)!=1){break Ab}if(!Ob(d+1074312|0,89)){break Ab}b=y[e+819|0];h=y[e+820|0];f=h<<2&124;b=(!(y[e+90|0]&2)|y[d+480209|0]&16?b:y[e+823|0]+b|0)&32?f^127:f;b=h&32?0-b|0:b}if(x[d+480180>>2]!=131072){b=x[a>>2]+((D(y[e+827|0],b)|0)/(1<<c)|0)|0}else{c=64-b|0;b=x[a>>2];b=((D(y[e+827|0],D(c,b))|0)/-8192|0)+b|0}x[a>>2]=b}b=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|b&4?b&4096:0){break yb}b=Ob(d+1074312|0,21);c=y[e+826|0];f=y[e+820|0];v[e+820|0]=(b?c<<2:f)+(b?f:c)}f=H&65535;h=fb-16|0;fb=h;b=d+1074312|0;Kb(h+8|0,b,71);Bb:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){b=(D(f,872)+d|0)+1075831|0;c=v[b|0];if((c|0)>=0){break Bb}if(!(y[d+480209|0]&16|y[(D(f,872)+d|0)+1075797|0]!=18)){Cb:{Db:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break Db}c=y[(D(f,872)+d|0)+1075832|0]>>>4|-64;break Cb}c=y[(D(f,872)+d|0)+1075832|0]&15|-128;break Cb}c=c-1|0}v[b|0]=c;b=(D(f,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}if((c&224)!=128){break Bb}x[a>>2]=0;break Bb}if(y[(D(f,872)+d|0)+1075797|0]!=18){break Bb}Kb(h+8|0,b,22);Eb:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){r=D(f,872)+d|0;b=r+1075831|0;m=y[b|0];c=m<<24>>24;if(!((c|0)>=0|!x[r+1075068>>2])){Fb:{Gb:{if((m|0)!=192){if((m|0)!=128){break Gb}c=y[(D(f,872)+d|0)+1075832|0]>>>4|-64;break Fb}c=y[(D(f,872)+d|0)+1075832|0]&15|-128;break Fb}c=c-1|0}v[b|0]=c}if((c&192)!=128){break Eb}x[a>>2]=0;break Eb}b=y[(D(f,872)+d|0)+1075832|0];c=b>>>4|0;r=c+(b&15)|0;m=x[d+480180>>2];if(!(y[d+480208|0]&4?0:m&16777248)){r=r+2|0;c=c+1|0}b=(D(f,872)+d|0)+1075831|0;n=y[b|0];if(!(m&4)){m=c;c=(n&255)>>>0<r>>>0?n:0;if(m>>>0<=(c&255)>>>0){x[a>>2]=0}v[b|0]=c+1;break Eb}Hb:{if(y[d+480209|0]&16){b=n&255;m=b-1|0;n=b>>>0>=m>>>0?m:0;break Hb}v[b|0]=n+1}if(((n&255)>>>0)%(r>>>0)>>>0<c>>>0){break Eb}x[a>>2]=0}b=(D(f,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}b=D(f,872)+d|0;Ib:{if(y[b+1075797|0]!=18){break Ib}c=x[b+1075648>>2];if(!c){break Ib}b=y[c+34|0];if(!b|y[c+15|0]&2){break Ib}m=D(f,872)+d|0;if(x[m+1075080>>2]&134218752){break Ib}m=m+1075791|0;r=y[m|0];if(!Sc(r)){break Ib}b=x[sd(d+906300|0,b-1|0)>>2];if(!b){break Ib}r=ib[x[x[b>>2]+104>>2]](b,r,f)|0;n=x[a>>2];if(!(!r|n)){ib[x[x[b>>2]+96>>2]](b,c,y[m|0]|256,0,f);break Ib}if(r|!n){break Ib}ib[x[x[b>>2]+96>>2]](b,c,y[m|0],z[(D(f,872)+d|0)+1075680>>1],f)}fb=h+16|0;Ee(a,0,256);x[o+8>>2]=x[o+8>>2]<<6;Jb:{if(G){Kb(o+16|0,u,31);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){wu(d,e)}a=o+8|0;Kb:{if(!rA(d,e,0)){break Kb}c=x[e+656>>2];h=d+1074312|0;m=Ob(h,31);b=x[e+724>>2];if(b?0:m){break Kb}r=b-Ob(h,31)|0;b=Fq(c+48|0,r,256,64);n=y[c+65|0];Lb:{if((n|0)==255){break Lb}m=w[e+728>>1];if((m|0)==-1){break Lb}n=xb(x[c+48>>2],n);V=y[n+2|0];c=V<<2;b=(r|0)==z[n>>1]?c:b;if(Ob(h,94)){b=m+(b-c<<1)|0;break Lb}if(!V){b=0;break Lb}b=(D(b,m)|0)/(c|0)|0}Va=a,Wa=(D(Xb(b,0,512),x[a>>2])|0)/256|0,x[Va>>2]=Wa}QS(e,a);Mb:{if(!rA(d,e,1)){break Mb}a=x[e+656>>2];b=d+1074312|0;h=Ob(b,31);c=x[e+732>>2];if(c?0:h){break Mb}b=Fq(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[e+684>>2];Va=e,Wa=Xb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Va+684>>2]=Wa}Kb(o+16|0,u,115);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Jb}b=y[j+1075789|0];if(!b){break Jb}a=x[M>>2];if(!a|!y[a+26|0]){break Jb}TS(j+1075676|0,b,y[a+26|0],y[a+27|0]);break Jb}if(!(y[t+1|0]&16)){break Jb}x[j+1075688>>2]=0;x[o+8>>2]=0}Nb:{if(y[j+1075843|0]&8){c=0;x[o+8>>2]=0;break Nb}c=x[o+8>>2];if(!c){c=0;break Nb}if(y[t+3|0]&8){x[s>>2]=0;break Nb}if(Bd(y[U|0])){a=D(x[o+32>>2],x[j+1075740>>2]);b=a;h=a>>31;a=c<<8;Va=s,Wa=Fc(Aua(zua(b,h,a,a>>31),hb,1048576,0),hb),x[Va>>2]=Wa;break Nb}a=D(x[o+32>>2],x[j+1075740>>2]);b=a;h=a>>31;a=D(x[d+1074456>>2],c);Va=s,Wa=Fc(Aua(zua(b,h,a,a>>31),hb,1048576,0),hb),x[Va>>2]=Wa}x[I>>2]=c;Ob:{Pb:{c=x[k>>2];if(!(x[q>>2]==2|(c|0)>=x[d+480260>>2])){if(!Ej(d)){break Pb}c=x[k>>2]}if((c|0)<x[d+480264>>2]){break Ob}Kb(o+16|0,u,113);if(!Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Ob}if(Ej(d)){break Ob}x[k>>2]=x[d+480264>>2];break Ob}x[k>>2]=x[d+480260>>2]}Kb(o+16|0,u,73);a=x[k>>2];x[o+36>>2]=a;Qb:{if((x[t>>2]&1572864)!=1572864){break Qb}b=x[d+480208>>2];if(b&2097152){if(!Il(y[j+1075782|0],y[j+1075783|0])|b&4096){break Qb}}b=j+1075704|0;Rb:{if((a|0)==x[b>>2]){c=x[j+1075708>>2];break Rb}x[b>>2]=a;c=a;a=j+1075764|0;b=j+1075696|0;c=uh(d,tu(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[j+1075708>>2]=c}x[o+36>>2]=c}h=fb-16|0;fb=h;n=D(f,872)+d|0;V=n+1075648|0;a=x[V>>2];Sb:{if(!a){break Sb}b=y[a+34|0];if(x[(D(f,872)+d|0)+1075080>>2]&134218752|(!b|y[a+15|0]&2)){break Sb}if(!x[sd(d+906300|0,b-1|0)>>2]){break Sb}a=D(f,872)+d|0;m=a+1075780|0;b=y[a+1075793|0];Y=a+1075783|0;r=y[Y|0];Tb:{Ub:{if((r|0)==1){a=b;Vb:{Wb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:a=b+(y[(D(f,872)+d|0)+1075798|0]>>>4|0)|0;break Vb;case 1:break Wb;default:break Vb}}a=b+(y[(D(f,872)+d|0)+1075798|0]&15)|0}c=D(f,872)+d|0;if(y[c+1075792|0]==(a&255)){break Tb}if(!(v[c+1075843|0]&1)){break Ub}if(!Sc(y[m|0])){break Ub}if(Il(y[m+2|0],1)){break Ub}break Tb}if(y[m|0]){a=b;if(!Il(y[m+2|0],r)){break Tb}}a=b;if(!y[(D(f,872)+d|0)+1075792|0]){break Tb}}Vm(d,f,a&255|512,z[(D(f,872)+d|0)+1075680>>1])}Z=(D(f,872)+d|0)+1075792|0;c=y[Z|0];Xb:{Yb:{if(c){if((r|0)!=1|(a&255)!=(c|0)){break Yb}break Xb}if(!(v[(D(f,872)+d|0)+1075843|0]&1)|(r|0)!=1){break Xb}if(Sc(y[m|0])){break Xb}c=b;if(!Sc(b)){break Xb}}Vm(d,f,c&255|256,0)}v[Z|0]=y[Y|0]==1?a:0}Zb:{if(y[n+1075797|0]!=1){break Zb}if(Oj(x[V>>2])){a=0;_b:{$b:{ac:{switch(A[d+1074392>>2]%3|0){case 1:a=y[(D(f,872)+d|0)+1075798|0]>>>4|0;break $b;case 0:break $b;case 2:break ac;default:break _b}}a=y[(D(f,872)+d|0)+1075798|0]&15}w[o+42>>1]=a}a=(D(f,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break Zb}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(f,872)+d|0;b=uh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[o+36>>2]=b;x[a+1075692>>2]=b}c=d+1074312|0;Kb(h+8|0,c,13);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){a=y[(D(f,872)+d|0)+1075798|0];if(!a){break Zb}b=65536;bc:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:a=a<<4;case 0:b=x[((a&240)<<2)+35552>>2];break;default:break bc}}f=Ej(d);a=x[o+36>>2];c=a>>31;if(f){a=zua(a,c,b,b>>31);f=hb;a=a+32768|0;f=a>>>0<32768?f+1|0:f;a=Aua(a,f,65536,0);b=hb}else{f=(b|0)/2|0;r=f>>31;m=c<<16|a>>>16;c=a<<16;a=c+f|0;n=m+r|0;a=Aua(a,a>>>0<c>>>0?n+1|0:n,b,b>>31);b=hb}Va=o,Wa=Fc(a,b),x[Va+36>>2]=Wa;break Zb}Kb(h+8|0,c,51);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(y[d+480209|0]&16){break Zb}cc:{dc:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break dc}if((a|0)==16){break Zb}b=0;ec:{switch((a|0)%3|0){case 0:break Zb;case 2:break dc;case 1:break ec;default:break cc}}b=y[(D(f,872)+d|0)+1075798|0]>>>4|0;break cc}b=y[(D(f,872)+d|0)+1075798|0]&15}c=b;a=D(f,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+tu(d,x[o+36>>2],w[b>>1],x[a>>2])|0;b=uh(d,c,w[b>>1],x[a>>2]);x[o+36>>2]=b;if(c>>>0<109){break Zb}x[h+8>>2]=b;Va=h,Wa=uh(d,109,0,x[a>>2]),x[Va+4>>2]=Wa;Va=o,Wa=x[$c(h+8|0,h+4|0)>>2],x[Va+36>>2]=Wa;break Zb}m=x[d+1074392>>2];r=d+480180|0;a=x[r>>2];fc:{if((a|0)!=1){b=y[(D(f,872)+d|0)+1075789|0];break fc}a=D(f,872)+d|0;b=tu(d,x[o+36>>2],w[a+1075764>>1],x[a+1075696>>2]);a=x[r>>2]}gc:{hc:{switch((((a&67633152?m+2|0:m)>>>0)%3|0)-1|0){case 0:b=(y[(D(f,872)+d|0)+1075798|0]>>>4|0)+b|0;break gc;case 1:break hc;default:break gc}}b=(y[(D(f,872)+d|0)+1075798|0]&15)+b|0}if(!(a&67633408|y[(D(f,872)+d|0)+1075789|0]!=(b&255))){Kb(h+8|0,c,82);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Zb}}if(y[d+480210|0]&32){a=b&255;if((a|0)==85){x[o+36>>2]=2147483647;break Zb}b=a>>>0>85?b-37|0:b}a=D(f,872)+d|0;m=uh(d,b&255,w[a+1075764>>1],x[a+1075696>>2]);x[o+36>>2]=m;if(x[d+480180>>2]&71860480){x[a+1075692>>2]=m;break Zb}Kb(h+8|0,c,82);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Zb}v[(D(f,872)+d|0)+1075792|0]=b}fb=h+16|0;if(!(!(y[R|0]&33)|x[o+36>>2]==2147483647)){ic:{if(x[q>>2]==2){c=452;a=3424;break ic}a=D(z[j+1075764>>1]>>>4&15,24);b=z[a+31286>>1]>>>1|0;c=b>>>0<=452?452:b;a=z[a+31264>>1]<<1}Ee(o+36|0,c,a);Ee(k,c,a)}YS(d,e);a=x[t>>2]}jc:{if(!(a&256)|y[C|0]&64){break jc}Kb(o+16|0,u,37);if(!Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break jc}x[j+1075676>>2]=128}a=jT(d,e);kc:{if((a|0)<0|!(y[t+1|0]&2)){break kc}b=x[d+1298300>>2];if(!yd(b)){break kc}Cq(b,H&65535,a&255,1)}h=H&65535;CR(d,h);lc:{if(!g){break lc}a=RS(d,e,o+36|0);if((a|0)<0|!(y[t+1|0]&2)){break lc}b=x[d+1298300>>2];if(!yd(b)){break lc}Cq(b,h,a>>>2&255,1)}mc:{if(y[j+1075782|0]!=8){break mc}nc:{oc:{a=y[j+1075783|0];switch(a-5|0){case 1:break mc;case 0:case 2:break nc;default:break oc}}if((a|0)!=26){break mc}}a=x[q>>2];if((a|0)==4){if(y[C|0]&16){break mc}a=j+1075811|0;v[a|0]=y[a|0]+y[j+1075815|0];break mc}if(!(a&16777248)){break mc}Gl(e,y[j+1075784|0]);BR(d,h,o+36|0,o+44|0)}BR(d,h,o+36|0,o+44|0);pc:{if(!g){break pc}x[o+32>>2]=0;f=o+36|0;m=fb-16|0;fb=m;c=x[e+104>>2];qc:{if(!c|!y[c+40|0]){break qc}r=Oj(x[e+656>>2]);g=Ej(d);b=g?36576:35552;k=g?35552:36576;a=d+480180|0;if(!(r|!Ob(d+1074312|0,21)|x[a>>2]==1048576)){n=y[c+41|0];if(!n){break qc}a=y[e+818|0];x[m+12>>2]=x[e+756>>2]+y[c+39|0];xi(m+12|0,y[c+40|0]<<8);r=x[m+12>>2];v[e+818|0]=a+n;x[e+756>>2]=r;r=(r|0)/256|0;rc:{sc:{switch(y[c+38|0]-1|0){case 3:c=zR(yo(d))+-64|0;break rc;case 2:c=64-(a+1>>>1|0)|0;break rc;case 1:c=(a+1>>>1|0)+-64|0;break rc;case 0:c=(a^-1)>>>1&64;break rc;default:break sc}}c=v[a+31856|0]}xi(f,8388607);a=x[f>>2]<<8;x[f>>2]=a;V=D(c,r);r=(V|0)/64|0;c=r>>31;r=(c^r)-c|0;c=r&3;r=r>>>2|0;n=a>>31;tc:{uc:{if((V|0)<=-64){b=x[(r<<2)+b>>2];b=Fc(Aua(zua(b,b>>31,a,n),hb,65536,0),hb)-a|0;if(!c){break tc}g=g?35488:35424;break uc}b=x[k+(r<<2)>>2];b=Fc(Aua(zua(b,b>>31,a,n),hb,65536,0),hb)-a|0;if(!c){break tc}g=g?35424:35488}c=x[(c<<2)+g>>2];b=(Fc(Aua(zua(a,n,c,c>>31),hb,65536,0),hb)+b|0)-a|0}x[f>>2]=(b+a|0)/256;x[o+32>>2]=b&255;break qc}g=x[a>>2]&16777248;a=y[c+39|0];vc:{if(!(g|a)){x[e+756>>2]=y[c+40|0]<<8;break vc}wc:{xc:{if(g){g=a<<1;n=x[e+756>>2];a=e+756|0;break xc}if(y[e+89|0]&8){break wc}n=((y[c+40|0]<<8&65280)>>>0)/(a>>>0)|0;g=x[e+756>>2];a=e+756|0}x[a>>2]=g+n}xi(e+756|0,y[c+40|0]<<8)}a=y[e+818|0]+y[c+41|0]|0;v[e+818|0]=a;a=a<<24>>24;yc:{zc:{switch(y[c+38|0]-1|0){case 3:v[e+818|0]=a+1;g=v[(a&63)+31792|0];break yc;case 2:g=(64-(a>>>1|0)&127)+-64|0;break yc;case 1:g=((a>>>1|0)- -64&127)+-64|0;break yc;case 0:g=(a|0)>=0?-64:64;break yc;default:break zc}}g=0-v[(a&255)+31856|0]|0;if(x[d+480180>>2]!=1048576){break yc}g=(64-v[(a+-64&255)+31856|0]|0)/2<<16>>16}a=g;n=D(a,x[e+756>>2]);g=(n|0)/256|0;if(r){B[o+44>>2]=B[o+44>>2]+E(E(E(E(y[c+40|0])*E(.05000000074505806))*E(a|0))*E(.000244140625));v[e+851|0]=y[e+851|0]|64;break qc}if(x[d+480180>>2]!=4){Ac:{if((n|0)<=-256){g=0-g|0;c=g>>>8|0;a=(c<<2)+b|0;break Ac}b=k;c=g>>>8|0;a=b+(c<<2)|0}k=x[f>>2];a=x[a>>2];a=((D(x[((c<<2)+b|0)+4>>2]-a|0,g>>>2&63)|0)/64|0)+a|0;a=Fc(Aua(zua(k,k>>31,a,a>>31),hb,256,0),hb);x[f>>2]=a;x[o+32>>2]=a&255;x[f>>2]=x[f>>2]/256;break qc}x[f>>2]=x[f>>2]+((n|0)/16384|0)}fb=m+16|0;g=x[o+36>>2];if((g|0)<=x[d+480260>>2]){Kb(o+16|0,u,81);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){x[j+1075068>>2]=0}g=x[d+480260>>2];x[o+36>>2]=g}Bc:{if(!Oj(x[e+656>>2])){break Bc}a=j+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break Bc}TU(e,B[o+44>>2],w[o+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=o+16|0;hB(a,d,e,g,x[o+32>>2]);c=Ab(a);a=zua(x[o+16>>2],x[o+20>>2],x[d+480240>>2],0);g=hb;b=Aua(a,g,65536,0);f=hb;k=b;a=a+65535|0;b=!(a>>>0<65535?g+1|0:g)&a>>>0<131071;a=b?1:k;x[o+16>>2]=a;b=b?0:f;x[o+20>>2]=b;x[i>>2]=a;x[i+4>>2]=b;if((x[t>>2]&134219264)!=512){break pc}if(!yd(x[d+1298300>>2])){break pc}Kb(o+8|0,u,99);Cc:{Dc:{if(Va=Hb(x[x[o+8>>2]>>2],x[o+12>>2]),Wa=1,Ya=y[t+1|0]&16,Ya?Va:Wa){b=x[q>>2];break Dc}b=x[q>>2];if((b|0)!=2){break Cc}}a=(b|0)==2;b=x[t>>2];f=b&2048;Ec:{if(f?a:0){break Ec}a=zua(x[c>>2],0,261625,0);g=hb;a=a+66904|0;g=a>>>0<66904?g+1|0:g;c=Bc(Bua(a,g,133808,0),hb);a=1;Fc:{if(f){break Fc}a=0;if(!(b&4096)){break Fc}a=!x[j+1075688>>2]}Kb(o+8|0,u,110);if(Va=Hb(x[x[o+8>>2]>>2],x[o+12>>2]),Wa=0,Ya=a,Ya?Va:Wa){break Ec}b=x[d+1298300>>2];Kb(o+8|0,u,95);BB(b,h,c,a,Hb(x[x[o+8>>2]>>2],x[o+12>>2]))}a=x[d+1298300>>2];b=zua(D(x[j+1075744>>2],D(x[j+1075740>>2],x[I>>2])),0,63,0);g=hb;b=b+33554432|0;g=b>>>0<33554432?g+1|0:g;Cq(a,h,Bc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);a=j+1075676|0;g=a;b=x[a>>2];c=0;a=x[d+1298300>>2];f=Pl(a,h);Gc:{if((f|0)==255){break Gc}k=x[a>>2];if(Ak(k)){break Gc}c=vb(Dd(a+318|0,f),10);m=x[a+4>>2];f=Nu(f)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;wh(k,m,h,f,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[g>>2]=(c<<7)+128}Hc:{a=x[M>>2];if(!a|(y[a+60|0]&7)!=1){break Hc}b=x[a+48>>2];a=x[a+52>>2];if(kc(b,a)){break Hc}b=x[AR(e,0)>>2];a=pi(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Hc}Jj(x[d+1298300>>2],h,1);Kb(o+8|0,u,109);a=x[t>>2];Va=t,Wa=(Hb(x[x[o+8>>2]>>2],x[o+12>>2])?a:a&-4609)|4096,x[Va>>2]=Wa;x[j+1075688>>2]=0;break pc}Kb(o+8|0,u,99);if(!Hb(x[x[o+8>>2]>>2],x[o+12>>2])|!(y[t+1|0]&16)|x[j+1075688>>2]){break pc}Jj(x[d+1298300>>2],h,1);x[t>>2]=x[t>>2]&-513}Ic:{if(!G){break Ic}Kb(o+16|0,u,31);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Ic}wu(d,e)}b=x[t>>2];a=b&-65537;k=x[s>>2];r=j+1075016|0;G=j+1075012|0;c=k|(x[r>>2]|x[G>>2])?(a|b<<7&65536)^65536:a;x[t>>2]=c;s=j+1075664|0;a=s;x[a>>2]=0;x[a+4>>2]=0;h=j+1075834|0;a=y[h|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[h|0]=a;m=j+1075835|0;b=y[m|0];f=b-4|0;b=b>>>0>=f>>>0?f:0;v[m|0]=b;Jc:{Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{f=x[j+1075096>>2];Sc:{if(!f){break Sc}g=x[f+20>>2];if(!ge(x[f>>2],g)|!x[j+1075068>>2]){break Sc}if(Pi(x[e+8>>2],x[e+12>>2])){break Rc}}x[j+1075008>>2]=0;break Qc}x[j+1075008>>2]=g;if(g){break Pc}}if(!Gj(x[e+656>>2])){break Oc}g=0;if(c&6144){break Oc}}n=x[j+1075676>>2];f=(D(k,256-n|0)|0)/16384|0;f=f>>>0>=127?127:f;if(a<<24>>24<0){v[h|0]=f;_=f}else{_=a}a=f>>>1|0;if((_&255)>>>0<a>>>0){v[h|0]=a}a=(D(k,n)|0)/16384|0;a=a>>>0>=127?127:a;if(b<<24>>24<0){v[m|0]=a;b=a}a=a>>>1|0;if(a>>>0>(b&255)>>>0){break Nc}break Mc}if((a&255)>>>0>=129){v[h|0]=0}g=0;a=0;if((b&255)>>>0<129){break Lc}}v[m|0]=a}if(!g){break Lc}g=128;h=x[d+24624>>2];if(h>>>0>=2){g=Xb(x[j+1075676>>2],0,256)}x[o+16>>2]=g;a=D(k,l)>>>(Bd(y[P|0])?7:8)|0;Tc:{Uc:{Vc:{switch(y[T|0]){case 0:if(!(y[d+24616|0]&16)){break Uc}case 1:if((g|0)<=127){b=a>>>1|0;f=(D(a,g)|0)/256|0;break Tc}b=(D(a,256-g|0)|0)/256|0;f=a>>>1|0;break Tc;case 3:break Vc;default:break Uc}}xi(o+16|0,255);f=x[o+16>>2];if((f|0)<=0){b=65536}else{b=z[(0-f<<1)+38112>>1]}b=D(b,a)>>>16|0;f=D(a,z[(f<<1)+37600>>1])>>>16|0;break Tc}b=(D(a,256-g|0)|0)/256|0;f=(D(a,g)|0)/256|0}a=x[M>>2];Wc:{if(a){g=y[a+14|0];if(lp(g)){break Wc}}g=y[d+480268|0];if(lp(g)){break Wc}a=y[d+24648|0];g=y[R|0]&128?x[d+24668>>2]?-1:a:a}k=j+1075668|0;m=j+1075786|0;v[m|0]=g;a=x[i>>2];r=x[i+4>>2];if(!(c&131072|((a|0)!=0|(r|0)!=1)|(x[j+1075748>>2]|(g&255)==255))){v[m|0]=0}g=b;b=1<<x[W>>2];x[s>>2]=(g|0)/(b|0);b=(f|0)/(b|0)|0;x[k>>2]=(c&256)>>>8|0?(h|0)==2?0-b|0:b:b;if(c&128){x[i>>2]=0-a;x[i+4>>2]=0-(((a|0)!=0)+r|0)}n=0;h=fb-16|0;fb=h;x[e+28>>2]=0;x[e+32>>2]=0;xi(e+672|0,524287);xi(e+676|0,524287);_=e;Xc:{Yc:{f=x[e+88>>2];if(!(f&65536)){a=x[e+676>>2];b=x[e+672>>2];break Yc}b=x[e+20>>2];g=x[e+672>>2];Zc:{if((b|0)!=(g|0)){a=x[e+24>>2];c=x[e+676>>2];break Zc}a=x[e+24>>2];c=x[e+676>>2];if((a|0)==(c|0)){break Yc}}f=x[d+24620>>2];c=(b|0)>=(g|0)&(a|0)>=(c|0);_c:{if(!c){b=Pu(f,x[d+24636>>2]);break _c}b=Pu(f,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=zua(a,a>>31,5,0);f=hb;a=a+500|0;f=a>>>0<500?f+1|0:f;b=Fc(Aua(a,f,1e3,0),hb)}a=b;f=x[e+656>>2];$c:{if(c|!f){break $c}c=z[f+12>>1];if(!c){break $c}n=1;a=(D(c,x[d+24620>>2])>>>0)/1e5|0}g=a>>>0<=1?1:a;f=x[e+672>>2];m=x[e+20>>2];i=f-m<<12;c=x[e+676>>2];a=x[e+24>>2];k=c-a<<12;if(!(y[e+90|0]&32|(!(c|f)|(!(a|m)|n)))){x[h+12>>2]=x[d+1074380>>2];Ee(h+12|0,b,2048);g=x[h+12>>2]}k=(k|0)/(g|0)|0;x[e+32>>2]=k;m=(i|0)/(g|0)|0;x[e+28>>2]=m;a=c+((D(g,k)|0)/-4096|0)|0;x[e+24>>2]=a;b=f+((D(g,m)|0)/-4096|0)|0;x[e+20>>2]=b;if(k|m){x[e+100>>2]=g;c=x[e+88>>2];break Xc}x[e+24>>2]=c;x[e+20>>2]=f;a=c;b=f;c=x[e+88>>2]&-65537;break Xc}x[e+24>>2]=a;x[e+20>>2]=b;c=f&-65537}x[_+88>>2]=c&-2097153;x[e+40>>2]=a<<12;x[e+36>>2]=b<<12;fb=h+16|0;c=x[t>>2];if(!(c&512)){break Kc}break Jc}x[G>>2]=0;x[r>>2]=0;x[j+1075068>>2]=0;if(x[j+1075088>>2]){break Kc}if(!x[j+1075084>>2]){break Jc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=H}x[j+1075660>>2]=c;a=j+1075843|0;v[a|0]=y[a|0]&253}H=H+1|0;continue}break}}fb=o+48|0;if(K){a=x[d+480208>>2];break h}if(Bd(y[Ha|0])){b=x[d+480208>>2]|512;break i}l=0;ad:{a=x[d+24620>>2]/10|0;c=Fc(a,a>>31);if(!c){break ad}b=c>>>0>=1048576?1048576:c;x[d+1074380>>2]=b;f=z[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(l|0)){break ad}a=e+D(z[(e+(l<<1)|0)+102>>1],872)|0;h=a+1288|0;x[h>>2]=0;x[h+4>>2]=0;x[a+716>>2]=b;h=x[a+640>>2]<<12;x[a+656>>2]=h;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(b|0);x[a+648>>2]=(0-h|0)/(b|0);l=l+1|0;continue}}a=x[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[ma+480208>>2]=a}if(!(a&512)){break g}Va=d+1074392|0,Wa=Hl(Ga),x[Va>>2]=Wa}fb=L+96|0;break f}x[L+80>>2]=512;a=x[d+1074380>>2];x[L+88>>2]=ia;x[L+84>>2]=a;o=_D(L+80|0);if(x[d+24632>>2]){a=0;b=fb-48|0;fb=b;c=o<<2;while(1){if((a|0)==4){bd:{a=0;while(1){if((a|0)==4){break bd}x[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{x[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Mz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=x[d+24632>>2];x[b+28>>2]=o;x[b+24>>2]=a;x[b+20>>2]=b+32;a=x[x[ha>>2]+8>>2];x[b+16>>2]=o;c=x[b+24>>2];x[b+8>>2]=x[b+20>>2];x[b+12>>2]=c;ib[a|0](ha,b+8|0);fb=b+48|0}if(Bd(Fa)){a=0;while(1){if((a|0)==4){a=x[d+24632>>2];x[L+76>>2]=o;x[L+72>>2]=a;x[L+68>>2]=L+80;a=x[x[qa>>2]+8>>2];x[L+40>>2]=o;b=x[L+72>>2];x[L+32>>2]=x[L+68>>2];x[L+36>>2]=b;ib[a|0](qa,L+32|0)}else{x[(L+80|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}aa=0;ja=0;k=fb-48|0;fb=k;if(o){r=d+12|0;H=d+24592|0;G=d+24588|0;En(r,o,H,G);if(A[d+24624>>2]>=3){En(d+8204|0,o,d+24600|0,d+24596|0)}w[k+42>>1]=0;va=d+1074312|0;Ja=d+24648|0;ba=d+906300|0;Ka=d+24596|0;La=d+24600|0;Ma=d+8204|0;M=d+397452|0;R=d+397448|0;s=d+393352|0;wa=d+397456|0;na=d+1074376|0;Na=d+480190|0;while(1){if(z[d+480212>>1]<=aa>>>0){Va=d,Wa=z[oe(d+480214|0,k+42|0)>>1],w[Va+480214>>1]=Wa}else{f=na+(aa<<1)|0;n=z[f+102>>1];a=D(n,872);U=a+na|0;cd:{dd:{if(x[U+632>>2]){break dd}b=a+d|0;if(x[b+1075088>>2]){break dd}if(!x[b+1075084>>2]){break cd}}j=a+d|0;a=y[j+1075786|0]+1&255;if(a>>>0<=5){g=x[(a<<2)+26128>>2]}else{g=0}C=j+1075080|0;h=x[C>>2];ed:{if(!(!(h&16777216)&y[d+24612|0]>>>5)){a=H;c=G;b=h;e=r;if(!(b&8388608)){break ed}}a=R;c=M;if(!y[wa+12|0]){En(s,o,a,c)}v[wa+12|0]=1;n=z[f+102>>1];b=x[C>>2];e=s}b=b>>>8&A[d+24624>>2]>2;P=b?Ka:c;T=b?La:a;b=b?Ma:e;ea=mm(d,na,n,2,1)-1|0;xa=(ea&255)>>>0>249;fd:{if(xa){break fd}if(!x[sd(ba,ea)>>2]){break fd}c=x[sd(ba,ea)>>2];a=x[c+24>>2];if(!a){break fd}P=c+36|0;T=c+40|0;if(!(v[c+28|0]&1)){En(a,o,T,P);x[c+28>>2]=x[c+28>>2]|1}b=a}l=U+616|0;if(y[j+1075843|0]&8){EF(l,b,o);a=j+1075084|0;x[T>>2]=x[T>>2]+x[a>>2];x[P>>2]=x[P>>2]+x[j+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break cd}ca=0;a=k+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;c=d+1074312|0;Va=a,Wa=Ob(c,33),v[Va+16|0]=Wa;Va=a,Wa=Ob(c,116)^1,v[Va+17|0]=Wa;if(x[l+16>>2]){DF(a,l);c=x[l+12>>2];f=c>>31;e=f;m=e^x[l+8>>2];c=(c^e)-((e>>>0>m>>>0)+e|0)|0;x[a+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}Oa=h>>>12&8|(h>>>5&2|(g|h&1));Pa=ja&65535;Qa=j+1075795|0;Ra=j+1075778|0;Sa=j+1075688|0;Ta=j+1075024|0;Ua=j+1075020|0;ma=j+1075668|0;_=j+1075664|0;W=j+1075088|0;V=j+1075084|0;ya=j+1075016|0;za=j+1075012|0;ka=j+1075096|0;Y=j+1075076|0;K=j+1075068|0;I=j+1075e3|0;la=j+1075072|0;Z=j+1075092|0;q=a;a=o;while(1){gd:{c=x[Z>>2];ga=c?a>>>0>c>>>0?c:a:a;x[k+12>>2]=ga;hd:{id:{if(!ga){break id}c=x[I+4>>2];j=c;h=x[I>>2];if(!(c|h)){break id}m=x[K>>2];if(!m){break id}e=x[q>>2];if(!e){break id}c=x[C>>2];u=x[la>>2];x[U+632>>2]=e;e=x[l>>2];jd:{kd:{t=u&c<<30>>31;f=x[l+4>>2];if((t|0)>(f|0)){if((j|0)<0){e=eh(0,t<<1,e,f);x[l>>2]=e;f=hb;x[l+4>>2]=f;if(!(f>>>0<m+t>>>1>>>0&(f|0)>=(t|0))){e=0;x[l>>2]=e;f=t;x[l+4>>2]=f}ld:{if(c&4){c=c&-129;x[C>>2]=c;j=0-(((h|0)!=0)+j|0)|0;h=0-h|0;x[I>>2]=h;x[I+4>>2]=j;break ld}x[l>>2]=e;f=m-1|0;x[l+4>>2]=f}if(!(c&2)){break id}if(f>>>0<m>>>0){break jd}break id}if((f|0)>0|(f|0)>=0){break jd}f=0;break kd}if(f>>>0<m>>>0){break jd}if(!(c&2)){break id}if(c&4){if(!!h&(j|0)>=0|(j|0)>0){j=0-(((h|0)!=0)+j|0)|0;h=0-h|0;x[I>>2]=h;x[I+4>>2]=j}c=c|128;x[C>>2]=c;if(y[k+37|0]){g=y[k+36|0];i=x[Y>>2]-(g+u|0)|0;e=eh(e,f,0,m);f=hb;if(f>>>0<i>>>0){e=eh(0,m-g|0,e,f);f=hb;break kd}f=u;e=0;break kd}g=0-e|0;i=(m<<1)-((1-((e|0)!=0)|0)+f|0)|0;f=i;e=g;x[l>>2]=e;n=0;f=n|f;x[l+4>>2]=f;if(i>>>0<m>>>0&i>>>0>u>>>0){break jd}x[k+44>>2]=y[k+36|0]+1;f=n|m-x[Gb(K,k+44|0)>>2];break kd}if((j|0)<0){e=0-(((h|0)!=0)+j|0)|0;j=e;h=0-h|0;x[I>>2]=h;x[I+4>>2]=e}Pb(l,0,t-m|0);c=x[C>>2]|8192;x[C>>2]=c;e=x[l>>2];f=x[l+4>>2];break jd}x[l>>2]=e;x[l+4>>2]=f}md:{if((f|0)<(t|0)){if((f|j)<0){break id}x[k+44>>2]=ga;g=h;m=j;break md}g=x[K>>2];if(g>>>0<f>>>0|(!!h&(j|0)>=0|(j|0)>0)&(f|0)==(g|0)){break id}x[k+44>>2]=ga;g=j>>31;m=g;i=g^h;g=i-g|0;m=(j^m)-((i>>>0<m>>>0)+m|0)|0}u=g;i=m;uc(k+12|0,x[k+32>>2]);Aa=x[k+12>>2];cg(e,f,rf(h,j,Aa-1|0),hb);m=hb;g=x[la>>2];Ba=g>>>0>f>>>0|g+16>>>0<=f>>>0;if(Ba){c=c&-8193;x[C>>2]=c}nd:{od:{n=x[k+24>>2];pd:{if(n){g=x[k+28>>2];if(g>>>0<=f>>>0){qd:{if((j|0)<0){h=0;j=g;break qd}h=e;j=f;e=0;f=x[Y>>2]}Va=k,Wa=xp(eh(eh(e,f,h,j),hb,1,0),hb,u,i)+1|0,x[Va+44>>2]=Wa;x[U+632>>2]=n;break nd}if(!(Ba|!(c&8192))){Va=k,Wa=xp(eh(eh(0,t+16|0,e,f),hb,1,0),hb,u,i)+1|0,x[Va+44>>2]=Wa;Va=U,Wa=n+D(x[Y>>2]-t|0,bl(z[x[ka>>2]+34>>1]))|0,x[Va+632>>2]=Wa;break nd}if(!h&(j|0)<=0|(j|0)<0){break pd}if(ga>>>0<2|g>>>0>m>>>0){break od}Va=k,Wa=xp(eh(eh(0,g,e,f),hb,1,0),hb,u,i)+1|0,x[Va+44>>2]=Wa;break nd}if((j|0)>0|(j|0)>=0){break od}}if((m|0)>=(t|0)){break nd}Va=k,Wa=xp(eh(eh(e,f,0,t),hb,1,0),hb,u,i)+1|0,x[Va+44>>2]=Wa;break nd}c=x[K>>2];if((c|0)>(m|0)){break nd}Va=k,Wa=xp(eh(eh(0,c,e,f),hb,1,0),hb,u,i)+1|0,x[Va+44>>2]=Wa}wp(k+44|0,1,Aa);f=x[k+44>>2];if((f|0)>0){break hd}}x[U+632>>2]=0;x[K>>2]=0;x[l>>2]=0;x[l+4>>2]=0;x[Z>>2]=0;EF(l,b,a);x[T>>2]=x[T>>2]+x[V>>2];x[P>>2]=x[P>>2]+x[W>>2];x[W>>2]=0;x[V>>2]=0;x[C>>2]=x[C>>2]&-129;break gd}rd:{sd:{if(Pa>>>0<A[d+24608>>2]){c=4;if(x[Z>>2]){break sd}c=0;if(x[ya>>2]|x[za>>2]){break sd}}Pb(l,rf(x[I>>2],x[I+4>>2],f),hb);ca=0;x[W>>2]=0;x[V>>2]=0;b=(f<<3)+b|0;break rd}e=(f<<3)+b|0;h=e-8|0;x[V>>2]=0-x[h>>2];g=e-4|0;x[W>>2]=0-x[g>>2];ib[x[((c|Oa)<<2)+25744>>2]](l,Ja,b,f);x[V>>2]=x[V>>2]+x[h>>2];x[W>>2]=x[W>>2]+x[g>>2];ca=1;b=e}c=x[Z>>2];td:{if(!c){break td}if(c>>>0<=f>>>0){x[Z>>2]=0;x[za>>2]=x[_>>2];x[ya>>2]=x[ma>>2];x[Ua>>2]=0;x[Ta>>2]=0;if(x[Sa>>2]|!(y[C+1|0]&16)){break td}x[K>>2]=0;x[U+632>>2]=0;break td}x[Z>>2]=c-f}h=0;n=0;c=x[l+4>>2];n=c>>>0>=A[Y>>2]?(y[C|0]&2)>>>1|0:n;e=c;c=x[K>>2];h=x[C>>2]&2|(e>>>0<c>>>0|!c)?h:!z[Ra>>1];a=a-f|0;Kb(k+12|0,va,85);ud:{vd:{wd:{if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])){break wd}c=y[Qa|0];if(!c){break wd}if(c>>>0<=z[Na>>1]){break vd}}c=0;break ud}g=x[ka>>2];e=D(c,104)+d|0;f=e+484380|0;c=(g|0)!=(f|0);if((f|0)==(g|0)|(h|n)!=1){break ud}x[ka>>2]=f;c=x[e+484400>>2];x[U+632>>2]=c;f=z[e+484414>>1];x[C>>2]=f|x[C>>2]&-768;h=f<<30>>31;f=x[e+484388>>2];x[K>>2]=h&f;e=x[e+484384>>2];x[la>>2]=e;x[Y>>2]=f;x[l+4>>2]=e;DF(q,l);if(!c){break gd}if((a|0)>0){continue}break gd}xd:{if(!n|c){break xd}Kb(k+12|0,va,83);if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])|x[la>>2]){break xd}x[l>>2]=x[l>>2];x[l+4>>2]=0;c=x[x[ka>>2]+8>>2];x[K>>2]=c;x[Y>>2]=c}if((a|0)>0){continue}}break}x[U+632>>2]=x[q>>2];ja=ca+ja|0;w[k+42>>1]=ja;if(xa|!ca){break cd}if(!x[sd(ba,ea)>>2]){break cd}a=x[sd(ba,ea)>>2];ib[x[x[a>>2]+152>>2]](a)}aa=aa+1|0;continue}break}}fb=k+48|0;i=x[d+1298300>>2];if(yd(i)){a=$;c=o;b=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=fb-16|0;fb=k;yd:{if(!y[i+534|0]){break yd}e=zua(b,0,6169,0);b=hb;g=b>>>16|0;q=Bc((b&65535)<<16|e>>>16,g);while(1){if(!c){break yd}h=x[i>>2];g=x[h>>2];b=x[h+4>>2];while(1){if((b|0)>=(g|0)){x[h+8>>2]=x[h+12>>2];g=0;l=0;m=0;b=fb-16|0;fb=b;while(1){if((m|0)==18){e=(g|0)>=32767?32767:g;w[h+12>>1]=(e|0)<=-32768?-32768:e;e=(l|0)>=32767?32767:l;w[h+14>>1]=(e|0)<=-32768?-32768:e;w[h+3832>>1]=z[h+3832>>1]+1;e=(z[h+3834>>1]+1>>>0)%13440|0;w[h+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[h+3836>>1]=e>>>8;if(!y[h+3843|0]){w[h+3836>>1]=e>>>10}e=z[h+3838>>1]+1|0;w[h+3838>>1]=e;if((e&65535)>>>0>=1024){w[h+3838>>1]=0;w[h+3840>>1]=z[h+3840>>1]+1&7}fb=b+16|0}else{f=h+D(m,44)|0;zd:{if(!y[f+56|0]){w[b+12>>1]=0;w[b+14>>1]=0;break zd}j=x[f+32>>2];e=z[j+3840>>1];if(e&3){j=(z[f+36>>1]>>>7&7)>>>!y[j+3844|0]>>>(e&1)<<z[f+38>>1];e=e&4?0-j|0:j}else{e=0}j=x[f+52>>2];Ad:{if(j){r=z[j+32>>1];s=z[f+48>>1];e=e<<16>>16;j=yg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);t=x[f+40>>2];u=x[f+20>>2];if(!r){if(!s){j=yg(u,t,e,j,0);j=yg(x[f+24>>2],x[f+40>>2],e,j,0);e=yg(x[f+28>>2],x[f+40>>2],e,j,0);break Ad}t=yg(u,t,e,0,0);t=yg(x[f+24>>2],x[f+40>>2],e,t,0);e=yg(x[f+28>>2],x[f+40>>2],e,t,0)+j|0;break Ad}if(!s){j=yg(u,t,e,j,0);t=yg(x[f+24>>2],x[f+40>>2],e,0,0);e=yg(x[f+28>>2],x[f+40>>2],e,t,0)+j|0;break Ad}t=yg(u,t,e,0,0);e=(yg(x[f+24>>2],x[f+40>>2],e,t,0)+j|0)+yg(x[f+28>>2],x[f+40>>2],e,0,0)|0;break Ad}s=z[f+48>>1];e=e<<16>>16;j=yg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);t=x[f+40>>2];u=x[f+20>>2];if(!s){e=yg(u,t,e,j,0);break Ad}e=yg(u,t,e,0,0)+j|0}w[b+14>>1]=y[f+57|0]?e:0;w[b+12>>1]=y[f+58|0]?e:0}m=m+1|0;l=w[b+12>>1]+l|0;g=w[b+14>>1]+g|0;continue}break}g=x[h>>2];b=x[h+4>>2]-g|0;x[h+4>>2]=b;continue}break}e=g-b|0;w[k+14>>1]=(D(w[h+12>>1],b)+D(e,w[h+8>>1])|0)/(g|0);w[k+12>>1]=(D(w[h+14>>1],b)+D(e,w[h+10>>1])|0)/(g|0);x[h+4>>2]=b+49716;x[a>>2]=x[a>>2]+D(q,w[k+14>>1]);x[a+4>>2]=x[a+4>>2]+D(q,w[k+12>>1]);a=a+8|0;c=c-1|0;continue}}fb=k+16|0}a=y[J+12|0];if(a|x[J+16>>2]){if(!a){En(da,o,ua,ta)}a=x[J>>2];b=x[J+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[J+98>>1]=c;w[J+96>>1]=c;c=x[J+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[J+49946>>1]=f;e=e+255>>>4|0;w[J+49944>>1]=e;w[J+49942>>1]=e;w[J+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;h=0;while(1){if((h|0)!=(o|0)){b=h<<3;c=b+$|0;x[c>>2]=x[c>>2]+D(a,x[b+da>>2]>>4);b=b|4;c=b+$|0;x[c>>2]=x[c>>2]+D(a,x[b+da>>2]>>4);h=h+1|0;continue}break}j=J+68|0;l=0;c=w[J+84>>1];b=x[J+40>>2];g=x[J+36>>2];while(1){if((l|0)==(o|0)){x[J+40>>2]=b;x[J+36>>2]=g;f=o}else{a=(l<<3)+da|0;e=x[a>>2]>>12;g=(D(c,e-g|0)>>15)+e|0;x[a>>2]=g;f=a;a=x[a+4>>2]>>12;b=(D(c,a-b|0)>>15)+a|0;x[f+4>>2]=b;l=l+1|0;continue}break}if(f){c=da;a=f;m=x[j>>2]-1|0;e=z[j+22>>1];k=z[j+20>>1];b=w[j+26>>1];h=w[j+24>>1];u=w[j+18>>1];i=w[j+16>>1];n=x[j+4>>2];g=j+32928|0;while(1){if(a){l=md(x[c>>2]);t=md(x[c+4>>2]);k=md((k<<16>>16)-l|0);e=md((e<<16>>16)-t|0);k=dd(md((D(i,k)|0)/65536<<1)+l|0);e=dd(md((D(e,u)|0)/65536<<1)+t|0);t=g+(n<<2)|0;q=w[t>>1];l=dd(((D(q,h)|0)/-65536|0)+k|0);n=n+1&127;s=g+(n<<2)|0;t=w[t+2>>1];r=dd(((D(t,b)|0)/-65536|0)+e|0);w[s+2>>1]=r;w[s>>1]=l;m=m+1&8191;s=j+(m<<2)|0;Va=s,Wa=dd(q+((D(h,l)|0)/65536|0)|0),w[Va+160>>1]=Wa;Va=s,Wa=dd(t+((D(b,r)|0)/65536|0)|0),w[Va+162>>1]=Wa;c=c+8|0;a=a-1|0;continue}break}w[j+22>>1]=e;w[j+20>>1]=k;x[j+4>>2]=n}k=J+49892|0;H=J+33508|0;c=f;a=da;while(1){if(c){h=x[J+76>>2];g=h&4095;e=H+(g<<2)|0;b=a;g=4096-g|0;s=h-x[J+49892>>2]&4095;h=4096-s|0;h=g>>>0<h>>>0?g:h;h=c>>>0<h>>>0?c:h;h=h>>>0>=64?64:h;n=h;g=0;u=fb-32|0;fb=u;l=x[j>>2];while(1){if((g|0)==7){Bd:{i=w[j+28>>1]/8<<16>>16;Cd:while(1){if(!n){break Bd}n=n-1|0;g=0;l=0;t=0;while(1)if((g|0)==4){g=4;m=0;r=dd((t|0)/32768|0);G=dd((l|0)/32768|0);l=0;while(1)if((g|0)==7){g=dd(r+((l|0)/32768|0)|0);w[e>>1]=g;x[b>>2]=D(g,i);g=dd(G+((m|0)/32768|0)|0);w[e+2>>1]=g;x[b+4>>2]=D(g,i);b=b+8|0;e=e+4|0;continue Cd}else{t=u+(g<<2)|0;q=x[t>>2]+1&8191;x[t>>2]=q;_=m;m=j+(q<<2)|0;q=w[m+160>>1];t=j+(g<<4)|0;M=w[m+162>>1];m=(_+D(q,w[t+44>>1])|0)+D(M,w[t+46>>1])|0;l=(D(q,w[t+40>>1])+l|0)+D(M,w[t+42>>1])|0;g=g+1|0;continue}}else{m=u+(g<<2)|0;q=x[m>>2]+1&8191;x[m>>2]=q;_=l;l=j+(q<<2)|0;q=w[l+160>>1];m=j+(g<<4)|0;r=w[l+162>>1];l=(_+D(q,w[m+44>>1])|0)+D(r,w[m+46>>1])|0;t=(D(q,w[m+40>>1])+t|0)+D(r,w[m+42>>1])|0;g=g+1|0;continue}}}}else{x[u+(g<<2)>>2]=l+(x[(j+(g<<4)|0)+32>>2]^-1);g=g+1|0;continue}break}fb=u+32|0;l=H+(s<<2)|0;e=a;b=h;G=k+2|0;n=x[k+4>>2];g=k+24640|0;m=k+16448|0;while(1){t=n&2047;if(b){U=k+8256|0;M=w[U+((n+1206&2047)<<2)>>1];i=k- -64|0;s=w[i+((n+1750&2047)<<2)>>1];R=w[(G+((n+754&2047)<<2)|0)+8256>>1];r=w[(G+((n+1602&2047)<<2)|0)- -64>>1];u=w[l>>1];q=w[l+2>>1];C=g+((n+502&2047)<<2)|0;I=w[C>>1];K=md(w[k+32>>1]-I|0);C=w[C+2>>1];P=md(w[k+34>>1]-C|0);T=w[k+26>>1];W=g+((n+22&2047)<<2)|0;V=w[W>>1];Y=md(w[k+36>>1]-V|0);Z=w[k+28>>1];W=w[W+2>>1];aa=md(w[k+38>>1]-W|0);ba=w[k+30>>1];I=dd(md((D(K,w[k+24>>1])|0)/65536<<1)+I|0);w[k+32>>1]=I;Va=k,Wa=dd(md((D(P,T)|0)/65536<<1)+C|0),w[Va+34>>1]=Wa;Va=k,Wa=dd(md((D(Y,Z)|0)/65536<<1)+V|0),w[Va+36>>1]=Wa;C=dd(md((D(aa,ba)|0)/65536<<1)+W|0);w[k+38>>1]=C;I=md((D(I,w[k+16>>1])|0)/32768|0);K=md((D(C,w[k+22>>1])|0)/32768|0);C=md(I+((u|0)/4<<16>>16)|0);I=md(K+((q|0)/4<<16>>16)|0);u=w[k+8>>1];K=md(C+((D(u,s)|0)/-65536|0)|0);_=i;i=t<<2;P=_+i|0;q=w[k+10>>1];T=md(I+((D(q,r)|0)/-65536|0)|0);w[P+2>>1]=T;w[P>>1]=K;s=md(s+((D(u,K)|0)/65536|0)|0);K=i+m|0;r=md(r+((D(q,T)|0)/65536|0)|0);w[K+2>>1]=r;w[K>>1]=s;C=md(s+C|0);I=md(r+I|0);s=m+((n+682&2047)<<2)|0;K=w[s+2>>1];P=w[s>>1];s=md((D(K,w[k+42>>1])+D(P,w[k+40>>1])|0)/32768|0);r=m+((n+426&2047)<<2)|0;n=w[r+2>>1];T=w[r>>1];r=md((D(n,w[k+46>>1])+D(T,w[k+44>>1])|0)/32768|0);P=md(md(C+P|0)-s|0);K=md(md(I+K|0)-r|0);C=md(md(C+T|0)-s|0);n=md(md(n+I|0)-r|0);s=md(s+((D(u,M)|0)/-65536|0)|0);I=i+U|0;r=md(r+((D(q,R)|0)/-65536|0)|0);w[I+2>>1]=r;w[I>>1]=s;s=(D(s,u)|0)/65536|0;u=md(s+M|0);i=g+i|0;q=(D(q,r)|0)/65536|0;r=md(q+R|0);w[i+2>>1]=r;w[i>>1]=u;Va=e,Wa=(x[e>>2]+D(md(u+P|0),w[k+48>>1])|0)+D(md(r+K|0),w[k+50>>1])|0,x[Va>>2]=Wa;Va=e,Wa=(x[e+4>>2]+D(md(md(s)+C|0),w[k+52>>1])|0)+D(md(md(q)+n|0),w[k+54>>1])|0,x[Va+4>>2]=Wa;e=e+8|0;n=t+1|0;l=l+4|0;b=b-1|0;continue}break}x[k+4>>2]=t;x[J+76>>2]=h+x[J+76>>2]&4095;x[J+68>>2]=h+x[J+68>>2]&8191;c=c-h|0;a=(h<<3)+a|0;continue}break}x[J+68>>2]=x[J+68>>2]&8191;l=da;e=$;b=f;g=0;k=0;m=x[J+56>>2];c=x[J- -64>>2];h=x[J+52>>2];a=x[J+60>>2];while(1){if(b){g=x[l>>2];k=x[l+4>>2];c=c-k|0;c=(((c|0)/1024|0)-c|0)+m|0;x[e+4>>2]=c+x[e+4>>2];a=a-g|0;a=(((a|0)/1024|0)-a|0)+h|0;x[e>>2]=a+x[e>>2];m=c+((c|0)/-512|0)|0;h=a+((a|0)/-512|0)|0;e=e+8|0;l=l+8|0;b=b-1|0;a=g;c=k;continue}break}x[J+64>>2]=k;x[J+60>>2]=g;x[J+56>>2]=m;x[J+52>>2]=h;a=x[J+20>>2];Dd:{if(y[J+12|0]){break Dd}a=x[J+16>>2];if(a>>>0>f>>>0){a=a-f|0;break Dd}BP(J,ua,ta);a=0}v[J+12|0]=0;x[J+16>>2]=a}if(x[d+946300>>2]){Ed:{g=0;e=0;f=o<<2;u=d+906300|0;n=z[d+480214>>1]!=0;Ca=B[d+1074336>>2];X=B[d+1074332>>2];while(1)if((g|0)==250){k=d+12|0;l=d+12300|0;j=d+14348|0;Kw(k,l,j,o,X);a=d+1074476|0;r=y[a|0];v[a|0]=0;a=j;b=l;while(1){Fd:{Gd:{Hd:{if((e|0)!=250){t=sd(u,e);f=x[t>>2];if(!f|!x[f+24>>2]){break Fd}if(!wi(f+44|0)){break Fd}m=f;Id:{if(vp(y[t+24|0])){break Id}c=ib[x[x[f>>2]+148>>2]](f)|0;m=x[t>>2];if(c){break Id}g=0;if(y[m+28|0]&2){break Id}while(1){if((e|0)==(g|0)){break Fd}c=sd(u,g);g=g+1|0;if((lm(x[c+28>>2])|0)!=(e|0)){continue}break}}c=x[f+44>>2];i=Gc(c,0);s=Gc(c,1);q=(b|0)==(i|0);b=q?l:b;h=b;a=q?j:a;g=x[t+28>>2];c=a;Jd:{if(!g){break Jd}g=lm(g);c=a;if(g>>>0<=e>>>0){break Jd}c=a;if(g>>>0>249){break Jd}c=a;if(!x[sd(u,g)>>2]){break Jd}g=x[sd(u,g)>>2];if(!(y[m+28|0]&4)){ib[x[x[g>>2]+152>>2]](g)}c=a;if(!wi(g+44|0)){break Jd}c=x[g+44>>2];h=Gc(c,0);c=Gc(c,1)}if(!vp(y[t+24|0])){break Gd}g=0;Kd:{if(q){break Kd}while(1){if((g|0)==(o|0)){break Kd}q=g<<2;H=q+i|0;G=b+q|0;B[H>>2]=B[G>>2]+B[H>>2];H=q+s|0;q=a+q|0;B[H>>2]=B[q>>2]+B[H>>2];x[G>>2]=0;x[q>>2]=0;g=g+1|0;continue}}a=c;b=h;if(!(n&1)){break Gd}a=x[t>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}g=lm(x[t+28>>2]);a=e;while(1){b=g;g=b&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Hd}q=sd(u,g);g=lm(x[q+28>>2]);a=b;b=x[q>>2];if(!b){continue}ib[x[x[b>>2]+152>>2]](b);continue}}c=0;while(1){if((c|0)!=(o|0)){X=E(B[b>>2]*Ca);Ld:{if(E(F(X))<E(2147483648)){f=~~X;break Ld}f=-2147483648}x[k>>2]=f;X=E(B[a>>2]*Ca);Md:{if(E(F(X))<E(2147483648)){f=~~X;break Md}f=-2147483648}x[k+4>>2]=f;c=c+1|0;k=k+8|0;a=a+4|0;b=b+4|0;continue}break}break Ed}a=c;b=h}g=0;Nd:{Od:{q=y[t+24|0];if(!AF(q)){if(!zF(q)|!(y[m+28|0]&4)){break Od}}while(1){if((g|0)==(o|0)){break Nd}f=g<<2;t=f+h|0;B[t>>2]=B[f+i>>2]+B[t>>2];t=c+f|0;B[t>>2]=B[f+s>>2]+B[t>>2];g=g+1|0;continue}}if(r){ib[x[x[f>>2]+132>>2]](f)}ib[x[x[f>>2]+60>>2]](f,h,c,o);x[m+32>>2]=o+x[m+32>>2];if(!zF(y[t+24|0])){break Nd}if((ib[x[x[f>>2]+160>>2]](f)|0)<=0|A[m+32>>2]<x[d+24620>>2]<<2>>>0){break Nd}Pd:{while(1){if((g|0)==(o|0)){break Pd}f=g<<2;X=B[f+h>>2];Qd:{if(X>=E(1.1920928955078125e-7)|X<=E(-1.1920928955078125e-7)){break Qd}X=B[c+f>>2];if(X>=E(1.1920928955078125e-7)){break Qd}g=g+1|0;if(!(X<=E(-1.1920928955078125e-7))){continue}}break}x[m+32>>2]=0;break Nd}x[m+28>>2]=x[m+28>>2]|4}x[m+28>>2]=x[m+28>>2]&-3}e=e+1|0;continue}}else{h=sd(u,g);a=x[h>>2];Rd:{if(!a|!x[a+24>>2]){break Rd}if(!wi(a+44|0)){break Rd}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Gc(c,0);c=Gc(c,1);Sd:{if(v[a+28|0]&1){Kw(x[a+24>>2],b,c,o,X);break Sd}k=a+40|0;if(x[k>>2]|x[a+36>>2]){En(x[a+24>>2],o,k,a+36|0);Kw(x[a+24>>2],b,c,o,X);break Sd}Tb(b,0,f);Tb(c,0,f)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(vp(y[h+24|0])){break Rd}n=!(a&4)|n}g=g+1|0;continue}}}if(x[d+24624>>2]==1){c=0;while(1){if((c|0)!=(o|0)){a=(c<<3)+$|0;x[(c<<2)+$>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(Bd(y[Ia|0])){b=0;h=fb-16|0;fb=h;Td:{if(!x[d+1074376>>2]){l=d+1074460|0;a=l;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Td}a=x[d+1074456>>2];c=x[d+1074468>>2];Ud:{if((a|0)==(c|0)){e=x[d+1074460>>2];break Ud}x[d+1074468>>2]=a;e=x[d+24620>>2];f=d+1074460|0;Vd:{if((a|0)>(c|0)){e=Pu(e,x[d+24636>>2]);break Vd}e=Pu(e,x[d+24640>>2])}x[f>>2]=e;x[d+1074464>>2]=e;c=a}l=d+1074460|0;if((e|0)<=0){break Td}c=(c<<12)-x[d+1074472>>2]|0;b=(c|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Td}x[h+12>>2]=50;f=x[d+1074464>>2];x[h+8>>2]=1e4/(f+1|0);g=x[We(h+12|0,h+8|0)>>2];while(1){k=b>>31;if((g|0)>=((k^b)-k|0)){break Td}e=e+f|0;x[l>>2]=e;b=(c|0)/(e|0)|0;continue}}Wd:{Xd:{switch(x[d+24624>>2]-1|0){case 0:g=a<<12;e=d+12|0;k=a>>31;c=0;while(1){if((c|0)==(o|0)){break Wd}Yd:{if(x[l>>2]>0){f=x[d+1074472>>2]+b|0;x[d+1074472>>2]=f;j=x[e>>2];Va=e,Wa=Fc(Aua(zua(j,j>>31,f,f>>31),hb,1048576,0),hb),x[Va>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break Yd}f=x[e>>2];Va=e,Wa=Fc(Aua(zua(f,f>>31,a,k),hb,256,0),hb),x[Va>>2]=Wa;x[d+1074472>>2]=g}c=c+1|0;e=e+4|0;continue};case 1:k=a<<12;e=d+12|0;f=a>>31;c=0;while(1){if((c|0)==(o|0)){break Wd}Zd:{if(x[l>>2]>0){g=x[d+1074472>>2]+b|0;x[d+1074472>>2]=g;j=x[e>>2];Va=e,Wa=Fc(Aua(zua(j,j>>31,g,g>>31),hb,1048576,0),hb),x[Va>>2]=Wa;g=x[d+1074472>>2];j=g;m=g>>31;g=x[e+4>>2];Va=e,Wa=Fc(Aua(zua(j,m,g,g>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break Zd}g=x[e>>2];Va=e,Wa=Fc(Aua(zua(g,g>>31,a,f),hb,256,0),hb),x[Va>>2]=Wa;g=x[e+4>>2];Va=e,Wa=Fc(Aua(zua(g,g>>31,a,f),hb,256,0),hb),x[Va+4>>2]=Wa;x[d+1074472>>2]=k}c=c+1|0;e=e+8|0;continue};case 3:break Xd;default:break Wd}}j=a<<12;e=d+8204|0;c=d+12|0;f=a;g=a>>31;a=0;while(1){if((a|0)==(o|0)){break Wd}_d:{if(x[l>>2]>0){k=x[d+1074472>>2]+b|0;x[d+1074472>>2]=k;m=x[c>>2];Va=c,Wa=Fc(Aua(zua(m,m>>31,k,k>>31),hb,1048576,0),hb),x[Va>>2]=Wa;k=x[d+1074472>>2];m=k;i=k>>31;k=x[c+4>>2];Va=c,Wa=Fc(Aua(zua(m,i,k,k>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;k=x[d+1074472>>2];m=k;i=k>>31;k=x[e>>2];Va=e,Wa=Fc(Aua(zua(m,i,k,k>>31),hb,1048576,0),hb),x[Va>>2]=Wa;k=x[d+1074472>>2];m=k;i=k>>31;k=x[e+4>>2];Va=e,Wa=Fc(Aua(zua(m,i,k,k>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break _d}k=x[c>>2];Va=c,Wa=Fc(Aua(zua(k,k>>31,f,g),hb,256,0),hb),x[Va>>2]=Wa;k=x[c+4>>2];Va=c,Wa=Fc(Aua(zua(k,k>>31,f,g),hb,256,0),hb),x[Va+4>>2]=Wa;k=x[e>>2];Va=e,Wa=Fc(Aua(zua(k,k>>31,f,g),hb,256,0),hb),x[Va>>2]=Wa;k=x[e+4>>2];Va=e,Wa=Fc(Aua(zua(k,k>>31,f,g),hb,256,0),hb),x[Va+4>>2]=Wa;x[d+1074472>>2]=j}a=a+1|0;e=e+8|0;c=c+8|0;continue}}fb=h+16|0}if(x[ra>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];$d:{if((a|0)==128|e>>>0<2){break $d}vR(b,o,a);if(e>>>0<4){break $d}vR(c,o,a)}}if(x[d+24624>>2]==4){a=o;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+$|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+sa>>2];x[b+8>>2]=x[c+sa>>2];x[b+4>>2]=x[e+$>>2];x[b>>2]=x[c+$>>2];continue}break}}if(Bd(Ea)){a=x[d+24624>>2];x[L- -64>>2]=o;x[L+60>>2]=a;x[L+56>>2]=$;a=x[x[pa>>2]+8>>2];x[L+24>>2]=o;b=x[L+60>>2];x[L+16>>2]=x[L+56>>2];x[L+20>>2]=b;ib[a|0](pa,L+16|0)}a=x[d+24624>>2];x[L+52>>2]=o;x[L+48>>2]=a;x[L+44>>2]=$;a=x[x[oa>>2]+8>>2];x[L+8>>2]=o;b=x[L+48>>2];x[L>>2]=x[L+44>>2];x[L+4>>2]=b;ib[a|0](oa,L);x[d+1074380>>2]=x[d+1074380>>2]-o;x[d+1074376>>2]=o+x[d+1074376>>2];ia=ia-o|0;Da=o+Da|0;continue}break}fb=fa+32|0;return Da}function ag(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,m=0,o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=0,J=E(0),K=0,L=0,M=0,O=0,V=0;k=fb-2240|0;fb=k;a:{b:{c:{d:{e:{f:{if(Nw(x[c>>2])){uc(b,268435456);L=x[c+8>>2];I=k+2220|0;f=I;x[f>>2]=0;x[f+4>>2]=0;Nb(f+8|0);x[k+2216>>2]=0;g:{h:{i:{j:{k:{l:{m:{f=y[a+3|0];n:{o:{if((f-4&255)>>>0<=4){x[31721]=0;d=R(205,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break m}x[k+2216>>2]=d;break o}if(f>>>0>17){break n}p:{g=1<<f;if(!(g&63503)){if(!(g&198144)){break n}break p}if(y[a|0]){break p}break o}f=0;e=dD(a,x[b>>2]);x[31721]=0;S(189,k+48|0,c|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break l}d=k+48|0;e=x[d+4>>2];x[I>>2]=x[d>>2];x[I+4>>2]=e;rn(I+8|0,d+8|0);Ic(d);e=Se(I);d=x[I>>2];x[k+2216>>2]=d;if(!e){break g}}f=y[a+3|0]}q:{r:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!y[a|0];case 9:case 10:case 16:case 17:g=x[b>>2];if(!(g>>>0<262145|h)){f=f&255;x[k+48>>2]=((f|0)==10)<<4;h=d-x[Gb(k+48|0,k+2216|0)>>2]|0;if(f>>>0>15){break k}s:{if(!(1<<f&63503)){if((f|0)==10){break s}break k}if(!(y[a|0]&7)){break k}}f=(h|0)<0?-1:h<<1;break j}f=f&255;if(f>>>0>8){break h}if(1<<f&432){break q}if((f|0)!=6){break h}break;case 4:case 5:case 7:case 8:break q;case 6:break r;default:break i}}f=0;if(d>>>0<10){break g}x[31721]=0;P(186,c|0,4)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}x[31721]=0;f=R(154,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[k+48>>2]=f;x[k+28>>2]=x[k+2216>>2];d=x[Gb(k+48|0,k+28|0)>>2];Dh(c,8);f=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}g=8/(Xq(y[a+1|0])>>>0)|0;f=D(g,d);zua(g,0,d,0);f=hb?-1:f;break j}a=N()|0;break a}a=N()|0;break a}g=0;d=Xq(y[a+1|0]);t:{u:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=y[a|0];break t;case 9:g=16;break t;case 10:g=4;break t;case 16:case 17:break u;default:break t}}g=8}f=D(d,g&255)>>>3|0;d=(f+h|0)-1|0;f=((d>>>0<h>>>0?-1:d)>>>0)/(f>>>0)|0}uc(b,f)}g=x[b>>2]}if(!g){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Bh(b)){f=0;x[b>>2]=0;break g}v:{if(me(a,Wc(k+48|0,8,1,0,10))){x[31721]=0;d=P(206,c|0,k+48|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){f=0;if(!d){break v}a=x[b>>2];d=0;x[31721]=0;x[k+28>>2]=a+1>>>1;f=R(205,c|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break b}uc(k+28|0,f);a=e+16|0;b=x[b+20>>2];h=x[k+28>>2];f=h;while(1)if(f){g=k+48|0;e=d+y[g|y[a|0]&15]|0;v[b|0]=e;d=y[g|y[a|0]>>>4]+(e&255)|0;v[b+1|0]=d;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=h+16|0;break v}}a=N()|0;break a}w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{g=y[a+3|0];switch(g-4|0){case 3:break E;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break C}}x[31721]=0;b=ba(207,k+1128|0,c|0,b|0,(g|0)==5|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break f}ub(b);f=x[c+8>>2]-L|0;break v}if(y[a+1|0]!=1){break D}x[31721]=0;P(186,c|0,4)|0;a=x[31721];x[31721]=0;if((a|0)==1){break f}x[31721]=0;e=R(154,c|0)|0;a=x[31721];x[31721]=0;J:{K:{L:{if((a|0)!=1){x[31721]=0;x[k+28>>2]=e;d=R(200,c|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break L}x[31721]=0;S(208,k+48|0,c|0,e|0);a=x[31721];x[31721]=0;if((a|0)==1){break K}uc(k+28|0,x[k+48>>2]);e=x[k+28>>2];Gn(k+1120|0,k+48|0);ac(k+1112|0,x[b+20>>2],Sk(x[b>>2],z[b+34>>1]));x[31721]=0;aa(209,x[k+1120>>2],x[k+1124>>2],x[k+1112>>2],x[k+1116>>2],d<<24>>24);a=x[31721];x[31721]=0;if((a|0)==1){break J}f=e+9|0;Ic(k+48|0);break v}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Ic(k+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break D}f=x[k+2216>>2];d=$k(k+1110|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=a;d=x[Gb(h+12|0,h+8|0)>>2];f=d;while(1){if(f){a=y[e|0]+g|0;g=a+y[e+1|0]|0;w[b>>1]=g<<8|a&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=h+16|0;f=d<<1;break v}if(y[a+1|0]!=1|y[a|0]>16){break D}d=x[c+8>>2];e=x[c>>2];f=0;x[31721]=0;d=U(153,e|0,d|0,8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}if(!d){break v}x[31721]=0;d=R(154,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}x[k+2216>>2]=d;if(d>>>0<4){break v}x[31721]=0;S(188,k+28|0,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break c}e=k+28|0;t=$r(k+48|0,e);ub(e);e=x[t>>2];x[31721]=0;d=R(210,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}f=d+4|0;m=y[a|0];s=(m|0)!=16;g=0;h=0;while(1){if(A[b>>2]<=h>>>0){break x}M:{if(s){break M}x[31721]=0;o=P(161,t|0,8)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break M}a=T(28832)|0;break y}x[31721]=0;i=P(161,t|0,1)|0;a=x[31721];x[31721]=0;if((a|0)==1){break z}x[31721]=0;e=P(161,t|0,1)|0;a=x[31721];x[31721]=0;if((a|0)==1){break z}N:{O:{P:{if(!e){e=8;while(1){x[31721]=0;d=P(161,t|0,1)|0;a=x[31721];x[31721]=0;if((a|0)==1){break N}if(d){break P}e=e+16|0;continue}}x[31721]=0;a=P(161,t|0,3)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break O}break z}x[31721]=0;d=P(161,t|0,4)|0;a=x[31721];x[31721]=0;if((a|0)==1){break z}a=e+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;Q:{if((m|0)!=16){v[x[b+20>>2]+h|0]=g;break Q}w[x[b+20>>2]+(h<<1)>>1]=o&255|g<<8}h=h+1|0;continue}break}a=T(28832)|0;break y}if(y[a+1|0]!=1){break C}break B}if((g|0)!=7){break C}if(y[a+1|0]==1){break B}}f=y[a|0];break A}f=y[a|0];if(f>>>0>16){break A}f=0;if(A[k+2216>>2]<5){break v}d=z[b+34>>1];e=x[b+20>>2];a=x[b>>2];x[31721]=0;f=U(211,c|0,e|0,Sk(a,d)|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break v}break f}R:{if((g&254)!=16|(f&255)!=16){break R}d=y[a+1|0];if((d-1&255)>>>0>1){break R}M=k,O=D(x[b>>2],Xq(d)),x[M+48>>2]=O;uc(k+48|0,x[k+2216>>2]);a=x[b+20>>2];f=x[k+48>>2];if((g|0)==16){b=f;while(1){if(!b){break v}M=a,O=z[Zb(28864,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break v}M=a,O=z[Zb(29376,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}d=(f&255)!=8;if(!(d|y[a+1|0]!=1)){S:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break S}}f=x[k+2216>>2];d=bv(k+27|0);a=x[b>>2];b=x[b+20>>2];g=y[d|0];d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}fb=d+16|0;f=a;break v}if(!(y[a+1|0]!=3|d)){T:{switch(g|0){case 0:i=fb-16|0;fb=i;f=x[k+2216>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;f=f+g|0;break v;case 1:i=fb-16|0;fb=i;f=x[k+2216>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;f=f+g|0;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break T}}h=x[k+2216>>2];f=y[bv(k+26|0)|0];m=fb-16|0;fb=m;x[m+12>>2]=h;g=x[b>>2];x[m+8>>2]=g;d=m+8|0;i=x[Gb(d,m+12|0)>>2];x[m+8>>2]=g;x[m+4>>2]=h-i;h=x[Gb(d,m+4|0)>>2];s=b;o=x[b+20>>2];d=f;b=i;g=e;while(1){if(b){d=y[g|0]+d|0;v[o|0]=d;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}o=x[s+20>>2]+1|0;g=x[s>>2]+e|0;b=h;while(1){if(b){f=y[g|0]+f|0;v[o|0]=f;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}fb=m+16|0;f=h+i|0;if(y[a+3|0]!=11){break v}a=x[s+20>>2];b=a+(x[s>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break v}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=f&255;h=a;if(!((d|0)!=8|y[a+1|0]!=2)){f=0;U:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 2:break U;default:break v}}f=x[k+2216>>2];a=bv(k+25|0);d=x[b>>2];g=x[b+20>>2];a=y[a|0];h=fb-16|0;fb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<1;break v}if(!(y[h+2|0]|((d|0)!=16|y[h+1|0]!=1))){V:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break V}}f=x[k+2216>>2];d=$k(k+22|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=fb-16|0;fb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<1;break v}a=f&255;if(!((a|0)!=16|y[h+1|0]!=1|y[h+2|0]!=1)){f=0;W:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>1;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>1;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<1;break v;case 2:break W;default:break v}}f=x[k+2216>>2];d=$k(k+20|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=fb-16|0;fb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<1;break v}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=3))){X:{switch(g|0){case 0:s=fb-16|0;fb=s;d=x[k+2216>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Gb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Gb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=s+16|0;f=a+h<<1;break v;case 1:s=fb-16|0;fb=s;d=x[k+2216>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Gb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Gb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=s+16|0;f=a+h<<1;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break X}}g=x[k+2216>>2];a=z[$k(k+18|0)>>1];t=fb-16|0;fb=t;x[t+12>>2]=g;m=x[b>>2]<<1;x[t+8>>2]=m;d=t+8|0;f=x[Gb(d,t+12|0)>>2];x[t+8>>2]=m;x[t+4>>2]=g-f;s=x[Gb(d,t+4|0)>>2];g=b;d=x[g+20>>2];b=a;i=f>>>1|0;o=i;f=e;while(1){if(o){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[d>>1]=b;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}f=e+m|0;d=x[g+20>>2]+2|0;b=s>>>1|0;o=b;while(1){if(o){a=(y[f|0]+a|0)+(y[f+1|0]<<8)|0;w[d>>1]=a;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}fb=t+16|0;f=b+i<<1;if(y[h+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break v}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}a=f&255;if(!((a|0)!=16|y[h+1|0]!=3|y[h+2|0]!=1)){f=0;Y:{switch(g|0){case 0:m=fb-16|0;fb=m;d=x[k+2216>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Gb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Gb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=a<<8|a>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=a<<8|a>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=m+16|0;f=b+h<<1;break v;case 1:m=fb-16|0;fb=m;d=x[k+2216>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Gb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Gb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=(a<<8|a>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=m+16|0;f=b+h<<1;break v;case 2:break Y;default:break v}}f=x[k+2216>>2];a=z[$k(k+16|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=f;m=x[b>>2]<<1;x[o+8>>2]=m;d=o+8|0;g=x[Gb(d,o+12|0)>>2];x[o+8>>2]=m;x[o+4>>2]=f-g;s=x[Gb(d,o+4|0)>>2];f=b;h=x[b+20>>2];b=a;i=g>>>1|0;d=i;g=e;while(1){if(d){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=e+m|0;h=x[f+20>>2]+2|0;b=s>>>1|0;d=b;while(1){if(d){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}fb=o+16|0;f=b+i<<1;break v}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=2))){f=0;Z:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<2;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<2;break v;case 2:break Z;default:break v}}f=x[k+2216>>2];a=$k(k+14|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<2;break v}a=f&255;if(!((a|0)!=16|y[h+1|0]!=2|y[h+2|0]!=1)){f=0;_:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>2;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=a<<8|a>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<2;break v;case 1:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>2;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<2;break v;case 2:break _;default:break v}}f=x[k+2216>>2];a=$k(k+12|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<2;break v}if(!(g|y[h+1|0]!=1|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,3);break v}g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,3);break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;M=a,O=od(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=O;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,6);break v}g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;M=a,O=od(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=O;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,6);break v}if(!(g|y[h+1|0]!=1|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;M=a,O=od(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}if(!(g|y[h+1|0]!=1|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=Qc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}o=fb-16|0;fb=o;x[o+12>>2]=b>>>3;x[o+8>>2]=d;s=x[Gb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=Qc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=o+16|0;f=s<<3;break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>4;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=Qc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;M=a,O=Qc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<4;break v}o=fb-16|0;fb=o;x[o+12>>2]=b>>>4;x[o+8>>2]=d;s=x[Gb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=Qc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=O;m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=a,O=Qc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=o+16|0;f=s<<4;break v}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=Xf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));$:{if(E(F(j))<E(2147483648)){d=~~j;break $}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));aa:{if(E(F(j))<E(2147483648)){d=~~j;break aa}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=Xf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ba:{if(E(F(j))<E(2147483648)){d=~~j;break ba}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;j=Xf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ca:{if(E(F(j))<E(2147483648)){d=~~j;break ca}d=-2147483648}M=a,O=dd(d),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));da:{if(E(F(j))<E(2147483648)){d=~~j;break da}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(Eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ea:{if(E(F(j))<E(2147483648)){d=~~j;break ea}d=-2147483648}M=a,O=dd(d),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=b>>>3;x[g+16>>2]=d;d=x[Gb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Dg(+n());M=g,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);fa:{if(F(q)<2147483648){b=~~q;break fa}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=g+32|0;f=d<<3;break v}m=fb-32|0;fb=m;x[m+24>>2]=b>>>3;x[m+16>>2]=d;i=x[Gb(m+24|0,m+16|0)>>2];f=i;while(1){if(f){s=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);h=s<<24|(s&65280)<<8;g=s&-16777216;d=g>>>24|0;b=s&16711680;o=b<<24|g<<8;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,o|(((g&255)<<24|s>>>8)&-16777216|((g&16777215)<<8|s>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Dg(+n());M=m,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;q=De(C[Ug(m+24|0,m+16|0,m+8|0)>>3]*32768);ga:{if(F(q)<2147483648){b=~~q;break ga}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=m+32|0;f=i<<3;break v}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=b>>>4;x[g+16>>2]=d;d=x[Gb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Dg(+n());M=g,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(q)<2147483648){b=~~q;break ha}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;b=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,b|0);q=Dg(+n());M=g,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ia:{if(F(q)<2147483648){b=~~q;break ia}b=-2147483648}M=a,O=dd(b),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=g+32|0;f=d<<4;break v}o=fb-32|0;fb=o;x[o+24>>2]=b>>>4;x[o+16>>2]=d;s=x[Gb(o+24|0,o+16|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)));l(1,i|(b|g));q=Dg(+n());M=o,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=De(C[Ug(o+24|0,o+16|0,o+8|0)>>3]*32768);ja:{if(F(q)<2147483648){b=~~q;break ja}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);h=i<<24|(i&65280)<<8;g=i&-16777216;d=g>>>24|0;b=i&16711680;m=b<<24|g<<8;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|i>>>8)&-16777216|((g&16777215)<<8|i>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Dg(+n());M=o,V=vf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=De(C[Ug(o+24|0,o+16|0,o+8|0)>>3]*32768);ka:{if(F(q)<2147483648){b=~~q;break ka}b=-2147483648}M=a,O=dd(b),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=o+32|0;f=s<<4;break v}la:{if((a|0)==24){if((g|0)!=15|(y[h+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=-2147483648;a=x[k+2216>>2];ma:{if(!y[h+2|0]){o=k+48|0;f=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;na:{oa:{pa:{if((i|0)>=0){d=i;break pa}d=-2147483648;if((i|0)==-2147483648){break oa}d=0-i|0}if(d>>>0<=f>>>0){break na}}f=d}h=h-1|0;a=a+3|0;continue}else{qa:{if(!f){break qa}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break qa}d=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;ra:{if((i|0)>0|(i|0)>=0){d=Bua(d,i,f,0);i=hb;break ra}i=Bua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}fb=t+16|0;f=D(g,3);break ma}o=k+48|0;f=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;sa:{ta:{ua:{if((i|0)>=0){d=i;break ua}d=-2147483648;if((i|0)==-2147483648){break ta}d=0-i|0}if(d>>>0<=f>>>0){break sa}}f=d}h=h-1|0;a=a+3|0;continue}else{va:{if(!f){break va}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break va}d=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;wa:{if((i|0)>0|(i|0)>=0){d=Bua(d,i,f,0);i=hb;break wa}i=Bua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}fb=t+16|0;f=D(g,3)}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}e=zua(z[b+32>>1],0,a,0);a=hb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,O=Hd(Bc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}a=f&255;if((a|0)==32){if(!((g|0)!=15|(y[h+1|0]-1&255)>>>0>1)){x[k+48>>2]=-2147483648;d=x[k+2216>>2];xa:{if(!y[h+2|0]){o=k+48|0;a=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){i=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);ya:{za:{Aa:{if((i|0)>=0){d=i;break Aa}d=-2147483648;if((i|0)==-2147483648){break za}d=0-i|0}if(d>>>0<=a>>>0){break ya}}a=d}e=e-1|0;h=h+4|0;continue}else{Ba:{if(!a){break Ba}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Ba}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);i=d&-2147483648|d>>>1;d=s|d<<31;Ca:{if((i|0)>0|(i|0)>=0){d=Bua(d,i,a,0);i=hb;break Ca}i=Bua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}fb=t+16|0;f=g<<2;break xa}o=k+48|0;a=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);i=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Da:{Ea:{Fa:{if((i|0)>=0){d=i;break Fa}d=-2147483648;if((i|0)==-2147483648){break Ea}d=0-i|0}if(a>>>0>=d>>>0){break Da}}a=d}e=e-1|0;h=h+4|0;continue}else{Ga:{if(!a){break Ga}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Ga}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);i=d&-2147483648|d>>>1;d=s|d<<31;Ha:{if((i|0)>0|(i|0)>=0){d=Bua(d,i,a,0);i=hb;break Ha}i=Bua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}fb=t+16|0;f=g<<2}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}e=zua(z[b+32>>1],0,a,0);a=hb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,O=Hd(Bc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=1065353216;a=x[k+2216>>2];Ia:{if(!y[h+2|0]){f=k+48|0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(h+12|0,a>>>2|0);g=e;d=x[h+12>>2];a=d;while(1){if(a){j=Xf((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));j=E(F(Eg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ja:{a=u==E(0);if(a){break Ja}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ja}j=Xf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=ni(E(Ld(E(J*(Eg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ka:{if(E(F(j))<E(2147483648)){i=~~j;break Ka}i=-2147483648}M=g,O=dd(i),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}fb=h+16|0;f=d<<2}break}break Ia}f=k+48|0;i=fb-16|0;fb=i;M=i,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+12>>2]=O;uc(i+12|0,a>>>2|0);g=e;d=x[i+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);j=Xf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=E(F(Eg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{La:{a=u==E(0);if(a){break La}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break La}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Xf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=ni(E(Ld(E(J*(Eg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ma:{if(E(F(j))<E(2147483648)){h=~~j;break Ma}h=-2147483648}M=g,O=dd(h),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}fb=i+16|0;f=d<<2}break}}if(!f){break v}j=B[k+48>>2];if(j==E(1)){break v}j=ni(lB(E(j*E(z[b+32>>1])),E(1),E(64)));a=65535;Na:{if(j>=E(65535)){break Na}a=0;if(j<=E(0)){break Na}a=~~j>>>0;if(j<E(4294967296)&j>=E(0)){break Na}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1|(a|0)!=64){break la}x[k+48>>2]=0;x[k+52>>2]=1072693248;a=x[k+2216>>2];Oa:{if(!y[h+2|0]){h=k+48|0;i=fb-32|0;fb=i;M=i,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+4>>2]=O;uc(i+4|0,a>>>3|0);d=e;f=x[i+4>>2];a=f;while(1){if(a){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);q=Dg(+n());q=F(vf(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Pa:{a=H==0;if(a){break Pa}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Pa}g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);q=Dg(+n());M=i,V=K*(vf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;q=De(C[Ug(i+24|0,i+16|0,i+8|0)>>3]*32768);Qa:{if(F(q)<2147483648){g=~~q;break Qa}g=-2147483648}M=d,O=dd(g),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=H}fb=i+32|0;f=f<<3}break}break Oa}o=k+48|0;G=fb-32|0;fb=G;M=G,O=D(x[b>>2],Yd(z[b+34>>1])),x[M+4>>2]=O;uc(G+4|0,a>>>3|0);d=e;f=x[G+4>>2];a=f;while(1){if(a){m=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);s=m<<24|(m&65280)<<8;i=m&-16777216;h=i>>>24|0;g=m&16711680;t=g<<24|i<<8;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,t|(((i&255)<<24|m>>>8)&-16777216|((i&16777215)<<8|m>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,s|(h|g>>>8));q=Dg(+n());q=F(vf(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Ra:{a=H==0;if(a){break Ra}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Ra}t=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=t<<24|(t&65280)<<8;s=t&16711680;i=s>>>8|0;h=t&-16777216;g=h>>>24|0;s=h<<8|s<<24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,s|(((h&255)<<24|t>>>8)&-16777216|((h&16777215)<<8|t>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,m|(g|i));q=Dg(+n());M=G,V=K*(vf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[G+16>>2]=0;x[G+20>>2]=-1074790400;x[G+8>>2]=0;x[G+12>>2]=1072693248;q=De(C[Ug(G+24|0,G+16|0,G+8|0)>>3]*32768);Sa:{if(F(q)<2147483648){g=~~q;break Sa}g=-2147483648}M=d,O=dd(g),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(o){C[o>>3]=H}fb=G+32|0;f=f<<3}break}}if(!f){break v}q=C[k+48>>3];if(q==1){break v}M=b,O=pD(Iv(q*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}Ta:{Ua:{Va:{Wa:{a=(f&255)!=32;Xa:{if(!(a|(y[h+1|0]!=1|(g|0)!=12))){u=E(30517578125e-15);f=x[k+2216>>2];if(!y[h+2|0]){break Xa}break Ta}if(!(y[h+1|0]!=2|(g|0)!=12|a)){u=E(30517578125e-15);f=x[k+2216>>2];if(!y[h+2|0]){break Va}break Ua}a=(f&255)!=32;if(a|(y[h+1|0]!=1|(g|0)!=13)){break Wa}u=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[h+2|0]){break Ta}}a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=f>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=Xf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Ya:{if(E(F(j))<E(2147483648)){g=~~j;break Ya}g=-2147483648}M=b,O=dd(g),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<2;break v}f=0;if(y[h+1|0]!=2|(g|0)!=13|a){break v}u=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[h+2|0]){break Ua}}a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=f>>>3;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=Xf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Za:{if(E(F(j))<E(2147483648)){g=~~j;break Za}g=-2147483648}M=b,O=dd(g),w[M>>1]=O;j=Xf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));_a:{if(E(F(j))<E(2147483648)){g=~~j;break _a}g=-2147483648}M=b,O=dd(g),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<3;break v}a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=f>>>3;x[g+8>>2]=a;a=x[Gb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));$a:{if(E(F(j))<E(2147483648)){d=~~j;break $a}d=-2147483648}M=b,O=dd(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));ab:{if(E(F(j))<E(2147483648)){d=~~j;break ab}d=-2147483648}M=b,O=dd(d),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=a<<3;break v}a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=f>>>2;x[g+8>>2]=a;a=x[Gb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Xf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=ni(E(Ld(E((Eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));bb:{if(E(F(j))<E(2147483648)){d=~~j;break bb}d=-2147483648}M=b,O=dd(d),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=a<<2;break v}a=T(28832)|0}if((gb|0)!=($(28832)|0)){break d}Y(a|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break w}}ub(t);break v}a=N()|0;break d}x[31721]=0;P(152,c|0,f+L|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break f}}Ic(I)}fb=k+2240|0;return f|0}a=N()|0;break a}a=N()|0}ub(t);break a}a=N()|0;break a}a=N()|0}Ic(I);Q(a|0);p()}function Yra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0;d=fb-608|0;fb=d;vc(b);f=fb-16|0;fb=f;h=d+416|0;dw(f+8|0,h);j=x[f+12>>2];g=b;jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){Ub(g,x[f+12>>2])}fb=f+16|0;b=(b|0)==(j|0);if(!b){oZ(h)}a:{b:{c:{if(!b){break c}if(!qZ(d+416|0)){break c}if(!Mb(x[g>>2],x[g+8>>2],Bc(pZ(d+416|0),hb))){break c}if(!c){e=1;break c}Ad(a,32);v[d+415|0]=0;j=Fb(d+400|0);d:{e:{f:{g:{h:{i:{if((y[d+416|0]|y[d+417|0]<<8|(y[d+418|0]<<16|y[d+419|0]<<24))==778924148){x[31721]=0;O(421,a|0,16777216);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=x[g>>2];x[31721]=0;b=R(157,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;P(152,g|0,b-4|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}x[31721]=0;B=R(154,g|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[d+456|0]|y[d+457|0]<<8)-2185&65535)>>>0>1910){break o}b=x[g>>2];x[31721]=0;b=R(157,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}x[31721]=0;P(152,g|0,b-4|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}x[31721]=0;B=R(154,g|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}if(B>>>0<256){break o}b=x[g>>2];x[31721]=0;b=R(157,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}if(b>>>0<=B>>>0){break o}x[31721]=0;b=P(152,g|0,B|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}if(!b){break o}x[31721]=0;b=R(422,g|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}if(!b){break o}x[31721]=0;O(421,a|0,16777216);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=y[d+456|0]|y[d+457|0]<<8;if(b>>>0>=4096){x[31721]=0;c=P(1,d+160|0,16523)|0;b=x[31721];x[31721]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31721]=0;S(389,a|0,1,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(c);break d}b=N()|0;tb(c);break a}if(b>>>0<2194){break o}x[31721]=0;e=P(1,d+388|0,16052)|0;b=x[31721];x[31721]=0;if((b|0)==1){break n}b=x[a+1298472>>2];x[31721]=0;S(389,b|0,4,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break m}tb(e)}if(x[a+480180>>2]!=32){break i}b=y[d+456|0]|y[d+457|0]<<8;if((b&61440)!=20480){break j}b=b&4095;e=b<<16;if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))!=1414548815){break l}v[d+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(e);break a}if(b>>>0<297){break k}e=y[d+476|0]|y[d+477|0]<<8|e}x[a+1074308>>2]=e;break i}e=y[d+458|0]|y[d+459|0]<<8;if(!((e|0)!=2184&(b|0)!=2184)){v[d+415|0]=1;x[a+1074308>>2]=18284544;break i}if((b|0)!=768){if((b|0)!=532|(e|0)!=514|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31721]=0;b=P(1,d+376|0,14695)|0;e=x[31721];x[31721]=0;if((e|0)!=1){yb(j,b);tb(b);v[d+415|0]=1;break i}b=N()|0;break a}if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|(e|0)!=768|((y[d+448|0]|y[d+449|0]<<8)!=256|y[d+468|0]!=128)){break i}if(y[d+469|0]){break i}x[a+1074308>>2]=18285088;v[d+415|0]=1}b=y[d+460|0]|y[d+461|0]<<8;e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Mr(b,d+420|0);x[31721]=0;O(221,d+160|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}b=d+160|0;yb(a+1298308|0,b);tb(b);if(!(!(y[d+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+446|0];x[a+480220>>2]=y[d+447|0]}b=y[d+464|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+466|0];if(b){x[a+480196>>2]=b}v[d+160|0]=31;v[d+280|0]=y[d+467|0];b=d+160|0;e=d+280|0;T=a,X=D(y[af(b,e)|0],1e4),x[T+480204>>2]=X;v[d+160|0]=y[d+465|0];v[d+280|0]=128;T=a,X=y[Sb(b,e)|0],x[T+480228>>2]=X;e=0;while(1){if((e|0)==64){p:{x[31721]=0;P(152,g|0,192)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&((y[d+456|0]|y[d+457|0]<<8)-2187&65535)>>>0<=2){break p}b=y[a+484376|0];e=x[a+484360>>2];x[31721]=0;aa(351,Wb(e,b)|0,g|0,y[d+448|0]|y[d+449|0]<<8,255,254);b=x[31721];x[31721]=0;if((b|0)==1){break b}break e}}else{h=(d+416|0)+e|0;i=h- -64|0;q:{if(y[i|0]==255){break q}f=(e<<5)+a|0;b=f+480280|0;Ue(b);T=f+480286|0,X=Hd(y[h+128|0],0,64),w[T>>1]=X;h=v[i|0];if((h|0)<0){x[b>>2]=x[b>>2]|1024}h=h&127;if(h>>>0<=64){w[f+480284>>1]=h<<2;break q}if((h|0)!=100){break q}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[31721]=0;b=R(192,g|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break f}if(b){break d}x[31721]=0;b=R(154,g|0)|0;f=x[31721];x[31721]=0;r:{if((f|0)==1){break r}if(b>>>0>4e3){break d}f=y[a+484376|0];h=x[a+484360>>2];x[31721]=0;b=U(423,Wb(h,f)|0,g|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break r}if(!b){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}q=Nb(d+364|0);o=Nb(d+352|0);e=0;n=Nb(d+340|0);x[31721]=0;b=U(424,g|0,q|0,y[d+450|0]|y[d+451|0]<<8)|0;f=x[31721];x[31721]=0;s:{t:{u:{if((f|0)==1){break u}if(!b){break s}x[31721]=0;b=U(424,g|0,o|0,y[d+452|0]|y[d+453|0]<<8)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}if(!b){break s}x[31721]=0;b=U(424,g|0,n|0,y[d+454|0]|y[d+455|0]<<8)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}if(!b){break s}x[d+336>>2]=-1;T=d,X=wb(x[q>>2]),x[T+160>>2]=X;f=wb(x[q+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{T=d,X=wb(x[o>>2]),x[T+160>>2]=X;f=wb(x[o+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{T=d,X=wb(x[n>>2]),x[T+160>>2]=X;f=wb(x[n+4>>2]);b=x[d+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{if(v[d+462|0]&1){x[d+160>>2]=y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24);b=x[Gb(d+336|0,d+160|0)>>2];x[d+336>>2]=b}e=0;if((y[d+458|0]|y[d+459|0]<<8)!=532){break D}f=y[d+456|0]|y[d+457|0]<<8;if(y[d+447|0]|(f?(f|0)!=532:0)|(y[d+446|0]|y[d+469|0])){break D}if(y[d+460|0]&192|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break D}if(y[d+450|0]|y[d+451|0]<<8){break E}f=y[d+452|0]|y[d+453|0]<<8;if(!f){break E}if((x[g+8>>2]+(nc(x[o>>2],x[o+4>>2])<<2)|0)+2>>>0>b>>>0){break E}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[31721]=0;b=R(154,g|0)|0;f=x[31721];x[31721]=0;F:{if((f|0)!=1){if(!b){break F}Dh(g,((e&65535)<<2)+4|0);break E}b=N()|0;break t}e=e+1|0;f=y[d+452|0]|y[d+453|0]<<8;continue}break}x[31721]=0;b=P(1,d+324|0,14968)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}yb(j,b);tb(b)}e=1;if(y[d+456|0]|y[d+457|0]<<8){break D}x[31721]=0;b=P(1,d+312|0,15475)|0;f=x[31721];x[31721]=0;if((f|0)==1){break B}yb(j,b);tb(b)}b=y[d+462|0]|y[d+463|0]<<8;G:{if(b&2){x[31721]=0;f=R(192,g|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break w}b=x[g+8>>2];h=x[g>>2];x[31721]=0;i=b;b=f<<3;h=U(153,h|0,i|0,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break w}if(!(!h|A[d+336>>2]<b+x[g+8>>2]>>>0)){x[31721]=0;b=a+1298412|0;O(425,b|0,f|0);h=x[31721];x[31721]=0;if((h|0)==1){break w}T=d,X=wb(x[b>>2]),x[T+280>>2]=X;h=wb(x[a+1298416>>2]);H:{I:{while(1){b=x[d+280>>2];if(!Ib(b,h)){if(!(!f&e)){break G}if(!(y[d+462|0]&4)){break H}x[31721]=0;b=P(1,d+300|0,15508)|0;e=x[31721];x[31721]=0;if((e|0)==1){break I}yb(j,b);tb(b);break G}x[31721]=0;O(426,g|0,d+160|0);i=x[31721];x[31721]=0;if((i|0)!=1){x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;i=y[d+160|0]|y[d+161|0]<<8;if(i|(y[d+162|0]|y[d+163|0]<<8)){x[b>>2]=((i&65024)>>>9|0)+1980;T=b,X=Xb((y[d+160|0]|y[d+161|0]<<8)>>>5&15,1,12),x[T+4>>2]=X;T=b,X=Xb((y[d+160|0]|y[d+161|0]<<8)&31,1,31),x[T+8>>2]=X;T=b,X=Xb((y[d+162|0]|y[d+163|0]<<8)>>>11|0,0,23),x[T+12>>2]=X;T=b,X=Xb((y[d+162|0]|y[d+163|0]<<8)>>>5&63,0,59),x[T+16>>2]=X;i=Xb((y[d+162|0]|y[d+163|0]<<8)<<1&62,0,59);x[b+24>>2]=i;x[b+28>>2]=i>>31}x[b+32>>2]=y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24);x[d+280>>2]=x[d+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31721]=0;b=P(1,d+300|0,14990)|0;e=x[31721];x[31721]=0;if((e|0)!=1){yb(j,b);tb(b);break G}b=N()|0;break t}Dh(g,2);break G}if(e^1|b>>>0>1){break G}x[31721]=0;b=R(192,g|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break v}if(!b){x[31721]=0;b=P(1,d+300|0,14968)|0;e=x[31721];x[31721]=0;if((e|0)!=1){yb(j,b);tb(b);break G}b=N()|0;break t}Dh(g,2)}J:{if(!(y[d+460|0]&128|y[d+462|0]&8)){break J}x[31721]=0;b=a+901404|0;e=P(427,g|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break A}if(!e){break J}hD(b)}if((y[d+456|0]|y[d+457|0]<<8)>>>0<=531){_q(a+901404|0)}x[31721]=0;C=R(171,d+280|0)|0;b=x[31721];x[31721]=0;K:{L:{M:{if((b|0)!=1){x[31721]=0;e=P(416,g|0,13890)|0;b=x[31721];x[31721]=0;if((b|0)==1){break M}if(e){x[31721]=0;b=R(154,g|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break L}x[31721]=0;S(188,d+260|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}b=d+260|0;f=hc(d+160|0,b);gd(C,f);ub(f);ub(b)}w[a+480188>>1]=1;x[31721]=0;b=P(416,g|0,13895)|0;f=x[31721];x[31721]=0;if((f|0)==1){break M}if(!b){break y}x[31721]=0;b=R(154,g|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;S(188,d+260|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}b=d+260|0;f=hc(d+160|0,b);ub(b);b=x[f>>2];x[31721]=0;b=R(157,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break z}w[d+260>>1]=(b>>>0)/20;b=z[Lc(24996,d+260|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){ub(f);e=1;break y}x[31721]=0;S(428,f|0,((e<<5)+a|0)+480289|0,20);h=x[31721];x[31721]=0;if((h|0)!=1){e=e+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(f);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{b=x[d+336>>2];f=x[g+8>>2];W:{if(b>>>0>=f>>>0){b=b-f|0;break W}x[31721]=0;b=R(205,g|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break V}}x[31721]=0;S(188,d+160|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break V}b=d+160|0;E=hc(d+260|0,b);ub(b);x[31721]=0;S(429,d+258|0,a|0,E|0);b=x[31721];x[31721]=0;if((b|0)==1){break U}F=Hc(d+258|0);G=y[d+258|0]!=0|e;if((y[d+456|0]|y[d+457|0]<<8)!=535|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[F|0]|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break Q}X:{if(G){break X}e=Wb(x[a+484360>>2],y[a+484376|0]);b=x[e+4>>2];if(!kc(x[e>>2],b)){if(z[x$(b)>>1]==65535){break X}}if(!gD(d+480|0,255,64)){break S}}x[a+1074308>>2]=18219008;x[31721]=0;b=P(1,d+244|0,14825)|0;e=x[31721];x[31721]=0;if((e|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31721]=0;b=P(1,d+244|0,16874)|0;e=x[31721];x[31721]=0;if((e|0)==1){break P}}yb(j,b);tb(b);v[d+415|0]=1}Y:{if(!(v[d+462|0]&1)|!(y[d+470|0]|y[d+471|0]<<8)){break Y}x[31721]=0;b=P(152,g|0,y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24))|0;e=x[31721];x[31721]=0;if((e|0)==1){break O}if(!b){break Y}x[31721]=0;V(339,a+1298332|0,g|0,y[d+470|0]|y[d+471|0]<<8,4);b=x[31721];x[31721]=0;if((b|0)==1){break O}}f=a+480192|0;w[f>>1]=0;b=0;if(y[d+460|0]&4){w[d+160>>1]=y[d+450|0]|y[d+451|0]<<8;w[d+100>>1]=255;b=z[Lc(d+160|0,d+100|0)>>1];w[f>>1]=b}e=0;Z:{while(1){if((b&65535)>>>0<=e>>>0){x[d+240>>2]=0;e=y[d+452|0]|y[d+453|0]<<8;if(e){b=xb(x[o>>2],e-1|0);x[d+240>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+160>>1]=e;w[d+100>>1]=3999;m=a+480190|0;b=z[Lc(d+160|0,d+100|0)>>1];w[m>>1]=b;l=c&2;r=d+180|0;s=a+1298472|0;e=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((b&65535)>>>0>e>>>0){b=xb(x[o>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!b){break $}x[31721]=0;b=P(152,g|0,b|0)|0;f=x[31721];x[31721]=0;ha:{ia:{ja:{ka:{la:{if((f|0)==1){break la}if(!b){break $}x[31721]=0;b=P(430,g|0,d+160|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break la}if(!b){break $}x[31721]=0;b=e+1|0;f=D(b,104)+a|0;i=f+484380|0;h=P(431,d+160|0,i|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ka}k=d+148|0;Mr(k,r);x[31721]=0;O(221,d+100|0,k|0);k=x[31721];x[31721]=0;if((k|0)==1){break ja}k=d+100|0;xc(((b<<5)+a|0)+946304|0,k);tb(k);x[31721]=0;h=P(152,g|0,h|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ka}if(!h){break $}f=z[f+484414>>1];if(!(f&512)){break ia}x[31721]=0;b=P(432,g|0,d+100|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ga}if(!b){break ha}x[d+16>>2]=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);b=y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24);x[d+8>>2]=y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24);x[d+12>>2]=b;Yk(i,1,d+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(f&16384)){t=y[d+456|0]|y[d+457|0]<<8;h=y[d+178|0];k=h&2;b=y[d+206|0];f=Wc(d+100|0,k?16:8,1,0,(b^-1)&1);if(!(!(h&4)|t>>>0<532)){np(f,3)}ma:{na:{if(h&8){h=b&4?5:4;break na}if(!k){h=10;if((b|0)==255){break na}}if(b&2){v[f+2|0]=1}if(b&4){tg(f,2)}if(!(b&8)){break ma}h=9;if(!k){break ma}}tg(f,h)}if(l){b=0;x[31721]=0;U(218,d+100|0,i|0,g|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break ca}break _}b=1;f=y[d+103|0];if(f>>>0>17){break ba}h=1<<f;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[d+100|0]){break da}break ca}x[31721]=0;O(433,g|0,d+88|0);f=x[31721];x[31721]=0;if((f|0)==1){break ea}h=x[d+88>>2];if(!(!l|!h)){f=Fb(d+100|0);x[31721]=0;S(273,g|0,f|0,h|0);h=x[31721];x[31721]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31721]=0;O(387,d+136|0,16445);h=x[31721];x[31721]=0;if((h|0)==1){break ua}x[d+76>>2]=b;x[31721]=0;S(261,d+124|0,0,f|0);b=x[31721];x[31721]=0;if((b|0)==1){break ta}x[31721]=0;V(434,d+148|0,d+136|0,d+76|0,d+124|0);b=x[31721];x[31721]=0;if((b|0)==1){break sa}b=x[s>>2];x[31721]=0;S(389,b|0,2,d+148|0);b=x[31721];x[31721]=0;if((b|0)==1){break ra}tb(d+148|0);tb(d+124|0);Eb(d+136|0);tb(f);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(d+148|0)}tb(d+124|0)}Eb(d+136|0)}tb(f);break N}x[31721]=0;P(186,g|0,h|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ea}}b=0;break aa}w[d+160>>1]=1;w[d+100>>1]=b;T=a+480190|0,X=z[oe(d+160|0,d+100|0)>>1],w[T>>1]=X;if(!((y[d+456|0]|y[d+457|0]<<8)==516&u)|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[d+462|0]|y[d+463|0]<<8|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break fa}if(((y[d+460|0]|y[d+461|0]<<8)&65527)!=21|y[d+464|0]!=128|(y[d+465|0]!=48|y[d+468|0]!=128)){break fa}if(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8)){break fa}b=d+544|0;f=d+480|0;e=1;while(1)if((b|0)==(f|0)){f=d+608|0;while(1)if((b|0)==(f|0)){b=20;while(1){if((b|0)==26){va:{if(!(e&1)){break fa}x[31721]=0;b=P(1,d+148|0,9879)|0;e=x[31721];x[31721]=0;if((e|0)==1){break va}yb(j,b);tb(b);break fa}}else{e=!y[(b+d|0)+420|0]&e;b=b+1|0;continue}break}b=N()|0;break N}else{e=y[b|0]==64&e;b=b+1|0;continue}}else{e=(y[f|0]&127)==32&e;f=f+1|0;continue}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=nc(x[n>>2],x[n+4>>2]);w[d+160>>1]=b;r=z[Lc(d+160|0,x[a+8>>2]+10|0)>>1];w[d+122>>1]=r;wa:{xa:{ya:{za:{if((b|0)!=(r|0)){x[31721]=0;W(435,d+100|0);b=x[31721];x[31721]=0;if((b|0)==1){break wa}b=x[n+4>>2];e=x[n>>2];x[31721]=0;T=d,X=nc(e,b),x[T+136>>2]=X;V(436,d+160|0,d+100|0,d+136|0,d+122|0);b=x[31721];x[31721]=0;if((b|0)==1){break ya}b=x[a+1298472>>2];x[31721]=0;S(389,b|0,2,d+160|0);b=x[31721];x[31721]=0;if((b|0)==1){break za}tb(d+160|0);Eb(d+100|0)}if(!(c&1)){w[d+122>>1]=0;r=0}l=a+480188|0;h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(r|0)){b=x[d+240>>2];if(!b){break Oa}x[31721]=0;P(152,g|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Qa}if(!t){break Oa}while(1){Sa:{b=x[g+8>>2];c=x[g>>2];x[31721]=0;b=U(153,c|0,b|0,4)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Sa}if(!b){break Oa}x[31721]=0;b=P(416,g|0,13869)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Sa}Ta:{if(!b){x[31721]=0;b=P(416,g|0,13874)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Sa}if(!b){break Ta}}x[31721]=0;b=R(154,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Pa}Dh(g,8);if(b&-2139062144){break Ta}if(b&1616928864){break Oa}}x[31721]=0;b=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Sa}x[31721]=0;P(186,g|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}b=N()|0;break N}Ua:{b=xb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);Va:{if(!b){break Va}x[31721]=0;b=P(152,g|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Na}if(!b){break Va}x[31721]=0;b=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Aa}x[31721]=0;m=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ba}if((m-1025&65535)>>>0<64512){break Va}x[31721]=0;c=P(186,g|0,4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Ba}if(!c){break Va}x[31721]=0;S(188,d+100|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ca}b=d+100|0;f=hc(d+160|0,b);ub(b);b=z[l>>1];k=0;x[31721]=0;i=P(437,d+136|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Ea}Wa:{while(1){if(k>>>0>=m>>>0){break Wa}b=x[f>>2];x[31721]=0;b=U(153,b|0,x[d+168>>2],1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ua}if(!b){break Wa}x[31721]=0;b=R(200,f|0)|0;c=x[31721];x[31721]=0;Xa:{if((c|0)!=1){c=b<<24>>24;if(c){break Xa}k=k+1|0;continue}break Ra}Ya:{b=c&127;u=b?b-1|0:0;b=u&65535;if(Rc(x[i>>2],x[d+140>>2])>>>0>b>>>0){break Ya}x[31721]=0;v[d+100|0]=0;S(438,i|0,b+1|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)!=1){break Ya}break Ra}Za:{if((c|0)<0){x[31721]=0;c=R(200,f|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Za}T=vb(x[i>>2],b),X=c,v[T|0]=X}e=vb(x[i>>2],b);c=y[e|0];if(!(!(c&15)|b>>>0<z[l>>1])){w[l>>1]=u+1;c=y[e|0]}if(c&1){x[31721]=0;P(186,f|0,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Za}e=vb(x[i>>2],b)}if(y[e|0]&2){x[31721]=0;P(186,f|0,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Za}e=vb(x[i>>2],b)}if(y[e|0]&4){x[31721]=0;P(186,f|0,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Za}e=vb(x[i>>2],b)}if(!(y[e|0]&8)){continue}x[31721]=0;P(186,f|0,2)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break Ra}x[d+100>>2]=x[g+8>>2];T=d,X=x[$c(d+240|0,d+100|0)>>2],x[T+240>>2]=X;cc(i);ub(f)}h=h+1|0;continue}}break}b=N()|0;cc(i);break Da}b=N()|0;break N}b=N()|0;break N}x[31721]=0;H=P(439,a|0,g|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){b=y[d+415|0]|H;v[d+415|0]=b;if(!(y[F|0]|!(b&255))){Dv(a+1074312|0);v[a+1074368|0]=0}x[31721]=0;I=ba(440,a|0,g|0,0,d+415|0)|0;b=x[31721];x[31721]=0;_a:{if((b|0)==1){break _a}x[31721]=0;s=a+484344|0;O(226,s|0,r|0);b=x[31721];x[31721]=0;if((b|0)==1){break _a}t=a+480188|0;M=a+480183|0;h=0;while(1){$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{if((h|0)!=(r|0)){b=xb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[31721]=0;b=P(152,g|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break nb}if(b){break mb}}x[31721]=0;b=U(199,s|0,h&65535,64)|0;c=x[31721];x[31721]=0;if((c|0)==1){break nb}if(b){break ob}w[d+64>>1]=h;x[31721]=0;W(441,d+100|0);b=x[31721];x[31721]=0;if((b|0)==1){break sb}x[31721]=0;S(442,d+160|0,d+100|0,d- -64|0);b=x[31721];x[31721]=0;if((b|0)==1){break rb}b=x[a+1298472>>2];x[31721]=0;S(389,b|0,2,d+160|0);b=x[31721];x[31721]=0;if((b|0)==1){break qb}tb(d+160|0);Eb(d+100|0)}if(!x[a+1074308>>2]){e=y[d+456|0]|y[d+457|0]<<8;if((e|0)!=2184){break kb}x[a+1074308>>2]=18284544}if(!zd(x[j+4>>2],y[j+11|0])){break lb}x[31721]=0;c=P(1,d+100|0,18232)|0;b=x[31721];x[31721]=0;if((b|0)==1){break bb}b=x[a+1074308>>2];x[31721]=0;O(137,d+76|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break db}x[31721]=0;S(2,d+160|0,c|0,d+76|0);b=x[31721];x[31721]=0;if((b|0)==1){break eb}e=d+160|0;b=yb(j,e);tb(e);tb(d+76|0);tb(c);e=x[a+1074308>>2];if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))==1414548815){break jb}if((e|0)!=18284544){break ib}e=18284544;if(!(G|I|H)){break hb}break gb}b=N()|0;break N}b=N()|0;break pb}b=N()|0;tb(d+160|0)}Eb(d+100|0);break N}b=x[s>>2];x[31721]=0;O(443,Vb(b,h)|0,C|0);b=x[31721];x[31721]=0;if((b|0)!=1){break $a}}b=N()|0;break N}x[31721]=0;b=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fa}x[31721]=0;J=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ga}x[31721]=0;c=P(186,g|0,4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31721]=0;c=U(199,s|0,h&65535,J|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31721]=0;S(188,d+100|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ha}b=d+100|0;k=hc(d+160|0,b);ub(b);b=x[s>>2];x[31721]=0;O(443,Vb(b,h)|0,C|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ja}b=z[t>>1];x[31721]=0;m=P(437,d+124|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Ka}b=z[t>>1];w[d+104>>1]=0;x[31721]=0;x[d+100>>2]=0;l=U(444,d+88|0,b|0,d+100|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Ma}T=d,X=wb(x[Vb(x[s>>2],h)>>2]),x[T+76>>2]=X;u=0;while(1){tb:{ub:{vb:{wb:{if(u>>>0>=J>>>0){break wb}b=x[k>>2];x[31721]=0;b=U(153,b|0,x[d+168>>2],1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ab}if(!b){break wb}x[31721]=0;b=R(200,k|0)|0;c=x[31721];x[31721]=0;xb:{if((c|0)!=1){b=b<<24>>24;if(b){break xb}c_(d+76|0,z[t>>1]);u=u+1|0;continue}break ab}yb:{c=b&127;i=c?c-1&65535:0;if(Rc(x[m>>2],x[d+128>>2])>>>0>i>>>0){break yb}x[31721]=0;v[d+100|0]=0;c=i+1|0;S(438,m|0,c|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)==1){break ab}w[d+104>>1]=0;x[31721]=0;x[d+100>>2]=0;S(445,l|0,c|0,d+100|0);c=x[31721];x[31721]=0;if((c|0)!=1){break yb}break ab}if((b|0)<0){x[31721]=0;b=R(200,k|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ab}T=vb(x[m>>2],i),X=b,v[T|0]=X}w[d+104>>1]=0;x[d+100>>2]=0;b=d+100|0;if(i>>>0<z[t>>1]){b=Vc(x[d+76>>2],i)}f=vb(x[m>>2],i);e=y[f|0];if(e&16){T=b,X=y[Vc(x[l>>2],i)|0],v[T|0]=X;e=y[f|0]}if(e&32){T=b,X=y[Vc(x[l>>2],i)+1|0],v[T+1|0]=X;e=y[f|0]}if(e&64){c=Vc(x[l>>2],i);v[b+2|0]=y[c+2|0];v[b+4|0]=y[c+4|0];e=y[f|0]}if(e<<24>>24<0){c=Vc(x[l>>2],i);v[b+3|0]=y[c+3|0];v[b+5|0]=y[c+5|0];e=y[f|0]}if(e&1){x[31721]=0;c=R(200,k|0)|0;e=x[31721];x[31721]=0;zb:{Ab:{if((e|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[M|0]&1)){break Ab}e=c;break zb}break ab}e=253;if((c-121&255)>>>0<132){break zb}e=(c&255)!=253?c:0}v[b|0]=e;T=Vc(x[l>>2],i),X=e,v[T|0]=X;f=vb(x[m>>2],i)}if(y[f|0]&2){x[31721]=0;c=R(200,k|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break ab}v[b+1|0]=c;T=Vc(x[l>>2],i),X=c,v[T+1|0]=X;f=vb(x[m>>2],i)}if(!(y[f|0]&4)){break tb}x[31721]=0;f=R(200,k|0)|0;c=x[31721];x[31721]=0;Bb:{Cb:{if((c|0)!=1){if(f>>>0>64){break Cb}v[b+4|0]=f;e=1;break Bb}break ab}if(f<<24>>24<=-64){e=2;v[b+2|0]=2;f=f^-128;v[b+4|0]=f;break ub}if(f>>>0<=74){e=5;v[b+2|0]=5;f=f-65|0;v[b+4|0]=f;break ub}if(f>>>0<=84){e=6;v[b+2|0]=6;f=f-75|0;v[b+4|0]=f;break ub}if(f>>>0<=94){e=3;v[b+2|0]=3;f=f-85|0;v[b+4|0]=f;break ub}if(f>>>0<=104){e=4;v[b+2|0]=4;f=f-95|0;v[b+4|0]=f;break ub}if(f>>>0<=114){e=13;v[b+2|0]=13;f=f-105|0;v[b+4|0]=f;break ub}if(f>>>0<=124){e=12;v[b+2|0]=12;f=f-115|0;v[b+4|0]=f;break ub}c=f+63|0;if((c&255)>>>0<=9){v[b+4|0]=c;e=11;v[b+2|0]=11;f=c;break ub}c=f+53|0;K=c&255;if(K>>>0<=9){v[b+4|0]=c;e=8;v[b+2|0]=8;if(!K){f=0;break ub}if(x[a+1074308>>2]-1>>>0>18285139){break vb}e=7;v[b+2|0]=7;break vb}f=f+33|0;if((f&255)>>>0>=10){f=y[b+4|0];e=y[b+2|0];break ub}v[b+4|0]=f;e=15}v[b+2|0]=e;break ub}Ok(l);cc(m);ub(k);break $a}f=c}c=Vc(x[l>>2],i);v[c+4|0]=f;v[c+2|0]=e;f=vb(x[m>>2],i)}if(!(y[f|0]&8)){continue}x[31721]=0;O(201,d+52|0,k|0);c=x[31721];x[31721]=0;if((c|0)!=1){eD(b,y[d+52|0],y[Hc(d+52|0)|0],1);c=Vc(x[l>>2],i);v[c+3|0]=y[b+3|0];v[c+5|0]=y[b+5|0];continue}break}break ab}e=y[d+456|0]|y[d+457|0]<<8}Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{b=e&65535;switch(b>>>12|0){case 13:break Ib;case 7:break Jb;case 6:break Kb;case 4:break Lb;case 1:break Nb;case 0:break Ob;default:break fb}}if(y[F|0]){x[31721]=0;b=P(1,d+160|0,8340)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{c=e&65535;if((c|0)!=532){break Xb}b=y[d+458|0]|y[d+459|0]<<8;if((b|0)!=512){break Wb}if(y[d+462|0]|y[d+463|0]<<8|(y[d+460|0]|y[d+461|0]<<8)!=9|(y[d+447|0]|y[d+446|0])){break Xb}if(y[d+450|0]|y[d+451|0]<<8|((y[d+454|0]|y[d+455|0]<<8)+1|0)!=(y[d+448|0]|y[d+449|0]<<8)|(y[d+464|0]!=128|y[d+465|0]!=100)){break Xb}if(y[d+466|0]!=1|y[d+468|0]!=128|(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8))){break Xb}if(y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24)|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break Xb}x[31721]=0;b=P(1,d+160|0,9860)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}Yb:{if((c|0)!=514|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[d+447|0]|y[d+446|0])){break Yb}if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)){break Yb}b=x[n>>2];if(kc(b,x[n+4>>2])){break Ub}c=x[o>>2];if(kc(c,x[o+4>>2])){break Ub}b=xb(b,0);f=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!f){break Ub}b=xb(c,0);if(f>>>0>=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0){break Ub}x[a+1074308>>2]=16777376;x[31721]=0;b=P(1,d+160|0,13471)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);v[d+415|0]=1;break fb}b=N()|0;break N}if((e&65535)!=532){break Vb}b=y[d+458|0]|y[d+459|0]<<8;if((b|0)!=512){break Wb}e=532;if(y[d+447|0]|y[d+446|0]){break Eb}b=512;if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)){break Db}Zb:{if(y[d+462|0]&6){_b:{c=x[q>>2];if(nc(c,x[q+4>>2])>>>0<2){break _b}b=xb(c,1);e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=xb(c,0);if((e-(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|0)!=557){break _b}x[a+1074308>>2]=16777394;x[31721]=0;c=P(1,d+160|0,15194)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777393;x[31721]=0;c=P(1,d+160|0,13361)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777381;x[31721]=0;c=P(1,d+160|0,14906)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Hb}}yb(j,c);tb(c);v[d+415|0]=1;break fb}e=532;if((b|0)!=532){break Tb}if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))==1229080643){x[31721]=0;b=P(1,d+160|0,8378)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);b=38;break Mb}b=N()|0;break N}if(y[d+469|0]|(y[d+462|0]|y[d+463|0]<<8)>>>0>1|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|((y[d+460|0]|y[d+461|0]<<8)&4294)!=4)){break Ub}if(!z[a+480190>>1]){break Ub}x[31721]=0;e=P(37,d+100|0,13604)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Rb}b=fb-32|0;fb=b;c=fb-16|0;fb=c;Ew(c+8|0,a+484527|0);WY(b+24|0,x[c+8>>2],x[c+12>>2]);fb=c+16|0;ve(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Nc(x[b+24>>2],x[b+28>>2],b+8|0);fb=b+32|0;tb(e);if(c){break Sb}e=y[d+456|0]|y[d+457|0]<<8}if(e&65535){break Ub}if(zd(x[j+4>>2],y[j+11|0])){break Pb}}b=y[d+458|0]|y[d+459|0]<<8}if((b&65535)>>>0>767){break fb}break Db}x[31721]=0;b=P(1,d+160|0,8404)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Qb}yb(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}x[31721]=0;b=P(1,d+160|0,9750)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}c=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);x[31721]=0;S(446,d+160|0,b|0,y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24));e=x[31721];x[31721]=0;$b:{ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){e=d+160|0;yb(j,e);tb(e);c=(b|0)==8191?c:b-4176|0;if((c|0)>1915){break hc}b=x[a+480208>>2];if(!(b&16)){break gc}x[31721]=0;P(270,a+1074312|0,7)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break fc}break Fb}b=N()|0;break N}if(c>>>0>4200){break dc}b=x[a+480208>>2]}if(!(b&16)){x[31721]=0;P(270,a+1074312|0,7)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fb}}if((c|0)>2385){break ec}}x[31721]=0;P(270,a+1074312|0,38)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fb}}x[31721]=0;b=P(270,a+1074312|0,102)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fb}x[31721]=0;P(270,b|0,48)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fb}break cc}if(c>>>0>4383){break bc}}x[31721]=0;b=U(269,a+1074312|0,116,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fb}x[31721]=0;P(270,b|0,115)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fb}break ac}if(c>>>0>4563){break $b}}x[31721]=0;b=P(270,a+1074312|0,43)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fb}x[31721]=0;b=P(270,b|0,42)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fb}x[31721]=0;P(270,b|0,87)|0;c=x[31721];x[31721]=0;b=120;if((c|0)==1){break Fb}break Mb}b=120;if(c>>>0>4876){break fb}}x[31721]=0;P(270,a+1074312|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fb}break fb}x[31721]=0;W(447,d+100|0);b=x[31721];x[31721]=0;ic:{jc:{kc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+64>>2]=b>>>8&15;x[31721]=0;x[d+52>>2]=b&255;O(448,d+76|0,d+52|0);b=x[31721];x[31721]=0;if((b|0)==1){break kc}x[31721]=0;V(434,d+160|0,d+100|0,d- -64|0,d+76|0);b=x[31721];x[31721]=0;if((b|0)==1){break jc}b=d+160|0;yb(j,b);tb(b);tb(d+76|0);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;break ic}b=N()|0;tb(d+76|0)}Eb(d+100|0);break N}x[31721]=0;b=P(1,d+160|0,8340)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}if(!((b|0)!=32767|(y[d+458|0]|y[d+459|0]<<8)!=533)){x[31721]=0;b=P(1,d+160|0,5042)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}x[31721]=0;O(134,d+100|0,4150);b=x[31721];x[31721]=0;lc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+76>>2]=b>>>8&15;x[d+64>>2]=b>>>4&15;x[31721]=0;x[d+52>>2]=b&15;aa(135,d+160|0,d+100|0,d+76|0,d- -64|0,d+52|0);b=x[31721];x[31721]=0;if((b|0)==1){break lc}b=d+160|0;yb(j,b);tb(b);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;Eb(d+100|0);break N}x[31721]=0;b=P(1,d+160|0,6123)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Gb}yb(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=512}if(!zd(x[j+4>>2],y[j+11|0])){break fb}mc:{nc:{oc:{pc:{qc:{if((b&65535)>>>0>=533){x[31721]=0;b=P(1,d+76|0,14938)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(j,b);tb(b);break qc}b=N()|0;break N}if((e&65535)>>>0>=533){x[31721]=0;O(449,d+76|0,4015);b=x[31721];x[31721]=0;rc:{if((b|0)!=1){x[31721]=0;x[d+64>>2]=(y[d+456|0]|y[d+457|0]<<8)-532;S(450,d+160|0,d+76|0,d- -64|0);b=x[31721];x[31721]=0;if((b|0)==1){break rc}b=d+160|0;yb(j,b);tb(b);Eb(d+76|0);break qc}b=N()|0;break N}b=N()|0;Eb(d+76|0);break N}x[31721]=0;O(271,d+76|0,4314);b=x[31721];x[31721]=0;if((b|0)==1){break pc}b=y[d+456|0]|y[d+457|0]<<8;x[d+52>>2]=b>>>8&15;x[31721]=0;x[d+40>>2]=b&255;O(448,d- -64|0,d+40|0);b=x[31721];x[31721]=0;if((b|0)==1){break oc}x[31721]=0;V(434,d+160|0,d+76|0,d+52|0,d- -64|0);b=x[31721];x[31721]=0;if((b|0)==1){break nc}b=d+160|0;yb(j,b);tb(b);tb(d- -64|0);Eb(d+76|0)}b=a+1298412|0;if(!kc(x[b>>2],x[a+1298416>>2])){break fb}c=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);if(!c){break fb}c=nF(y[d+456|0]|y[d+457|0]<<8,c);e=cp(d+160|0);x[e+32>>2]=c;x[31721]=0;O(451,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break mc}b=N()|0;tb(d- -64|0)}Eb(d+76|0);break N}if(!((e|0)!=18284544|I|G|H)){break hb}break gb}if(((y[d+456|0]|y[d+457|0]<<8)&61440)!=20480){break gb}}x[31721]=0;c=P(1,d+160|0,16886)|0;e=x[31721];x[31721]=0;sc:{if((e|0)!=1){x[31721]=0;P(77,b|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break sc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!BG(e)){break fb}x[31721]=0;c=P(1,d+160|0,17122)|0;e=x[31721];x[31721]=0;tc:{if((e|0)!=1){x[31721]=0;P(77,b|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break tc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(L&1){x[31721]=0;c=P(1,d- -64|0,17136)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Cc}x[31721]=0;P(77,j|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Bc}tb(c)}e=x[a+480180>>2];if(!((e|0)!=16777216|(y[d+456|0]|y[d+457|0]<<8)>>>0<2186)){x[31721]=0;b=P(152,g|0,B|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break _a}if(b){x[31721]=0;S(452,a|0,g|0,y[d+456|0]|y[d+457|0]<<8);b=x[31721];x[31721]=0;if((b|0)==1){break _a}}e=x[a+480180>>2]}if((e|0)!=16777216){break Ac}x[31721]=0;P(1,d+52|0,13852)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break zc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31721]=0;O(271,d+40|0,4314);b=x[31721];x[31721]=0;if((b|0)==1){break yc}b=y[d+458|0]|y[d+459|0]<<8;x[d+36>>2]=b>>>8;x[31721]=0;x[d+20>>2]=b&255;O(448,d+24|0,d+20|0);b=x[31721];x[31721]=0;if((b|0)==1){break xc}x[31721]=0;V(434,d+52|0,d+40|0,d+36|0,d+24|0);b=x[31721];x[31721]=0;if((b|0)==1){break wc}}b=d+52|0;yb(a+1298344|0,b);tb(b);if((e|0)!=16777216){tb(d+24|0);Eb(d+40|0)}b=x[a+480180>>2];x[31721]=0;b=P(1,d+52|0,((b|0)==16777216?10124:6127)|0)|0;c=x[31721];x[31721]=0;e=1;if((c|0)==1){break uc}yb(a+1298356|0,b);tb(b);yb(a+1298368|0,j);T=a+1298404|0,X=x[Ec(d+36|0,x[a+1074308>>2]?22:4)>>2],x[T>>2]=X;x[a+1298408>>2]=0;ub(E);ub(C);break s}b=N()|0;break N}b=N()|0;break vc}b=N()|0;tb(d+24|0)}Eb(d+40|0);break N}b=N()|0;break N}b=N()|0;tb(d+76|0);break cb}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Ok(l);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}cc(m);break Ia}b=N()|0;break Ia}b=N()|0}ub(k);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(f);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(d+160|0);break xa}b=N()|0}Eb(d+100|0);break N}b=N()|0;break N}b=N()|0;break N}b=0;f=dD(d+100|0,x[i>>2]);x[31721]=0;P(186,g|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break _}}f=y[d+103|0];if(!x[i>>2]|(f|0)!=1){break ba}u=1;break aa}L=(f|0)==10|L}x[d+100>>2]=x[g+8>>2];T=d,X=x[$c(d+240|0,d+100|0)>>2],x[T+240>>2]=X;t=(b|0)!=0}e=e+1|0;b=z[m>>1];continue}break}b=N()|0;break N}Dc:{b=xb(x[q>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);Ec:{if(!b){break Ec}x[31721]=0;b=P(152,g|0,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Dc}if(!b){break Ec}b=x[g+8>>2];h=x[g>>2];x[31721]=0;b=U(153,h|0,b|0,554)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Dc}if(!b){break Ec}x[31721]=0;b=U(254,a|0,e+1&65535,0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Z}if(!b){break Ec}x[31721]=0;V(453,a|0,g|0,b|0,y[d+458|0]|y[d+459|0]<<8);h=x[31721];x[31721]=0;if((h|0)==1){break Z}v[b+33|0]=y[d+469|0]}e=e+1|0;b=z[f>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(E)}ub(C);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}sc(n);sc(o);sc(q);break a}sc(n);sc(o);sc(q)}tb(j)}fb=d+608|0;return e|0}b=N()|0}tb(j);Q(b|0);p()}function zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0;d=fb-1712|0;fb=d;vc(b);a:{if(!yi(b,d+1704|0)){break a}if(!eY(d+1704|0)){break a}if(!c){i=1;break a}j=y[d+1707|0];v[d+1703|0]=j;x[d+1696>>2]=-1;x[d+1692>>2]=1048576;if(j>>>0>=5){f=Mg(b);x[d+1696>>2]=f;if(!Mb(x[b>>2],x[b+8>>2],f)){break a}x[d+288>>2]=134217727;T=d,X=x[Gb(d+288|0,d+1696|0)>>2]<<5,x[T+1692>>2]=X}C=Nb(d+1680|0);x[d+288>>2]=y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24);f=x[Gb(d+1692|0,d+288|0)>>2];x[31721]=0;O(556,C|0,f|0);f=x[31721];x[31721]=0;b:{c:{d:{e:{f:{if((f|0)!=1){x[31721]=0;f=U(557,b|0,C|0,y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24))|0;e=x[31721];x[31721]=0;g:{if((e|0)==1){break g}if(!f){break b}if(j>>>0>=5){x[31721]=0;P(152,b|0,x[d+1696>>2]+12|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break g}}x[31721]=0;O(249,a|0,0);f=x[31721];x[31721]=0;if((f|0)==1){break g}bg(a);le(d+1648|0,x[C>>2],x[C+4>>2]);f=Jd(d+1640|0);x[31721]=0;e=x[f+4>>2];x[d+88>>2]=x[f>>2];x[d+92>>2]=e;m=eg(558,d+1660|0,x[d+1648>>2],x[d+1652>>2],d+88|0);f=x[31721];x[31721]=0;h:{i:{j:{if((f|0)!=1){x[31721]=0;S(361,m|0,a+1298308|0,-1);f=x[31721];x[31721]=0;if((f|0)==1){break j}x[31721]=0;S(361,m|0,a+1298332|0,-1);f=x[31721];x[31721]=0;if((f|0)==1){break j}x[31721]=0;f=P(559,m|0,d+1218|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}if(!f){break c}f=v[d+1218|0];if((f|0)<=0|(y[d+1227|0]|y[d+1228|0]<<8)>>>0>255|(y[d+1229|0]|y[d+1230|0]<<8)>>>0>3999){break c}E=a+480188|0;w[E>>1]=f&255;Ze(Wb(x[a+484360>>2],y[a+484376|0]),y[d+1221|0]|y[d+1222|0]<<8);w[a+480192>>1]=y[d+1227|0]|y[d+1228|0]<<8;w[a+480190>>1]=y[d+1229|0]|y[d+1230|0]<<8;f=y[d+1231|0];x[a+480196>>2]=f?f:6;f=y[d+1232|0];x[a+480204>>2]=D(f?f:125,1e4);e=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);f=32;k:{if(e&256){break k}f=2;if(e&2){break k}f=1;if(e&128){break k}f=e&8?16:4}x[31721]=0;O(421,a|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break f}g=x[a+480208>>2];e=g|16777216;x[a+480208>>2]=e;f=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);if(f&1){e=g|16777232;x[a+480208>>2]=e}g=x[a+480180>>2];k=(g|0)==32;h=k&!(f&1024);l=(g|0)==2;i=l&f>>>4;s=f&2097152;l=l&f>>>2;k=k&!(f&2048);if(h|(s|l|(k|i))){e=i?e|65536:e;e=l?e|2:e;e=k?e|4:e;x[a+480208>>2]=s>>>6|(h?e|8:e)}if(f&524288){x[31721]=0;U(269,a+1074312|0,5,1)|0;f=x[31721];x[31721]=0;if((f|0)==1){break f}g=x[a+480180>>2]}if((g|0)==2){break i}if((g|0)!=32){break h}v[d+288|0]=y[d+1237|0];v[d+220|0]=128;T=a,X=y[Sb(d+288|0,d+220|0)|0]<<1,x[T+480200>>2]=X;break h}h=N()|0;break d}h=N()|0;break e}v[d+288|0]=y[d+1237|0];v[d+220|0]=64;T=a,X=y[Sb(d+288|0,d+220|0)|0]<<2,x[T+480200>>2]=X}f=v[d+1239|0];l:{if((f|0)<0){f=f+52|0;break l}G=Rs(+(f|0)*3.1/20);m:{if(G<4294967296&G>=0){f=~~G>>>0;break m}f=0}f=f+51|0}x[a+480228>>2]=f;w[d+288>>1]=64;h=z[Lc(E,d+288|0)>>1];e=0;k=(g|0)!=32;l=(g|0)==4;i=0;while(1)if((h|0)==(i|0)){i=0;k=0;while(1){if((e|0)!=16){k=y[(d+e|0)+1368|0]!=0|k;e=e+1|0;continue}break}while(1){if((i|0)!=128){k=y[((i<<1)+d|0)+1385|0]!=0|k;i=i+1|0;continue}break}n:{if(!(k&1)){break n}f=a+901692|0;i=0;while(1){if((i|0)==16){f=a+902204|0;i=0;while(1){if((i|0)!=128){e=(d+1218|0)+(i<<1)|0;o:{if(y[e+167|0]){x[31721]=0;W(560,d+220|0);g=x[31721];x[31721]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=y[e+167|0];x[31721]=0;x[d+244>>2]=g-1;O(561,d+1164|0,d+244|0);g=x[31721];x[31721]=0;if((g|0)==1){break t}e=y[e+166|0];x[31721]=0;v[d+192|0]=e;O(562,d+1144|0,d+192|0);e=x[31721];x[31721]=0;if((e|0)==1){break s}x[31721]=0;V(563,d+288|0,d+220|0,d+1164|0,d+1144|0);e=x[31721];x[31721]=0;if((e|0)==1){break r}e=d+288|0;ve(d+1192|0,e);pf(Me(f,i),x[d+1192>>2],x[d+1196>>2]);tb(e);tb(d+1144|0);tb(d+1164|0);Eb(d+220|0);break o}h=N()|0;break e}h=N()|0;break p}h=N()|0;break q}h=N()|0;tb(d+1144|0)}tb(d+1164|0)}Eb(d+220|0);break e}e=oc(d+1184|0,22250);pf(Me(f,i),x[e>>2],x[d+1188>>2])}i=i+1|0;continue}break}g=x[a+480180>>2];break n}e=(d+i|0)+1368|0;u:{if(y[e|0]){x[31721]=0;W(564,d+220|0);g=x[31721];x[31721]=0;v:{w:{x:{if((g|0)!=1){e=y[e|0];x[31721]=0;x[d+1144>>2]=e-1;O(561,d+1164|0,d+1144|0);e=x[31721];x[31721]=0;if((e|0)==1){break x}x[31721]=0;S(293,d+288|0,d+220|0,d+1164|0);e=x[31721];x[31721]=0;if((e|0)==1){break w}e=d+288|0;ve(d+1208|0,e);pf(Me(f,i),x[d+1208>>2],x[d+1212>>2]);tb(e);tb(d+1164|0);Eb(d+220|0);break u}h=N()|0;break e}h=N()|0;break v}h=N()|0;tb(d+1164|0)}Eb(d+220|0);break e}e=oc(d+1200|0,22250);pf(Me(f,i),x[e>>2],x[d+1204>>2])}i=i+1|0;continue}}f=y[a+484376|0];e=x[a+484360>>2];x[31721]=0;e=Wb(e,f);f=g&5;aa(351,e|0,m|0,y[d+1219|0]|y[d+1220|0]<<8,(f?65535:255)|0,(f?65535:254)|0);f=x[31721];x[31721]=0;if((f|0)!=1){x[31721]=0;S(188,d+288|0,m|0,D(y[d+1218|0],y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31721];x[31721]=0;if((f|0)!=1){f=d+288|0;H=hc(d+1164|0,f);ub(f);x[31721]=0;S(188,f|0,m|0,(y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31721];x[31721]=0;y:{if((f|0)!=1){f=d+288|0;I=hc(d+1144|0,f);ub(f);x[31721]=0;s=P(217,d+1132|0,y[d+1225|0]|y[d+1226|0]<<8)|0;f=x[31721];x[31721]=0;z:{if((f|0)!=1){T=d,X=wb(x[s>>2]),x[T+244>>2]=X;f=wb(x[s+4>>2]);A:{B:{C:{while(1){e=x[d+244>>2];if(!Ib(e,f)){q=a+480180|0;f=x[q>>2];r=c&1;if(!r){break B}x[31721]=0;O(226,a+484344|0,y[d+1223|0]|y[d+1224|0]<<8);e=x[31721];x[31721]=0;if((e|0)!=1){break B}h=N()|0;break A}x[31721]=0;g=R(154,m|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;S(188,d+220|0,m|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break C}h=e;e=d+220|0;g=hc(d+288|0,e);gd(h,g);ub(g);ub(e);Yf(d+244|0);continue}break}h=N()|0;break A}h=N()|0;break A}t=(f|0)==16?14:(f|0)==32?1:13;J=a+484344|0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1223|0]|y[d+1224|0]<<8)>>>0<=n>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[31721]=0;f=R(192,I|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break H}x[d+220>>2]=f;if(!r){break D}x[31721]=0;f=U(199,J|0,n&65535,f|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break H}u=0;if(!f){break D}while(1){g=u&65535;if(g>>>0>=y[d+1218|0]){break D}x[31721]=0;f=R(192,H|0)|0;e=x[31721];x[31721]=0;J:{if((e|0)!=1){e=x[s>>2];if(Mf(e,x[s+4>>2])>>>0<=f>>>0){break J}o=$g(e,f);vc(o);e=0;f=Vb(x[J>>2],n);i=jd(x[f>>2],x[x[f+48>>2]+12>>2],0,g);K:while(1){if(A[d+220>>2]<=e>>>0){break J}x[31721]=0;f=R(200,o|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){if(!f){break J}B=f>>>4|0;K=f&15;k=0;g=Ig(d+288|0);while(1){L:{M:{N:{if(K>>>0>(k&255)>>>0){x[31721]=0;O(201,d+244|0,o|0);f=x[31721];x[31721]=0;if((f|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{f=y[vb(d+244|0,0)|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(f-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}f=y[vb(d+244|0,1)|0];fa:{if(f>>>0<=119){f=f+t|0;break fa}ga:{switch(f-254|0){case 1:f=255;break fa;case 0:f=254;break fa;default:break ga}}f=253}v[g|0]=f;l=sD(f)&l;break L}T=d,X=y[vb(d+244|0,1)|0]+1|0,v[T+289|0]=X;break L}ha:{if(y[d+290|0]){break ha}f=x[q>>2];if((f|0)!=32){if((f|0)!=4){break ha}f=y[vb(d+244|0,1)|0];if(f&15){break ha}v[d+290|0]=11;v[d+292|0]=f>>>4;break L}f=y[vb(d+244|0,1)|0];h=0;while(1){if((h|0)==10){break ha}if((f|0)==y[h+42192|0]){v[d+292|0]=h;v[d+290|0]=11;break L}else{h=h+1|0;continue}}}T=d,X=y[vb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=4;break L}f=vb(d+244|0,1);ia:{if(y[d+290|0]){break ia}h=y[f|0];if(x[q>>2]!=32|h>>>0>9){break ia}v[d+292|0]=h;v[d+290|0]=8;break L}v[d+293|0]=y[f|0];v[d+291|0]=5;break L}ja:{if(y[d+290|0]){break ja}ka:{f=x[q>>2];if((f|0)!=4){if((f|0)!=32){break ja}h=vb(d+244|0,1);f=y[h|0];if((f|0)!=255){break ka}v[d+292|0]=64;v[d+290|0]=2;break L}h=vb(d+244|0,1);if(y[h|0]&15){break ja}break M}if(!(f&3)){break M}}T=d,X=y[vb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=9;break L}h=y[d+290|0];f=vb(d+244|0,1);la:{if(h|x[q>>2]==1){break la}h=y[f|0];if(h>>>0>64){break la}v[d+292|0]=h;v[d+290|0]=1;break L}v[d+293|0]=y[f|0];v[d+291|0]=13;break L}f=y[vb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=14;if(x[q>>2]==32){break L}v[d+293|0]=D((f&240)>>>4|0,10)+(f&15);break L}f=y[vb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=f>>>0<32?16:17;break L}h=y[vb(d+244|0,1)|0];if(h>>>0>=16){v[d+292|0]=h>>>4;v[d+290|0]=(f|0)==20?3:5;break L}v[d+292|0]=h&15;v[d+290|0]=(f|0)==20?4:6;break L}f=y[vb(d+244|0,1)|0];if(f>>>0>=16){v[d+290|0]=10;v[d+292|0]=f>>>4;break L}v[d+290|0]=9;v[d+292|0]=f&15;break L}f=y[vb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|16;break L}f=y[vb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|32;break L}T=d,X=y[vb(d+244|0,1)|0],v[T+292|0]=X;v[d+290|0]=(f|0)==31?7:8;break L}f=y[d+291|0];v[d+291|0]=(f|0)==4?6:(f|0)==5?7:11;T=d,X=y[vb(d+244|0,1)|0],v[T+293|0]=X;break L}f=vb(d+244|0,1);v[d+292|0]=y[f|0]%10;f=y[f|0];if(f>>>0<=9){v[d+290|0]=5;break L}if(f>>>0<=19){v[d+290|0]=6;break L}if(f>>>0<=29){v[d+290|0]=3;break L}if(f>>>0>39){break L}v[d+290|0]=4;break L}T=d,X=y[vb(d+244|0,1)|0],v[T+292|0]=X;v[d+290|0]=(f|0)==49?13:12;break L}f=y[vb(d+244|0,1)|0]+33|0;if((f&255)>>>0>9){break L}v[d+290|0]=15;v[d+292|0]=f;break L}if(f>>>0>57){break L}T=d,X=y[vb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=y[f+25168|0];break L}x[d+244>>2]=e+B;f=x[Gb(d+244|0,d+220|0)>>2];f=e>>>0>f>>>0?e:f;while(1){if((e|0)!=(f|0)){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[i|0]=h;v[i+1|0]=h>>>8;v[i+2|0]=h>>>16;v[i+3|0]=h>>>24;h=y[g+4|0]|y[g+5|0]<<8;v[i+4|0]=h;v[i+5|0]=h>>>8;e=e+1|0;i=D(y[d+1218|0],6)+i|0;continue}break}e=f;continue K}h=N()|0;break A}f=y[h|0];v[d+290|0]=2;v[d+292|0]=f>>>2}k=k+1|0;continue}}break}h=N()|0;break A}h=N()|0;break A}u=u+1|0;continue}}i=z[a+480192>>1];f=0;break E}h=N()|0;break A}if(!(z[E>>1]==4&l)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}i=0;f=!((y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24))&512)}x[31721]=0;u=P(565,d+1120|0,i|0)|0;e=x[31721];x[31721]=0;ma:{na:{oa:{pa:{qa:{if((e|0)!=1){q=a+480192|0;i=j>>>0<5;l=a+480180|0;k=1;ra:{while(1){h=k&65535;if(h>>>0>z[q>>1]){break ra}sa:{ta:{ua:{va:{if(!f){x[31721]=0;g=U(254,a|0,h|0,0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break va}if(g){break ua}}while(1){x[31721]=0;e=R(200,m|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break na}if(e){continue}break}if(!i){while(1){x[31721]=0;e=R(200,m|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){h=N()|0;break ma}if(e){continue}break}}x[31721]=0;P(186,m|0,826)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break ta}}h=N()|0;break ma}e=Fb(d+220|0);x[31721]=0;S(361,m|0,e|0,-1);n=x[31721];x[31721]=0;if((n|0)==1){break sa}xc(g+492|0,e);if(!i){x[31721]=0;S(361,m|0,e|0,-1);n=x[31721];x[31721]=0;if((n|0)==1){break sa}xc(g+524|0,e)}x[31721]=0;n=P(566,m|0,d+288|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break oa}if(!n){break qa}n=x[l>>2];x[31721]=0;S(567,d+288|0,g|0,n|0);g=x[31721];x[31721]=0;if((g|0)==1){break oa}if(x[l>>2]==4){g=xb(x[u>>2],h-1|0);h=y[d+1090|0]|y[d+1091|0]<<8|(y[d+1092|0]<<16|y[d+1093|0]<<24);v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24}tb(e)}k=k+1|0;continue}break}break oa}if(!f){break pa}w[a+480192>>1]=0;break pa}h=N()|0;break A}tb(e)}f=z[a+480190>>1];x[31721]=0;q=P(568,d+276|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){B=y[d+1703|0];K=!(v[d+1233|0]&1)|B>>>0>4;o=c&2;M=a+480180|0;k=1;c=0;while(1){f=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{l=k&65535;if(l>>>0<=z[a+480190>>1]){i=Fb(d+264|0);x[31721]=0;S(361,m|0,i|0,-1);c=x[31721];x[31721]=0;Ra:{Sa:{if((c|0)!=1){xc(((l<<5)+a|0)+946304|0,i);c=B>>>0<5;if(c){break Sa}x[31721]=0;S(361,m|0,i|0,-1);e=x[31721];x[31721]=0;if((e|0)!=1){break Ra}}h=N()|0;break za}qf(i)}x[31721]=0;e=P(569,m|0,d+288|0)|0;g=x[31721];x[31721]=0;Ta:{Ua:{if((g|0)==1){break Ua}if(!e){break Ta}g=x[M>>2];x[31721]=0;h=D(l,104)+a|0;e=h+484380|0;V(570,d+288|0,e|0,g|0,K|0);g=x[31721];x[31721]=0;if((g|0)==1){break Ua}ye(h+484423|0,i);r=0;Va:{if(((y[d+308|0]|y[d+309|0]<<8)&61440)!=28672|c){break Va}x[31721]=0;r=R(571,m|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break Va}h=N()|0;break za}if(!o){break xa}g=y[d+323|0]|y[d+324|0]<<8|(y[d+325|0]<<16|y[d+326|0]<<24);c=y[d+308|0]|y[d+309|0]<<8;n=c&61440;if(!(g|n)){c=Wc(d+220|0,c&1?16:8,c&1024?3:1,0,0);x[31721]=0;U(218,c|0,e|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break xa}h=N()|0;break za}if((g|0)<0){c=g+l|0;if((c|0)<=0){break xa}dY(e,(D(c,104)+a|0)+484380|0);break xa}if((g|0)<=0){break xa}if(c&1){j=h+484414|0;w[j>>1]=z[j>>1]|1}if(c&1024){j=h+484414|0;w[j>>1]=z[j>>1]|64}x[31721]=0;S(188,d+220|0,b|0,g|0);g=x[31721];x[31721]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((g|0)!=1){j=d+220|0;g=hc(d+244|0,j);ub(j);j=Yd(z[e+34>>1]);L=(n|0)==16384;if(!L&(n|0)!=8192){break Za}t=x[g>>2];x[31721]=0;t=R(157,t|0)|0;F=x[31721];x[31721]=0;if((F|0)==1){break Wa}F=4/(j>>>0)|0;zua(F,0,t,0);uc(e,hb?-1:D(F,t));if((n|0)==8192){break $a}if(!L){break Za}if(!Bh(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(!(v[d+308|0]&1)){break _a}x[31721]=0;V(572,g|0,c|0,e|0,j|0);e=x[31721];x[31721]=0;c=f;if((e|0)==1){break Ba}break Xa}h=N()|0;break za}if(!Bh(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(v[d+308|0]&1){x[31721]=0;V(573,g|0,c|0,e|0,j|0);e=x[31721];x[31721]=0;c=f;if((e|0)!=1){break Xa}break Ba}x[31721]=0;V(574,g|0,c|0,e|0,j|0);e=x[31721];x[31721]=0;c=f;if((e|0)==1){break Ba}break Xa}x[31721]=0;V(575,g|0,c|0,e|0,j|0);e=x[31721];x[31721]=0;c=f;if((e|0)==1){break Ba}break Xa}if((c&45056)==12288){c=bY(d+220|0,g,y[d+327|0]|y[d+328|0]<<8,r);T=gd(sf(x[q>>2],l-1|0),c),X=x[c+20>>2],x[T+20>>2]=X;ub(c);break Ya}if((n|0)!=32768){c=1;if((n|0)!=4096){break Xa}n=Fe(d+220|0,g);x[31721]=0;c=P(576,d+214|0,g|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){ab:{bb:{if(!y[d+219|0]){break bb}r=y[d+327|0]|y[d+328|0]<<8;j=z[d+216>>1]<<1;if(r>>>0<(j&65535)>>>0){break bb}j=r-j|0;v[d+327|0]=j;v[d+328|0]=j>>>8;c=z[c>>1];x[31721]=0;P(152,g|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ab}x[31721]=0;c=R(205,g|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break ab}x[31721]=0;S(188,d+172|0,g|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break ab}c=d+172|0;j=hc(d+192|0,c);gd(n,j);ub(j);ub(c)}x[31721]=0;l=U(577,a|0,l|0,n|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ab}c=1;if(l){c=y[d+327|0]|y[d+328|0]<<8;cb:{if(!c){break cb}l=z[e+34>>1];j=Sk(x[e>>2],l);if(j>>>0<=c>>>0){break cb}l=bl(l);h=x[h+484400>>2];$h(h,c+h|0,j-c|0);x[e>>2]=x[e>>2]-((c>>>0)/(l>>>0)|0)}uc(e,y[d+296|0]|y[d+297|0]<<8|(y[d+298|0]<<16|y[d+299|0]<<24));c=f}ub(n);break Xa}}h=N()|0;ub(n);break Aa}x[31721]=0;c=P(432,g|0,d+220|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=y[d+228|0]|y[d+229|0]<<8|(y[d+230|0]<<16|y[d+231|0]<<24);c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);x[d+72>>2]=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);x[d+76>>2]=c;Yk(e,1,d+72|0)}c=f}ub(g);break wa}h=N()|0;break Aa}h=N()|0;break za}tb(i)}db:{if(!o){break db}l=1;while(1){c=l&65535;if(c>>>0>z[a+480190>>1]){break db}b=sf(x[q>>2],c-1|0);e=x[b>>2];x[31721]=0;e=R(175,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Pa}eb:{fb:{if(!e){break fb}e=c+w[b+22>>1]|0;e=((e|0)>0?e:l)&65535;k=z[b+20>>1];i=(e|0)!=(c|0)&(e|0)!=0&e>>>0<=z[a+480190>>1]&(k|0)!=0;gb:{if(i){e=sf(x[q>>2],e-1|0);break gb}e=x[b>>2];x[31721]=0;k=R(157,e|0)|0;g=x[31721];x[31721]=0;e=b;if((g|0)==1){break Oa}}vc(e);hb:{if(i){g=x[e+8>>2];h=x[e>>2];n=z[b+20>>1];x[31721]=0;g=U(153,h|0,g|0,n|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Oa}if(!g){break fb}x[d+220>>2]=0;x[d+244>>2]=0;x[31721]=0;S(189,d+288|0,e|0,k|0);g=x[31721];x[31721]=0;ib:{if((g|0)!=1){g=IC(Se(d+288|0),qh(x[d+288>>2]),d+220|0,d+244|0);x[31721]=0;P(186,e|0,x[d+220>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break ib}Ic(d+288|0);break hb}h=N()|0;break ya}h=N()|0;Ic(d+288|0);break ya}g=0;x[d+220>>2]=0;x[d+244>>2]=0}x[31721]=0;O(578,d+288|0,b|0);e=x[31721];x[31721]=0;jb:{kb:{if((e|0)!=1){h=Se(d+288|0);k=x[d+288>>2];if(!i){g=IC(h,qh(k),d+220|0,d+244|0);x[31721]=0;e=x[d+220>>2];P(186,b|0,e|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break eb}k=k-e|0;h=e+h|0}if(g){break kb}f=1;break jb}h=N()|0;break ya}c=D(c,104)+a|0;n=c+484380|0;Bh(n);t=c+484400|0;e=0;i=x[d+244>>2];while(1){lb:{if(!k|(i|0)!=1?i:0){break lb}c=x[n>>2];if(c>>>0<=e>>>0){break lb}if(!ge(c,x[n+20>>2])){break lb}x[d+192>>2]=0;x[d+172>>2]=0;j=aY(g,h,qh(k),d+192|0,d+264|0,d+172|0);x[31721]=0;x[d+220>>2]=j;P(186,b|0,j|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ca}xi(d+172|0,qh(x[n>>2]-e|0));c=x[d+172>>2];mb:{if((c|0)<=0){break mb}i=x[d+192>>2];B=z[n+34>>1];if((Yd(B)|0)!=(i|0)){break mb}o=D(e,i);r=x[t>>2];if(B&1){x[d+168>>2]=c;x[d+156>>2]=c;x[d- -64>>2]=c;x[d+48>>2]=c;x[d+152>>2]=i;x[d+148>>2]=x[d+264>>2];x[d+164>>2]=i;x[d+160>>2]=r+(o<<1);x[31721]=0;i=x[d+152>>2];x[d+40>>2]=x[d+148>>2];x[d+44>>2]=i;i=x[d+164>>2];x[d+56>>2]=x[d+160>>2];x[d+60>>2]=i;O(579,d+56|0,d+40|0);i=x[31721];x[31721]=0;if((i|0)!=1){break mb}break Ca}x[d+144>>2]=c;x[d+132>>2]=c;x[d+32>>2]=c;x[d+16>>2]=c;x[d+128>>2]=i;x[d+124>>2]=x[d+264>>2];x[d+140>>2]=i;x[d+136>>2]=o+r;x[31721]=0;i=x[d+128>>2];x[d+8>>2]=x[d+124>>2];x[d+12>>2]=i;i=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=i;O(580,d+24|0,d+8|0);i=x[31721];x[31721]=0;if((i|0)==1){break Ca}}k=k-j|0;h=h+j|0;i=$X(g);x[d+244>>2]=i;e=c+e|0;continue}break}_X(g)}Ic(d+288|0)}l=l+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}i=0;c=a+480192|0;while(1){if(z[c>>1]<=i>>>0){break nb}b=xb(x[u>>2],i);e=y[b+3|0];g=y[b+2|0];h=y[b+1|0];b=y[b|0];x[31721]=0;i=i+1|0;ja(404,a|0,i&65535,b|0,h|0,g|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){continue}break}h=N()|0;break ya}if(!(y[d+1235|0]&16)){break Ka}b=x[m+8>>2];c=x[m>>2];x[31721]=0;b=U(153,c|0,b|0,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ma}if(!b){break Ka}i=0;x[31721]=0;b=R(200,m|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=i>>>0){break La}x[31721]=0;b=R(154,m|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){v[((i<<5)+a|0)+480288|0]=b;i=i+1|0;continue}break}h=N()|0;break ya}h=N()|0;break Aa}h=N()|0;break ya}h=N()|0;break ya}h=N()|0;break ya}h=N()|0;break ya}e=a+906300|0;while(1){b=x[m+8>>2];c=x[m>>2];x[31721]=0;b=U(153,c|0,b|0,1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Da}if(!b){break Ka}x[31721]=0;b=R(200,m|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[31721]=0;c=R(154,m|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ja}x[31721]=0;S(188,d+220|0,m|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break Ja}g=d+220|0;c=hc(d+288|0,g);ub(g);ob:{if(b>>>0<=250){b=sd(e,b-1|0);x[31721]=0;O(454,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break ob}}ub(c);continue}break}h=N()|0;ub(c);break ya}k=a+901404|0;c=Fb(d+192|0);l=a+480180|0;n=a+484348|0;e=0;h=0;while(1){b=x[m+8>>2];g=x[m>>2];x[31721]=0;b=U(153,g|0,b|0,8)|0;g=x[31721];x[31721]=0;pb:{qb:{rb:{sb:{tb:{if((g|0)!=1){if(b){x[31721]=0;g=R(154,m|0)|0;b=x[31721];x[31721]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[31721]=0;b=R(154,m|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break Bb}x[31721]=0;S(188,d+288|0,m|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ab}i=d+288|0;b=hc(d+220|0,i);ub(i);if((g|0)==1229211981){break xb}if((g|0)==1229476432){break yb}if((g|0)==1397900630){break zb}if((g|0)!=1414548815){break pb}x[31721]=0;g=P(416,b|0,13890)|0;i=x[31721];x[31721]=0;if((i|0)==1){break Ha}if(!g){break qb}x[31721]=0;g=R(154,b|0)|0;i=x[31721];x[31721]=0;if((i|0)!=1){x[31721]=0;S(188,d+288|0,b|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){break wb}}h=N()|0;break Ga}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}Cb:{Db:{Eb:{g=x[l>>2];switch(g-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((g|0)==16){break Cb}if((g|0)!=32){break pb}x[31721]=0;e=R(192,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}x[31721]=0;h=R(192,b|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break pb}break Ha}g=Ec(d+120|0,4);x[d+288>>2]=32;i=x[b>>2];x[31721]=0;i=R(157,i|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){x[d+244>>2]=i;g=x[g>>2];i=x[Gb(d+288|0,d+244|0)>>2];x[31721]=0;V(581,b|0,c|0,g|0,i|0);g=x[31721];x[31721]=0;if((g|0)!=1){break pb}}h=N()|0;break Ga}x[31721]=0;g=R(200,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break ub}x[31721]=0;O(582,d+244|0,4211);i=x[31721];x[31721]=0;Fb:{if((i|0)!=1){x[d+264>>2]=g>>>4;x[31721]=0;x[d+104>>2]=g&15;V(310,d+288|0,d+244|0,d+264|0,d+104|0);g=x[31721];x[31721]=0;if((g|0)==1){break Fb}g=d+288|0;yb(c,g);tb(g);Eb(d+244|0);break pb}h=N()|0;break Ga}h=N()|0;Eb(d+244|0);break Ga}x[31721]=0;g=R(200,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break Ha}x[a+480216>>2]=g;x[31721]=0;g=R(200,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break Ha}x[a+480220>>2]=g;break pb}x[31721]=0;P(427,b|0,k|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}hD(k);break pb}i=d+288|0;g=hc(d+244|0,i);ub(i);i=x[g>>2];x[31721]=0;i=R(157,i|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break rb}w[d+288>>1]=i>>>5;T=d,X=aj(x[a+484344>>2],x[n>>2]),w[T+264>>1]=X;j=z[Lc(d+288|0,d+264|0)>>1];i=0;while(1){if((i|0)==(j|0)){ub(g);break qb}x[31721]=0;O(583,g|0,d+288|0);o=x[31721];x[31721]=0;Gb:{if((o|0)==1){break Gb}o=x[J>>2];x[31721]=0;O(584,Vb(o,i)|0,d+288|0);o=x[31721];x[31721]=0;if((o|0)==1){break Gb}i=i+1|0;continue}break}break rb}x[31721]=0;e=R(192,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}break pb}h=N()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}g=e&65535;if(g>>>0<256){break Jb}if(g>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}g=e&65535;if(g>>>0<12544){break Kb}if(g>>>0<12820){break Ib}}if(b){break Hb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}_q(k)}i=1;Lb:{if(!(v[d+1235|0]&1)){break Lb}e=x[a+1074308>>2];if(!e){e=a+480192|0;g=a+480180|0;while(1){b=i&65535;if(b>>>0<=z[e>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){k=x[g>>2];x[31721]=0;O(585,Wh(b,2)|0,k|0);k=x[31721];x[31721]=0;if((k|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}i=i+1|0;continue}break}e=x[a+1074308>>2]}if(e>>>0<=18350079){x[31721]=0;b=P(270,a+1074312|0,27)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Fa}x[31721]=0;P(270,b|0,57)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0<=19070975){x[31721]=0;P(270,a+1074312|0,73)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0>19267583){break Lb}x[31721]=0;P(270,a+1074312|0,50)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(zd(x[c+4>>2],y[c+11|0])){x[31721]=0;W(586,d+220|0);b=x[31721];x[31721]=0;_b:{if((b|0)!=1){x[31721]=0;S(554,d+288|0,d+220|0,d+1703|0);b=x[31721];x[31721]=0;if((b|0)==1){break _b}break Zb}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}x[31721]=0;W(587,d+220|0);b=x[31721];x[31721]=0;if((b|0)==1){break Yb}x[31721]=0;V(588,d+288|0,d+220|0,d+1703|0,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break Xb}}b=d+288|0;yb(c,b);tb(b);b=d+220|0;Eb(b);x[31721]=0;O(553,b|0,3977);b=x[31721];x[31721]=0;if((b|0)==1){break Vb}x[31721]=0;S(554,d+288|0,d+220|0,d+1703|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ub}b=d+288|0;yb(a+1298344|0,b);tb(b);Eb(d+220|0);x[31721]=0;b=P(1,b|0,14986)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Tb}yb(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[31721]=0;b=P(1,d+220|0,10124)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Nb}yb(a+1298392|0,b);tb(b);x[31721]=0;b=P(1,d+244|0,13852)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Mb}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}h=N()|0;break Ea}x[31721]=0;b=P(1,d+220|0,10129)|0;e=x[31721];x[31721]=0;$b:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31721]=0;b=P(1,d+244|0,8365)|0;e=x[31721];x[31721]=0;if((e|0)==1){break $b}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31721]=0;b=P(1,d+220|0,12386)|0;e=x[31721];x[31721]=0;ac:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31721]=0;b=P(1,d+244|0,14243)|0;e=x[31721];x[31721]=0;if((e|0)==1){break ac}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31721]=0;b=P(1,d+220|0,10102)|0;e=x[31721];x[31721]=0;bc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31721]=0;b=P(1,d+244|0,15280)|0;e=x[31721];x[31721]=0;if((e|0)==1){break bc}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31721]=0;b=P(1,d+220|0,10474)|0;e=x[31721];x[31721]=0;cc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31721]=0;b=P(1,d+244|0,15021)|0;e=x[31721];x[31721]=0;if((e|0)==1){break cc}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31721]=0;b=P(1,d+220|0,6127)|0;e=x[31721];x[31721]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);if(!(h&65535)){break dc}x[31721]=0;O(271,d+264|0,4314);b=x[31721];x[31721]=0;if((b|0)==1){break hc}x[d+116>>2]=(h&65280)>>>8;x[31721]=0;x[d+100>>2]=h&255;O(448,d+104|0,d+100|0);b=x[31721];x[31721]=0;if((b|0)==1){break gc}x[31721]=0;V(434,d+244|0,d+264|0,d+116|0,d+104|0);b=x[31721];x[31721]=0;if((b|0)==1){break fc}b=d+244|0;yb(a+1298380|0,b);tb(b);tb(d+104|0);Eb(d+264|0);break sb}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break ec}h=N()|0;tb(d+104|0)}Eb(d+264|0);break Ea}x[31721]=0;b=P(1,d+244|0,8557)|0;e=x[31721];x[31721]=0;if((e|0)!=1){yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}yb(a+1298368|0,c);ic:{if(x[a+1074308>>2]){T=a,X=x[Ec(d+264|0,22)>>2],x[T+1298404>>2]=X;break ic}if(x[a+480180>>2]==1){T=a,X=x[Ec(d+264|0,28)>>2],x[T+1298404>>2]=X;break ic}T=a,X=x[Ec(d+264|0,4)>>2],x[T+1298404>>2]=X}i=1;jc:{kc:{if(f&1){x[31721]=0;b=P(1,d+264|0,16657)|0;f=x[31721];x[31721]=0;if((f|0)==1){break kc}a=x[a+1298472>>2];x[31721]=0;S(389,a|0,2,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break jc}tb(b)}tb(c);ZX(q);sc(u);Pc(s);ub(I);ub(H);break c}h=N()|0;break Ea}h=N()|0;tb(b);break Ea}h=N()|0;ub(g);break Ga}x[31721]=0;g=P(416,b|0,13895)|0;i=x[31721];x[31721]=0;if((i|0)==1){break Ha}lc:{if(!g){break lc}x[31721]=0;g=R(154,b|0)|0;i=x[31721];x[31721]=0;mc:{if((i|0)!=1){x[31721]=0;S(188,d+244|0,b|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){break mc}}h=N()|0;break Ga}i=d+244|0;g=hc(d+288|0,i);ub(i);i=x[g>>2];x[31721]=0;i=R(157,i|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){w[d+244>>1]=(i>>>0)/20;w[d+264>>1]=z[E>>1];j=z[Lc(d+244|0,d+264|0)>>1];i=0;while(1){if((i|0)==(j|0)){ub(g);break lc}x[31721]=0;S(428,g|0,((i<<5)+a|0)+480289|0,20);o=x[31721];x[31721]=0;if((o|0)!=1){i=i+1|0;continue}break}}h=N()|0;ub(g);break Ga}x[31721]=0;P(439,a|0,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}x[31721]=0;ba(440,a|0,b|0,1,0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}if((e-2186&65535)>>>0<=117){x[l>>2]=16777216;x[31721]=0;S(452,a|0,b|0,e&65535);g=x[31721];x[31721]=0;if((g|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[31721]=0;g=P(1,d+172|0,18232)|0;i=x[31721];x[31721]=0;nc:{oc:{pc:{if((i|0)!=1){i=x[a+1074308>>2];x[31721]=0;O(137,d+244|0,i|0);i=x[31721];x[31721]=0;if((i|0)==1){break pc}x[31721]=0;S(2,d+288|0,g|0,d+244|0);i=x[31721];x[31721]=0;if((i|0)==1){break oc}i=d+288|0;yb(c,i);tb(i);tb(d+244|0);tb(g);break pb}h=N()|0;break Ga}h=N()|0;break nc}h=N()|0;tb(d+244|0)}tb(g);break Ga}ub(b);continue}}h=N()|0;break ya}h=N()|0;break ya}h=N()|0}ub(b);break Ea}h=N()|0}tb(c);break ya}h=N()|0;break ya}h=N()|0;Ic(d+288|0);break ya}h=N()|0}ub(g)}tb(i)}ZX(q);break ma}c=f}tb(i);k=k+1|0;continue}}h=N()|0;break ma}h=N()|0;tb(e);break ma}h=N()|0}sc(u);break A}n=n+1|0;continue}}Pc(s);break z}h=N()|0}ub(I);break y}h=N()|0}ub(H);break e}h=N()|0;break e}h=N()|0;break e}else{qc:{rc:{if(!k){v[d+288|0]=y[(d+i|0)+1240|0];v[d+220|0]=64;T=((i<<5)+a|0)+480286|0,X=y[Sb(d+288|0,d+220|0)|0],w[T>>1]=X;break rc}if(l){break qc}}sc:{f=y[(d+i|0)+1304|0];if((f|0)!=255){if((f|0)!=127){break sc}x[((i<<5)+a|0)+480280>>2]=256;break qc}w[((i<<5)+a|0)+480284>>1]=256;break qc}w[((i<<5)+a|0)+480284>>1]=f}i=i+1|0;continue}}h=N()|0;break d}h=N()|0;break d}h=N()|0}ub(m)}cc(C);Q(h|0);p()}ub(m)}cc(C)}fb=d+1712|0;return i|0}function Lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=fb-944|0;fb=e;vc(b);a:{if(!oY(b,e+892|0)){break a}if(!sY(e+892|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(rY(e+892|0),hb))){break a}if(!c){d=1;break a}Ad(a,8);bg(a);f=y[e+895|0]-48|0;v[e+891|0]=f;bd(b,_b(y[e+900|0]|y[e+901|0]<<8|(y[e+902|0]<<16|y[e+903|0]<<24)));g=e+584|0;ce(g,b,504);K=hc(e+868|0,g);ub(g);x[31721]=0;O(527,b|0,g|0);g=x[31721];x[31721]=0;b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(y[e+867|0]>63){break b}if(Cb(z[e+584>>1])<<16>>16<0){break b}Tb(e+504|0,0,80);h:{g=_b(y[e+924|0]|y[e+925|0]<<8|(y[e+926|0]<<16|y[e+927|0]<<24));if(!g){break h}x[31721]=0;g=P(152,b|0,g|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){if(!g){break h}x[31721]=0;O(528,b|0,e+504|0);g=x[31721];x[31721]=0;if((g|0)!=1){break h}}h=N()|0;break e}x[31721]=0;S(529,e+500|0,b|0,f&255);g=x[31721];x[31721]=0;if((g|0)!=1){X=Ye(e+500|0);g=z[e+500>>1];if((g-128&65535)>>>0<65409){break b}w[a+480188>>1]=g;I=Nb(e+488|0);d=_b(y[e+916|0]|y[e+917|0]<<8|(y[e+918|0]<<16|y[e+919|0]<<24));i:{if(d){x[31721]=0;P(152,b|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;S(530,b|0,I|0,y[e+867|0]);d=x[31721];x[31721]=0;if((d|0)==1){break g}i=y[e+867|0];break i}i=y[e+867|0];d=0;if(i){break c}}E=a+480188|0;i=i&255;w[a+480192>>1]=i;w[a+480190>>1]=i;Y=(f&255)>>>0<2|v[e+848|0]>=0;q=!Y;t=c&2;k=1;n=1;while(1){j:{k:{l:{m:{n:{o:{d=n&65535;if(d>>>0<=(i&65535)>>>0){x[31721]=0;u=k&65535;g=U(254,a|0,d|0,u|0)|0;f=x[31721];x[31721]=0;p:{if((f|0)!=1){if(g){break p}break d}h=N()|0;break f}g=x[((d<<2)+a|0)+900380>>2];w[e+92>>1]=0;x[e+88>>2]=0;x[31721]=0;j=R(171,e+468|0)|0;f=x[31721];x[31721]=0;q:{if((f|0)!=1){d=xb(x[I>>2],d-1|0);d=_b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31721]=0;d=P(152,b|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}if(!d){break r}x[31721]=0;O(531,b|0,e+88|0);d=x[31721];x[31721]=0;if((d|0)==1){break k}d=x[e+88>>2];f=w[e+92>>1];x[31721]=0;h=_b(d);d=we(f);S(188,e+128|0,b|0,h<<(d>>>5&1&(d|0)>0));d=x[31721];x[31721]=0;if((d|0)==1){break k}d=e+128|0;f=hc(e+188|0,d);gd(j,f);ub(f);ub(d)}i=we(w[e+92>>1]);d=i&15;if((i|0)>=0){break q}xv(g,0);$=1;break o}h=N()|0;break f}if(d>>>0>6){break o}l=y[d+25046|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+l|0)-1;A=g+108|0;m=g+236|0;r=l-2|0;h=4;s:while(1){f=1;if((h|0)==10){break n}f=D(h,12);d=(r<<3)+h|0;o=y[d+25052|0]+k|0;s=y[d+25100|0];d=0;while(1)if((d|0)==12){h=h+1|0;continue s}else{B=d+f|0;ia=Zb(m,B),ja=o,w[ia>>1]=ja;B=vb(A,B);v[B|0]=s+y[B|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{d=_b(x[e+508>>2]);if(!d){break G}if(!Cb(z[e+512>>1])){break G}x[31721]=0;d=P(152,b|0,d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break F}if(!d){break G}ia=e,ja=Cb(z[e+512>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];l=z[Lc(e+188|0,e+128|0)>>1];d=e+136|0;n=e+132|0;f=Cb(z[e+514>>1]);m=f>>>0<5;u=f>>>0<19;r=f>>>0<21;q=f>>>0<15;t=f>>>0<6;i=0;while(1){if((i|0)==(l|0)){break G}x[31721]=0;S(532,b|0,e+188|0,f|0);g=x[31721];x[31721]=0;H:{I:{J:{if((g|0)!=1){i=i+1|0;g=x[((i<<2)+a|0)+900380>>2];j=y[e+188|0];if(j){k=_l(e+128|0,0,64);_l(n,j-1&65535,64);h=y[e+189|0];if(h){h=64/(h>>>0)|0}else{h=0}_l(d,h+j|0,0);x[31721]=0;j=g+48|0;S(533,j|0,k|0,3);h=x[31721];x[31721]=0;if((h|0)==1){break J}if(y[e+188|0]==1){k=x[zb(e+464|0,wb(x[j>>2]))>>2];h=fb-16|0;fb=h;A=wb(x[j>>2]);k=x[j>>2]+(vv(k,A)<<2)|0;Xh(j,Nv(k+4|0,x[j+4>>2],k));zb(h+12|0,k);fb=h+16|0}j=y[e+189|0];x[g>>2]=j?j<<9:32767;v[g+60|0]=y[g+60|0]|1;A=1}K:{if(m){break K}j=y[e+192|0];if(j){ia=vb(g+108|0,24),ja=j+24|0,v[ia|0]=ja;A=1}if(u){break K}x[g+4>>2]=y[e+206|0]+1>>>1;if(r){break K}w[g+28>>1]=y[e+208|0]|y[e+209|0]<<8}g=D(z[Zb(g+236|0,61)>>1],104)+a|0;v[g+484417|0]=y[e+191|0]<<4;if(q){break I}j=_b(y[e+198|0]|y[e+199|0]<<8|(y[e+200|0]<<16|y[e+201|0]<<24));x[g+484384>>2]=j;ia=g+484388|0,ja=_b(y[e+202|0]|y[e+203|0]<<8|(y[e+204|0]<<16|y[e+205|0]<<24))+j|0,x[ia>>2]=ja;break H}h=N()|0;break f}h=N()|0;break f}if(t){continue}}j=g+484414|0;h=j;k=z[j>>1]&65529;j=y[e+193|0];w[h>>1]=k|j<<1&2|j>>>1&4;if(!(j&4)){continue}w[g+484412>>1]=0;continue}}L:{d=_b(x[e+524>>2]);if(!d){break L}if(!Cb(z[e+528>>1])){break L}x[31721]=0;d=P(152,b|0,d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break F}if(!d){break L}ia=e,ja=Cb(z[e+528>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];h=z[Lc(e+188|0,e+128|0)>>1];i=Cb(z[e+530>>1]);d=0;M:while(1){if((d|0)==(h|0)){break L}x[31721]=0;S(534,b|0,e+188|0,i|0);g=x[31721];x[31721]=0;if((g|0)==1){break t}g=e+88|0;j_(g,e+188|0);x[31721]=0;O(221,e+128|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break u}d=d+1|0;j=((d<<2)+a|0)+900380|0;g=e+128|0;xc(x[j>>2]+492|0,g);tb(g);f=x[j>>2];x[31721]=0;O(393,g|0,f|0);g=x[31721];x[31721]=0;if((g|0)==1){break v}ia=e,ja=Xi(x[e+128>>2]),x[ia+88>>2]=ja;k=Kf(e+128|0);while(1){g=x[e+88>>2];if(Ib(g,k)){f=(z[Yo(g)>>1]<<5)+a|0;l=f+946328|0;g=x[j>>2];n=x[g+520>>2];x[l>>2]=x[g+516>>2];x[l+4>>2]=n;n=x[g+512>>2];l=f+946320|0;x[l>>2]=x[g+508>>2];x[l+4>>2]=n;n=x[g+504>>2];l=f+946312|0;x[l>>2]=x[g+500>>2];x[l+4>>2]=n;l=x[g+496>>2];f=f+946304|0;x[f>>2]=x[g+492>>2];x[f+4>>2]=l;Yg(e+88|0);continue}else{Gv(e+128|0);continue M}}}}_q(a+901404|0);d=oc(e+456|0,4940);pf(Me(a+901692|0,0),x[d>>2],x[d+4>>2]);vc(b);aa=c&1;u=a+484344|0;r=a+1298332|0;Z=a+1298308|0;L=a+484360|0;j=0;while(1){c=j&255;if(c>>>0>=y[X|0]){break w}x[31721]=0;V(535,b|0,e+892|0,e+504|0,e+584|0);d=x[31721];x[31721]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)==1){break W}X:{if(!c){d=0;break X}x[31721]=0;c=R(277,L|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break W}d=j;if((c|0)==255){break d}}k=Sj(x[L>>2],d&255);n=mg(e+444|0);gj(k);Y:{l=y[e+891|0];if(l>>>0<=1){c=Cb(z[e+586>>1]);if(c>>>0>256){break y}d=e+188|0;mY(d,e+584|0);x[31721]=0;S(536,k|0,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break Y}ia=e,ja=wb(x[k>>2]),x[ia+188>>2]=ja;d=wb(x[k+4>>2]);while(1){c=x[e+188>>2];if(Ib(c,d)){w[c>>1]=z[c>>1]+G;Od(e+188|0);continue}break}Uh(a,1);w[e+188>>1]=16;c=z[Lc(E,e+188|0)>>1];d=0;while(1)if((c|0)==(d|0)){d=32;break O}else{v[e+188|0]=y[(d+e|0)+850|0];v[e+128|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Sb(e+188|0,e+128|0)|0],w[ia>>1]=ja;d=d+1|0;continue}}mY(e+188|0,e+584|0);c=Cb(z[e+200>>1]);if(!c|c>>>0>64|z[E>>1]>64){break y}m=_b(x[e+208>>2]);c=Cb(z[e+212>>1]);if(c){w[e+128>>1]=c;w[e+88>>1]=800;c=Bc(((z[Lc(e+128|0,e+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{c=32}d=x[e+196>>2];x[31721]=0;g=P(152,b|0,_b(d)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break V}d=0;Z:{if(!g){break Z}while(1){if(z[E>>1]<=d>>>0){break Z}x[31721]=0;g=R(200,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){v[e+128|0]=g;v[e+88|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Sb(e+128|0,e+88|0)|0],w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break z}_:{$:{d=_b(x[e+204>>2]);if(!d){break $}x[31721]=0;g=P(152,b|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break V}d=0;if(!g){break $}while(1){if(z[E>>1]<=d>>>0){break _}x[31721]=0;g=R(537,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){ia=((d<<5)+a|0)+480284|0,ja=(Xb(g,-16,16)<<3)+128|0,w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break z}Uh(a,1)}g=Nb(e+176|0);d=x[e+192>>2];x[31721]=0;f=P(152,b|0,_b(d)|0)|0;d=x[31721];x[31721]=0;aa:{if((d|0)==1){break aa}h=1;d=0;if(!f){break P}f=z[e+586>>1];i=x[b+8>>2];q=x[b>>2];x[31721]=0;f=U(153,q|0,i|0,Cb(f)<<1)|0;i=x[31721];x[31721]=0;if((i|0)==1){break aa}if(!f){break P}f=z[e+586>>1];x[31721]=0;f=U(538,b|0,g|0,Cb(f)|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break aa}if(!f){break P}ia=e,ja=wb(x[g>>2]),x[ia+172>>2]=ja;q=wb(x[e+180>>2]);t=x[e+188>>2];o=z[e+202>>1];while(1){d=x[e+172>>2];if(!Ib(d,q)){h=0;d=1;break P}d=Cb(y[d|0]|y[d+1|0]<<8);ba:{if(Cb(o)>>>0<d>>>0){break ba}x[31721]=0;P(152,b|0,_b(t)+(d<<2)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break U}x[31721]=0;d=R(284,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break U}x[31721]=0;d=P(152,b|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break U}if(!d){break ba}d=x[b+8>>2];f=x[b>>2];x[31721]=0;d=U(153,f|0,d|0,42)|0;f=x[31721];x[31721]=0;if((f|0)==1){break U}if(!d){break ba}x[31721]=0;O(539,b|0,e+128|0);d=x[31721];x[31721]=0;ca:{if((d|0)!=1){if(kc(x[k>>2],x[k+4>>2])){break ca}x[31721]=0;O(540,k|0,65534);d=x[31721];x[31721]=0;if((d|0)!=1){break ca}}h=N()|0;break Q}d=Cb(y[e+168|0]|y[e+169|0]<<8);x[e+124>>2]=d;f=x[b+8>>2];h=x[b>>2];x[31721]=0;d=U(153,h|0,f|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break T}if(!d){x[31721]=0;d=R(205,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break T}uc(e+124|0,d)}uc(e+124|0,65534);f=x[k+4>>2];h=x[k>>2];d=0;x[31721]=0;i=x[e+124>>2];s=Yc(h,f);O(541,k|0,i+s|0);f=x[31721];x[31721]=0;if((f|0)==1){break R}while(1){da:{if((d|0)==(i|0)){if(y[e+128|0]){An(e+88|0,e+128|0);x[31721]=0;S(542,e+112|0,x[e+88>>2],x[e+92>>2]);d=x[31721];x[31721]=0;if((d|0)==1){break S}d=e+112|0;hp(k,d);tb(d)}d=_b(y[e+160|0]|y[e+161|0]<<8|(y[e+162|0]<<16|y[e+163|0]<<24));if(!d){break ba}x[31721]=0;d=P(152,b|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break da}break R}x[31721]=0;f=R(276,b|0)|0;h=x[31721];x[31721]=0;ea:{if((h|0)!=1){f=f<<16>>16;if((f|0)<0){break ea}x[31721]=0;O(540,k|0,f+G&65535);f=x[31721];x[31721]=0;if((f|0)!=1){break ea}}h=N()|0;break Q}d=d+1|0;continue}break}if(!d){break ba}fa:{while(1){ga:{x[31721]=0;d=P(543,b|0,e+108|0)|0;f=x[31721];x[31721]=0;ha:{ia:{ja:{ka:{if((f|0)!=1){if(!d){break ba}x[31721]=0;S(188,e+68|0,b|0,y[e+111|0]);d=x[31721];x[31721]=0;if((d|0)==1){break ka}d=e+68|0;i=hc(e+88|0,d);ub(d);f=Cb(z[e+108>>1]);d=em(f+s|0);w[e+68>>1]=d;if((f|0)==65535){break fa}h=x[k>>2];if(Yc(h,x[k+4>>2])>>>0<=d>>>0){break fa}f=65535;switch(y[e+110|0]-1|0){case 0:break ia;case 1:break ja;default:break ha}}h=N()|0;break Q}h=N()|0;break Q}x[31721]=0;d=R(276,i|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ga}x[31721]=0;f=P(544,n|0,e+68|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break ga}w[f>>1]=d;h=x[k>>2];f=65534;d=z[e+68>>1]}ia=Zb(h,d),ja=f,w[ia>>1]=ja}ub(i);continue}break}h=N()|0;ub(i);break Q}ub(i)}Od(e+172|0);continue}}h=N()|0;break Q}h=N()|0;break z}h=N()|0;break f}h=N()|0;break z}h=N()|0;break Q}h=N()|0;break Q}h=N()|0;break Q}h=N()|0}ld(g);break z}ld(g);if(d){d=c>>>(m>>>1&1)|0;break O}uv(n);if(!h){break d}break N}f=Cb(z[e+844>>1]);g=y[e+847|0];_=g&64;c=y[e+848|0];M=c&32;J=(c&31)+1|0;ia=a,ja=jY(f,_>>>6|0,M>>>5|0,J),x[ia+480204>>2]=ja;ia=a,ja=Hd(y[e+849|0],1,32),x[ia+480196>>2]=ja;if(M){x[a+480216>>2]=J;x[a+480220>>2]=J<<2}c=y[e+866|0];if(c){v[e+188|0]=c;v[e+128|0]=64;ia=a,ja=y[Sb(e+188|0,e+128|0)|0]<<2,x[ia+480200>>2]=ja}x[a+480228>>2]=d;x[a+480232>>2]=d;x[a+480208>>2]=x[a+480208>>2]&-3|(g^-1)>>>4&2;la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{c=_b(x[e+548>>2]);va:{if(!c){break va}x[31721]=0;c=P(152,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break ua}if(!c){break va}c=x[e+552>>2];x[31721]=0;S(273,b|0,Z|0,_b(c)|0);c=x[31721];x[31721]=0;if((c|0)==1){break ua}if(y[X|0]<2){break va}x[31721]=0;S(261,e+56|0,28,Z|0);c=x[31721];x[31721]=0;if((c|0)==1){break ua}c=e+56|0;hp(k,c);tb(c)}wa:{if(_b(x[e+520>>2])>>>0<2){break wa}c=x[e+516>>2];x[31721]=0;c=P(152,b|0,_b(c)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break ua}if(!c){break wa}c=x[e+520>>2];x[31721]=0;V(339,r|0,b|0,_b(c)-1|0,4);c=x[31721];x[31721]=0;if((c|0)==1){break ua}}c=_b(x[e+560>>2]);if(!c){break la}x[31721]=0;c=P(152,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break ua}if(!c){break la}c=x[b+8>>2];d=x[b>>2];x[31721]=0;c=U(153,d|0,c|0,12)|0;d=x[31721];x[31721]=0;if((d|0)==1){break ua}if(!c){break la}x[31721]=0;P(186,b|0,6)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ua}x[31721]=0;c=R(276,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break ua}if((c|0)!=1){break la}x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break sa}if(!c){break la}d=x[b+8>>2];f=x[b>>2];x[31721]=0;d=U(153,f|0,d|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break sa}if(d){break ta}break la}h=N()|0;break z}d=CG(e+188|0,r);x[31721]=0;V(339,r|0,b|0,c|0,4);c=x[31721];x[31721]=0;if((c|0)==1){break na}if(!zd(x[e+192>>2],y[e+199|0])){x[31721]=0;c=U(545,e+32|0,2,13)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ra}x[31721]=0;S(546,e+128|0,d|0,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break qa}x[31721]=0;S(547,e+44|0,e+128|0,r|0);f=x[31721];x[31721]=0;if((f|0)==1){break pa}f=e+44|0;yb(r,f);tb(f);tb(e+128|0);tb(c)}tb(d);break la}h=N()|0;break z}h=N()|0;break ma}h=N()|0;break oa}h=N()|0;tb(e+128|0)}tb(c);break ma}h=N()|0}tb(d);break z}xa:{if(l>>>0<2){break xa}h=0;if(!_b(x[e+572>>2])){break xa}while(1){if(z[E>>1]<=h>>>0){break xa}c=x[e+572>>2];x[31721]=0;c=P(152,b|0,_b(c)+(h<<2)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break A}ya:{if(!c){break ya}x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break A}x[31721]=0;c=P(152,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break A}f=0;d=0;if(!c){break ya}while(1){za:{c=x[b+8>>2];i=x[b>>2];x[31721]=0;c=U(153,i|0,c|0,8)|0;i=x[31721];x[31721]=0;Aa:{Ba:{Ca:{if((i|0)!=1){if(!c){break za}x[31721]=0;O(548,b|0,e+188|0);c=x[31721];x[31721]=0;if((c|0)==1){break Ca}c=_b(x[e+188>>2]);if(!c){break za}switch((c&536870911)-1|0){case 1:break Aa;case 0:break Ba;default:continue}}h=N()|0;break z}h=N()|0;break z}f=_b(x[e+192>>2]);continue}d=_b(x[e+192>>2]);continue}break}if(!f|!d){break ya}x[31721]=0;c=P(152,b|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break B}if(!c){break ya}x[31721]=0;S(428,b|0,((h<<5)+a|0)+480289|0,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break B}}h=h+1|0;continue}}c=z[e+584>>1];x[31721]=0;q=Cb(c);O(226,u|0,q+G&65535);c=x[31721];x[31721]=0;if((c|0)==1){break C}ba=g&16;ca=G&65535;t=0;Da:{Ea:{while(1){if((q|0)==(t|0)){ia=e,ja=Xi(x[n>>2]),x[ia+128>>2]=ja;f=Kf(n);while(1){c=x[e+128>>2];if(!Vg(c,f)){h=1;c=_b(x[e+504>>2]);if(!c){break x}x[31721]=0;c=P(152,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break C}if(!c){break x}G=q+G|0;uv(n);break N}c=Yo(c);g=Ye(c);Fa:{Ga:{Ha:{Ia:{d=z[c>>1];if(!d){d=0;break Ia}h=d-1&65535;if(!_i(k,h)){break Ia}x[31721]=0;d=P(371,k|0,h|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Fa}break Ha}if(z[g>>1]==(d+1|0)){break Ga}x[31721]=0;d=P(370,u|0,1)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Fa}if((d|0)==65535){break Ga}ia=Zb(x[k>>2],z[c>>1]),ja=d,w[ia>>1]=ja}c=Vb(x[u>>2],d);xe(c,sn(Ve(Le(e+188|0,12,Qv(z[g>>1])),x[c+12>>2]-1|0)));q=(q&65535)>>>0>d>>>0?q:d+1|0}Yg(e+128|0);continue}break}h=N()|0;break z}Ja:{Ka:{if(!aa){break Ka}c=y[e+908|0]|y[e+909|0]<<8|(y[e+910|0]<<16|y[e+911|0]<<24);x[31721]=0;c=P(152,b|0,_b(c)+(t<<2)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break Ea}if(!c){break Ka}x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break Ea}x[31721]=0;c=P(152,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break Ea}if(!c){break Ka}s=Fb(e+68|0);x[31721]=0;c=v[e+846|0];B=R(171,e+12|0)|0;d=x[31721];x[31721]=0;La:{Ma:{if((d|0)!=1){l=c+48|0;T=y[e+891|0];if(T){break Ma}x[31721]=0;O(549,b|0,e+188|0);c=x[31721];x[31721]=0;if((c|0)==1){break Ja}w[e+172>>1]=y[e+188|0];o=y[e+189|0]+1|0;break La}h=N()|0;break D}x[31721]=0;O(550,b|0,e+176|0);d=x[31721];x[31721]=0;Na:{Oa:{if((d|0)!=1){d=Cb(z[e+176>>1]);w[e+172>>1]=d;o=Cb(z[e+178>>1])+1|0;g=_b(z[e+180>>1]|z[e+182>>1]<<16);if(!g){break Na}f=x[b+8>>2];x[31721]=0;P(152,b|0,g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break E}x[31721]=0;O(551,b|0,e+188|0);g=x[31721];x[31721]=0;if((g|0)==1){break E}g=y[e+192|0]|y[e+193|0]<<8|(y[e+194|0]<<16|y[e+195|0]<<24);x[31721]=0;g=P(152,b|0,_b(g)|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break E}if(!g){break Oa}g=y[e+196|0]|y[e+197|0]<<8|(y[e+198|0]<<16|y[e+199|0]<<24);x[31721]=0;S(273,b|0,s|0,_b(g)|0);g=x[31721];x[31721]=0;if((g|0)!=1){break Oa}break E}break E}g=_b(y[e+204|0]|y[e+205|0]<<8|(y[e+206|0]<<16|y[e+207|0]<<24));Pa:{if(!g){break Pa}x[31721]=0;g=P(152,b|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break E}if(!g){break Pa}x[31721]=0;g=R(284,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break E}x[31721]=0;g=P(152,b|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break E}if(!g){break Pa}x[31721]=0;S(188,e+88|0,b|0,D(d,o)|0);d=x[31721];x[31721]=0;if((d|0)==1){break E}d=e+88|0;g=hc(e+128|0,d);gd(B,g);ub(g);ub(d)}x[31721]=0;P(152,b|0,f|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break E}}l=T>>>0>2?c+24|0:l}x[31721]=0;c=t+ca|0;d=U(199,u|0,c&65535,o|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break E}Qa:{if(!d){break Qa}d=x[u>>2];x[31721]=0;m=Vb(d,c);O(286,m|0,s|0);c=x[31721];x[31721]=0;if((c|0)==1){break Da}Qf(e+172|0,z[E>>1]);da=o-1|0;c=0;ea=z[e+172>>1];Ra:while(1){if((c|0)==(o|0)){break Qa}g=c+1|0;fa=c-1|0;h=0;d=jd(x[m>>2],x[x[m+48>>2]+12>>2],c,0);while(1){F=h&65535;if(ea>>>0<=F>>>0){c=g;continue Ra}cD(e+128|0,y[d+3|0],d+5|0);Sa:{if(!T){x[31721]=0;O(552,e+188|0,b|0);f=x[31721];x[31721]=0;if((f|0)!=1){f=y[e+188|0];i=e+188|0;C=Hc(i);v[d+1|0]=f>>>3&16|y[C|0]>>>4|f>>>1&32;C=y[C|0];ia=d,ja=y[Ye(i)|0],v[ia+5|0]=ja;f=f&63;i=f?f+l|0:0;f=C&15;break Sa}break E}x[31721]=0;O(360,e+188|0,b|0);f=x[31721];x[31721]=0;Ta:{Ua:{if((f|0)!=1){f=e+188|0;C=Hc(f);W=Ye(f);H=cj(f);x[31721]=0;f=R(200,B|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break E}v[d+4|0]=f;f=y[e+188|0];i=f&127;if(!i){break Ua}i=i+l|0;break Ta}break E}i=0;if((f|0)!=128){break Ta}v[d|0]=254}v[d+1|0]=y[C|0]&63;f=y[W|0];v[d+5|0]=y[H|0]}if(i-1>>>0<=119){v[d|0]=i}W=(i|0)>84;C=e+188|0;H=(_|0)!=0;ga=(M|0)!=0;ha=(ba|0)!=0;i=fb-16|0;fb=i;v[d+3|0]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{f=f&255;switch(f-4|0){case 4:case 10:break Wa;case 42:break Ya;case 37:break Za;case 28:break _a;case 27:break $a;case 26:break ab;case 25:break bb;case 24:break cb;case 23:break db;case 22:break eb;case 21:break fb;case 20:break gb;case 18:break hb;case 17:break ib;case 16:break jb;case 14:break kb;case 13:break lb;case 12:break mb;case 11:break nb;case 9:break ob;case 8:break pb;case 5:break qb;case 0:break rb;default:break Xa}}v[d+3|0]=5;f=y[d+5|0];v[i+15|0]=f>>>3;v[i+14|0]=15;H=y[Sb(i+15|0,i+14|0)|0];v[i+13|0]=f<<1&30;v[i+12|0]=15;ia=d,ja=y[Sb(i+13|0,i+12|0)|0]|H<<4,v[ia+5|0]=ja;break Wa}if((y[d+5|0]-1&255)>>>0>19){break Wa}v[d+3|0]=16;break Wa}v[d+3|0]=13;f=y[d+5|0];sb:{if(!ha){if(f>>>0>152){break sb}v[d+5|0]=D((f&240)>>>4|0,10)+(f&15);break Wa}v[d+5|0]=(f&127)+1>>>1;break Wa}v[d+3|0]=0;break Wa}v[d+3|0]=11;break Wa}f=y[d+5|0];if(!f){v[d+3|0]=14;break Wa}if(f>>>0>240){break Wa}v[d+3|0]=17;if(f>>>0<=2){v[d+5|0]=112;break Wa}f=pD(+(jY(f,H,ga,J)>>>0)/1e4);if(f>>>0<=255){v[d+5|0]=f;break Wa}v[d+5|0]=f>>>8;v[i+11|0]=f;be(C,34,i+11|0);break Va}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Wa}v[d+3|0]=19;v[i+10|0]=15;ia=d,ja=y[Sb(d+5|0,i+10|0)|0]|16,v[ia+5|0]=ja;break Wa}v[d+3|0]=19;v[i+9|0]=15;ia=d,ja=y[Sb(d+5|0,i+9|0)|0]|32,v[ia+5|0]=ja;break Wa}v[d+3|0]=5;f=y[d+5|0];v[i+8|0]=(f>>>4|0)+1;v[i+7|0]=15;ia=d,ja=f&15|y[Sb(i+8|0,i+7|0)|0]<<4,v[ia+5|0]=ja;break Wa}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Wa}v[d+3|0]=19;v[i+6|0]=15;ia=d,ja=y[Sb(d+5|0,i+6|0)|0]|96,v[ia+5|0]=ja;break Wa}v[d+3|0]=19;v[i+5|0]=15;ia=d,ja=y[Sb(d+5|0,i+5|0)|0]|192,v[ia+5|0]=ja;break Wa}v[d+3|0]=10;break Wa}v[d+3|0]=19;v[i+4|0]=15;ia=d,ja=y[Sb(d+5|0,i+4|0)|0]|160,v[ia+5|0]=ja;break Wa}v[d+3|0]=19;v[i+3|0]=15;ia=d,ja=y[Sb(d+5|0,i+3|0)|0]|176,v[ia+5|0]=ja;break Wa}f=y[d+5|0]-1<<24>>24;if((f|0)<0){break Wa}v[d+5|0]=f;v[d+3|0]=31;break Wa}v[d+3|0]=14;break Wa}v[d+3|0]=19;v[i+2|0]=15;ia=d,ja=y[Sb(d+5|0,i+2|0)|0]|224,v[ia+5|0]=ja;break Wa}f=y[d+5|0];if(f>>>0>=16){v[d+3|0]=19;v[d+5|0]=f>>>4|208;break Wa}if(!f){break Wa}v[d+3|0]=19;v[d+5|0]=f|144;break Wa}if(y[d+5|0]|y[d+4|0]){break Wa}if(!Sc(y[d|0])){break Wa}v[d+5|0]=159;v[d+3|0]=20;break Wa}f=y[d+4|0];if(!f){break Wa}v[d+3|0]=44;ia=d,ja=ui(Bc(((y[d+5|0]<<8&65280)>>>0)/(f>>>0)|0,0)),v[ia+5|0]=ja;break Wa}f=y[d+5|0];if((f+16&255)>>>0>32){break Wa}v[d+3|0]=9;ia=d,ja=Zg(((f^128)<<3)-896|0),v[ia+5|0]=ja;break Wa}if(f>>>0>15){break Wa}xf(d,f,y[d+5|0])}v[i+1|0]=0;cD(C,0,i+1|0)}fb=i+16|0;tb:{if(y[e+128|0]!=34){break tb}if(!y[d+3|0]){f=z[e+128>>1];v[d+3|0]=f;v[d+5|0]=f>>>8;break tb}if(!c){break tb}ia=jd(x[m>>2],x[x[m+48>>2]+12>>2],fa,F),ja=255,v[ia+5|0]=ja}f=W&Y;ub:{if(!y[e+188|0]){break ub}if(c>>>0<da>>>0){i=jd(x[m>>2],x[x[m+48>>2]+12>>2],g,F);F=z[e+188>>1];v[i+3|0]=F;v[i+5|0]=F>>>8;break ub}v[d+5|0]=255}A=f|A;d=d+6|0;h=h+1|0;continue}}}ub(B);tb(s)}t=t+1|0;continue}break}break E}h=N()|0;break z}break E}j=j+1|0;continue}}h=N()|0;break f}h=N()|0;ub(B)}tb(s);break z}h=N()|0;break z}h=N()|0;break z}h=N()|0}uv(n);break f}h=0}uv(n);d=0;if(!h){break c}}_j(L,0);d=1;vb:{if(A&1){break vb}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break vb}b=((b<<2)+a|0)+900380|0;c=x[b>>2];if(c){Db(wv(c))}x[b>>2]=0;d=d+1|0;continue}}wb:{if(!$){break wb}x[31721]=0;b=P(1,e+188|0,16398)|0;c=x[31721];x[31721]=0;xb:{if((c|0)!=1){c=x[a+1298472>>2];x[31721]=0;S(389,c|0,2,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break xb}tb(b);break wb}h=N()|0;break f}h=N()|0;tb(b);break f}i=22250;yb:{zb:{switch(y[e+891|0]){case 0:i=z[E>>1]>4?17286:17272;break yb;case 1:i=17254;break yb;case 2:i=17236;break yb;case 3:break zb;default:break yb}}i=17209}x[31721]=0;O(553,e+88|0,16808);b=x[31721];x[31721]=0;Ab:{Bb:{Cb:{if((b|0)!=1){x[31721]=0;S(554,e+128|0,e+88|0,e+891|0);b=x[31721];x[31721]=0;if((b|0)==1){break Cb}b=e+128|0;yb(a+1298344|0,b);tb(b);Eb(e+88|0);x[31721]=0;b=P(1,b|0,12706)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Bb}yb(a+1298356|0,b);tb(b);x[31721]=0;O(133,a+1298368|0,i|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ab}ia=a+1298404|0,ja=x[Ec(e+88|0,28)>>2],x[ia>>2]=ja;d=1;break c}h=N()|0;break f}h=N()|0;Eb(e+88|0);break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;break f}l=1;if((d|0)!=7){break m}d=g+108|0;f=wC(d);while(1){if((d|0)!=(f|0)){ia=d,ja=dm(y[d|0]-24|0),v[ia|0]=ja;d=d+1|0;continue}break}f=0}A=1;break l}f=0;Db:{if(q|(i|0)<0){break Db}m=g+108|0;h=7;Eb:while(1){if((h|0)==10){break Db}r=D(h,12);o=D(h,-12)+72|0;d=0;while(1)if((d|0)==12){h=h+1|0;continue Eb}else{s=vb(m,d+r|0);v[s|0]=o+y[s|0];d=d+1|0;continue}}}}x[31721]=0;O(555,K|0,e+188|0);d=x[31721];x[31721]=0;if((d|0)!=1){Fb:{d=y[e+192|0];if((d-1&255)>>>0<=15){v[g+31|0]=d;A=1}d=y[e+193|0];if(d-1<<24>>24>=0){v[g+30|0]=d}d=0;Gb:{while(1){if((d|0)==(l|0)){if(!t){break j}if((i|0)>=0){break Gb}break j}x[31721]=0;g=D(d+u|0,104)+a|0;O(282,g+484380|0,8);h=x[31721];x[31721]=0;if((h|0)!=1){v[e+128|0]=y[e+194|0];v[e+68|0]=64;ia=g+484410|0,ja=y[Sb(e+128|0,e+68|0)|0]<<2,w[ia>>1]=ja;v[g+484416|0]=y[e+195|0];d=d+1|0;continue}break}break k}g=Wc(e+128|0,8,1,1,0);r=Cb(z[e+190>>1]);h=Cb(z[e+188>>1]);d=x[j>>2];x[31721]=0;i=R(157,d|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=we(w[e+92>>1]);if(d&16){ed(g,16);i=i>>>1|0}if(d&32){np(g,3);i=i>>>1|0}if(d&64){tg(g,2)}i=f?(i>>>0)/((-1<<l^-1)>>>0)|0:i;f=h+r|0;d=0;while(1){if((d|0)==(l|0)){break j}m=D(d+u|0,104)+a|0;o=m+484380|0;x[o>>2]=i;x[31721]=0;U(218,g|0,o|0,j|0)|0;o=x[31721];x[31721]=0;if((o|0)==1){break Fb}h=h<<1;f=f<<1;if(r>>>0>=2){x[m+484388>>2]=f;x[m+484384>>2]=h;m=m+484414|0;w[m>>1]=z[m>>1]|2}d=d+1|0;i=i<<1;continue}}}}}h=N()|0;ub(j);break f}ub(j);n=n+1|0;k=k+l|0;i=z[a+480192>>1];continue}}h=N()|0;break e}h=N()|0;break e}h=N()|0}sc(I)}ub(K);Q(h|0);p()}d=0}sc(I)}ub(K)}fb=e+944|0;return d|0}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=E(0),fa=0,ga=0,ia=0,ja=0,ka=0,la=0;e=fb-608|0;fb=e;vc(b);a:{b:{c:{if(!yi(b,e+600|0)){break c}if(!aW(e+600|0)){break c}if((gp(b)|0)>=0){break c}if(!c){d=1;break c}Ad(a,16777216);d=a+480208|0;x[d>>2]=x[d>>2]|1681e4;dr(e+256|0,32);f=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=f;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;Zf(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);u=Nb(e+564|0);l=Nb(e+552|0);Dh(b,4);i=a+480190|0;K=c&1;J=a+1298332|0;s=2500;I=!(c&2);G=a+1298472|0;d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31721]=0;c=U(153,d|0,c|0,4)|0;d=x[31721];x[31721]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[31721]=0;c=R(715,b|0)|0;d=x[31721];x[31721]=0;o:{if((d|0)==1){break o}m=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ka=a,la=Xb(512/(d>>>0)|0,16,128),x[ka+480228>>2]=la;continue}c=N()|0;break a;case 19:x[31721]=0;M=R(284,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[31721]=0;c=R(284,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ka=a,la=Xe(+A[Gb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ka+480204>>2]=la;continue}c=N()|0;break a;case 31:x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break o}Z=1;s=Hd(c,0,1e4);continue;case 32:case 33:x[31721]=0;c=R(284,b|0)|0;d=x[31721];x[31721]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[31721]=0;d=P(1,e+540|0,12615)|0;c=x[31721];x[31721]=0;if((c|0)==1){break t}c=x[G>>2];x[31721]=0;S(389,c|0,2,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31721]=0;P(186,b|0,4)|0;c=x[31721];x[31721]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!kc(x[q>>2],x[q+4>>2])){break q}x[31721]=0;O(716,e+256|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){if(x[q>>2]){HX(q);c=x[q>>2];Qo(q);Db(c);ka=Ab(q),la=0,x[ka>>2]=la;x[q>>2]=0;x[q+4>>2]=0}c=e+256|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(q),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Ui(c);continue}c=N()|0;break a;case 3:case 4:case 10:f=Oh(x[l>>2],x[l+4>>2]);d=z[i>>1];if(f>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!ri(d)){break q}d=d+1|0;w[i>>1]=d;t=Nb(e+528|0);x[31721]=0;k=R(171,e+508|0)|0;g=x[31721];x[31721]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[31721]=0;c=R(284,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break u}x[31721]=0;S(188,e+152|0,b|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break u}c=e+152|0;g=hc(e+256|0,c);gd(k,g);ub(g);break g}c=N()|0;break d}x[31721]=0;O(717,e+256|0,b|0);c=x[31721];x[31721]=0;x:{if((c|0)!=1){c=e+256|0;g=rn(t,c);cc(c);le(e+480|0,x[g>>2],x[e+532>>2]);c=Jd(e+472|0);x[31721]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=eg(330,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[31721];x[31721]=0;if((g|0)==1){break x}gd(k,c);break g}c=N()|0;break e}c=N()|0;break e}x[31721]=0;O(718,e+256|0,b|0);c=x[31721];x[31721]=0;y:{if((c|0)!=1){c=e+256|0;g=rn(t,c);cc(c);le(e+440|0,x[g>>2],x[e+532>>2]);c=Jd(e+432|0);x[31721]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=eg(330,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[31721];x[31721]=0;if((g|0)==1){break y}gd(k,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[i>>1];if(!ri(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!kc(x[u>>2],x[u+4>>2])){break q}x[31721]=0;O(719,e+256|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){c=e+256|0;_V(u,c);sc(c);continue}c=N()|0;break a;case 7:if(!kc(x[l>>2],x[l+4>>2])){break q}x[31721]=0;O(720,e+256|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){if(x[l>>2]){vV(l);c=x[l>>2];XB(l);Db(c);ka=Ab(l),la=0,x[ka>>2]=la;x[l>>2]=0;x[l+4>>2]=0}c=e+256|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(l),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ev(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!kc(x[r>>2],x[r+4>>2])){break q}x[31721]=0;O(721,e+256|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){if(x[r>>2]){AV(r);c=x[r>>2];Uu(r);Db(c);ka=Ab(r),la=0,x[ka>>2]=la;x[r>>2]=0;x[r+4>>2]=0}c=e+256|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(r),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;dn(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[31721]=0;O(722,e+256|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];d=x[e+260>>2];if(kc(c,d)){break z}x[31721]=0;V(346,J|0,c|0,Rc(c,d)|0,1);c=x[31721];x[31721]=0;if((c|0)!=1){break z}c=N()|0;cc(e+256|0);break a}cc(e+256|0);continue}x[31721]=0;m=R(284,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break o}}x[31721]=0;P(186,b|0,m|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[l>>2];c=x[l+4>>2];if(kc(b,c)){break m}if(K){if(kc(x[q>>2],x[q+4>>2])){break m}if(kc(x[u>>2],x[u+4>>2])){break m}if(kc(x[r>>2],x[r+4>>2])){break m}}b=Oh(b,c);if(b>>>0>=256){x[31721]=0;O(723,l|0,255);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=Oh(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;ka=m,la=z[oe(i,n)>>1],w[ka>>1]=la;if(g&1){x[31721]=0;b=P(1,e+528|0,16487)|0;c=x[31721];x[31721]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31721]=0;S(389,c|0,2,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break i}tb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){h=d&65535;if(h>>>0>z[n>>1]){g=g+1|0;continue A}B:{f=bn(x[l>>2],h-1|0);if(!y[f|0]|v[f+128|0]<0){break B}if((_u(f)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!_u(f)){break F}if(Cb(y[f+6|0]|y[f+7|0]<<8)){break F}if(Cb(y[f+14|0]|y[f+15|0]<<8)>>>0>20){break F}c=(Cb(y[f+18|0]|y[f+19|0]<<8)|0)==4}G:{H:{if(c){c=y[f+23|0];b=y[f+140|0];x[31721]=0;b=ha(724,f|0,a|0,(b&2)>>>1|0,(D(h,104)+a|0)+484380|0,s&65535)|0;k=x[31721];x[31721]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[31721]=0;b=P(37,e+384|0,10755)|0;k=x[31721];x[31721]=0;if((k|0)==1){break J}xc(((h<<5)+a|0)+946304|0,b);tb(b);k=x[l>>2];b=d;if(Oh(k,x[l+4>>2])>>>0<=c>>>0){break G}ka=f,la=y[f+143|0]+y[bn(k,c)+143|0]|0,v[ka+143|0]=la;break H}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break G}c=0;K:{if(!_u(f)){break K}if((Cb(y[f+6|0]|y[f+7|0]<<8)|0)!=1){break K}if((Cb(y[f+14|0]|y[f+15|0]<<8)|0)!=2){break K}c=(Cb(y[f+18|0]|y[f+19|0]<<8)|0)==10}b=d;if(!c){break G}QV(e+256|0,f);b=Cb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[i>>1]){break H}x[31721]=0;c=R(713,e+152|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break E}k=y[e+292|0]|y[e+293|0]<<8;o=z[m>>1];x[31721]=0;t=D(b,104);b=a+484380|0;k=Cb(k);b=ba(725,e+256|0,(t+b|0)+104|0,(k>>>0<o>>>0?(b+D(k,104)|0)+104|0:c)|0,b+D(h,104)|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break D}if(!b){break H}x[31721]=0;b=P(37,e+140|0,11253)|0;c=x[31721];x[31721]=0;if((c|0)==1){break C}xc(((h<<5)+a|0)+946304|0,b);tb(b);v[f+139|0]=y[f+139|0]+12}b=d}x[31721]=0;b=b&65535;c=U(254,a|0,h|0,b|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[31721]=0;V(726,f|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}J=mg(e+128|0);t=mg(e+116|0);b=nc(x[u>>2],x[u+4>>2]);_=D(z[a+480188>>1],M);$=em((b>>>0)/(_>>>0)|0);x[31721]=0;X=a+484344|0;O(226,X|0,$|0);b=x[31721];x[31721]=0;if((b|0)==1){break k}aa=a+484376|0;gj(Wb(x[a+484360>>2],y[aa|0]));b=z[a+480188>>1];x[31721]=0;G=P(727,e+104|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}ka=e,la=wb(x[r>>2]),x[ka+52>>2]=la;fa=a+902204|0;ga=wb(x[r+4>>2]);ia=a+480208|0;while(1){L:{M:{N:{k=x[e+52>>2];if(!Ib(k,ga)){break N}b=we((y[k+6|0]|y[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Cb(y[k|0]|y[k+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=Gg(b,f);if(g>>>0>=c>>>0){break L}d=Cb(y[k+2|0]|y[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Gg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];fc(e+76|0,b+(Cb(y[k|0]|y[k+1|0]<<8)<<5)|0,Cb(y[k+2|0]|y[k+3|0]<<8));O:{I=Wb(x[a+484360>>2],y[aa|0]);if(kc(x[I>>2],x[I+4>>2])){break O}x[31721]=0;O(540,I|0,65534);b=x[31721];x[31721]=0;if((b|0)!=1){break O}break M}ka=e,la=wb(x[e+76>>2]),x[ka+40>>2]=la;b=fb-16|0;fb=b;ja=x[zb(b+12|0,x[e+76>>2]+(x[e+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[e+40>>2];if(!Ib(i,ja)){break L}b=we(we((y[k+8|0]|y[k+9|0]<<8)<<16>>16)+we((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=ae(J);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!Wu(i,d)){c=1;if(!Wu(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31721]=0;b=P(728,J|0,i|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}F=z[b>>1];break S}F=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31721]=0;F=P(370,X|0,Cb(b)|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break M}if((F|0)==65535){break L}x[31721]=0;b=P(728,J|0,i|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}w[b>>1]=F;if(Cb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Cb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}n=Cb(y[i+14|0]|y[i+15|0]<<8);c=Fk(wb(x[u>>2]),D(Cb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ka=e,la=Fk(c,D(b,Cb(y[i+10|0]|y[i+11|0]<<8))),x[ka+28>>2]=la;T=0;x[e+100>>2]=0;o=Ig(e- -64|0);T:while(1){U:{d=Cb(y[i+12|0]|y[i+13|0]<<8);c=Vb(x[X>>2],F);if(d>>>0<=T>>>0){break U}m=0;Y=jd(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=m>>>0){T=T+1|0;continue T}b=wb(x[u+4>>2]);d=x[e+28>>2];h=Ib(d,b)?d:e+100|0;b=wb(x[u+4>>2]);if(Ib(x[e+28>>2],b)){XV(e+28|0)}d=Y+D(m,6)|0;g=y[h+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[l>>2];L=Oh(f,x[l+4>>2]);H=y[h+3|0];V:{if(L>>>0<=H>>>0){break V}s=H+1|0;if(v[bn(f,H)+142|0]&1|(b|0)<0){break V}b=dm(we((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!y[d|0]|!(y[h|0]|(g|0)!=255|H|y[h+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[bn(f,g-1|0)+132|0]!=2){break W}Oo(d)}f=dv(x[G>>2],m);X:{Y:{if(!(c&1)){g=y[h|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[dv(x[G>>2],m-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[h|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[h+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((n&255)>>>0<2){break $}n=n-1|0;break aa;case 7:if((n&255)==255){n=255;break $}n=n+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[h+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){break $}ka=f,la=$l(+(b>>>0)*.64),v[ka+19|0]=la;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Sb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0]>>>3;ka=f,la=y[Sb(e+256|0,e+96|0)|0]|b<<4,v[ka+24|0]=la;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=Zg((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+96>>2]=D(b,(n&255)-1|0);ka=f,la=c-x[qd(e+256|0,e+96|0)>>2]|0,w[ka+32>>1]=la;break _;case 13:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Sb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0];ka=f,la=y[Sb(e+256|0,e+96|0)|0]|b<<4,v[ka+23|0]=la;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=ae(t);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!Yu(h,g)){c=1;if(!Yu(g,h)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31721]=0;b=P(729,t|0,h|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[Ab(t)>>2];if(b>>>0>127){break _}x[e+92>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=Me(fa,b&255);g=x[ia>>2];x[31721]=0;x[e+24>>2]=x[e+92>>2];c=U(730,e+24|0,c|0,g|0)|0;g=x[31721];x[31721]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[31721]=0;c=P(729,t|0,h|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;ca=(y[h|0]&254)==24|ca;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+96>>2]=y[h+3|0]+1;ka=d,la=x[qd(e+256|0,e+96|0)>>2],v[ka+5|0]=la;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];n=b?b:4;v[d+5|0]=n;break _;case 19:ia:{b=y[h+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[h+3|0]:g;v[e+91|0]=g;v[e+256|0]=y[h+2|0];v[e+96|0]=100;b=e+256|0;s=e+96|0;c=y[Sb(b,s)|0];x[e+256>>2]=128;x[e+96>>2]=256-(g&255);g=x[qd(b,s)>>2];v[e+256|0]=128;b=y[Sb(b,e+91|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Bc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(m|0)){break _}g=m+1|0;h=dv(x[G>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){da=(Ti(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}v[d+3|0]=44;ka=d,la=$l(da+ +(c+y[h+2|0]|0)),v[ka+5|0]=la}w[f+32>>1]=0;break _}v[d+5|0]=n;v[d+3|0]=16}b=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(m&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(m|0)){break _}b=x[l>>2];if(Oh(b,x[l+4>>2])>>>0<=H>>>0){break _}if(y[bn(b,H)+132|0]!=1){break _}g=m+1|0;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=dv(x[G>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=n&255;w[e+256>>1]=b;c=f+30|0;ka=c,la=z[oe(c,e+256|0)>>1]-b|0,w[ka>>1]=la;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=n&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;C=E(g|0);if(!(C<=j)){break pa}v[e+256|0]=15;ka=e,la=xh(E(j/C)),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+256|0]=15;ka=e,la=xh(E(E(-j)/C)),v[ka+96|0]=la;c=y[Sb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+256|0]=14;ka=e,la=xh(E(-j)),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+256|0]=15;ka=e,la=xh(j),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=n&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break ta}v[e+256|0]=223;ka=e,la=xh(E(j/C)),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[e+256|0]=223;ka=e,la=xh(E(E(-j)/C)),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+256|0]=14;ka=e,la=xh(E(-j)),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}ea=E(j*E(.25));c=b-1|0;C=E(c|0);if(ea>=C){v[e+256|0]=9;ka=e,la=xh(E(j/C))>>>2|0,v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(ea<=E(1-b|0))){break qa}v[e+256|0]=9;ka=e,la=xh(E(E(-j)/C))>>>2|0,v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+256|0]=15;ka=e,la=xh(j),v[ka+96|0]=la;b=y[Sb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(n&255)-1|0);ka=f,la=z[f+32>>1]-z[Lc(c,e+256|0)>>1]|0,w[ka+32>>1]=la}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],n&255)&1023;c=0;if(m&1){break X}b=y[f+18|0];if(!b){break X}g=x[l>>2];if(Oh(g,x[l+4>>2])>>>0<b>>>0){break X}g=bn(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+65|0];if(!b|y[g+132|0]!=1){break X}v[e+65|0]=b+1}m=m+1|0;b=z[a+480188>>1];continue}}break}xe(c,Vh(Ve(Le(e+256|0,16,Cb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=fm(x[I>>2],x[I+4>>2]);ka=e,la=Cb(y[i+4|0]|y[i+5|0]<<8),w[ka+256>>1]=la;w[e+64>>1]=1;c=z[oe(e+256|0,e- -64|0)>>1];x[31721]=0;V(731,I|0,b|0,c|0,F&65535);b=x[31721];x[31721]=0;if((b|0)==1){break Q}b=we((y[k+8|0]|y[k+9|0]<<8)<<16>>16);b=we(we((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}cv(e+40|0);continue}break}break M}d=ca&1;if(d){g=a+906300|0;b=sd(g,0);x[31721]=0;W(289,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+256>>2]=0;f=b+48|0;c=e+256|0;G$(b+32|0,f,c);x[31721]=0;c=P(37,c|0,9571)|0;h=x[31721];x[31721]=0;if((h|0)==1){break M}aE(f,c);tb(c);x[31721]=0;c=P(37,e+76|0,9564)|0;f=x[31721];x[31721]=0;if((f|0)==1){break M}bw(b+80|0,c);tb(c);x[31721]=0;b=P(37,e- -64|0,9556)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}aE(sd(g,1)+48|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){ID(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[31721]=0;b=P(1,e+52|0,12165)|0;c=x[31721];x[31721]=0;Ca:{Da:{Ea:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,e+40|0,12383)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}yb(a+1298356|0,b);tb(b);if(Z){break Ea}x[31721]=0;b=P(1,e+28|0,12165)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}break Da}break M}if(Oh(x[l>>2],x[l+4>>2])>>>0<=128){x[31721]=0;b=P(1,e+28|0,9298)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break Da}break M}x[31721]=0;b=P(1,e+28|0,14797)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Ca}}yb(a+1298368|0,b);tb(b);ka=a+1298404|0,la=x[Ec(e+100|0,28)>>2],x[ka>>2]=la;WV(G);KV(t);JV(J);d=1;break m}}c=N()|0;WV(G);break j}Lq(e+52|0);continue}}c=N()|0;break a}c=N()|0;break a}ev(l);sc(u);dn(r);Ui(q);break c}c=N()|0;break j}c=N()|0}KV(t);JV(J);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31721]=0;c=d&65535;d=U(732,a|0,c|0,k|0)|0;g=x[31721];x[31721]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[31721]=0;d=U(733,a|0,c|0,k|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31721]=0;d=U(734,a|0,c|0,k|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31721]=0;d=P(735,(D(c,104)+a|0)+484380|0,k|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31721]=0;d=P(1,e+420|0,16198)|0;g=x[31721];x[31721]=0;if((g|0)==1){break Ha}g=x[G>>2];x[31721]=0;S(389,g|0,2,d|0);g=x[31721];x[31721]=0;if((g|0)==1){break Ga}tb(d);break Fa}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ja:{Ka:{La:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[i>>1];if(ri(d)){break La}}d=x[l>>2];if(Oh(d,x[l+4>>2])>>>0<=c>>>0){break Ka}if(y[bn(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!ri(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[i>>1]=c;H=D(c&65535,104)+a|0;o=H+484380|0;h=F+484380|0;d=x[h>>2];g=x[h+20>>2];Ma:{if(!ge(d,g)){break Ma}f=z[h+34>>1];if((h|0)==(o|0)|(Yd(f)|0)!=2){break Ma}c=(h|0)==(o|0);if(!(ge(x[o>>2],x[o+20>>2])?c:1)){break Ma}ge(x[h>>2],x[h+20>>2]);if(!c){g=Zu(d,Dn(f))}f=x[h+20>>2];if(!(f?g:0)){if(!c){NB(g)}break Ma}Na:{Oa:{switch(Dn(z[h+34>>1])-1|0){case 1:d=g;c=f;m=x[h+20>>2];n=x[h>>2];while(1){if(n){w[d>>1]=z[m>>1];w[c>>1]=z[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;n=n-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=f;m=x[h+20>>2];n=x[h>>2];while(1){if(n){v[d|0]=y[m|0];v[c|0]=y[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;n=n-1|0;continue}break}}d=Po(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=Po(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}Mj(d,a);Mj(g,a)}x[31721]=0;c=P(37,e+408|0,6320)|0;d=x[31721];x[31721]=0;if((d|0)==1){break Ja}ye(H+484423|0,c);tb(c);x[31721]=0;c=P(37,e+396|0,6223)|0;d=x[31721];x[31721]=0;if((d|0)==1){break f}ye(F+484423|0,c);tb(c)}ub(k);cc(t);g=0;continue}break}c=N()|0;break e}c=N()|0}ub(k)}cc(t);break a}fb=e+608|0;return d|0}c=N()|0}ev(l);sc(u);dn(r);Ui(q);Q(c|0);p()}function pv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=0,la=0,ma=0,na=0,oa=E(0),pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=E(0);g=fb-192|0;fb=g;Z=Nb(a);s=g+160|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;ia=x[d+16>>2];a=y[d+6|0];pa=b+484360|0;h=x[pa>>2];qa=(Aa=a,Ba=y[b+484376|0],Ca=Kj(h,x[b+484364>>2])>>>0>a>>>0,Ca?Aa:Ba);a=qa&255;K=Sj(h,a);x[31721]=0;t=P(606,g+128|0,b|0)|0;h=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=1){k=x[t+4>>2];x[31721]=0;L=U(607,g+92|0,b|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break g}ca=c&7;m=x[d>>2];a=z[d+4>>1];h=Yc(x[K>>2],x[K+4>>2]);while(1){f=a&65535;if(f>>>0>=h>>>0){break f}if(_i(K,f)){break f}a=a+1|0;m=0;continue}}a=N()|0;break d}a=N()|0;break e}x[d>>2]=m;w[d+4>>1]=a;x[k+52>>2]=m;M=k+48|0;x[M>>2]=m;x[s+16>>2]=m;w[k+74>>1]=a;w[k+72>>1]=a;w[s+24>>1]=a;ra=Jd(g+84|0);h:{if((ca|0)!=7){break h}a=fb-16|0;fb=a;h=a+8|0;Kb(h,ra,1);Vo(h);fb=a+16|0;if((ia|0)!=2){break h}a=x[K>>2];f=Yc(a,x[K+4>>2]);h=z[d+12>>1];if(f>>>0<=h>>>0){break h}f=x[b+484344>>2];r=x[b+484348>>2];a=z[Zb(a,h)>>1];if(!Ge(f,r,a)){break h}h=Vb(f,a);f=x[d+8>>2];if(A[h+12>>2]<=f>>>0){break h}a=0;n=jd(x[h>>2],x[x[h+48>>2]+12>>2],f,0);h=z[b+480188>>1];f=x[t+8>>2];r=z[b+480192>>1];while(1){if((a|0)==(h|0)){break h}i:{j:{k:{l:{e=y[n|0];switch(e-253|0){case 1:case 2:break j;case 0:break l;default:break k}}if(r){break j}}if(!Sc(e)){break i}if(Il(y[n+2|0],y[n+3|0])){break i}}Aa=Re(f,a),Ba=-1,x[Aa>>2]=Ba}n=n+6|0;a=a+1|0;continue}}_=c&1;if(_){qT(k+223860|0)}R=k+74|0;va=k+223872|0;T=k+80|0;xa=b+901692|0;ya=b+902204|0;da=k+44|0;ka=k+223860|0;$=k+20|0;J=b+1074312|0;sa=k+616|0;ea=32768;Y=b+480188|0;I=b+480180|0;la=b+484348|0;za=k+223884|0;ta=(ca|0)!=7;ma=b+480192|0;r=0;m:{n:{o:{p:{q:{r:{s:{t:{u:while(1){ua=C[d+8>>3];o(+ua);h=j(1)|0;a=j(0)|0;l=x[d+16>>2];f=a;v:{w:{x:{y:{while(1){pT(g+24|0,x[I>>2],z[Y>>1],k,F&1);i=y[g+24|0];if((l|0)==3&C[t+24>>3]>=ua){break y}a=65535;e=x[K>>2];m=Yc(e,x[K+4>>2]);n=z[k+72>>1];if(m>>>0>n>>>0){a=z[Zb(e,n)>>1]}w[k+70>>1]=a;m=x[b+484344>>2];e=x[la>>2];q=a&65535;if(!(Ge(m,e,q)|(l|0)!=2|(q|0)==65535)&(n|0)==(h&65535)){break y}z:{while(1){a=a&65535;if(aj(m,e)>>>0>a>>>0){break z}n=z[k+72>>1];A:{B:{if((a|0)!=65535){q=x[K>>2];u=Yc(q,x[K+4>>2]);if(n>>>0<u>>>0){break B}}a=z[K+28>>1];if((n|0)==(a|0)){break z}q=x[K>>2];u=Yc(q,x[K+4>>2]);break A}a=n+1|0}w[k+72>>1]=a;n=65535;G=u;u=a&65535;if(G>>>0>u>>>0){n=z[Zb(q,u)>>1]}w[k+74>>1]=a;w[k+70>>1]=n;C:{if(!Ge(m,e,n&65535)){e=vq(g+24|0,sa);x[31721]=0;a=ha(608,L|0,a&65535,0,e|0,(i|0)!=0|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break q}if(a){break C}m=x[b+484344>>2];e=x[la>>2]}a=z[k+70>>1];continue}break}if(ia>>>0<=1){a=z[k+72>>1];x[s+8>>2]=0;w[s+20>>1]=a}if(!l){break z}if(!Fu(L,R,M)){break z}C[s>>3]=C[t+24>>3];x[31721]=0;O(609,Z|0,s|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31721]=0;W(610,t|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}a=z[k+74>>1];w[k+72>>1]=a;Aa=k,Ba=z[Zb(x[K>>2],a)>>1],w[Aa+70>>1]=Ba;x[k+52>>2]=x[k+48>>2]}if(z[R>>1]==65535){break n}a=x[b+484344>>2];e=z[k+70>>1];if(!Ge(a,x[la>>2],e)){a=z[k+72>>1];if((a|0)==z[K+28>>1]){if(!l){break o}if(!Fu(L,R,M)){break p}C[s>>3]=C[t+24>>3];x[31721]=0;O(609,Z|0,s|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31721]=0;W(610,t|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}x[k+52>>2]=x[k+48>>2];continue}w[R>>1]=a+1;continue}break}m=x[M>>2];if(m>>>0>=A[Vb(a,e)+12>>2]){x[M>>2]=0;m=0}if((l|0)!=2){break x}if(z[k+72>>1]!=(h&65535)|(f|0)!=(m|0)){break w}}l=1;v[s+26|0]=1;break n}a=0;if((l|0)==3){break v}}a=0;if(A[L+28>>2]<ea>>>0){break v}x[t+24>>2]=0;x[t+28>>2]=2146435072;x[L+28>>2]=0;ea=ea>>>(ea>>>0>256)|0;m=x[M>>2];a=1}h=z[k+72>>1];f=vq(g+24|0,sa);x[31721]=0;h=ha(608,L|0,h|0,m|0,f|0,(i|0)!=0|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break t}if((a|h)==1){if(ia>>>0<=1){w[s+20>>1]=z[k+72>>1];x[s+8>>2]=x[k+48>>2]}if(!l){break o}if(!Fu(L,R,M)){break p}C[s>>3]=C[t+24>>3];x[31721]=0;O(609,Z|0,s|0);a=x[31721];x[31721]=0;if((a|0)==1){break s}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31721]=0;W(610,t|0);a=x[31721];x[31721]=0;if((a|0)==1){break s}x[k+52>>2]=x[k+48>>2];continue}w[s+22>>1]=z[k+72>>1];x[s+12>>2]=x[k+48>>2];oT(b,k,0);n=x[k+48>>2];h=Vb(x[b+484344>>2],z[k+70>>1]);if(n>>>0>=A[h+12>>2]){x[M>>2]=0;n=0}if(i){continue}a=0;n=jd(x[h>>2],x[x[h+48>>2]+12>>2],n,0);Kb(g+24|0,J,77);l=Hb(x[x[g+24>>2]>>2],x[g+28>>2]);D:{while(1){if(z[Y>>1]>a>>>0){E:{if(!(!iB(n)&(!l|!(y[((a<<5)+b|0)+480281|0]&4)))){Oo((k+D(a,872)|0)+1404|0);break E}if(Sg(y[n|0])){F:{if(!Bd(y[za|0])){break F}h=y[n+1|0];if(h-251>>>0<5|!h){break F}e=y[n+5|0];i=y[n+3|0];m=Hj(y[n+2|0],y[n+4|0]);f=g+24|0;v[f|0]=h-1;x[f+4>>2]=m&65535;x[31721]=0;h=P(611,va|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break D}Aa=h,Da=E(E(Hj(i,e)>>>0)/E(999)),B[Aa>>2]=Da}Oo((k+D(a,872)|0)+1404|0);break E}h=k+D(a,872)|0;f=h+1408|0;e=y[n+4|0]|y[n+5|0]<<8;v[f|0]=e;v[f+1|0]=e>>>8;f=h+1404|0;e=y[n|0]|y[n+1|0]<<8|(y[n+2|0]<<16|y[n+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;G:{H:{I:{J:{switch(y[n+3|0]-16|0){case 0:e=y[n+5|0];break I;case 3:break G;case 4:break H;case 1:break J;default:break E}}Kb(g+24|0,J,5);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break E}e=y[n+5|0];if(!e){break E}}mT(b,k,e&255);break E}f=h+1409|0;e=y[f|0];K:{if(!(e|!(x[I>>2]&16777250))){v[f|0]=y[h+1449|0];break K}v[h+1449|0]=e}h=y[n+5|0];f=h&240;if((f|0)!=224){if((f|0)!=96){break E}x[k+24>>2]=x[k+24>>2]+(h&15);break E}if(x[$>>2]){break E}h=h&15;if(h?0:y[I|0]&2){break E}x[$>>2]=h+1;break E}h=y[n+5|0];if((h&240)!=224){break E}x[$>>2]=(h&15)+1}n=n+6|0;a=a+1|0;continue}break}h=Hl(k);x[g+24>>2]=1;a=x[$c($,g+24|0)>>2];w[k+68>>1]=65535;x[k+60>>2]=-1;x[k+64>>2]=-1;na=h-1|0;a=h-a|0;X=D(a,1e4);n=0;while(1){L:{M:{N:{O:{P:{if(z[Y>>1]<=n>>>0){if(x[I>>2]!=4|x[k+40>>2]!=65535){break P}w[k+74>>1]=z[k+72>>1];x[k+52>>2]=x[k+48>>2];continue u}i=k+D(n,872)|0;m=i+1404|0;if(iB(m)){break L}q=i+616|0;fa=i+1409|0;e=y[fa|0];ba=i+1407|0;u=y[ba|0];if(!_){break N}G=y[m|0];f=G;l=i+1405|0;H=y[l|0];if(H){v[i+1415|0]=0;v[i+1419|0]=H;Aa=Re(x[t+8>>2],n),Ba=255,v[Aa+5|0]=Ba;f=y[m|0]}Q:{if(!Sc(f)){break Q}v[i+1415|0]=G;UU(q);if(!ta){if(x[Re(x[t+8>>2],n)>>2]!=-1){break Q}}H=i+1272|0;f=y[i+1419|0];f=x[(f?f>>>0>z[ma>>1]?H:((f<<2)+b|0)+900380|0:H)>>2];if(!f){break Q}H=y[f+21|0];if(Cd(H)){Aa=i+1453|0,Ba=Rh(H),v[Aa|0]=Ba}f=y[f+22|0];if(!Cd(f)){break Q}Aa=i+1454|0,Ba=Rh(f),v[Aa|0]=Ba}R:{if(!(Sc(y[m|0])|y[l|0])){break R}H=i+1419|0;l=y[H|0];S:{if(!l){l=0;break S}if(z[ma>>1]<l>>>0){break S}f=x[((l<<2)+b|0)+900380>>2];if(!f|!(v[f+15|0]&1)){break S}Gq(q,x[f+8>>2],b);l=y[H|0]}f=cr(b,G,l&255);if(!f){break R}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break R}Gq(q,z[f+484408>>1],b)}T:{U:{V:{f=y[i+1406|0];switch(f-1|0){case 1:break N;case 2:case 3:break U;case 0:break V;default:break T}}Aa=Re(x[t+8>>2],n),Ba=y[i+1408|0],v[Aa+5|0]=Ba;break N}f=y[i+1408|0];if(!f){break N}v[i+1450|0]=f;break N}if((f|0)==11){break O}break N}x[k+32>>2]=x[b+480216>>2];a=Vb(x[b+484344>>2],z[k+70>>1]);f=x[a+16>>2];if(lT(f,x[a+20>>2])){x[k+32>>2]=f}f=kT(b,k);a=D(f,h);C[t+24>>3]=C[t+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[k>>2]=a+x[k>>2];W:{X:{Y:{if(ta){break Y}n=0;na=(r|0)!=0&(f|0)!=(r|0);while(1){if(z[Y>>1]<=n>>>0){break Y}F=Re(x[t+8>>2],n);Z:{if(x[F>>2]==-1){break Z}q=k+D(n,872)|0;G=q+1404|0;X=x[q+1316>>2];if(!X){if(iB(G)){break Z}}u=q+1409|0;m=y[u|0];e=Il(y[G+2|0],y[G+3|0]);if(y[q+1405|0]){x[q+1276>>2]=0}i=q+616|0;a=m&15;l=0;_:{if(!Sc(y[G|0])){break _}if(e&y[F+4|0]!=0){hB(g+24|0,b,i,X,0);l=x[g+28>>2];x[q+624>>2]=x[g+24>>2];x[q+628>>2]=l}v[q+1418|0]=y[q+1415|0];X=q+1308|0;fa=x[X>>2];l=y[q+1419|0];if(l){Fo(b,i,l,e,1,1)}l=y[G|0];x[31721]=0;ga(612,b|0,i|0,l|0,e|0,1,0,65535);l=x[31721];x[31721]=0;if((l|0)==1){break X}m=m>>>4|0;jT(b,i);iT(x[I>>2],z[Y>>1],k,n&65535);ba=Re(x[t+8>>2],n);v[ba+4|0]=1;F=y[q+1407|0];$:{if(!((y[u|0]&240)!=208|(F-19&255)>>>0>1)){l=a;if(a>>>0<h>>>0){break $}}l=(F|0)==33?h>>>0>m>>>0?m:0:0}H=x[$>>2];if(!(!(x[I>>2]&16777250)|(!l|H>>>0<2))){l=D(H-1|0,x[k+24>>2]+x[k+40>>2]|0)+l|0}if(!e){x[ba>>2]=0}aa:{if((F|0)==9){break aa}ba:{if((F|0)!=19){if((F|0)!=20|(m|0)!=8){break ba}break aa}if((m|0)==8){break aa}}if(y[q+1406|0]!=2){break _}}x[X>>2]=fa}ca:{if(!Sc(y[G|0])){Kb(g+24|0,J,114);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break ca}}da:{ea:{fa:{ga:{e=y[q+1407|0];switch(e-42|0){case 1:break da;case 0:break ea;case 2:break fa;default:break ga}}if((e|0)!=10){break da}e=z[k+70>>1];m=x[k+48>>2];x[31721]=0;aa(613,b|0,i|0,n&65535,m|0,e|0);e=x[31721];x[31721]=0;if((e|0)!=1){break ca}break W}m=zua(y[u|0],0,x[q+692>>2],0);e=hb;F=e>>>8|0;Eo(b,i,Bc((e&255)<<24|m>>>8,F));break ca}if(!x[q+720>>2]){break da}x[31721]=0;V(614,t|0,n&65535,r|0,-1);e=x[31721];x[31721]=0;if((e|0)==1){break W}gT(i,y[u|0]);l=x[k+40>>2]-1|0;break ca}if(y[q+1406|0]!=15){break ca}m=x[q+720>>2];if(!m){break ca}e=y[q+1408|0];if(e>>>0>9){break ca}ha:{if(!e){e=x[q+1280>>2];break ha}e=x[xb(m+68|0,e-1|0)>>2];x[q+1280>>2]=e}Eo(b,i,e)}ia:{ja:{ka:{switch(y[G|0]-253|0){case 0:if(z[ma>>1]){break ja}break;case 1:case 2:break ja;default:break ka}}e=y[q+1407|0];if(!((y[u|0]&240)!=192|(e-19&255)>>>0>1)&a>>>0<h>>>0){break ja}F=e&255;if((F|0)==25){break ja}m=0;if(!((F|0)==33&(a|0)!=0&h>>>0>a+l>>>0)){break ia}}e=y[q+1407|0];m=1}H=q+1304|0;la:{ma:{na:{a=e&255;if((a|0)!=46){if((a|0)!=13){break na}F=y[u|0]<<2;break ma}F=y[u|0];break ma}if(y[q+1406|0]!=1){break la}F=y[q+1408|0]<<2}x[H>>2]=F}F=q+1407|0;oa:{pa:{qa:{if(m|(!x[q+720>>2]|a>>>0>46)){break qa}Kb(g+24|0,ra,a);if(Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break pa}e=y[F|0];if((e|0)!=19){break qa}a=y[u|0]&240;if((a|0)==16){break pa}e=19;if((a|0)==32){break pa}}if(!m){break oa}}VU(i);Aa=Re(x[t+8>>2],n),Ba=0,x[Aa>>2]=Ba;break Z}if(na){x[31721]=0;V(614,t|0,n&65535,r|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break W}e=y[F|0]}ra:{sa:{ta:{ua:{va:{a=e&255;if(a-6>>>0>=2){wa:{switch(a-19|0){case 1:break ua;case 0:break va;default:break wa}}if(a-35>>>0<2){break sa}if((a|0)==45){break ta}if((a|0)!=11){break ra}}if(!y[u|0]&x[I>>2]==1){break ra}a=q+1467|0;e=0;while(1){if((e|0)==(h|0)){break ra}v[a|0]=!e|y[a|0]&254;Do(b,i,y[u|0]);e=e+1|0;continue}}e=y[u|0];a=e&15;if(!(a|x[I>>2]&1048580)){break ra}m=q+1467|0;v[m|0]=y[m|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ra}Co(b,i,a,0);break ra}Bo(b,i,a,0);break ra}xa:{ya:{za:{a=y[u|0];switch(a-158|0){case 1:break ya;case 0:break za;default:break xa}}x[31721]=0;V(614,t|0,n&65535,r|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break W}x[q+704>>2]=x[q+704>>2]&-129;break ra}x[31721]=0;V(614,t|0,n&65535,r|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break W}a=x[q+704>>2];x[q+704>>2]=a|128;if(x[i+4>>2]){break ra}e=x[q+692>>2];if(!e){break ra}if(!(Aa=Sc(y[G|0]),Ba=1,Ca=a&2,Ca?Aa:Ba)){break ra}x[i>>2]=-1;x[i+4>>2]=e-1;break ra}if((a&240)!=112|a>>>0<115){break ra}SU(i,a,x[I>>2]);break ra}fT(i,y[u|0]);break ra}x[31721]=0;a=n&65535;V(614,t|0,a|0,r|0,-1);e=x[31721];x[31721]=0;if((e|0)==1){break W}Aa=q+1390|0,Ba=eT(b,z[k+70>>1],x[k+48>>2],a),w[Aa>>1]=Ba}e=q+1467|0;a=y[e|0]|1;v[e|0]=a;Aa:{Ba:{Ca:{Da:{Ea:{m=q+1406|0;switch(y[m|0]-3|0){case 11:break Ba;case 0:case 1:break Ca;case 3:break Da;case 2:break Ea;default:break Aa}}a=y[q+1408|0];Kb(g+24|0,J,41);Co(b,i,a,Hb(x[x[g+24>>2]>>2],x[g+28>>2]));break Aa}a=y[q+1408|0];Kb(g+24|0,J,41);Bo(b,i,a,Hb(x[x[g+24>>2]>>2],x[g+28>>2]));break Aa}a=y[q+1408|0];Fa:{if(a){break Fa}Kb(g+24|0,J,41);a=0;if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break Fa}a=y[q+1450|0];if(!a){break Aa}}m=y[m|0]==3?a<<4:a;a=0;while(1){if((a|0)==(h|0)){break Aa}v[e|0]=!a|y[e|0]&254;Do(b,i,m&255);a=a+1|0;continue}}i=y[q+1408|0];if(i>>>0>1){break Aa}v[e|0]=a&247|!i<<3}if(y[e|0]&8){break Z}a=1;Ga:{Ha:{Ia:{e=y[G+3|0];if(e>>>0>28){break Ia}i=1<<e;if(i&92){break Ga}if(!(i&268959744)){break Ia}if((y[G+5|0]-16&255)>>>0<32){break Ga}break Ha}if(e-38>>>0<4){break Ga}}a=(y[G+2|0]-11&255)>>>0<3}if(a){e=Re(x[t+8>>2],n);a=x[e>>2];x[e>>2]=a+h;x[31721]=0;V(614,t|0,n&65535,f|0,a+l|0);a=x[31721];x[31721]=0;if((a|0)!=1){break Z}a=N()|0;break m}a=Re(x[t+8>>2],n);x[a>>2]=x[a>>2]+(h-l|0)}n=n+1|0;continue}}F=dT(b,k,K,0);r=f;continue u}a=N()|0;break m}a=N()|0;break m}f=y[i+1408|0];if(!f){break N}l=g+24|0;fB(l,b,y[m+3|0],f,0);w[i+1384>>1]=z[g+24>>1];if(y[Ye(l)|0]){break M}}Ja:{Ka:{La:{Ma:{Na:{switch(u-12|0){case 0:cT(b,k,n&65535);break Ja;case 2:f=bT(b,k,n&65535,e);if((f|0)==-1){break Ja}x[k+60>>2]=f;break Ja;case 5:Kb(g+24|0,J,5);if(Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break Ja}m=D(Ao(b,z[k+70>>1],x[k+48>>2],n&65535,0),1e4);x[g+56>>2]=m;Oa:{if(!_|!(x[I>>2]&16777250)){break Oa}if(m>>>0>=1e4){v[i+1451|0]=(m>>>0)/1e4;break Oa}m=D(y[i+1451|0],1e4);x[g+56>>2]=m}f=x[b+8>>2];if(m>>>0>=32e4){x[g+24>>2]=D(x[f+24>>2],1e4);Aa=da,Ba=x[Gb(g+56|0,g+24|0)>>2],x[Aa>>2]=Ba;break Ja}l=x[da>>2];G=(m>>>0)/1e4|0;H=D(X,G&15);m=l-H|0;x[da>>2]=(G&240)==16?l+H|0:l>>>0>=m>>>0?m:0;l=x[f+20>>2];f=x[f+24>>2];Kb(g+24|0,J,8);wp(da,D(l,1e4),Hb(x[x[g+24>>2]>>2],x[g+28>>2])?255e4:D(f,1e4));break Ja;case 8:Pa:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break Ja}x[i+704>>2]=x[i+704>>2]&-257|((e|0)==145)<<8;break Ja;case 1:v[i+1452|0]=e&15;break Ja;case 2:break Ma;case 6:break Pa;default:break Ja}}v[i+1460|0]=e&15;break Ja;case 1:case 3:case 4:case 6:break Ja;case 7:break Na;default:break Ka}}f=e&240;if((f|0)==240){break La}if((f|0)!=96){break Ja}}eB(b,k,n&65535,e&15);break Ja}v[i+1460|0]=e&15;break Ja}if((u|0)!=28|(e&240)!=160){break Ja}Kb(g+24|0,J,58);if(Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break Ja}v[i+1452|0]=e&15}if(!_){break L}Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(u-2|0){case 0:if(!e){break Qa}Kb(g+24|0,J,90);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){v[i+1428|0]=e}v[i+1427|0]=e;break M;case 1:if(!e){break Qa}Kb(g+24|0,J,90);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){v[i+1427|0]=e}v[i+1428|0]=e;break M;case 2:if(!e){break Qa}w[i+1384>>1]=e;break M;case 8:if(!e){break Qa}x[i+1280>>2]=e<<8;break M;case 4:case 9:if(!e){break Qa}v[i+1425|0]=e;break M;case 11:Aa=Re(x[t+8>>2],n),Ba=e,v[Aa+5|0]=Ba;break M;case 44:Aa=Re(x[t+8>>2],n),Ba=e+3>>>2|0,v[Aa+5|0]=Ba;break M;case 21:f=x[I>>2];e=e<<(!(f&59593760)&e<<24>>24>=0);l=e&255;if(l>>>0<=128){x[T>>2]=l<<1;break M}if(f&16777250){break M}x[T>>2]=256;break M;case 22:Kb(g+24|0,J,9);Za:{if(Hb(x[x[g+24>>2]>>2],x[g+28>>2])){f=i+1433|0;if(e){v[f|0]=e;break Za}e=y[f|0];break Za}if(e){v[k+1433|0]=e;break Za}e=y[k+1433|0]}f=e&15;l=e&255;_a:{if(!((f|0)!=15|l>>>0<16)){e=(e&240)>>>4<<!(x[I>>2]&59593760);f=x[T>>2]+(e<<1)|0;break _a}l=l&240;if(!(!f|(l|0)!=240)){e=f<<(x[I>>2]&59593760?1:2);f=x[T>>2]-e|0;break _a}if(l){e=(e>>>3&30)<<!(x[I>>2]&59593760);f=x[T>>2]+D(a,e)|0;break _a}e=f<<(x[I>>2]&59593760?1:2);f=x[T>>2]-D(a,e)|0}x[T>>2]=f;Ee(T,0,256);break M;case 19:if(e>>>0>64){break M}x[i+1364>>2]=e;break M;case 20:f=i+1432|0;$a:{if(e){v[f|0]=e;break $a}e=y[f|0]}u=i+1364|0;f=x[u>>2];l=e&15;m=e&255;ab:{if(!((l|0)!=15|m>>>0<16)){x[g+24>>2]=f+(m>>>4|0);break ab}if(!(!l|(m&240)!=240)){x[g+24>>2]=f-l;break ab}if(l){x[g+24>>2]=f-D(a,l);break ab}x[g+24>>2]=f+D(a,m>>>4|0)}Ee(g+24|0,0,64);x[u>>2]=x[g+24>>2];break M;case 7:Ym(b,q,e,8);break M;case 29:case 30:break Ra;case 25:break Sa;case 6:break Ta;case 24:break Ua;case 3:break Va;case 5:break Wa;case 18:break Xa;case 17:break Ya;default:break M}}if(e>>>0>15){break Xa}f=(e&1)<<14;l=z[Y>>1];m=0;while(1){if((l|0)==(m|0)){break Xa}u=k+D(m,872)|0;x[u+704>>2]=(f|x[u+704>>2]&-16385)^16384;m=m+1|0;continue}}if((e&240)!=128){break M}Ym(b,q,e&15,4);break M}if(e){v[i+1425|0]=e}e=0}Gl(q,e);break M}aT(b,q,e);break M}$S(q,e);break M}_S(q,e);break M}bb:{if(e<<24>>24>=0){f=Me(xa,y[i+1460|0]);break bb}f=Me(ya,e&127)}l=y[fa|0];x[31721]=0;ja(615,b|0,k|0,n&65535,0,f|0,l|0);f=x[31721];x[31721]=0;if((f|0)!=1){break M}a=N()|0;break m}e=0}cb:{db:{switch(y[i+1406|0]-2|0){case 0:Ym(b,q,y[i+1408|0],6);break cb;case 5:Kb(g+24|0,J,53);f=y[i+1408|0];if(Hb(x[x[g+24>>2]>>2],x[g+28>>2])){v[i+1439|0]=f&15;break cb}Gl(q,f<<4);break cb;case 6:break db;default:break cb}}Gl(q,y[i+1408|0])}eb:{fb:{gb:{hb:{ib:{f=y[ba|0];switch(f-5|0){case 1:break eb;case 3:break gb;case 0:case 2:break hb;default:break ib}}switch(f-26|0){case 1:break fb;case 0:break hb;default:break eb}}jb:{if(x[I>>2]&16777248){f=h;if(!(y[b+480208|0]&4)){break jb}}f=a}l=y[i+1439|0];Kb(g+24|0,J,21);i=i+1435|0;m=y[i|0];f=D(f,l);Aa=i,Ba=(Hb(x[x[g+24>>2]>>2],x[g+28>>2])?f<<2:f)+m|0,v[Aa|0]=Ba;break eb}kb:{if(x[I>>2]&16777248){f=h;if(!(y[b+480208|0]&4)){break kb}}f=a}l=y[i+1442|0];Kb(g+24|0,J,21);i=i+1436|0;m=y[i|0];f=D(f,l);Aa=i,Ba=(Hb(x[x[g+24>>2]>>2],x[g+28>>2])?f<<2:f)+m|0,v[Aa|0]=Ba;break eb}f=i+1437|0;v[f|0]=y[f|0]+D(na,y[i+1445|0]);YS(b,q)}Kb(g+24|0,J,78);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break L}f=e&255;if(!f){break L}XS(q,f)}n=n+1|0;continue}}break}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}l=1;break n}l=0}lb:{if((ca|0)!=7){break lb}a=0;d=b+480188|0;while(1){if(z[d>>1]<=a>>>0){break lb}mb:{if(x[Re(x[t+8>>2],a)>>2]==-1){break mb}x[31721]=0;V(614,t|0,a&65535,r|0,-1);h=x[31721];x[31721]=0;if((h|0)!=1){break mb}a=N()|0;break m}a=a+1|0;continue}}if(y[s+26|0]){w[s+20>>1]=z[k+72>>1];x[s+8>>2]=x[k+48>>2]}C[s>>3]=C[t+24>>3];x[31721]=0;O(609,Z|0,s|0);a=x[31721];x[31721]=0;if((a|0)!=1){if(!_){break a}if(!(l?y[s+26|0]:1)){break c}f=UA(g+56|0);if(Bd(y[ka+24|0])){KS(f,ka)}dB(ka);a=yc(b+1074376|0,k,614);r=0;while(1){if((r|0)==256){rn(a+223848|0,k+223848|0);d=a+223860|0;r=y[d+24|0];h=k+223860|0;nb:{if((Bd(y[h+24|0])|0)==(r|0)){if(!r){break nb}r=dc(d);vu(d,x[r>>2]);x[d>>2]=x[h>>2];x[d+4>>2]=x[h+4>>2];x[d+8>>2]=x[h+8>>2];ob:{if(!x[Ab(d)>>2]){x[d>>2]=r;break ob}x[x[r>>2]+8>>2]=r;r=dc(h);x[h>>2]=r;x[r>>2]=0;Aa=Ab(h),Ba=0,x[Aa>>2]=Ba}d=d+12|0;r=dc(d);uu(d,x[r>>2]);h=h+12|0;x[d>>2]=x[h>>2];x[d+4>>2]=x[h+4>>2];x[d+8>>2]=x[h+8>>2];pb:{if(!x[Ab(d)>>2]){x[d>>2]=r;break pb}x[x[r>>2]+8>>2]=r;d=dc(h);x[h>>2]=d;x[d>>2]=0;Aa=Ab(h),Ba=0,x[Aa>>2]=Ba}break nb}if(r){dB(d);break nb}KS(d,h)}}else{d=D(r,872);tq((d+a|0)+616|0,(d+k|0)+616|0);r=r+1|0;continue}break}cB(a);a=0;x[b+1074400>>2]=0;v[b+1074476|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];qb:{rb:{d=x[b+1298300>>2];if(!yd(d)){break rb}x[31721]=0;W(616,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){break rb}break qb}while(1){if(z[b+480188>>1]<=a>>>0){a=oC(g+24|0);Aa=g,Ba=Xi(x[f+12>>2]),x[Aa+20>>2]=Ba;h=b+906300|0;l=Kf(f+12|0);while(1){d=x[g+20>>2];if(!Vg(d,l)){sb:{l=250;d=a;tb:{while(1){if(l>>>0>=32){if(x[a>>2]){a=1;break tb}else{l=l-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break sb}a=0;while(1){if((a|0)==250){break sb}Kb(g+12|0,d,a);ub:{if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){break ub}r=x[sd(h,a)>>2];e=x[x[r>>2]+180>>2];x[31721]=0;W(e|0,r|0);r=x[31721];x[31721]=0;if((r|0)!=1){break ub}break qb}a=a+1|0;continue}}Aa=g,Ba=Xi(x[f>>2]),x[Aa+12>>2]=Ba;a=Kf(f);while(1){d=x[g+12>>2];if(Vg(d,a)){d=rd(d);oa=B[dc(d)>>2];Aa=sd(h,y[d|0]),Da=oa,B[Aa+144>>2]=Da;Yg(g+12|0);continue}else{uq(f);break b}}}r=rd(d);i=Ab(r);vb:{e=y[r|0];d=x[sd(h,e)>>2];if(d){Kb(g+12|0,a,e);if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){x[31721]=0;P(617,a|0,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break vb}e=x[x[d>>2]+176>>2];x[31721]=0;O(e|0,d|0,-1);e=x[31721];x[31721]=0;if((e|0)==1){break vb}}oa=B[i>>2];r=x[r+4>>2];e=x[x[d>>2]+44>>2];x[31721]=0;wa(e|0,d|0,r|0,E(oa));d=x[31721];x[31721]=0;if((d|0)==1){break vb}}Yg(g+20|0);continue}break}break qb}d=D(a,872)+b|0;h=y[d+1075791|0];if(h){v[d+1075794|0]=h}d=Re(x[t+8>>2],a);if(!((ca|0)==7|y[d+5|0]==255)){v[g+24|0]=64;Aa=(D(a,872)+b|0)+1075680|0,Ba=y[Sb(d+5|0,g+24|0)|0]<<2,x[Aa>>2]=Ba}wb:{h=D(a,872)+b|0;d=x[h+1075096>>2];xb:{if(!d|!(y[d+35|0]&2)){break xb}r=x[b+1298300>>2];if(!yd(r)){break xb}x[31721]=0;l=r;r=a&65535;S(618,l|0,r|0,d+68|0);d=x[31721];x[31721]=0;if((d|0)==1){break wb}d=x[b+1298300>>2];x[31721]=0;S(619,d|0,r|0,1);d=x[31721];x[31721]=0;if((d|0)==1){break wb}}x[h+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;uq(f);break m}a=N()|0}zu(L)}WS(t)}Ui(Z);Q(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=qa&255;if((a|0)==y[b+484376|0]){break a}_j(pa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){NT(a);b=x[a>>2];gl(a);Db(b);Aa=Ab(a),Ba=0,x[Aa>>2]=Ba;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[L>>2];x[a+4>>2]=x[L+4>>2];b=Ab(L);Aa=Ab(a),Ba=x[b>>2],x[Aa>>2]=Ba;x[b>>2]=0;x[L>>2]=0;x[L+4>>2]=0;a=a+12|0;c=dc(a);zq(a,x[c>>2]);b=L+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];yb:{if(!x[Ab(a)>>2]){x[a>>2]=c;break yb}x[x[c>>2]+8>>2]=c;a=dc(b);x[b>>2]=a;x[a>>2]=0;Aa=Ab(b),Ba=0,x[Aa>>2]=Ba}}zu(L);WS(t);fb=g+192|0}function aY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=E(0),s=0,t=E(0),u=0,C=0,F=0,G=0,H=0,I=E(0),J=E(0),K=E(0),L=0,M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=E(0),X=E(0),Y=0,Z=0,$=0,aa=E(0),ba=E(0),ca=E(0),da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;$=fb-16|0;fb=$;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;Q=x[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(g|0)){x[(D(g,20)+a|0)+1436>>2]=0;g=g+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}g=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{k=b+d|0;if(y[k|0]!=79|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=(y[125908]|y[125909]<<8|(y[125910]<<16|y[125911]<<24))){break f}h=d+26|0;if((h|0)>=(c|0)){break e}m=d+27|0;i=b+h|0;f=y[i|0];if((m+f|0)>=(c|0)){break e}j=f+27|0;g=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((g|0)!=22){e=Yy(e,y[(d+g|0)+b|0]);g=g+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=Yy(e,0);continue}break}x[a+1420>>2]=Q+1;f=D(Q,20)+a|0;x[f+1432>>2]=e;x[f+1428>>2]=j-26;x[f+1424>>2]=y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24);e=y[(h+y[i|0]|0)+b|0]==255?-1:y[k+6|0]|y[k+7|0]<<8|(y[k+8|0]<<16|y[k+9|0]<<24);x[f+1436>>2]=h;x[f+1440>>2]=e;Q=x[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{j=y[(e+m|0)+b|0]+j|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}g=0;f=D(d,20)+a|0;n=f+1428|0;k=x[n>>2];m=x[f+1436>>2];j=c-m|0;h=(j|0)>(k|0)?k:j;S=(h|0)>0?h:0;o=f+1432|0;e=x[o>>2];while(1){if((g|0)!=(S|0)){e=Yy(e,y[(g+m|0)+b|0]);g=g+1|0;continue}break}x[n>>2]=k-h;x[o>>2]=e;if((j|0)>=(k|0)){g=e;e=f+1424|0;if((g|0)==x[e>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;g=h+m|0;break c}f=Q-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];g=f+1432|0;k=x[g+4>>2];x[e+8>>2]=x[g>>2];x[e+12>>2]=k;f=f+1424|0;g=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=g;Q=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=g}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!GL(a)){x[f>>2]=0;c=0;break a}fa=fb-16|0;fb=fa;ha=$+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=df(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=83){break j}if(!FL(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;ec(a,32);break i}k=Vy(a);break i}ec(a,30)}if(!k){break h}if(pc(a,1)){ec(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=pc(a,Gm(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[fa+12>>2]=c;j=D(c,6)+a|0;if(!y[j+412|0]){g=x[a+112>>2];k=g>>1;break m}g=x[a+116>>2];k=g>>1;c=pc(a,1);m=pc(a,1);if(c|!y[j+412|0]){break m}x[ha>>2]=g-x[a+112>>2]>>2;c=x[a+112>>2]+g>>2;break l}_(6325,13258,3152,10763);p()}x[ha>>2]=0;c=k}x[fa+8>>2]=c;n:{if(!(!y[j+412|0]|m)){c=D(g,3);x[$+8>>2]=c-x[a+112>>2]>>2;g=c+x[a+112>>2]>>2;break n}x[$+8>>2]=k}x[fa+4>>2]=g;g=1}if(g){S=x[ha>>2];ka=x[$+8>>2];ia=x[fa+4>>2];N=fb-2368|0;fb=N;C=x[a+404>>2];oa=D(x[fa+12>>2],6)+a|0;F=y[oa+413|0];R=C+D(F,40)|0;U=x[((y[oa+412|0]<<2)+a|0)+104>>2];da=U>>1;ra=0-da|0;o:{while(1){c=x[a+4>>2];if((c|0)>(h|0)){c=y[(x[R+4>>2]+D(h,3)|0)+2|0];G=(N+1344|0)+(h<<2)|0;x[G>>2]=0;g=y[(c+R|0)+9|0];if(z[((g<<1)+a|0)+132>>1]){k=x[a+260>>2];p:{q:{if(!pc(a,1)){break q}c=2;j=x[((h<<2)+a|0)+996>>2];k=k+D(g,1596)|0;o=x[(y[k+1588|0]<<2)+89116>>2];g=Gm(o)-1|0;ta=j,ua=pc(a,g),w[ta>>1]=ua;ta=j,ua=pc(a,g),w[ta+2>>1]=ua;u=0;while(1){if(y[k|0]>u>>>0){O=y[(k+u|0)+1|0];g=O+k|0;s=y[g+49|0];i=-1<<s;n=y[g+33|0];r:{if(!s){m=0;break r}g=x[a+124>>2]+D(y[g+65|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}m=x[a+1392>>2];H=w[(g+((m&1023)<<1)|0)+36>>1];s:{if((H|0)>=0){q=m;H=H&65535;m=y[H+x[g+8>>2]|0];x[a+1392>>2]=q>>>m;m=x[a+1396>>2]-m|0;x[a+1396>>2]=(m|0)>0?m:0;m=(m|0)<0?-1:H;break s}m=Fm(a,g)}if(!y[g+23|0]){break r}m=x[x[g+2088>>2]+(m<<2)>>2]}H=i^-1;g=c+n|0;while(1){if((c|0)!=(g|0)){n=0;i=w[((k+(O<<4)|0)+((m&H)<<1)|0)+82>>1];t:{if((i|0)<0){break t}i=x[a+124>>2]+D(i&65535,2096)|0;if(x[a+1396>>2]<=9){vl(a)}n=x[a+1392>>2];P=w[(i+((n&1023)<<1)|0)+36>>1];u:{if((P|0)>=0){q=n;P=P&65535;n=y[P+x[i+8>>2]|0];x[a+1392>>2]=q>>>n;n=x[a+1396>>2]-n|0;x[a+1396>>2]=(n|0)>0?n:0;n=(n|0)<0?-1:P;break u}n=Fm(a,i)}if(!y[i+23|0]){break t}n=x[x[i+2088>>2]+(n<<2)>>2]}m=m>>s;w[j+(c<<1)>>1]=n;c=c+1|0;continue}break}u=u+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[N+320>>1]=257;c=2;while(1){n=x[k+1592>>2];if((n|0)<=(c|0)){c=0;while(1){if((c|0)>=(n|0)){break p}if(!y[(N+320|0)+c|0]){w[j+(c<<1)>>1]=65535;n=x[k+1592>>2]}c=c+1|0;continue}}else{g=k+338|0;m=c<<1;n=m+k|0;u=y[n+1088|0];s=u<<1;i=z[g+s>>1];G=y[n+1089|0];O=G<<1;H=w[j+s>>1];n=w[O+j>>1]-H|0;s=n>>31;g=(D((n^s)-s|0,z[g+m>>1]-i|0)|0)/(z[g+O>>1]-i|0)|0;n=H+((n|0)<0?0-g|0:g)|0;s=j+m|0;m=z[s>>1];v:{w:{if(m){g=N+320|0;v[g+G|0]=1;v[g+u|0]=1;v[c+g|0]=1;g=m<<16>>16;i=o-n|0;if((g|0)>=((i|0)<(n|0)?i:n)<<1){if((i|0)>(n|0)){break v}n=o+(m^-1)|0;break w}if(g&1){n=n-(g+1>>>1|0)|0;break w}n=(g>>1)+n|0;break w}v[(N+320|0)+c|0]=0}w[s>>1]=n}c=c+1|0;continue}}}x[G>>2]=1}h=h+1|0;continue}else{ec(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){yc(N+320|0,N+1344|0,c<<2);k=z[R>>1];c=0;while(1){if((c|0)==(k|0)){la=C+D(F,40)|0}else{h=x[R+4>>2]+D(c,3)|0;g=y[h+1|0];n=N+1344|0;h=n+(y[h|0]<<2)|0;if(!(x[(g<<2)+n>>2]?x[h>>2]:0)){x[(N+1344|0)+(g<<2)>>2]=0;x[h>>2]=0}c=c+1|0;continue}break}m=0;while(1){x:{if(y[la+8|0]>m>>>0){n=0;c=x[a+4>>2];h=(c|0)>0?c:0;c=0;while(1){if((c|0)==(h|0)){break x}if(y[(x[R+4>>2]+D(c,3)|0)+2|0]==(m|0)){j=n+N|0;k=c<<2;y:{if(x[k+(N+1344|0)>>2]){k=0;g=1;break y}k=x[(a+k|0)+800>>2];g=0}v[j|0]=g;x[(N+256|0)+(n<<2)>>2]=k;n=n+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){h=(da|0)>0?da:0;g=z[R>>1];k=a+800|0;z:while(1){if((g|0)<=0){O=da<<2;n=0;c=0;while(1){m=x[a+4>>2];if((m|0)<=(c|0)){while(1){if((n|0)<(m|0)){O=y[oa+412|0];R=U>>1;g=R<<2;la=x[a+92>>2];s=U>>3;P=U>>2;k=x[((n<<2)+a|0)+800>>2];c=R<<2;F=k+c|0;A:{if(x[a+80>>2]){m=io(a,g);break A}m=Ed(g)}g=(m+c|0)-8|0;j=x[((O<<2)+a|0)+1068>>2];i=j;c=k;while(1){if((c|0)!=(F|0)){B[g+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[g>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;g=g-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(g>>>0>=m>>>0){B[g+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[g>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;g=g-8|0;continue}break}c=P<<2;u=c+k|0;g=c+m|0;i=(j+(R<<2)|0)-32|0;c=m;h=k;while(1){if(i>>>0>=j>>>0){l=B[c>>2];r=B[g>>2];t=B[g+4>>2];I=B[c+4>>2];B[u+4>>2]=t+I;B[u>>2]=B[g>>2]+B[c>>2];t=E(t-I);l=E(r-l);B[h+4>>2]=E(t*B[i+16>>2])-E(B[i+20>>2]*l);B[h>>2]=E(l*B[i+16>>2])+E(t*B[i+20>>2]);l=B[c+8>>2];r=B[g+8>>2];t=B[g+12>>2];I=B[c+12>>2];B[u+12>>2]=t+I;B[u+8>>2]=B[g+8>>2]+B[c+8>>2];t=E(t-I);l=E(r-l);B[h+12>>2]=E(t*B[i>>2])-E(B[i+4>>2]*l);B[h+8>>2]=E(l*B[i>>2])+E(t*B[i+4>>2]);c=c+16|0;g=g+16|0;h=h+16|0;u=u+16|0;i=i-32|0;continue}break}g=Gm(U);c=U>>4;o=R-1|0;h=0-s|0;BL(c,k,o,h,j);BL(c,k,o-P|0,h,j);H=U>>5;c=0-c|0;_p(H,k,o,c,j,16);_p(H,k,o-s|0,c,j,16);_p(H,k,o-(s<<1)|0,c,j,16);_p(H,k,o+D(s,-3)|0,c,j,16);c=g-4>>1;u=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(u|0)){ja=g-7|0;break D}i=0;h=2<<c;h=(h|0)>0?h:0;s=8<<c;C=U>>c+4;G=U>>c+2;Z=0-(G>>1)|0;while(1){if((h|0)==(i|0)){break C}_p(C,k,o-D(i,G)|0,Z,j,s);i=i+1|0;continue}}while(1){E:{if((u|0)<(ja|0)){ma=32<<u;s=2<<u;Z=8<<u;i=U>>u+6;Y=U>>u+2;ea=0-(Y>>1)|0;g=o;c=j;while(1){if((i|0)<=0){break E}h=s;C=(g<<2)+k|0;G=C+(ea<<2)|0;V=D(Z,12)+c|0;l=B[V>>2];L=(Z<<3)+c|0;r=B[L>>2];q=(Z<<2)+c|0;t=B[q>>2];I=B[V+4>>2];K=B[L+4>>2];W=B[q+4>>2];X=B[c+4>>2];ca=B[c>>2];V=0-Y<<2;while(1){if((h|0)>0){L=G-4|0;M=B[L>>2];aa=B[C>>2];ba=B[G>>2];B[C>>2]=aa+ba;q=C-4|0;J=B[q>>2];B[q>>2]=J+B[L>>2];J=E(J-M);M=E(aa-ba);B[L>>2]=E(J*ca)+E(X*M);B[G>>2]=E(M*ca)-E(X*J);L=G-12|0;aa=B[L>>2];q=C-8|0;J=B[q>>2];T=q;q=G-8|0;ba=B[q>>2];B[T>>2]=J+ba;T=C-12|0;M=B[T>>2];B[T>>2]=M+B[L>>2];M=E(M-aa);J=E(J-ba);B[L>>2]=E(M*t)+E(W*J);B[q>>2]=E(J*t)-E(W*M);L=G-20|0;aa=B[L>>2];q=C-16|0;J=B[q>>2];T=q;q=G-16|0;ba=B[q>>2];B[T>>2]=J+ba;T=C-20|0;M=B[T>>2];B[T>>2]=M+B[L>>2];M=E(M-aa);J=E(J-ba);B[L>>2]=E(M*r)+E(K*J);B[q>>2]=E(J*r)-E(K*M);L=G-28|0;aa=B[L>>2];q=C-24|0;J=B[q>>2];T=q;q=G-24|0;ba=B[q>>2];B[T>>2]=J+ba;T=C-28|0;M=B[T>>2];B[T>>2]=M+B[L>>2];M=E(M-aa);J=E(J-ba);B[L>>2]=E(M*l)+E(I*J);B[q>>2]=E(J*l)-E(I*M);h=h-1|0;G=G+V|0;C=C+V|0;continue}break}i=i-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(o<<2)+k|0;h=c-(H<<6)|0;l=B[j+(U>>3<<2)>>2];ca=E(-l);while(1){if(c>>>0>h>>>0){K=B[c>>2];g=c-32|0;W=B[g>>2];B[c>>2]=K+W;j=c-4|0;r=B[j>>2];q=j;j=c-36|0;X=B[j>>2];B[q>>2]=r+X;i=c-8|0;t=B[i>>2];q=i;i=c-40|0;J=B[i>>2];B[q>>2]=t+J;o=c-12|0;I=B[o>>2];q=o;o=c-44|0;M=B[o>>2];B[q>>2]=I+M;B[g>>2]=K-W;B[j>>2]=r-X;j=c-16|0;r=B[j>>2];q=j;j=c-48|0;aa=B[j>>2];B[q>>2]=r+aa;t=E(t-J);I=E(I-M);B[i>>2]=l*E(t+I);B[o>>2]=l*E(I-t);i=c-28|0;t=B[i>>2];o=c-60|0;I=B[o>>2];s=c-24|0;K=B[s>>2];u=c-56|0;W=B[u>>2];C=c-20|0;X=B[C>>2];q=C;C=c-52|0;J=B[C>>2];B[q>>2]=X+J;B[s>>2]=K+W;B[i>>2]=t+I;B[j>>2]=X-J;B[C>>2]=-E(r-aa);r=E(t-I);t=E(K-W);B[u>>2]=l*E(r-t);B[o>>2]=E(t+r)*ca;AL(c);AL(g);c=c+-64|0;continue}break}o=R-4|0;g=m+(o<<2)|0;i=(m+(P<<2)|0)-16|0;c=x[((O<<2)+a|0)+1100>>2];while(1){if(i>>>0>=m>>>0){h=(z[c>>1]<<2)+k|0;B[g+12>>2]=B[h>>2];B[g+8>>2]=B[h+4>>2];B[i+12>>2]=B[h+8>>2];B[i+8>>2]=B[h+12>>2];h=(z[c+2>>1]<<2)+k|0;B[g+4>>2]=B[h>>2];B[g>>2]=B[h+4>>2];B[i+4>>2]=B[h+8>>2];B[i>>2]=B[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;continue}break}c=x[((O<<2)+a|0)+1084>>2];i=m;g=i+(R<<2)|0;j=g;while(1){h=j-16|0;if(h>>>0>i>>>0){l=B[i+4>>2];s=j-4|0;r=B[s>>2];t=E(l-r);I=B[c+4>>2];l=E(l+r);r=B[i>>2];u=j-8|0;K=B[u>>2];W=E(r-K);X=B[c>>2];ca=E(E(I*l)-E(W*X));B[i+4>>2]=t+ca;r=E(r+K);l=E(E(I*W)+E(l*X));B[i>>2]=r+l;B[s>>2]=ca-t;B[u>>2]=r-l;l=B[i+8>>2];r=B[h>>2];t=E(l+r);I=B[c+12>>2];l=E(l-r);r=B[i+12>>2];j=j-12|0;K=B[j>>2];W=E(r+K);X=B[c+8>>2];ca=E(E(I*l)+E(W*X));B[i+8>>2]=t+ca;r=E(r-K);l=E(E(I*W)-E(l*X));B[i+12>>2]=r+l;B[h>>2]=t-ca;B[j>>2]=l-r;i=i+16|0;c=c+16|0;j=h;continue}break}i=x[((O<<2)+a|0)+1076>>2]+(R<<2)|0;c=(o<<2)+k|0;j=((U<<2)+k|0)-16|0;while(1){h=g-32|0;if(h>>>0>=m>>>0){l=B[g-8>>2];r=B[i-4>>2];t=B[i-8>>2];I=B[g-4>>2];K=E(E(l*r)-E(t*I));B[k>>2]=K;B[c+12>>2]=-K;l=E(E(t*E(-l))-E(r*I));B[F>>2]=l;B[j+12>>2]=l;l=B[g-16>>2];r=B[i-12>>2];t=B[i-16>>2];I=B[g-12>>2];K=E(E(l*r)-E(t*I));B[k+4>>2]=K;B[c+8>>2]=-K;l=E(E(t*E(-l))-E(r*I));B[F+4>>2]=l;B[j+8>>2]=l;l=B[g-24>>2];r=B[i-20>>2];t=B[i-24>>2];I=B[g-20>>2];K=E(E(l*r)-E(t*I));B[k+8>>2]=K;B[c+4>>2]=-K;l=E(E(t*E(-l))-E(r*I));B[F+8>>2]=l;B[j+4>>2]=l;l=B[h>>2];r=B[i-28>>2];i=i-32|0;t=B[i>>2];I=B[g-28>>2];K=E(E(l*r)-E(t*I));B[k+12>>2]=K;B[c>>2]=-K;l=E(E(t*E(-l))-E(r*I));B[F+12>>2]=l;B[j>>2]=l;j=j-16|0;c=c-16|0;F=F+16|0;k=k+16|0;g=h;continue}break}if(!x[a+80>>2]){Db(m)}x[a+92>>2]=la;break B}u=u+1|0;continue}}c=c+1|0;continue}break}n=n+1|0;m=x[a+4>>2];continue}break}}else{g=c<<2;k=g+a|0;i=x[k+800>>2];F:{if(x[g+(N+320|0)>>2]){Tb(i,0,O);break F}G=x[k+996>>2];G:{g=y[(y[(x[R+4>>2]+D(c,3)|0)+2|0]+R|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){ec(a,21);break G}o=U>>1;s=x[a+260>>2]+D(g,1596)|0;k=D(y[s+1588|0],w[G>>1]);u=1;g=0;while(1){if(x[s+1592>>2]>(u|0)){h=y[(u+s|0)+838|0]<<1;m=w[h+G>>1];if((m|0)>=0){j=D(y[s+1588|0],m&65535);m=z[(h+s|0)+338>>1];if((m|0)!=(g|0)){h=j-k|0;F=m-g|0;C=(h|0)/(F|0)|0;H:{H=(m|0)<(o|0)?m:o;if((H|0)<=(g|0)){break H}q=h;h=h>>31;P=C>>31;P=((q^h)-h|0)-D(F,(P^C)-P|0)|0;Z=h|1;h=i+(g<<2)|0;B[h>>2]=B[((k&255)<<2)+89136>>2]*B[h>>2];H=H-1|0;h=0;while(1){if((g|0)==(H|0)){break H}g=g+1|0;V=i+(g<<2)|0;h=h+P|0;L=(h|0)<(F|0);k=(k+C|0)+(L?0:Z)|0;B[V>>2]=B[((k&255)<<2)+89136>>2]*B[V>>2];h=h-(L?0:F)|0;continue}}g=m}k=j}u=u+1|0;continue}break}if((g|0)>=(o|0)){break G}k=(k<<2)+89136|0;while(1){if((g|0)==(o|0)){break G}h=i+(g<<2)|0;B[h>>2]=B[k>>2]*B[h>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}EL(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=U-ia;break I}c=x[a+1412>>2];if(!c){break I}g=ka-S|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[ha>>2]=ka;S=ka;break I}S=c+S|0;x[ha>>2]=S;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ia-S|0)>>>0){break N}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+S|0;c=(c|0)<(ia|0)?c:ia;x[$+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(S-da|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ka-S|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[$+12>>2]=ia}c=1;break o}_(6325,13258,3451,5634);p()}g=g-1|0;c=x[R+4>>2]+D(g,3)|0;m=x[k+(y[c+1|0]<<2)>>2];j=x[k+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(h|0)){continue z}i=c<<2;n=i+m|0;t=B[n>>2];i=i+j|0;l=B[i>>2];O:{if(l>E(0)){if(t>E(0)){r=E(l-t);break O}r=l;l=E(l+t);break O}if(t>E(0)){r=E(l+t);break O}r=l;l=E(l-t)}B[i>>2]=l;B[n>>2]=r;c=c+1|0;continue}}}_(6325,13258,3335,5634);p()}P=N+256|0;i=0;u=fb-16|0;fb=u;F=x[a+4>>2];G=x[a+396>>2];C=y[(m+la|0)+24|0];s=G+D(C,24)|0;g=x[s+4>>2];ja=z[((C<<1)+a|0)+268>>1];c=da<<((ja|0)==2);h=c>>>0>g>>>0?g:c;g=x[s>>2];O=(h-(c>>>0>g>>>0?g:c)>>>0)/A[s+8>>2]|0;k=O<<2;c=D(F,k+4|0);L=x[x[a+124>>2]+D(y[s+13|0],2096)>>2];T=x[a+92>>2];P:{if(x[a+80>>2]){g=io(a,c);F=x[a+4>>2];break P}g=Ed(c)}o=(n|0)>0?n:0;H=da<<2;h=0;c=(F|0)>0?F:0;j=(F<<2)+g|0;while(1){if((c|0)!=(h|0)){x[(h<<2)+g>>2]=j;h=h+1|0;j=j+k|0;continue}break}k=g;c=0;while(1){if((c|0)!=(o|0)){if(!y[c+N|0]){Tb(x[P+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((n|0)==1|(ja|0)!=2)){c=0;while(1){R:{if((c|0)!=(o|0)){if(y[c+N|0]){break R}}else{c=o}if((c|0)==(n|0)){break Q}F=G+D(C,24)|0;C=(n|0)!=2;G=(n|0)<3;while(1){if((i|0)==8){break Q}S:{if(!C){g=0;j=0;while(1){if((j|0)>=(O|0)){break S}c=x[s>>2]+D(x[s+8>>2],j)|0;x[u+12>>2]=c&1;x[u+8>>2]=c>>1;c=0;if(!i){o=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}h=x[a+1392>>2];H=w[(o+((h&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){q=h;H=H&65535;h=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:H;break T}h=Fm(a,o)}h=y[o+23|0]?x[x[o+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}x[x[k>>2]+(g<<2)>>2]=x[x[F+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(L|0)|(j|0)>=(O|0))){h=x[s+8>>2];o=w[(x[F+20>>2]+(y[x[x[k>>2]+(g<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!CL(a,x[a+124>>2]+D(o&65535,2096)|0,P,2,u+12|0,u+8|0,da,h)){break Q}j=j+1|0;break U}j=j+1|0;h=x[s>>2]+D(h,j)|0;x[u+8>>2]=h>>1;x[u+12>>2]=h&1}c=c+1|0;continue}break}g=g+1|0;continue}}if(G){break S}g=0;j=0;while(1){if((j|0)>=(O|0)){break S}h=x[s>>2]+D(x[s+8>>2],j)|0;c=(h|0)/(n|0)|0;x[u+12>>2]=h-D(c,n);x[u+8>>2]=c;c=0;if(!i){o=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}h=x[a+1392>>2];H=w[(o+((h&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){q=h;H=H&65535;h=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:H;break V}h=Fm(a,o)}h=y[o+23|0]?x[x[o+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}x[x[k>>2]+(g<<2)>>2]=x[x[F+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(L|0)|(j|0)>=(O|0))){h=x[s+8>>2];o=w[(x[F+20>>2]+(y[x[x[k>>2]+(g<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!CL(a,x[a+124>>2]+D(o&65535,2096)|0,P,n,u+12|0,u+8|0,da,h)){break Q}j=j+1|0;break W}j=j+1|0;h=x[s>>2]+D(h,j)|0;o=(h|0)/(n|0)|0;x[u+8>>2]=o;x[u+12>>2]=h-D(n,o)}c=c+1|0;continue}break}g=g+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=G+D(C,24)|0;n=0;while(1){if((n|0)==8){break Q}i=0;Z=0;X:while(1){if((i|0)<(O|0)){g=0;c=0;Y:{if(n){break Y}while(1){if((c|0)==(o|0)){break Y}if(!y[c+N|0]){j=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}h=x[a+1392>>2];F=w[(j+((h&1023)<<1)|0)+36>>1];Z:{if((F|0)>=0){q=h;F=F&65535;h=y[F+x[j+8>>2]|0];x[a+1392>>2]=q>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:F;break Z}h=Fm(a,j)}h=y[j+23|0]?x[x[j+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}x[x[k+(c<<2)>>2]+(Z<<2)>>2]=x[x[ma+16>>2]+(h<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((g|0)>=(L|0)){break $}c=0;if((i|0)>=(O|0)){break $}while(1){if((c|0)==(o|0)){break _}aa:{if(y[c+N|0]){break aa}h=c<<2;j=w[(x[ma+20>>2]+(y[x[x[h+k>>2]+(Z<<2)>>2]+g|0]<<4)|0)+(n<<1)>>1];if((j|0)<0){break aa}G=x[a+124>>2]+D(j&65535,2096)|0;Y=x[h+P>>2];V=x[s+8>>2];H=x[s>>2]+D(V,i)|0;ba:{ca:{if(ja){F=0;while(1){h=1;if((F|0)>=(V|0)){break ba}ea=Y+(H<<2)|0;h=V-F|0;C=0;l=E(0);da:{q=zL(a,G);if((q|0)<0){break da}j=x[G>>2];h=(h|0)>(j|0)?j:h;q=D(j,q);if(y[G+22|0]){j=0;h=(h|0)>0?h:0;C=1;while(1){if((h|0)==(j|0)){break da}ga=ea+(j<<2)|0;l=E(l+B[x[G+28>>2]+(j+q<<2)>>2]);B[ga>>2]=B[ga>>2]+l;j=j+1|0;l=E(l+B[G+12>>2]);continue}}j=0;h=(h|0)>0?h:0;C=1;while(1){if((h|0)==(j|0)){break da}ga=ea+(j<<2)|0;B[ga>>2]=B[ga>>2]+E(B[x[G+28>>2]+(j+q<<2)>>2]+E(0));j=j+1|0;continue}}if(!C){break ca}h=x[G>>2];H=h+H|0;F=h+F|0;continue}}F=0;ea=(V|0)/x[G>>2]|0;q=(ea|0)>0?ea:0;ga=Y+(H<<2)|0;h=1;while(1){if((F|0)==(q|0)){break ba}j=F+H|0;C=F<<2;F=F+1|0;sa=C+ga|0;Y=V-j|0;j=0;l=E(0);ea:{na=zL(a,G);if((na|0)<0){break ea}C=0;j=x[G>>2];Y=(j|0)<(Y|0)?j:Y;Y=(Y|0)>0?Y:0;na=D(j,na);j=1;while(1){if((C|0)==(Y|0)){break ea}qa=sa+(D(C,ea)<<2)|0;r=E(l+B[x[G+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+r;l=y[G+22|0]?r:l;C=C+1|0;continue}}if(j){continue}break}}h=0}if(!h){break Q}}c=c+1|0;continue}}Z=Z+1|0;continue X}i=i+1|0;g=g+1|0;continue}}break}n=n+1|0;continue}}if(!x[a+80>>2]){Db(k)}x[a+92>>2]=T;fb=u+16|0;m=m+1|0;continue}}_(6325,13258,3302,5634);p()}fb=N+2368|0}else{c=0}fb=fa+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Kh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Kh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}h=x[$+12>>2];j=x[$+4>>2];k=x[$+8>>2];ia:{ja:{m=x[a+992>>2];if(m){g=m<<1;ka:{if((g|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=x[a+116>>2]){break ka}c=a+1096|0}c=x[c>>2]}if(!c){break ja}n=(m|0)>0?m:0;while(1){if(x[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;g=0;while(1){if((g|0)!=(n|0)){S=x[i+800>>2]+(g+j<<2)|0;q=S;l=B[S>>2];S=g<<2;B[q>>2]=E(l*B[S+c>>2])+E(B[S+x[i+928>>2]>>2]*B[c+(m+(g^-1)<<2)>>2]);g=g+1|0;continue}break}Q=Q+1|0;continue}break}Q=x[a+992>>2]}x[a+992>>2]=h-k;m=(h|0)<(k|0);i=(m?k:h)-k|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;g=0;while(1){if((g|0)!=(i|0)){B[x[c+928>>2]+(g<<2)>>2]=B[x[c+800>>2]+(g+k<<2)>>2];g=g+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(m?h:k)-j|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}g=c;c=0;k=x[a+4>>2];h=(k|0)>0?k:0;while(1){if((c|0)!=(h|0)){m=(c<<2)+a|0;x[m+864>>2]=x[m+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){x[d>>2]=k}x[f>>2]=g;x[e>>2]=a+864;c=x[a+32>>2]-b|0}fb=$+16|0;return c}function Hpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-1728|0;fb=d;vc(b);f=fb-16|0;fb=f;h=d+1602|0;vX(f+8|0,h);g=x[f+12>>2];l=b;jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Ub(l,x[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){uX(h)}a:{if(!b){break a}if(!xX(d+1602|0)){break a}if(!Mb(x[l>>2],x[l+8>>2],Bc(256,0))){break a}b:{if(!c){break b}Ad(a,1048576);bg(a);b=fb-16|0;fb=b;e=rc(b+4|0,4230);Zc(d+1344|0,e);tb(e);fb=b+16|0;b=y[d+1610|0]|y[d+1611|0]<<8;x[d+144>>2]=b>>>8;x[31721]=0;x[d+12>>2]=b&255;O(448,d+72|0,d+12|0);b=x[31721];x[31721]=0;c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){x[31721]=0;V(434,d+256|0,d+1344|0,d+144|0,d+72|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}b=d+256|0;yb(a+1298344|0,b);tb(b);tb(d+72|0);e=d+1344|0;Eb(e);f=rc(b,15110);yb(a+1298356|0,f);tb(f);Te(e,2,d+1612|0);sr(b,22,e);yb(a+1298368|0,b);tb(b);H=a+1298404|0,I=x[Ec(b,22)>>2],x[H>>2]=I;rC(e,2,d+1644|0);Ac(b,e);yb(a+1298308|0,b);tb(b);w[a+480188>>1]=y[d+1714|0]|y[d+1715|0]<<8;f=y[d+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Hd(f,1,31),x[H+480196>>2]=I;w[a+480192>>1]=y[d+1724|0]|y[d+1725|0]<<8;w[a+480190>>1]=y[d+1726|0]|y[d+1727|0]<<8;f=Hd(y[d+1719|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;rw(l,e);f=a+484360|0;g=a+484376|0;Fr(Wb(x[f>>2],y[g|0]),e,y[d+1708|0]|y[d+1709|0]<<8,65535,65535);Ze(Wb(x[f>>2],y[g|0]),y[d+1710|0]|y[d+1711|0]<<8);r=dh(l);ce(b,l,r?274:0);C=hc(d+1324|0,b);ub(b);x[31721]=0;b=R(154,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}x[31721]=0;S(188,d+256|0,l|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}b=d+256|0;t=hc(d+1304|0,b);ub(b);b=a+480188|0;o=z[b>>1];if(r){w[b>>1]=o+8}B=c&1;if(!B){break f}x[31721]=0;O(226,a+484344|0,y[d+1712|0]|y[d+1713|0]<<8);b=x[31721];x[31721]=0;if((b|0)!=1){break f}g=N()|0;break e}g=N()|0;break h}g=N()|0;tb(d+72|0)}Eb(d+1344|0);break c}g=N()|0;break d}n=a+484344|0;E=a+480188|0;g=0;j:{k:{while(1){l:{m:{n:{o:{p:{q:{if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=s>>>0){b=y[d+1716|0]|y[d+1717|0]<<8;if((b-2&65535)>>>0>=4998){break o}if(!(g&1)){break q}h=0;b=Fc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break p}x[31721]=0;b=R(192,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}x[d+12>>2]=b;x[31721]=0;b=R(154,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break k}x[31721]=0;S(188,d+72|0,l|0,b+1&-2);b=x[31721];x[31721]=0;if((b|0)==1){break k}b=d+72|0;j=hc(d+256|0,b);ub(b);uc(d+12|0,1024);if(!B){break m}m=x[d+12>>2];if(!m){break m}x[31721]=0;b=U(199,n|0,s&65535,m|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if(!b){break m}k=0;e=0;if(v[d+1720|0]&1){break n}r:while(1){if((k|0)==(m|0)){break m}b=Vb(x[n>>2],s);_e(d+72|0,x[b>>2],x[x[b+48>>2]+12>>2],k);e=0;while(1){if((e|0)==(o|0)){k=k+1|0;continue r}x[31721]=0;O(626,j|0,d+144|0);b=x[31721];x[31721]=0;if((b|0)!=1){g=tX(Vc(x[d+72>>2],e),d+144|0)|g;e=e+1|0;continue}break}break}break l}break l}h=2;b=Xe(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}h=a+480188|0;b=z[h>>1];x[31721]=0;v[d+256|0]=0;s=U(627,d+1292|0,b|0,d+256|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){k=a+1298320|0;m=a+1298332|0;q=a+484348|0;j=0;s:{t:{u:{v:{w:{x:{while(1){b=x[t+8>>2];e=x[t>>2];x[31721]=0;b=U(153,e|0,b|0,8)|0;e=x[31721];x[31721]=0;y:{if((e|0)!=1){if(b){break y}b=a+906300|0;h=x[s>>2];k=0;m=a+480188|0;while(1){f=z[m>>1];if(f>>>0<=k>>>0){x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;x[d+232>>2]=0;x[d+236>>2]=0;x[d+224>>2]=0;x[d+228>>2]=0;z:{A:{if(!r){break A}e=0;x[31721]=0;O(628,C|0,d+256|0);b=x[31721];x[31721]=0;if((b|0)==1){break z}while(1){if((e|0)==8){e=0;x[31721]=0;k=P(217,d+212|0,z[d+256>>1])|0;b=x[31721];x[31721]=0;if((b|0)!=1){B:{C:{D:{E:{while(1){if(z[d+256>>1]<=e>>>0){x[31721]=0;m=U(629,d+200|0,y[d+1712|0]|y[d+1713|0]<<8,25272)|0;b=x[31721];x[31721]=0;if((b|0)==1){break C}q=a+484376|0;r=a+484348|0;B=a+480188|0;f=0;break D}x[31721]=0;b=R(192,l|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){x[31721]=0;S(188,d+144|0,l|0,b<<5);b=x[31721];x[31721]=0;if((b|0)==1){break E}f=d+144|0;b=hc(d+72|0,f);gd($g(x[k>>2],e),b);ub(b);e=e+1|0;ub(f);continue}break}g=N()|0;break B}g=N()|0;break B}while(1){if((y[d+1708|0]|y[d+1709|0]<<8)>>>0<=f>>>0){ld(m);Pc(k);break A}F:{g=d+f|0;e=y[g+274|0];if(e>>>0>=z[d+256>>1]){break F}b=z[Zb(x[Wb(x[a+484360>>2],y[q|0])>>2],f)>>1];if(b>>>0>=(y[d+1712|0]|y[d+1713|0]<<8)>>>0){break F}G:{h=Zb(x[m>>2],b);i=z[h>>1];H:{if((i|0)==65535){w[h>>1]=e;break H}if((e|0)==(i|0)){break H}x[31721]=0;e=P(630,n|0,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break G}if((e|0)==65535){break H}H=Zb(x[Wb(x[a+484360>>2],y[q|0])>>2],f),I=e,w[H>>1]=I;b=e}if(!Ge(x[a+484344>>2],x[r>>2],b)){break F}i=$g(x[k>>2],y[g+274|0]);vc(i);e=x[i>>2];x[31721]=0;e=R(157,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break G}E=e>>>5|0;h=0;I:while(1){e=Vb(x[n>>2],b);if(A[e+12>>2]<=h>>>0){break F}g=0;e=jd(x[e>>2],x[x[e+48>>2]+12>>2],h,z[B>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue I}v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;J:{if(h>>>0>=E>>>0){break J}x[31721]=0;P(631,i|0,d+72|0)|0;u=x[31721];x[31721]=0;if((u|0)==1){break G}if(v[d+72|0]>=0){break J}v[e|0]=61;v[e+1|0]=y[(d+240|0)+(g<<1)|0];u=y[d+72|0]&31;v[d+144|0]=u;if(u){Jf(d+144|0,15);v[e+3|0]=20;v[e+5|0]=y[d+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+73|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=N()|0;ld(m);break B}f=f+1|0;continue}}g=N()|0}Pc(k);break s}g=N()|0;break s}f=e<<1;g=f+(d+240|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){K:{L:{k=b&65535;if(k>>>0<=h>>>0){if(x[((k<<2)+a|0)+900380>>2]){break L}}else{b=65535}b=b&65535;break K}b=b+1|0;continue}break}w[g>>1]=b;h=f+(d+224|0)|0;f=z[(d+f|0)+258>>1];w[h>>1]=f;M:{if((b|0)!=65535){x[31721]=0;b=U(254,a|0,b|0,f+1&65535)|0;f=x[31721];x[31721]=0;N:{O:{if((f|0)!=1){if(!b){break M}x[31721]=0;O(291,d+144|0,4475);f=x[31721];x[31721]=0;if((f|0)==1){break O}x[31721]=0;x[d+12>>2]=e+1;S(632,d+72|0,d+144|0,d+12|0);f=x[31721];x[31721]=0;if((f|0)==1){break N}f=b+492|0;b=d+72|0;xc(f,b);tb(b);Eb(d+144|0);break M}g=N()|0;break s}g=N()|0;break s}g=N()|0;Eb(d+144|0);break s}w[g>>1]=0}e=e+1|0;continue}}P:{Q:{b=y[d+1720|0]|y[d+1721|0]<<8|(y[d+1722|0]<<16|y[d+1723|0]<<24);if(!(b&2)){break Q}b=(((b&8?z[a+480188>>1]:o)&65535)+((y[d+1610|0]|y[d+1611|0]<<8)>>>0>591?j:0)|0)+(b>>>4&1)|0;f=0;R:while(1){e=0;if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=f>>>0){break Q}while(1){S:{if((b|0)!=(e|0)){g=x[l+8>>2];h=x[l>>2];x[31721]=0;g=U(153,h|0,g|0,4)|0;h=x[31721];x[31721]=0;if((h|0)==1){break P}if(g){break S}}f=f+1|0;continue R}x[31721]=0;O(633,y[d+1610|0]|y[d+1611|0]<<8,l|0);g=x[31721];x[31721]=0;if((g|0)==1){break P}e=e+1|0;continue}}}x[31721]=0;k=P(217,d+188|0,255)|0;b=x[31721];x[31721]=0;if((b|0)!=1){q=a+480208|0;f=0;while(1){T:{b=f;U:{if((b|0)==255){n=oC(d+72|0);m=oC(d+144|0);g=0;while(1){V:{W:{X:{if((g|0)==256){h=0;break X}x[31721]=0;O(634,l|0,d+256|0);b=x[31721];x[31721]=0;if((b|0)==1){break W}x[31721]=0;b=R(154,l|0)|0;e=x[31721];x[31721]=0;Y:{Z:{_:{if((e|0)!=1){x[31721]=0;S(188,d+12|0,l|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break _}e=d+12|0;j=hc(d+52|0,e);ub(e);if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){e=d+40|0;Te(e,2,d+256|0);x[31721]=0;O(221,d+12|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break Y}e=d+12|0;xc(((g<<5)+a|0)+946336|0,e);tb(e)}if(!b){break V}if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){break Z}break V}g=N()|0;break U}g=N()|0;break U}x[31721]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;O(282,e|0,32);f=x[31721];x[31721]=0;$:{aa:{ba:{if((f|0)!=1){op(e);x[31721]=0;O(635,j|0,d+12|0);f=x[31721];x[31721]=0;if((f|0)==1){break Y}f=x[d+12>>2];x[e>>2]=f;x[b+484404>>2]=x[d+16>>2];if(y[d+20|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+21|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|64;x[e>>2]=f>>>1}h=2;switch(y[d+23|0]-1|0){case 0:break aa;case 1:break ba;default:break $}}break Y}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+24>>2];x[b+484388>>2]=x[d+28>>2];w[b+484410>>1]=z[d+32>>1]>>>7;e=y[d+34|0];ca:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ca}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+35|0];e=y[d+22|0];if(e&2){b=d+40|0;Kb(b,m,g);Vo(b);e=y[d+22|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break V}b=d+40|0;Kb(b,n,g);Vo(b);e=0;while(1){if((e|0)==8){break V}b=e<<1;da:{if(z[b+(d+224|0)>>1]!=(g|0)){break da}b=x[((z[b+(d+240|0)>>1]<<2)+a|0)+900380>>2];if(!b){break da}v[b+14|0]=0}e=e+1|0;continue}}g=N()|0;ub(j);break U}while(1){ea:{fa:{if((y[d+1724|0]|y[d+1725|0]<<8)>>>0<=h>>>0){if(!(c&2)){break fa}e=a+1298404|0;f=a+1298472|0;g=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{while(1){if(z[a+480190>>1]<=g>>>0){break fa}g=g+1|0;c=D(g,104)+a|0;h=c+484380|0;b=c+484416|0;am(h,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=Wc(d+256|0,b&1?16:8,b&64?3:1,0,11);x[31721]=0;U(218,b|0,h|0,l|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}g=N()|0;break U}x[31721]=0;h=R(154,l|0)|0;b=x[31721];x[31721]=0;oa:{if((b|0)==1){break oa}x[31721]=0;P(186,l|0,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break oa}b=Fb(d+256|0);x[31721]=0;S(273,l|0,b|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break na}ye(c+484423|0,b);x[31721]=0;O(387,d+52|0,16445);c=x[31721];x[31721]=0;if((c|0)==1){break ma}x[d+8>>2]=g;c=x[e>>2];x[31721]=0;S(636,d+40|0,c|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break la}x[31721]=0;V(434,d+12|0,d+52|0,d+8|0,d+40|0);c=x[31721];x[31721]=0;if((c|0)==1){break ka}c=x[f>>2];x[31721]=0;S(389,c|0,2,d+12|0);c=x[31721];x[31721]=0;if((c|0)==1){break ja}tb(d+12|0);tb(d+40|0);Eb(d+52|0);tb(b);continue}break}g=N()|0;break U}g=N()|0;break ga}g=N()|0;break ga}g=N()|0;break ha}g=N()|0;break ia}g=N()|0;tb(d+12|0)}tb(d+40|0)}Eb(d+52|0)}tb(b);break U}b=x[$g(x[k>>2],h)>>2];x[31721]=0;b=R(157,b|0)|0;e=x[31721];x[31721]=0;pa:{qa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=$g(x[k>>2],h);vc(b);x[31721]=0;O(637,b|0,d+256|0);b=x[31721];x[31721]=0;if((b|0)==1){break qa}j=Nb(d+12|0);x[31721]=0;S(638,l|0,j|0,z[d+256>>1]);b=x[31721];x[31721]=0;if((b|0)==1){break pa}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ea}x[b+4>>2]=32;e=0;xv(b,0);q=b+108|0;i=b+236|0;while(1){if((e|0)==96){break ea}f=y[(d+e|0)+258|0];ra:{if(f>>>0>=z[d+256>>1]){break ra}o=Re(x[j>>2],f);f=y[o|0];g=f+1|0;r=e+12|0;H=Zb(i,r),I=g,w[H>>1]=I;if(f>>>0>=z[a+480190>>1]){break ra}f=D(g,104)+a|0;v[f+484418|0]=y[d+354|0]&3;v[f+484419|0]=y[d+355|0];v[f+484420|0]=y[d+356|0];v[f+484421|0]=y[d+357|0];w[f+484412>>1]=y[o+1|0]<<1;v[f+484417|0]=y[o+2|0];f=g-1|0;Kb(d+52|0,n,f);if(Hb(x[x[d+52>>2]>>2],x[d+56>>2])){v[b+14|0]=0}Kb(d+52|0,m,f);if(!Hb(x[x[d+52>>2]>>2],x[d+56>>2])){break ra}H=vb(q,r),I=61,v[H|0]=I}e=e+1|0;continue}}g=N()|0;break U}g=N()|0;break U}g=N()|0;ze(j);break U}Pc(k);cc(s);ub(t);ub(C);break b}ze(j);continue}}g=N()|0;break U}ub(j);g=g+1|0;continue}}x[31721]=0;O(634,l|0,d+144|0);e=x[31721];x[31721]=0;sa:{ta:{ua:{va:{if((e|0)!=1){x[31721]=0;e=R(154,l|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break va}x[31721]=0;e=(e|0)==32?428:e;j=e?(y[d+1610|0]|y[d+1611|0]<<8)>>>0>513?e+4|0:e:e;S(188,d+72|0,l|0,j|0);e=x[31721];x[31721]=0;if((e|0)==1){break ua}g=d+72|0;e=hc(d+256|0,g);h=Fe(d+12|0,gd($g(x[k>>2],b),e));ub(e);f=b+1|0;ub(g);if(b>>>0>=(y[d+1724|0]|y[d+1725|0]<<8)>>>0){break T}x[31721]=0;b=f&65535;g=U(254,a|0,b|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break ta}break sa}g=N()|0;break U}g=N()|0;break U}g=N()|0;break U}if(!g){break T}b=d+72|0;Te(b,2,d+144|0);x[31721]=0;O(221,d+256|0,b|0);b=x[31721];x[31721]=0;wa:{if((b|0)!=1){b=d+256|0;xc(g+492|0,b);tb(b);if(!j){break T}x[31721]=0;O(637,h|0,d+256|0);b=x[31721];x[31721]=0;if((b|0)!=1){j=3;n=0;if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<513){m=0;break wa}x[31721]=0;m=R(192,h|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break sa}if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<514){break wa}x[31721]=0;j=R(154,h|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break wa}break sa}break sa}break sa}x[g>>2]=y[d+358|0]|y[d+359|0]<<8;v[g+16|0]=y[((y[d+360|0]|y[d+361|0]<<8)&3)+25274|0];v[g+17|0]=y[(y[d+361|0]&3)+25274|0];v[g+18|0]=y[((y[d+360|0]|y[d+361|0]<<8)>>>12&3)+25278|0];while(1){xa:{ya:{if((n|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}gk(g,127,1);fk(g,0,1);if(!m){break T}x[31721]=0;O(639,h|0,d+72|0);b=x[31721];x[31721]=0;if((b|0)==1){break sa}if(m&2){gk(g,oD(x[q>>2],+((y[d+74|0]|y[d+75|0]<<8)>>>0)),1);fk(g,y[d+76|0],1)}v[g+25|0]=y[d+73|0]==1;if(!(m&4)){break T}v[g+31|0]=y[d+79|0]+1;b=v[d+80|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+87|0]+1}if(!y[d+84|0]){break ya}j=g+108|0;e=0;while(1){if((e|0)==128){break ya}b=e+1|0;x[d+52>>2]=b+v[d+84|0];rX(d+52|0);n=x[d+52>>2];H=vb(j,e),I=n,v[H|0]=I;e=b;continue}}if(!(j&1)){break xa}x[31721]=0;O(640,h|0,d+72|0);b=x[31721];x[31721]=0;za:{if((b|0)!=1){b=Wh(g,y[n+25282|0]);Aa:{if((n|0)!=3){e=y[d+72|0];o=y[b+12|0]&-17;break Aa}e=y[d+72|0];o=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));v[d+52|0]=y[d+73|0];v[d+40|0]=16;e=y[Sb(d+52|0,d+40|0)|0];x[31721]=0;O(296,b|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break za}e=y[d+74|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+75|0];v[b+14|0]=y[d+76|0];e=0;o=x[b>>2];i=Pd(o,x[b+4>>2]);while(1){if((e|0)==(i|0)){break xa}r=xb(o,e);b=(d+72|0)+(e<<2)|0;w[r>>1]=y[b+8|0]|y[b+9|0]<<8;H=r,I=Hd(y[b+10|0]|y[b+11|0]<<8,0,64),v[H+2|0]=I;e=e+1|0;continue}}break sa}break sa}xv(g,0);break T}n=n+1|0;j=j>>>1|0;continue}}g=N()|0;ub(h)}Pc(k);break s}ub(h);continue}}g=N()|0;break s}g=N()|0;break s}g=N()|0;break s}else{e=v[vb(h,k)|0];Ba:{if((e|0)<=(k|0)|(e|0)>=(f|0)){break Ba}e=y[((e<<5)+a|0)+480288|0];if(!e){break Ba}f=((k<<5)+a|0)+480288|0;g=y[f|0];if(!g){v[f|0]=e;break Ba}g=g-1|0;while(1){f=g&255;g=lm(x[sd(b,f)+28>>2]);f=sd(b,f);if((g|0)==255){e=e-1&255;x[f+28>>2]=e>>>0<250?e+128|0:0}else{g=lm(x[f+28>>2]);continue}break}}k=k+1|0;continue}}}g=N()|0;break s}x[31721]=0;f=R(154,t|0)|0;b=x[31721];x[31721]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((b|0)!=1){x[31721]=0;b=R(154,t|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Ka}x[31721]=0;S(188,d+256|0,t|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ka}e=d+256|0;b=hc(d+72|0,e);ub(e);if((f|0)==4674381){break Ga}if((f|0)==5068115){break Fa}if((f|0)==726487106){break Ja}if((f|0)==844387158){break Ea}e=0;if((f|0)==1280004692){break Ia}if((f|0)==1314144592){break Ha}if((f|0)!=1397445204){break Da}x[31721]=0;e=R(192,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[h>>1]<=e>>>0){break Da}x[31721]=0;f=P(641,b|0,d+256|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break x}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+256>>1]>>>10;H=vb(x[s>>2],e),I=y[d+259|0],v[H|0]=I}e=e+1|0;continue}}g=N()|0;break s}g=N()|0;break s}if(g&1){break Da}v[a+480224|0]=2;x[31721]=0;F=+ia(642,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break Ca}if(!(F>1e-8)){break Da}H=a,I=Xe(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break Da}while(1){La:{if(z[h>>1]<=e>>>0){break Da}f=x[b>>2];x[31721]=0;f=U(153,f|0,x[d+80>>2],1)|0;i=x[31721];x[31721]=0;if((i|0)==1){break w}if(!f){break Da}f=Fb(d+256|0);x[31721]=0;S(361,b|0,f|0,-1);i=x[31721];x[31721]=0;if((i|0)!=1){i=d+12|0;rg(i,3,Jb(f),Xc(x[d+260>>2],y[d+267|0]));x[31721]=0;O(221,d+144|0,i|0);i=x[31721];x[31721]=0;if((i|0)==1){break La}i=d+144|0;Tk(((e<<5)+a|0)+480289|0,i);tb(i);tb(f);e=e+1|0;continue}}break}g=N()|0;tb(f);break t}while(1){if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=e>>>0){break Da}f=x[b>>2];x[31721]=0;f=U(153,f|0,x[d+80>>2],1)|0;i=x[31721];x[31721]=0;if((i|0)==1){break v}if(!f){break Da}if(!vn(x[a+484344>>2],x[q>>2],e&65535)){break Da}f=Fb(d+256|0);x[31721]=0;S(361,b|0,f|0,-1);i=x[31721];x[31721]=0;Ma:{if((i|0)==1){break Ma}i=x[n>>2];x[31721]=0;O(286,Vb(i,e)|0,f|0);i=x[31721];x[31721]=0;if((i|0)==1){break Ma}tb(f);e=e+1|0;continue}break}g=N()|0;tb(f);break t}x[31721]=0;P(186,b|0,1)|0;e=x[31721];x[31721]=0;if((e|0)==1){break u}x[31721]=0;e=R(205,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}x[31721]=0;V(339,m|0,b|0,e|0,2);e=x[31721];x[31721]=0;if((e|0)!=1){break Da}break u}x[31721]=0;P(643,b|0,d+12|0)|0;e=x[31721];x[31721]=0;Na:{if((e|0)!=1){e=Fb(d+256|0);x[31721]=0;S(361,b|0,e|0,-1);f=x[31721];x[31721]=0;if((f|0)==1){break Na}if(fr(e,12682)){x[31721]=0;S(261,d+144|0,22,e|0);f=x[31721];x[31721]=0;if((f|0)==1){break Na}f=d+144|0;yb(k,f);tb(f)}tb(e);break Da}g=N()|0;break t}g=N()|0;tb(e);break t}x[31721]=0;j=R(154,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break u}}ub(b);continue}break}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0}ub(b)}cc(s);break e}g=N()|0;break e}while(1){b=x[j>>2];x[31721]=0;b=U(153,b|0,x[d+264>>2],1)|0;f=x[31721];x[31721]=0;Oa:{if((f|0)!=1){if(!b){break m}x[31721]=0;h=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}q=0;if((h|0)!=255){break Oa}x[31721]=0;q=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;h=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break Oa}}break l}break l}if(h&127){b=Vb(x[n>>2],s);f=jd(x[b>>2],x[x[b+48>>2]+12>>2],e,k&65535);jE(d+72|0);if(h&1){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+72|0]=b}if(h&2){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+73|0]=b}if(h&4){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+74|0]=b}if(h&8){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+75|0]=b}if(h&16){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+76|0]=b}if(h&32){x[31721]=0;b=R(200,j|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break l}v[d+77|0]=b}if(h&64){x[31721]=0;b=R(200,j|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break l}v[d+78|0]=b}u=tX(f,d+72|0);x[d+144>>2]=q;x[d+52>>2]=m+(e^-1);G=x[Gb(d+144|0,d+52|0)>>2];h=0;b=f;while(1){if((h|0)!=(G|0)){b=D(z[E>>1],6)+b|0;i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=i;v[b+1|0]=i>>>8;v[b+2|0]=i>>>16;v[b+3|0]=i>>>24;i=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=i;v[b+5|0]=i>>>8;h=h+1|0;continue}break}g=g|u}e=(e+q|0)+1|0;while(1){if(e>>>0>=m>>>0){k=k+1|0;e=e-m|0;continue}break}if(o>>>0>(k&65535)>>>0){continue}break}}ub(j);s=s+1|0;continue}break}g=N()|0;ub(j);break e}g=N()|0;break e}g=N()|0}ub(t)}ub(C)}Q(g|0);p()}e=1}fb=d+1728|0;return e|0}function Csa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;d=fb-1120|0;fb=d;vc(b);e=fb-16|0;fb=e;r=d+884|0;SZ(e+8|0,r);g=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){RZ(r)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!UZ(d+884|0)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(TZ(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}if(!c){f=1;break o}Ad(a,16777216);bg(a);e=a+480208|0;x[e>>2]=x[e>>2]|16809984;e=d+448|0;dr(e,32);g=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=g;f=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=f;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);f=cp(d+840|0);E=f,F=Hd(y[d+1084|0],1,31),x[E+8>>2]=F;E=f,F=Hd(y[d+1085|0],1,12),x[E+4>>2]=F;E=f,F=Cb(y[d+1086|0]|y[d+1087|0]<<8),x[E>>2]=F;TD(a+1298412|0,f);w[a+480188>>1]=32;f=d+36|0;QZ(f,3,d+1088|0);sr(e,1,f);yb(a+1298368|0,e);tb(e);p:{if(y[d+887|0]<=5){dg(d+36|0,3924);break p}e=fb-16|0;fb=e;f=rc(e+4|0,3993);Zc(d+36|0,f);tb(f);fb=e+16|0}x[31721]=0;S(374,d+448|0,d+36|0,y[d+887|0]);e=x[31721];x[31721]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){e=d+448|0;yb(a+1298344|0,e);tb(e);f=d+36|0;Eb(f);g=rc(e,15114);yb(a+1298356|0,g);tb(g);E=a+1298404|0,F=x[Ec(e,26)>>2],x[E>>2]=F;Te(f,3,d+892|0);Ac(e,f);yb(a+1298308|0,e);tb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}E=d,F=Cb(y[d+1112|0]|y[d+1113|0]<<8),w[E+448>>1]=F;w[d+36>>1]=1;e=d+448|0;f=d+36|0;E=a,F=z[oe(e,f)>>1],x[E+480196>>2]=F;E=d,F=Cb(y[d+1114|0]|y[d+1115|0]<<8),w[E+448>>1]=F;w[d+36>>1]=1;E=a,F=D(z[oe(e,f)>>1],1e4),x[E+480204>>2]=F;E=d,F=Bc(((Cb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[E+448>>2]=F;x[d+36>>2]=256;E=a,F=x[Gb(e,f)>>2],x[E+480200>>2]=F;E=d,F=Cb(y[d+1118|0]|y[d+1119|0]<<8),w[E+448>>1]=F;Qf(e,127);f=0;e=z[d+448>>1];while(1){if((e|0)==(f|0)){break G}E=d,F=Bc(((Rk(b)<<8)+2047>>>0)/4095|0,0),w[E+36>>1]=F;w[d+344>>1]=256;E=((f<<5)+a|0)+480284|0,F=z[Lc(d+36|0,d+344|0)>>1],w[E>>1]=F;f=f+1|0;continue}}bd(b,_b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));r=Fe(d+820|0,b);x[31721]=0;O(379,d+808|0,r|0);b=x[31721];x[31721]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31721]=0;S(380,d+448|0,d+808|0,1346458707);b=x[31721];x[31721]=0;if((b|0)==1){break H}x[31721]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break K}if(!b){break I}x[31721]=0;b=R(276,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}w[a+480188>>1]=b;b=d+448|0;ub(b);x[31721]=0;S(380,b|0,d+808|0,1397706311);b=x[31721];x[31721]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31721]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break E}if(!b){break I}x[31721]=0;b=R(276,d+448|0)|0;e=x[31721];x[31721]=0;M:{if((e|0)==1){break M}w[d+36>>1]=b;b=y[a+484376|0];e=x[a+484360>>2];x[31721]=0;f=R(276,d+448|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break M}Ze(Wb(e,b),f);x[31721]=0;b=R(205,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break M}Qf(d+36|0,em(b>>>1|0));b=y[a+484376|0];e=x[a+484360>>2];x[31721]=0;S(279,Wb(e,b)|0,d+448|0,z[d+36>>1]);b=x[31721];x[31721]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31721]=0;S(380,b|0,d+808|0,1480806221);b=x[31721];x[31721]=0;if((b|0)==1){break F}x[31721]=0;b=U(153,x[d+448>>2],x[d+456>>2],3)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if(b){break D}b=160;while(1){N:{f=b;if(!b){f=0;break N}b=f-1|0;if(y[(d+b|0)+924|0]==32){continue}}break}x[31721]=0;V(346,a+1298332|0,d+924|0,f|0,4);b=x[31721];x[31721]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31721]=0;b=R(276,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;V(339,a+1298332|0,d+448|0,b|0,4);b=x[31721];x[31721]=0;if((b|0)!=1){break C}}break B}b=d+448|0;ub(b);x[31721]=0;S(380,b|0,d+808|0,1413697073);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[31721]=0;b=R(200,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break y}if(b){break z}x[31721]=0;b=P(152,d+448|0,2648)|0;e=x[31721];x[31721]=0;if((e|0)==1){break y}if(!b){break z}f=0;x[31721]=0;b=R(284,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break y}while(1){if((f|0)==32){break z}e=((f<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+448|0;ub(b);x[31721]=0;S(380,b|0,d+808|0,1413697074);b=x[31721];x[31721]=0;if((b|0)==1){break x}x[31721]=0;b=U(153,x[d+448>>2],x[d+456>>2],12)|0;e=x[31721];x[31721]=0;if((e|0)==1){break w}O:{if(!b){break O}x[31721]=0;O(381,d+36|0,d+448|0);b=x[31721];x[31721]=0;if((b|0)==1){break w}b=d+36|0;e=Ye(b);f=dc(b);g=PZ(b);h=Ab(b);n=OZ(b);b=D(Hd(Cb(y[e|0]|y[e+1|0]<<8),32,999),1e4);e=zua(Cb(y[f|0]|y[f+1|0]<<8),0,1e4,0);f=hb;e=e+32768|0;f=e>>>0<32768?f+1|0:f;E=a,F=((Bc((f&65535)<<16|e>>>16,f>>>16|0)>>>0)%1e4|0)+b|0,x[E+480204>>2]=F;E=a,F=Hd(Cb(y[g|0]|y[g+1|0]<<8),1,255),x[E+480196>>2]=F;b=16/(Hd(Cb(y[n|0]|y[n+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;E=a,F=D(Hd(Cb(y[h|0]|y[h+1|0]<<8),1,16),b),x[E+480220>>2]=F;if(!Cb(z[d+36>>1])){break O}x[31721]=0;b=R(276,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break w}e=a+480208|0;x[e>>2]=x[e>>2]&-17|!b<<4}b=d+448|0;ub(b);x[31721]=0;S(380,b|0,d+808|0,1414942540);b=x[31721];x[31721]=0;if((b|0)==1){break v}x[31721]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break t}if(!b){break u}x[31721]=0;b=R(276,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break t}w[d+36>>1]=b;w[d+344>>1]=z[a+480188>>1];b=z[Lc(d+36|0,d+344|0)>>1];f=0;while(1){if((b|0)==(f|0)){break u}x[31721]=0;e=R(276,d+448|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break t}w[d+36>>1]=e;w[d+344>>1]=4096;E=((f<<5)+a|0)+480286|0,F=z[Lc(d+36|0,d+344|0)>>1]>>>6&255,w[E>>1]=F;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}ub(d+448|0);x[31721]=0;S(380,d+36|0,d+808|0,1296652368);b=x[31721];x[31721]=0;if((b|0)==1){break s}x[31721]=0;b=U(153,x[d+36>>2],x[d+44>>2],56)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}if(!b){break r}x[31721]=0;O(382,d+36|0,d+448|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}if((Cb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Cb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}E=d,F=Cb(y[d+488|0]|y[d+489|0]<<8),w[E+344>>1]=F;w[d+796>>1]=16384;e=z[Lc(d+344|0,d+796|0)>>1];b=e>>>24|0;f=(e<<8)+2048|0;b=f>>>0<2048?b+1|0:b;E=a,F=Bc((b&4095)<<20|f>>>12,b>>>12|0),x[E+480200>>2]=F;h=a+480188|0;f=0;while(1){if(Cb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(f&65535)>>>0){break r}x[31721]=0;O(383,d+36|0,d+344|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}P:{if(y[d+344|0]){break P}b=Cb(y[d+346|0]|y[d+347|0]<<8);if(b>>>0>=z[h>>1]){break P}b=(b<<5)+a|0;E=b+480284|0,F=Bc(((Cb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[E>>1]=F;i=b+480286|0;e=Cb(y[d+348|0]|y[d+349|0]<<8);b=e>>>26|0;g=(e<<6)+2048|0;b=g>>>0<2048?b+1|0:b;E=i,F=Bc((b&4095)<<20|g>>>12,b>>>12|0)&255,w[E>>1]=F}f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31721]=0;S(384,b|0,d+808|0,1396788530);b=x[31721];x[31721]=0;if((b|0)==1){break e}E=d,F=wb(x[d+36>>2]),x[E+760>>2]=F;f=c&2;h=d+450|0;n=wb(x[d+40>>2]);g=a+480190|0;j=a+1298472|0;Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){e=x[d+760>>2];if(!Ib(e,n)){b=d+36|0;Pc(b);x[31721]=0;S(384,b|0,d+808|0,1396788560);b=x[31721];x[31721]=0;if((b|0)==1){break f}E=d,F=wb(x[d+36>>2]),x[E+784>>2]=F;h=d+450|0;n=wb(x[d+40>>2]);e=a+480190|0;break Q}x[31721]=0;b=P(385,e|0,d+448|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break S}_:{$:{if(!b){break $}b=Cb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Cb(z[d+496>>1])>>>0>1){break $}if(Cb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[g>>1]){w[g>>1]=b}x[31721]=0;m=D(b,104)+a|0;b=m+484380|0;O(386,d+448|0,b|0);i=x[31721];x[31721]=0;aa:{ba:{ca:{if((i|0)==1){break ca}i=d+796|0;Zi(i,3,h);x[31721]=0;O(221,d+344|0,i|0);i=x[31721];x[31721]=0;if((i|0)==1){break ba}i=d+344|0;xc(((Cb(z[d+448>>1])<<5)+a|0)+946304|0,i);tb(i);if(!f){break $}i=z[d+522>>1]|z[d+524>>1]<<16;x[31721]=0;i=P(152,e|0,_b(i)-8|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ca}if(!i){break $}if(Cb(z[d+478>>1])){break aa}i=d+344|0;Wc(i,(Cb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Cb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Cb(y[d+482|0]|y[d+483|0]<<8),0);x[31721]=0;U(218,i|0,b|0,e|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}b=Fb(d+344|0);i=z[d+498>>1];x[31721]=0;S(273,e|0,b|0,Cb(i)|0);e=x[31721];x[31721]=0;if((e|0)==1){break U}ye(m+484423|0,b);if((Cb(z[d+478>>1])|0)==1){x[31721]=0;O(387,d+784|0,16445);e=x[31721];x[31721]=0;if((e|0)==1){break _}x[31721]=0;S(261,d+772|0,0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break Z}x[31721]=0;V(388,d+796|0,d+784|0,z[d+448>>1],d+772|0);e=x[31721];x[31721]=0;if((e|0)==1){break Y}e=x[j>>2];x[31721]=0;S(389,e|0,2,d+796|0);e=x[31721];x[31721]=0;if((e|0)==1){break X}tb(d+796|0);tb(d+772|0);Eb(d+784|0)}tb(b)}Yf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(b);break R}a=N()|0}Pc(d+36|0);break c}da:{while(1){ea:{g=x[d+784>>2];if(!Ib(g,n)){Pc(d+36|0);x[31721]=0;S(384,d+796|0,d+808|0,1447382614);b=x[31721];x[31721]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31721]=0;b=P(390,g|0,d+448|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break ea}fa:{ga:{if(!b){break ga}b=Cb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Cb(z[d+502>>1])){break ga}if(b>>>0>z[e>>1]){w[e>>1]=b}x[31721]=0;b=(D(b,104)+a|0)+484380|0;O(391,d+448|0,b|0);j=x[31721];x[31721]=0;if((j|0)==1){break ea}j=d+796|0;Zi(j,3,h);x[31721]=0;O(221,d+344|0,j|0);j=x[31721];x[31721]=0;if((j|0)==1){break ea}j=d+344|0;xc(((Cb(z[d+448>>1])<<5)+a|0)+946304|0,j);tb(j);if(!f){break ga}j=z[d+478>>1];m=d+344|0;Wc(m,(Cb(z[d+482>>1])|0)==8?8:16,Cb(j)&1?2:1,1,0);x[31721]=0;U(218,m|0,b|0,g|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break fa}}Yf(d+784|0);continue}}break}a=N()|0;Pc(d+36|0);break c}x[31721]=0;S(384,d+784|0,d+808|0,1413828182);b=x[31721];x[31721]=0;if((b|0)==1){break h}x[31721]=0;S(384,d+772|0,d+808|0,1346719318);b=x[31721];x[31721]=0;if((b|0)==1){break j}x[31721]=0;S(384,d+760|0,d+808|0,1229869908);b=x[31721];x[31721]=0;if((b|0)==1){break l}E=d,F=wb(x[d+760>>2]),x[E+12>>2]=F;n=d+394|0;j=d+346|0;m=d+450|0;i=wb(x[d+764>>2]);k=a+480190|0;u=a+480208|0;while(1){ha:{ia:{ja:{ka:{g=x[d+12>>2];if(!Ib(g,i)){Pc(d+760|0);x[31721]=0;S(384,d+344|0,d+808|0,1346458692);b=x[31721];x[31721]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31721]=0;b=P(392,g|0,d+448|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}if(!b){break ha}if(Cb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31721]=0;e=U(254,a|0,Cb(b)|0,0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break n}if(!e){break ha}b=Cb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}b=d+344|0;Zi(b,3,m);x[31721]=0;O(221,d+36|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break ja}b=d+36|0;xc(e+492|0,b);tb(b);v[e+33|0]=2;if((we(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;f=we(w[d+482>>1]);b=f>>>24|0;h=(f<<8&-256)+2047|0;f=b&255;E=e,F=Bc(Bua(h,h>>>0<2047?f+1|0:f,4095,0),hb),x[E+8>>2]=F}h=e+108|0;l=e+236|0;b=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;f=b&255;if(f>>>0>=A[Gb(d+36|0,d+344|0)>>2]){x[31721]=0;O(393,d+36|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break la}E=d,F=Xi(x[d+36>>2]),x[E+344>>2]=F;b=Kf(d+36|0);f=z[k>>1];h=z[d+480>>1];while(1){l=x[d+344>>2];if(Ib(l,b)){l=z[Yo(l)>>1];if(f>>>0>(l-1&65535)>>>0){E=(D(l,104)+a|0)+484410|0,F=Cb(h),w[E>>1]=F}Yg(d+344|0);continue}break}Gv(d+36|0);gk(e,127,1);fk(e,0,1);b=Cb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31721]=0;V(394,e|0,0,Cb(b)|0,d+796|0);b=x[31721];x[31721]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31721]=0;V(394,e|0,1,Cb(b)|0,d+772|0);b=x[31721];x[31721]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31721]=0;V(394,e|0,2,Cb(b)|0,d+784|0);b=x[31721];x[31721]=0;if((b|0)!=1){break ha}break n}x[31721]=0;S(395,g|0,d+344|0,((b|0)==1?98:102)|0);b=x[31721];x[31721]=0;ma:{na:{oa:{if((b|0)!=1){b=Cb(z[d+344>>1]);h=b&1;if(!h){break ia}f=b&24;if(f){break oa}f=0;break na}a=N()|0;break m}if((f|0)!=8){break ma}f=1}v[e+25|0]=f}pa:{qa:{ra:{sa:{if(!(b&2)){break sa}x[31721]=0;b=U(396,d+332|0,j|0,24)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ra}x[31721]=0;t=+ia(397,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break qa}tb(b);if(!(t>20)){break sa}gk(e,oD(x[u>>2],t),1)}if(Cb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(b);break m}x[31721]=0;b=U(396,d+320|0,n|0,24)|0;f=x[31721];x[31721]=0;ta:{if((f|0)!=1){x[31721]=0;t=+ia(397,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break ta}tb(b);fk(e,$l(t*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(b);break m}else{o=(d+448|0)+(f<<1)|0;q=y[o+52|0];E=Zb(l,f),F=q,w[E>>1]=F;q=vb(h,f);o=dm(v[o+53|0]+y[q|0]|0);E=vb(h,f),F=o,v[E|0]=F;b=b+1|0;continue}}break}a=N()|0;break m}b=x[d+348>>2];e=x[d+344>>2];x[31721]=0;h=a+484344|0;O(226,h|0,Mf(e,b)&65535);b=x[31721];x[31721]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];E=d,F=wb(x[d+344>>2]),x[E+24>>2]=F;u=c&1;l=wb(x[d+348>>2]);o=a+480188|0;while(1){va:{wa:{xa:{ya:{za:{Aa:{c=x[d+24>>2];if(!Ib(c,l)){x[31721]=0;S(380,d+36|0,d+808|0,1414414669);b=x[31721];x[31721]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!u){break va}b=x[c+8>>2];e=x[c>>2];x[31721]=0;b=U(153,e|0,b|0,24)|0;e=x[31721];x[31721]=0;if((e|0)==1){break za}if(!b){break va}x[31721]=0;n=R(276,c|0)|0;b=x[31721];x[31721]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31721]=0;O(398,c|0,d+448|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ea}x[31721]=0;i=R(276,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Da}x[31721]=0;j=R(276,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Ca}x[31721]=0;m=R(276,c|0)|0;b=x[31721];x[31721]=0;Fa:{if((b|0)==1){break Fa}b=x[c+8>>2];e=x[c>>2];x[31721]=0;b=U(153,e|0,b|0,D(D(j,m),5)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Fa}if(!(b&i>>>0<2)){break va}x[31721]=0;b=U(199,h|0,n|0,j|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Fa}if(!b){break va}b=x[h>>2];x[31721]=0;O(399,Vb(b,n)|0,d+448|0);b=x[31721];x[31721]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=be(d+36|0,0,d+12|0);x[31721]=0;e=U(375,d+760|0,m|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break wa}g=0;Ga:while(1){if((g|0)==(j|0)){ld(e);break va}b=Vb(x[h>>2],n);_e(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],g);f=0;while(1){if((f|0)==(m|0)){g=g+1|0;continue Ga}b=Ig(d+12|0);if(z[o>>1]>f>>>0){b=Vc(x[d+36>>2],f)}x[31721]=0;O(400,c|0,d|0);k=x[31721];x[31721]=0;Ha:{if((k|0)==1){break Ha}k=y[d|0];if((k-1&255)>>>0<=119){k=k+1|0;v[b|0]=k;E=Zb(x[e>>2],f),F=k,v[E|0]=F}k=y[d+1|0];if(k){v[b+1|0]=k;E=Zb(x[e>>2],f),F=k,v[E+1|0]=F}k=y[d+4|0];if(k){v[b+2|0]=1;v[b+4|0]=i?k-16|0:k>>>2|0}k=y[d+887|0];q=y[d+3|0];B=y[d+2|0];s=Zb(x[e>>2],f);C=y[s+1|0];s=y[s|0];x[31721]=0;ya(377,a|0,b|0,B|0,q|0,k|0,s|0,C|0,d+32|0,d+28|0);b=x[31721];x[31721]=0;if((b|0)==1){break Ha}f=f+1|0;continue}break}break}a=N()|0;ld(e);break ua}x[31721]=0;b=U(153,x[d+36>>2],x[d+44>>2],38)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(!b){break xa}x[31721]=0;b=R(276,d+36|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ya}c=d+452|0;e=a+480188|0;f=0;Ia:{while(1){if(b>>>0<=(f&65535)>>>0){break xa}x[31721]=0;g=U(153,x[d+36>>2],x[d+44>>2],36)|0;h=x[31721];x[31721]=0;Ja:{if((h|0)!=1){if(g){break Ja}break xa}break ya}x[31721]=0;O(401,d+36|0,d+448|0);g=x[31721];x[31721]=0;if((g|0)!=1){Ka:{if(Cb(z[d+448>>1])){break Ka}if(Cb(z[d+450>>1])>>>0>=z[e>>1]){break Ka}Te(d,3,c);x[31721]=0;O(221,d+12|0,d|0);g=x[31721];x[31721]=0;if((g|0)==1){break Ia}g=d+12|0;Tk(((Cb(z[d+450>>1])<<5)+a|0)+480289|0,g);tb(g)}f=f+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Pc(d+344|0);Pc(d+772|0);Pc(d+784|0);Pc(d+796|0);f=1;break q}a=N()|0;break ua}Yf(d+24|0);continue}}a=N()|0}Pc(d+344|0);break k}a=N()|0;break m}f=0;while(1){if(y[d+445|0]<=f>>>0){break ha}x[31721]=0;O(402,g|0,d+36|0);b=x[31721];x[31721]=0;La:{Ma:{if((b|0)!=1){x[d>>2]=33620480;E=d,F=(Cb(z[d+484>>1])|0)!=0,v[E+32|0]=F;E=d,F=(Cb(z[d+486>>1])|0)!=0,v[E+33|0]=F;E=d,F=(Cb(z[d+488>>1])|0)!=0,v[E+34|0]=F;E=d,F=h&(Cb(z[d+490>>1])|0)!=0,v[E+35|0]=F;if(!y[(d+32|0)+f|0]|f>>>0>3){break La}b=(f|0)!=3;if(!b&(v[e+100|0]&1)){break La}x[31721]=0;l=y[d+f|0];S(403,d+36|0,e|0,l|0);o=x[31721];x[31721]=0;if((o|0)==1){break Ma}if(!b){v[e+100|0]=y[e+100|0]|16}Na:{switch(l|0){case 0:if(Cb(y[d+48|0]|y[d+49|0]<<8)&1){b=Cb(y[d+46|0]|y[d+47|0]<<8)&32767}else{b=0}x[e>>2]=b;break La;case 2:break Na;default:break La}}if(!(Cb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}E=d,F=Cb(y[d+42|0]|y[d+43|0]<<8),w[E+28>>1]=F;w[d+24>>1]=1;b=z[oe(d+28|0,d+24|0)>>1];l=ui(Bc(((Cb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));E=d,F=Cb(y[d+40|0]|y[d+41|0]<<8),w[E+28>>1]=F;w[d+24>>1]=1;o=Zg(256/z[oe(d+28|0,d+24|0)>>1]|0);q=z[d+448>>1];B=y[d+44|0]|y[d+45|0]<<8;x[31721]=0;s=Cb(q);q=Cb(B);ja(404,a|0,s|0,y[(q>>>0<6?q:0)+24944|0],255/(b>>>0)|0,l|0,o|0);b=x[31721];x[31721]=0;if((b|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}f=f+1|0;continue}}Yf(d+12|0);continue}}fe(d+808|0);ub(r)}fb=d+1120|0;return f|0}a=N()|0}Pc(d+760|0);break k}a=N()|0}Pc(d+772|0);break i}a=N()|0}Pc(d+784|0);break g}a=N()|0}Pc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}fe(d+808|0)}ub(r)}Q(a|0);p()}function gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0;l=fb-1168|0;fb=l;vc(b);a:{if(!bs(b,l+1144|0)){break a}if(!gR(l+1144|0)){break a}if((y[l+1152|0]|y[l+1153|0]<<8|(y[l+1154|0]<<16|y[l+1155|0]<<24))!=(gh(x[b>>2])|0)){break a}if((y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24))!=(hf(b)|0)){break a}if(!c){d=1;break a}f=l+1088|0;Tb(f,0,56);e=-2;b:{if(!f){break b}x[f+44>>2]=0;x[f+48>>2]=0;x[f+52>>2]=0;x[f+20>>2]=0;x[f+24>>2]=0;x[f+8>>2]=0;g=x[f+32>>2];if(!g){x[f+32>>2]=1174;g=1174}if(!x[f+36>>2]){x[f+36>>2]=1175}g=ib[g|0](x[f+40>>2],1,43784)|0;e=-4;if(!g){break b}x[f+28>>2]=g;x[g+43780>>2]=1;x[g+10992>>2]=0;x[g+10996>>2]=0;x[g>>2]=0;x[g+11008>>2]=15;x[g+11e3>>2]=1;x[g+11004>>2]=0;e=0}if(e){break a}d=y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24);x[l+1084>>2]=d;K=y[l+1164|0]|y[l+1165|0]<<8|(y[l+1166|0]<<16|y[l+1167|0]<<24);T=nZ(l+1072|0,K);c:{d:{while(1){if(!(!K|!d|(i|0)==1)){x[l+32>>2]=1024;d=l+32|0;V=x[Gb(d,l+1084|0)>>2];i=fc(l+40|0,l+48|0,V);f=x[i>>2];i=x[i+4>>2];x[31721]=0;Sn(162,d,b,f,i);d=x[31721];x[31721]=0;if((d|0)==1){break d}g=l+48|0;i=g;d=V;f=aa^-1;while(1){if(d>>>0<4){while(1){if(d){f=x[(((y[i|0]^f)&255)<<2)+79552>>2]^f>>>8;d=d-1|0;i=i+1|0;continue}break}aa=f^-1}else{f=x[(((y[i|0]^f)&255)<<2)+79552>>2]^f>>>8;f=f>>>8^x[(((f^y[i+1|0])&255)<<2)+79552>>2];f=f>>>8^x[(((f^y[i+2|0])&255)<<2)+79552>>2];f=f>>>8^x[(((f^y[i+3|0])&255)<<2)+79552>>2];d=d-4|0;i=i+4|0;continue}break}x[l+1092>>2]=V;x[l+1088>>2]=g;x[l+1104>>2]=K;x[l+1100>>2]=x[T>>2]+ba;B=fb-16|0;fb=B;i=-2;q=l+1088|0;e:{if(!q){break e}h=x[q+28>>2];if(!h){break e}da=x[q+4>>2];x[h+11e3>>2]=0;f:{if(x[h+43780>>2]<0){break f}if(x[h+11004>>2]){break e}f=x[h+11008>>2];i=0;x[h+11004>>2]=0;d=x[h+10996>>2];if(!d){X=(f|0)>0?11:10;I=h+11012|0;g=x[q+4>>2];f=x[h+10992>>2];while(1){x[B+12>>2]=g;x[B+8>>2]=32768-f;F=x[q>>2];d=0;g=0;C=0;E=0;J=0;L=0;W=0;M=0;Y=0;Z=fb-144|0;fb=Z;g:{h:{O=f+I|0;if(O>>>0>=I>>>0){G=x[B+8>>2]+O|0;r=G-I|0;$=(I^-1)+G|0;if(!(r&$)){break h}}x[B+8>>2]=0;x[B+12>>2]=0;n=-3;break g}o=x[B+12>>2];u=o+F|0;P=x[h+60>>2];t=x[h+40>>2];i=x[h+36>>2];s=x[h+32>>2];f=x[h+56>>2];e=x[h+4>>2];n=-1;m=O;j=F;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{k=x[h>>2];switch(k|0){case 36:break k;case 39:break m;case 10:break n;case 35:break o;case 17:break p;case 21:break q;case 34:break r;case 2:break w;case 53:break A;case 26:break C;case 25:break D;case 24:break E;case 23:break F;case 18:break G;case 16:break H;case 14:break I;case 51:break L;case 6:break M;case 3:break N;case 37:break O;case 42:break P;case 41:break Q;case 32:break R;case 27:break S;case 11:break T;case 38:break U;case 9:break V;case 52:break W;case 7:break X;case 5:break Y;case 1:break Z;case 0:break _;default:break j}}x[h+28>>2]=1;f=0;x[h+8>>2]=0;x[h+12>>2]=0;x[h+16>>2]=1;t=0;i=0;s=0;e=0;if(X&1){break Z}break v}if((o|0)<=0){n=1;x[h>>2]=1;break i}x[h+8>>2]=y[F|0];j=F+1|0;break w}if((o|0)<=0){break x}W=e+8|0;j=F+1|0;f=y[F|0]<<e|f;d=2;break u}d=4;break u}M=f;break K}d=7;break u}d=8;break u}C=i;break J}E=f;break B}n=1;if((o|0)<=0){break y}e=e+8|0;j=F+1|0;break t}g=i;d=e;break z}k=2;break s}k=37;break k}d=1;break u}d=3;break u}d=5;break u}d=6;break u}d=9;break u}d=10;break u}d=11;break u}d=12;break u}d=13;break u}d=14;break u}d=15;break u}d=16;break u}d=17;break u}d=18;break u}k=1;break s}x[h>>2]=32;break i}x[h>>2]=5;n=1;break i}if(j>>>0>=u>>>0){x[h>>2]=2;n=1;break i}d=y[j|0];x[h+12>>2]=d;j=j+1|0;k=36;g=x[h+8>>2];i=256<<(g>>>4);if(i>>>0>32768|i>>>0>r>>>0|(((d|g<<8)>>>0)%31|d&32)){break l}i=0;if((g&15)!=8){break l}}d=0}$:while(1){aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(d|0){case 0:if(e>>>0>2){break Ga}d=1;continue;case 3:break Ea;case 2:break Fa;case 1:break Ha;case 9:break la;case 10:break ma;case 11:break na;case 12:break oa;case 13:break pa;case 14:break qa;case 15:break ra;case 16:break sa;case 17:break ta;case 8:break za;case 7:break Aa;case 6:break Ba;case 5:break Ca;case 4:break Da;default:break ua}}while(1){if(j>>>0>=u>>>0){x[h>>2]=3;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=f&7;x[h+20>>2]=d;g=d>>>1|0;x[h+24>>2]=g;e=e-3|0;f=f>>>3|0;if(d>>>0>=2){break ya}W=e;break va}e=W&-8;f=f>>>(W&7)|0;i=0;d=0;break xa}while(1){if(j>>>0>=u>>>0){x[h>>2]=6;n=1;break i}f=y[j|0]<<e|f;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}d=1;break xa}if(j>>>0>=u>>>0){x[h>>2]=7;n=1;break i}v[(h+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break xa}while(1){if(j>>>0>=u>>>0){x[h>>2]=51;n=1;break i}f=y[j|0]<<e|f;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}break da}if(m>>>0<G>>>0){v[m|0]=s;i=i-1|0;m=m+1|0;f=M;break ea}n=2;k=52;f=M;break k}if(m>>>0<G>>>0){break wa}n=2;k=9;break k}if(j>>>0<u>>>0){d=G-m|0;g=u-j|0;d=d>>>0<g>>>0?d:g;d=d>>>0<i>>>0?d:i;i=i-d|0;m=yc(m,j,d)+d|0;j=d+j|0;break ca}x[h>>2]=38;n=1;break i}C=0;Ia:{switch(g-1|0){case 0:x[h+44>>2]=288;x[h+48>>2]=32;d=h+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h- -64|0;g=0;while(1){k=144;if((g|0)==144){while(1){g=256;if((k|0)==256){while(1){k=280;if((g|0)==280){while(1){if((k|0)==288){break ia}v[d|0]=8;k=k+1|0;d=d+1|0;continue}}else{v[d|0]=7;g=g+1|0;d=d+1|0;continue}}}else{v[d|0]=9;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=8;g=g+1|0;d=d+1|0;continue}};case 2:break n;default:break Ia}}d=0;break ka}while(1){Ja:{Ka:{La:{Ma:{Na:{Oa:{switch(d|0){case 0:if(i>>>0>3){break Na}if(!e){e=0;break Ma}if(e>>>0>7){break Ka}d=3;continue $;case 1:v[(h+i|0)+10528|0]=f;e=e-8|0;f=f>>>8|0;break Ja;default:break Oa}}i=i+1|0;break La}i=z[h+10528>>1];if((i|0)==(z[h+10530>>1]^65535)){break ea}break m}d=4;continue $}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(m>>>0<G>>>0){v[m|0]=y[(P-s&$)+I|0];m=m+1|0;P=P+1|0;d=7;break fa}n=2;k=53;break k}while(1){if(j>>>0>=u>>>0){x[h>>2]=27;n=1;f=E;break i}E=y[j|0]<<e|E;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=6;break fa}if(j>>>0>=u>>>0){x[h>>2]=26;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=4;if(e>>>0<15){break fa}d=5;break fa}while(1){if(j>>>0>=u>>>0){x[h>>2]=25;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=3;break fa}if(m>>>0>=G>>>0){n=2;k=24;break k}v[m|0]=i;m=m+1|0;break ga}if(j>>>0>=u>>>0){x[h>>2]=23;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=0;if(e>>>0<15){break fa}d=1;break fa}while(1){if(j>>>0>=u>>>0){x[h>>2]=18;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}Y=s-16|0;d=3;break ha}if(j>>>0>=u>>>0){x[h>>2]=16;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=1;if(e>>>0<15){break ha}d=2;break ha}while(1){if(j>>>0>=u>>>0){x[h>>2]=14;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break ja}d=C+22231|0;while(1){if(j>>>0>=u>>>0){x[h>>2]=11;n=1;i=C;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){Pa:{Qa:{Ra:{if(!d){if(C>>>0>2){break Ra}L=v[C+22231|0];if(L>>>0<=e>>>0){break Pa}d=9;continue $}d=C<<2;x[(d+h|0)+44>>2]=x[d+81088>>2]+((-1<<L^-1)&f);C=C+1|0;e=e-L|0;f=f>>>L|0;break Qa}i=0;Tb(h+7040|0,0,288);d=0;break ja}d=0;continue}d=1;continue}}while(1){Sa:{Ta:{Ua:{if(!d){if(A[h+52>>2]<=i>>>0){break Ua}if(e>>>0>2){break Sa}d=10;continue $}v[(y[i+81104|0]+h|0)+7040|0]=f&7;i=i+1|0;e=e-3|0;f=f>>>3|0;break Ta}x[h+52>>2]=19;break ia}d=0;continue}d=1;continue}}J=x[h+24>>2];d=0}while(1){Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{switch(d|0){case 0:d=0;if((J|0)<0){break ga}R=Tb(Z,0,64);g=D(J,3488)+h|0;Tb(g+352|0,0,3200);ca=g- -64|0;H=x[h+24>>2];k=x[((H<<2)+h|0)+44>>2];while(1){if((d|0)!=(k|0)){g=(y[d+ca|0]<<2)+R|0;x[g>>2]=x[g>>2]+1;d=d+1|0;continue}break};x[R+64>>2]=0;x[R+68>>2]=0;r=0;d=1;g=0;while(1){if((d|0)!=16){o=d<<2;d=d+1|0;o=x[o+R>>2];g=o+g<<1;x[(R- -64|0)+(d<<2)>>2]=g;r=o+r|0;continue}break};S=0;o=-1;if((g|0)!=65536&r>>>0>=2){break o}while(1){if(k>>>0>S>>>0){r=y[S+ca|0];cb:{if(!r){break cb}d=(R- -64|0)+(r<<2)|0;g=x[d>>2];x[d>>2]=g+1;d=0;k=r;while(1){if(k){d=g&1|d<<1;g=g>>>1|0;k=k-1|0;continue}break}if(r>>>0<=10){g=1<<r;r=r<<9|S;k=D(J,3488)+h|0;while(1){if(d>>>0>1023){break cb}w[(k+(d<<1)|0)+352>>1]=r;d=d+g|0;continue}}H=D(J,3488)+h|0;g=H+((d&1023)<<1)|0;k=w[g+352>>1];db:{if(k){g=o;o=k;break db}w[g+352>>1]=o;g=o-2|0}d=d>>>9|0;while(1){d=d>>>1|0;k=d&1;if(r>>>0>=12){k=(H+(k+(o^-1)<<1)|0)+2400|0;o=w[k>>1];if(!o){w[k>>1]=g;o=g;g=g-2|0}r=r-1|0;continue}break}w[((D(J,3488)+h|0)+(k+(o^-1)<<1)|0)+2400>>1]=S;o=g}S=S+1|0;H=x[h+24>>2];k=x[((H<<2)+h|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Wa}break _a;case 1:d=w[(((f&1023)<<1)+h|0)+7328>>1];eb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break eb}break Za}if(e>>>0<11){break eb}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+9376>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break Za}}d=11;continue $;case 2:s=w[(((f&1023)<<1)+h|0)+7328>>1];if((s|0)>=0){break ab}d=10;while(1){g=f>>>d|0;d=d+1|0;s=w[(((g&1)+(s^-1)<<1)+h|0)+9376>>1];if((s|0)<0){continue}break};break $a;default:break bb}}d=v[Y+18438|0]+((-1<<t^-1)&f)|0;e=e-t|0;f=f>>>t|0;g=h+i|0;Tb(g+10532|0,(s|0)==16?y[g+10531|0]:0,d);d=d+i|0;break _a}d=s>>>9|0;s=s&511}e=e-d|0;f=f>>>d|0;if(s>>>0>15){break Ya}v[(h+i|0)+10532|0]=s;d=i+1|0}g=x[h+48>>2];i=x[h+44>>2];o=g+i|0;if(o>>>0<=d>>>0){break Xa}if(e>>>0<=14){if((u-j|0)<=1){i=d;d=1;continue}f=y[j|0]<<e|y[j+1|0]<<e+8|f;j=j+2|0;e=e+16|0}i=d}d=2;continue}if(!((s|0)!=16|i)){i=0;s=16;break p}Y=s-16|0;t=v[s+22211|0];if(t>>>0<=e>>>0){break Va}d=12;continue $}if((d|0)!=(o|0)){i=d;break q}o=h+10532|0;yc(h- -64|0,o,i);yc(h+3552|0,i+o|0,g);H=x[h+24>>2];i=d}J=H-1|0;x[h+24>>2]=J;d=0;continue}d=3;continue}}d=2}fb:while(1){gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{switch(d|0){case 0:d=w[(((f&1023)<<1)+h|0)+352>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break gb}if(e>>>0<11){break wb}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+2400>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break gb}}d=13;continue $;case 1:i=w[(((f&1023)<<1)+h|0)+352>>1];if((i|0)>=0){break ub}d=10;while(1){g=f>>>d|0;d=d+1|0;i=w[(((g&1)+(i^-1)<<1)+h|0)+2400>>1];if((i|0)<0){continue}break};break tb;case 3:break jb;case 4:break kb;case 5:break pb;case 6:break qb;case 2:break vb;default:break rb}}while(1){d=u-j|0;if(!((G-m|0)>1&(d|0)>=4)){if(e>>>0>14){break gb}if((d|0)<=1){d=0;continue fb}f=y[j|0]<<e|y[j+1|0]<<e+8|f;e=e+16|0;j=j+2|0;break gb}if(!(e>>>0>14)){f=(y[j|0]|y[j+1|0]<<8)<<e|f;j=j+2|0;e=e+16|0}r=e;i=w[(((f&1023)<<1)+h|0)+352>>1];xb:{if((i|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;i=w[(((g&1)+(i^-1)<<1)+h|0)+2400>>1];if((i|0)<0){continue}break}break xb}d=i>>>9|0}e=r-d|0;f=f>>>d|0;if(i&256){break sb}if(!(e>>>0>14)){f=(y[j|0]|y[j+1|0]<<8)<<e|f;j=j+2|0;e=e+16|0}r=e;k=w[(((f&1023)<<1)+h|0)+352>>1];yb:{if((k|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;k=w[(((g&1)+(k^-1)<<1)+h|0)+2400>>1];if((k|0)<0){continue}break}break yb}d=k>>>9|0}v[m|0]=i;e=r-d|0;f=f>>>d|0;if(!(k&256)){v[m+1|0]=k;m=m+2|0;continue}break}m=m+1|0;i=k;break sb}d=i>>>9|0;i=i&511}e=e-d|0;f=f>>>d|0;if(i>>>0>255){break sb}d=14;continue $}g=i&511;i=256;if((g|0)==256){break ba}d=g-257<<2;i=x[d+80576>>2];t=0;if(g-285>>>0<4294967276){break ib}t=x[d+80704>>2];if(t>>>0>e>>>0){d=15;continue $}d=3;continue}if(!i){i=-1;break nb}i=i-1|0;d=18;continue $}e=e-t|0;f=E>>>t|0;s=((-1<<t^-1)&E)+s|0;break ob}d=w[(((f&1023)<<1)+h|0)+3840>>1];zb:{if((d|0)<0){k=10;while(1){g=f>>>k|0;k=k+1|0;d=w[(((g&1)+(d^-1)<<1)+h|0)+5888>>1];if((d|0)<0){continue}break}break zb}k=d>>>9|0;d=d&511}e=e-k|0;E=f>>>k|0;g=d<<2;s=x[g+80832>>2];t=0;if(d-30>>>0<4294967270){f=E;break ob}t=x[g+80960>>2];if(t>>>0<=e>>>0){break mb}d=17;continue $}P=m-I|0;d=(P-s&$)+I|0;if((d>>>0<m>>>0?m:d)+i>>>0>G>>>0){break lb}while(1){if(i>>>0>=3){v[m|0]=y[d|0];v[m+1|0]=y[d+1|0];v[m+2|0]=y[d+2|0];i=i-3|0;d=d+3|0;m=m+3|0;continue}break}if(!i){i=0;break nb}v[m|0]=y[d|0];if((i|0)!=1){v[m+1|0]=y[d+1|0]}m=i+m|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((f&1023)<<1)+h|0)+3840>>1];Ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break Ab}break hb}if(e>>>0<11){break Ab}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+5888>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break hb}}d=16;continue $}e=e-t|0;i=((-1<<t^-1)&f)+i|0;f=f>>>t|0}if(e>>>0>14){break hb}if((u-j|0)<=1){d=4;continue}f=y[j|0]<<e|y[j+1|0]<<e+8|f;e=e+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!i|!e){break ca}if(e>>>0>7){break da}d=5;continue}e=e-8|0;M=f>>>8|0;s=f&255;d=6;continue}if(i){break aa}i=0}if(v[h+20|0]&1){break t}d=0;continue}d=7;continue}}f=0;d=e>>>3|0;g=j-F|0;g=g>>>0<=j>>>0?g:0;d=d>>>0<g>>>0?d:g;if((e&-8)==d<<3){j=j-d|0;g=0;d=0;e=0;if(!(X&1)){break r}k=0;break s}_(6874,13236,2797,6884);p()}while(1){Bb:{Cb:{Db:{Eb:{Fb:{switch(k|0){case 0:if(g>>>0>3){i=g;e=d;break r}e=0;if(!d){i=g;break Bb}if(d>>>0>7){break Eb}k=1;continue;case 1:break Fb;default:break Db}}while(1){if(j>>>0>=u>>>0){x[h>>2]=41;n=1;i=g;e=d;break i}f=y[j|0]<<d|f;o=d>>>0>4294967287;j=j+1|0;d=d+8|0;if(o){continue}break}}k=f&255;f=f>>>8|0;d=d-8|0;break Cb}if(j>>>0>=u>>>0){x[h>>2]=42;n=1;break i}k=y[j|0];j=j+1|0;g=i;d=e}x[h+16>>2]=x[h+16>>2]<<8|k;g=g+1|0;k=0;continue}k=2;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}i=1}x[h>>2]=k}d=e>>>3|0;g=j-F|0;g=g>>>0<=j>>>0?g:0;d=d>>>0<g>>>0?d:g;j=j-d|0;e=e-(d<<3)|0}x[h+4>>2]=e;x[h+60>>2]=P;x[h+40>>2]=t;x[h+36>>2]=i;x[h+32>>2]=s;x[h+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&f;x[B+12>>2]=j-F;e=m-O|0;x[B+8>>2]=e;if((n|0)<0){break g}j=(e>>>0)%5552|0;d=x[h+28>>2];f=d>>>16|0;k=d&65535;while(1){g=0;if(e){d=O;while(1){if((g|7)>>>0<j>>>0){i=y[d|0]+k|0;o=i+y[d+1|0]|0;r=o+y[d+2|0]|0;E=r+y[d+3|0]|0;M=E+y[d+4|0]|0;C=M+y[d+5|0]|0;m=C+y[d+6|0]|0;k=m+y[d+7|0]|0;f=k+(m+(C+(M+(E+(r+(o+(f+i|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;g=g+8|0;continue}break}g=j&8184;while(1){if((g|0)!=(j|0)){g=g+1|0;k=y[d|0]+k|0;f=k+f|0;d=d+1|0;continue}break}e=e-j|0;f=(f>>>0)%65521|0;k=(k>>>0)%65521|0;O=j+O|0;j=5552;continue}break}d=f<<16|k;x[h+28>>2]=d;if(n){break g}n=0;if(!(X&1)){break g}n=(d|0)!=x[h+16>>2]?-2:0}fb=Z+144|0;x[h+43780>>2]=n;d=x[B+12>>2];x[q>>2]=d+x[q>>2];x[q+4>>2]=x[q+4>>2]-d;x[q+8>>2]=d+x[q+8>>2];x[q+48>>2]=x[h+28>>2];d=x[B+8>>2];x[h+10996>>2]=d;i=x[q+16>>2];d=d>>>0<i>>>0?d:i;yc(x[q+12>>2],x[h+10992>>2]+I|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];e=x[h+10996>>2];x[h+10996>>2]=e-d;f=d+x[h+10992>>2]&32767;x[h+10992>>2]=f;if((n|0)<0){break f}if(!((n|0)!=1|da)){i=-5;break e}if(n){i=0;g=x[q+4>>2];if(!g|!x[q+16>>2]){break e}if((d|0)==(e|0)){continue}break e}break}i=(d|0)==(e|0);break e}f=x[q+16>>2];d=d>>>0<f>>>0?d:f;yc(x[q+12>>2],(x[h+10992>>2]+h|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];f=x[h+10996>>2];x[h+10996>>2]=f-d;x[h+10992>>2]=d+x[h+10992>>2]&32767;if(x[h+43780>>2]){break e}i=(d|0)==(f|0);break e}i=-3}fb=B+16|0;d=x[l+1084>>2]-V|0;x[l+1084>>2]=d;g=K+ba|0;K=x[l+1104>>2];ba=g-K|0;continue}break}b=l+1088|0;Gb:{if(!b){break Gb}d=x[b+28>>2];if(!d){break Gb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}d=0;Hb:{Ib:{if(!((y[l+1156|0]|y[l+1157|0]<<8|(y[l+1158|0]<<16|y[l+1159|0]<<24))!=(aa|0)|(i|0)!=1|K)){le(l+24|0,x[T>>2],x[T+4>>2]);b=Jd(l+16|0);x[31721]=0;d=x[b+4>>2];x[l+8>>2]=x[b>>2];x[l+12>>2]=d;b=eg(558,l+48|0,x[l+24>>2],x[l+28>>2],l+8|0);d=x[31721];x[31721]=0;if((d|0)==1){break Ib}x[31721]=0;d=U(919,a|0,b|0,c|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break Hb}ub(b)}cc(T);break a}a=N()|0;break c}a=N()|0;ub(b);break c}a=N()|0}cc(T);Q(a|0);p()}fb=l+1168|0;return d|0}function gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),O=0,P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=E(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=fb-96|0;fb=n;vc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}h=n+76|0;d=fb-16|0;fb=d;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){A=0;while(1){if((A|0)!=3){ah(h+A|0);A=A+1|0;continue}break}break c}Pw(d+8|0,h);pd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d:{e:{if(!hd(h,15013,3)){h=n+32|0;d=fb-16|0;fb=d;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){A=0;while(1){if((A|0)!=7){ah(h+A|0);A=A+1|0;continue}break}break f}xr(d+8|0,h);pd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;A=0;h=3;while(1){if((h|0)==7){break d}d=v[(n+32|0)+h|0];if((d|0)<0){break e}h=h+1|0;A=d&255|A<<7;continue}}g:{if(hd(n+76|0,14195,3)){break g}if(!LX(c,13675)){break g}Ub(c,Mg(c)+16|0);continue}if(!hd(n+76|0,28574,3)){continue}if(!hd(n+76|0,28578,3)){continue}if(!y[n+76|0]){Dh(c,2);continue}if(ZU(n+76|0)){break b}}h=0;break a}Ub(c,A);continue}break}vc(c);d=n+76|0;_C(d,c);V=x[n+76>>2];c=Se(d);O=Nb(n- -64|0);x[31721]=0;aa=R(595,n+60|0)|0;d=x[31721];x[31721]=0;h:{i:{j:{if((d|0)!=1){tB(Tb(x[aa>>2],0,6668));x[n+48>>2]=0;x[n+52>>2]=0;x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[31721]=0;ba=R(596,n+20|0)|0;d=x[31721];x[31721]=0;k:{if((d|0)!=1){A=0;while(1){G=x[aa>>2];g=Fc(V,ca);W=x[ba>>2];d=0;m=0;s=fb-17152|0;fb=s;x[s+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(g|0)<5){break n}if(!bq(G+6152|0,c)){break n}h=bz(y[c+1|0],y[c+2|0],x[G+6148>>2])+aq(c)|0;x[s+17148>>2]=h;if((g|0)==(h|0)){h=g;break m}o:{if((g|0)>=(h+4|0)){if(bq(c,c+h|0)){break o}}x[s+17148>>2]=0;break n}if(h){break m}}f=c;C=Tb(G,0,6668)+6148|0;r=s+17148|0;o=g-4|0;I=(o|0)>0?o:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=g;break s}if(!ML(f)){break q}i=bz(y[f+1|0],y[f+2|0],x[C>>2]);h=i+aq(f)|0;j=4;k=m+4|0;t:{while(1){if(!(j>>>0>2303|i)){if((o|0)<=((j<<1)+m|0)){break t}i=0;l=f+j|0;u:{if(!bq(f,l)){break u}e=j-aq(f)|0;q=aq(l)+e|0;if((g|0)<(q+(j+k|0)|0)){break u}if(!bq(f,l+q|0)){break u}x[C>>2]=e;i=e;h=j}j=j+1|0;continue}break}if(!i|(g|0)<(h+m|0)){break t}k=g-m|0;j=0;e=0;while(1){v:{w:{if((e|0)!=10){l=(e|0)!=0;K=j;j=f+j|0;j=(K+bz(y[j+1|0],y[j+2|0],i)|0)+aq(j)|0;if((k|0)<(j+4|0)){break v}if(bq(f,f+j|0)){break w}l=0}else{l=1}break v}e=e+1|0;continue}break}if(!l){break t}d=h;break s}if((g|0)!=(h|0)|m){break r}m=0;d=g}x[r>>2]=d;d=m;break p}x[C>>2]=0}f=f+1|0;m=m+1|0;continue}break}h=x[s+17148>>2];if((g|0)>=(d+h|0)?h:0){break m}x[n+32>>2]=d;q=0;break l}F=c+d|0;x[G+6152>>2]=y[F|0]|y[F+1|0]<<8|(y[F+2|0]<<16|y[F+3|0]<<24);x[n+36>>2]=d;x[n+32>>2]=d+h;x[n+40>>2]=y[F+3|0]>191?1:2;ra=n,sa=PL(y[F+1|0],y[F+2|0]),x[ra+44>>2]=sa;x[n+48>>2]=4-(y[F+1|0]>>>1&3);ra=n,sa=az(y[F+1|0],y[F+2|0]),x[ra+52>>2]=sa;if(!W){q=$y(y[F+1|0]);break l}OL(s+17136|0,F+4|0,h-4|0);if(!(v[F+1|0]&1)){se(s+17136|0,16)}x:{if(x[n+48>>2]==3){q=0;d=s+17136|0;ia=s+3728|0;h=ia;f=0;e=y[F+1|0];g=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[F+2|0]>>>2&3)|0;g=g-((g|0)!=0)|0;m=y[F+3|0]>191?1:2;y:{if(e&8){i=se(d,9);m=m<<1;f=se(d,m+7|0);break y}i=se(d,m|8)>>>m|0}e=D(g,40);C=e+81424|0;o=e+81744|0;r=D(g,23)+81232|0;e=-1;l=0;z:{while(1){g=y[F+3|0];I=se(d,12);w[h+4>>1]=I;j=se(d,9);w[h+6>>1]=j;if((j&65535)>>>0>288){break z}j=g>>>0>191?f<<4:f;ra=h,sa=se(d,8),v[ra+10|0]=sa;g=se(d,y[F+1|0]&8?4:9);v[h+13|0]=22;v[h+14|0]=0;x[h>>2]=r;w[h+8>>1]=g;A:{if(se(d,1)){g=se(d,2);v[h+11|0]=g;if(!(g&255)){break z}g=se(d,1);w[h+18>>1]=65287;v[h+12|0]=g;if(y[h+11|0]==2){B:{if(!(g&255)){x[h>>2]=C;v[h+18|0]=8;f=0;g=39;break B}x[h>>2]=o;f=y[F+1|0]&8?8:6;g=30}v[h+14|0]=g;v[h+13|0]=f;j=j&3855}g=se(d,10);ra=h,sa=se(d,3),v[ra+21|0]=sa;ra=h,sa=se(d,3),v[ra+22|0]=sa;ra=h,sa=se(d,3),v[ra+23|0]=sa;f=g<<5;break A}v[h+11|0]=0;v[h+12|0]=0;f=se(d,15);ra=h,sa=se(d,4),v[ra+18|0]=sa;g=se(d,3);v[h+20|0]=255;v[h+19|0]=g}v[h+17|0]=f&31;v[h+15|0]=f>>>10;v[h+16|0]=f>>>5&31;l=(I&65535)+l|0;C:{if(y[F+1|0]&8){g=se(d,1);break C}g=z[h+8>>1]>499}v[h+24|0]=g;ra=h,sa=se(d,1),v[ra+25|0]=sa;g=se(d,1);v[h+27|0]=j>>>12&15;v[h+26|0]=g;h=h+28|0;f=j<<4;m=m-1|0;if(m){continue}break}e=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((e|0)<0|x[s+17140>>2]>x[s+17144>>2])){d=s+17136|0;f=x[d+4>>2];j=x[d+8>>2];m=s+900|0;h=x[G+6144>>2];g=h-e|0;h=(e|0)>(h|0)?h:e;g=yc(m+12|0,(((g|0)>0?g:0)+G|0)+6156|0,h);i=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(j-f|0)/8|0;yc(g+h|0,i,d);OL(m,g,d+h|0);D:{h=x[G+6144>>2]>=(e|0);if(!h){break D}ma=G+2304|0;na=s+8608|0;oa=s+3840|0;while(1){if((y[F+1|0]&8?2:1)>>>0<=q>>>0){break D}pa=Tb(oa,0,4608);e=x[n+40>>2];m=D(D(e,q),28)+ia|0;d=0;ja=(e|0)>0?e:0;C=s+900|0;I=C+7548|0;Z=G+6152|0;while(1){if((d|0)!=(ja|0)){f=D(d,28)+m|0;K=z[f+4>>1];S=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;o=d;g=fb-48|0;fb=g;d=f;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+82064|0;E:{if(y[Z+1|0]&8){i=y[d+27|0];f=y[z[d+8>>1]+82160|0];j=f&3;v[g+47|0]=j;v[g+46|0]=j;f=f>>>2|0;v[g+45|0]=f;v[g+44|0]=f;break E}f=(y[Z+3|0]&16)>>>4&(o|0)!=0;k=f?12:0;f=z[d+8>>1]>>>f|0;while(1){if((f|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+82176|0];v[(g+44|0)+i|0]=((f|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;f=f-j|0;continue}break}H=k+H|0;i=-16}j=g;da=g+44|0;f=0;while(1){F:{G:{H:{if((f|0)==4){break H}r=y[f+H|0];if(!r){break H}if(i&8){yc(j,t,r);break G}k=y[f+da|0];if(!k){Tb(j,0,r);Tb(t,0,r);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(r|0)){break G}P=se(C,k);v[l+t|0]=(P|0)==(ea|0)?-1:P;v[j+l|0]=P;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;f=f+1|0;j=j+r|0;t=r+t|0;continue}break}I:{j=y[d+14|0];if(j){f=2-J|0;l=y[d+23|0]<<f;r=y[d+22|0]<<f;k=y[d+21|0]<<f;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}f=g+(i+t|0)|0;v[f|0]=k+y[f|0];v[f+1|0]=r+y[f+1|0];v[f+2|0]=l+y[f+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}f=g+i|0;v[f+11|0]=y[f+11|0]+y[i+82200|0];i=i+1|0;continue}}f=J+1|0;i=0;u=_y(E(2048),((((y[Z+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=_y(u,y[g+i|0]<<f),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}fb=g+48|0;l=(C+D(o,2304)|0)+2940|0;i=e;da=K+S|0;u=E(0);f=x[C+4>>2];g=x[C>>2]+((f|0)/8|0)|0;e=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))<<(f&7);k=f|-8;t=g+4|0;r=d;H=x[d>>2];J=z[d+6>>1];d=0;while(1){J:{K:{if((J|0)>0){g=d+1|0;f=d+r|0;d=y[f+15|0];ea=(w[(d<<1)+86624>>1]<<1)+82240|0;P=y[f+18|0];if(d>>>0>=16){fa=y[d+86688|0];qa=32-fa|0;while(1){ga=y[H|0]>>>1|0;ha=(J|0)<(ga|0)?J:ga;u=B[i>>2];while(1){f=e>>>27|0;d=5;while(1){f=w[ea+(f<<1)>>1];if((f|0)<0){e=e<<d;j=f&7;f=(e>>>32-j|0)-(f>>3)|0;k=d+k|0;d=j;continue}break}d=f>>>8|0;k=d+k|0;e=e<<d;j=0;while(1){if((j|0)!=2){K=f&15;L:{if((K|0)==15){k=k+fa|0;d=e<<fa;while(1){if((k|0)>=0){d=y[t|0]<<k|d;t=t+1|0;k=k-8|0;continue}break}K=(e>>>qa|0)+15|0;e=K;M:{if((e|0)<=128){L=B[(e<<2)+86784>>2];break M}ka=e>>>0<1024;e=ka?e<<3:e;S=e<<1&64;M=E(E((e&63)-S|0)/E(S+(e&-64)|0));L=E((ka?E(16):E(256))*E(E(E(M*E(E(M*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(e+S>>6<<2)+86784>>2]))}L=E(E(u*L)*E(d>>31|1));break L}d=e;L=E(u*B[(((d>>>27&16|K)^16)<<2)+86720>>2])}B[l>>2]=L;f=f>>>4|0;l=l+4|0;j=j+1|0;e=(K|0)!=0;k=e+k|0;e=d<<e;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}ha=ha-1|0;if(ha){continue}break}i=i+4|0;H=H+1|0;J=J-ga|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}while(1){S=y[H|0]>>>1|0;K=(J|0)<(S|0)?J:S;u=B[i>>2];while(1){d=e>>>27|0;f=5;while(1){d=w[ea+(d<<1)>>1];if((d|0)<0){e=e<<f;j=d&7;d=(e>>>32-j|0)-(d>>3)|0;k=f+k|0;f=j;continue}break}f=d>>>8|0;k=f+k|0;e=e<<f;f=0;while(1){if((f|0)!=2){j=d&15;B[l>>2]=u*B[(((j|e>>>27&16)^16)<<2)+86720>>2];d=d>>>4|0;l=l+4|0;f=f+1|0;j=(j|0)!=0;k=j+k|0;e=e<<j;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}K=K-1|0;if(K){continue}break}i=i+4|0;H=H+1|0;J=J-S|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}f=1-J|0;while(1){N:{g=y[r+26|0]?86608:86576;d=y[g+(e>>>28|0)|0];if(!(d&8)){d=y[g+((e<<4>>>32-(d&3))+(d>>>3)|0)|0]}g=d&7;k=g+k|0;if((da|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}f=f-1|0;if(!f){f=y[H|0];if(f>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=f>>>1|0}e=e<<g;if(d>>>0>=128){B[l>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&64){B[l+4>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}f=f-1|0;if(!f){g=y[H|0];if(g>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=g>>>1|0}if(d&32){B[l+8>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&16){B[l+12>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=da;break J}d=g;continue}break}d=o+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){l=C+16195|0;d=0;g=fb-16|0;fb=g;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];t=y[m+13|0];r=k+t|0;o=g+4|0;x[o+8>>2]=-1;x[o>>2]=-1;x[o+4>>2]=-1;while(1){if((d|0)!=(r|0)){H=d+I|0;f=y[H|0];e=0;P:{while(1){if(e>>>0>=f>>>0){break P}J=e<<2;if(B[J+i>>2]==E(0)){e=e+2|0;if(B[(J|4)+i>>2]==E(0)){continue}}break}x[o+((d>>>0)%3<<2)>>2]=d;f=y[H|0]}d=d+1|0;i=(f<<2)+i|0;continue}break}if(t){d=x[g+4>>2];e=x[g+8>>2];d=(d|0)>(e|0)?d:e;e=x[g+12>>2];d=(d|0)>(e|0)?d:e;x[g+12>>2]=d;x[g+8>>2]=d;x[g+4>>2]=d}e=k?3:1;i=r-e|0;d=0;while(1){if((d|0)!=(e|0)){o=d+i|0;f=o-e|0;if((f|0)<=x[(g+4|0)+(d<<2)>>2]){f=y[Z+1|0]<<28>>31&3}else{f=y[f+l|0]}v[l+o|0]=f;d=d+1|0;continue}break}o=x[m>>2];r=g+4|0;I=w[m+36>>1]&1;i=0;k=y[Z+1|0]&8?7:64;while(1){t=i+o|0;e=y[t|0];if(e){f=y[Z+3|0]&32;Q:{R:{if(x[r+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+l|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[Z+1|0]&8){d=d<<3;u=B[d+87316>>2];M=B[d+87312>>2];break S}M=_y(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):M;M=d?M:E(1)}M=E(L*M);L=E(L*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;u=B[f>>2];B[f+2304>>2]=u*L;B[f>>2]=u*M;d=d+1|0;continue}break}break Q}if(!f){break Q}LL(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}fb=g+16|0;break O}if((d&224)!=96){break O}LL(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ja|0)){e=y[G+6153|0];o=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){f=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(o,72)|0)+2940|0;g=t;e=j;while(1){r=y[f|0];if(r){k=r<<1;I=0;while(1){if((r|0)!=(I|0)){B[e>>2]=B[g>>2];B[e+4>>2]=B[(r<<2)+g>>2];B[e+8>>2]=B[(k<<2)+g>>2];g=g+4|0;I=I+1|0;e=e+12|0;continue}break}f=f+3|0;g=(k<<2)+g|0;continue}break}yc(t,j,e-j|0);e=o-1|0}else{e=31}while(1){g=0;if((e|0)>0){while(1){if((g|0)!=8){f=g<<2;r=f+i|0;u=B[r+72>>2];M=B[f+87376>>2];L=B[f+87408>>2];f=(17-g<<2)+i|0;la=B[f>>2];B[r+72>>2]=E(u*M)-E(L*la);B[f>>2]=E(u*L)+E(la*M);g=g+1|0;continue}break}i=i+72|0;e=e-1|0;continue}break}g=l;e=D(d,1152)+G|0;f=y[m+11|0];if(o){KL(g,e,87440,o);g=D(o,72)+g|0;e=D(o,36)+e|0}T:{if((f|0)==2){i=32-o|0;f=fb-80|0;fb=f;r=f|8;I=f|4;while(1){if((i|0)>0){o=yc(f,g,72);k=x[e+20>>2];x[g+16>>2]=x[e+16>>2];x[g+20>>2]=k;k=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=k;k=x[e+4>>2];x[g>>2]=x[e>>2];x[g+4>>2]=k;K=o;o=e+24|0;Zy(K,g+24|0,o);Zy(I,g+48|0,o);Zy(r,e,o);g=g+72|0;e=e+36|0;i=i-1|0;continue}break}fb=f+80|0;break T}KL(g,e,D((f|0)==3,72)+87440|0,32-o|0)}f=0;i=l+72|0;while(1){g=1;if(f>>>0<=31){while(1){if(g>>>0<=17){e=(g<<2)+i|0;B[e>>2]=-B[e>>2];g=g+2|0;continue}break}i=i+144|0;f=f+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}NL(ma,pa,18,x[n+40>>2],W,na);q=q+1|0;W=D(x[n+40>>2],1152)+W|0;continue}}e=s+900|0;f=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=f-j|0;g=(d|0)>=511?511:d;if((d|0)>0){$h(G+6156|0,(e+(d>>>0>511?f-511|0:j)|0)+12|0,g)}x[G+6144>>2]=g;break x}tB(G);break l}f=s+17136|0;q=0;m=0;i=0;g=s;d=0;U:{V:{W:{h=y[F+3|0];j=h>>>6|0;switch(j-1|0){case 2:break U;case 0:break W;default:break V}}d=(h>>>2&12)+4|0;break U}d=32}h=y[F+1|0];X:{if((h&6)==6){h=32;e=88844;break X}if(!(h&8)){h=30;e=88847;break X}l=y[F+2|0];e=l>>>2&3;h=az(h,l)>>>((j|0)!=3)|0;h=h?h:192;if(h>>>0<=55){h=(e|0)==2?12:8;e=88868;break X}h=h>>>0<=95?27:(e|0)!=1?30:27;e=88856}v[g+768|0]=h;v[g+769|0]=(d|0)<(h|0)?d:h;h=e;j=88752;while(1){d=y[g+768|0];if(q>>>0>=d>>>0){q=0;while(1){e=d<<1&510;if(e>>>0>q>>>0){e=g+q|0;Y:{if(!y[e+770|0]){h=6;break Y}h=2;if((y[F+1|0]&6)==6){break Y}h=se(f,2);d=y[g+768|0]}v[e+834|0]=h;q=q+1|0;continue}break}m=g+770|0;j=g+834|0;h=0;i=e;while(1){if((h|0)!=(i|0)){l=y[m|0];e=l?19>>>y[h+j|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&e){C=se(f,6);o=(C|0)/3|0;u=E(B[(l+(D(o,-3)+C|0)<<2)+88880>>2]*E(2097152>>>o|0))}B[g>>2]=u;d=d>>>1|0;g=g+4|0;continue}break}h=h+1|0;continue}break}q=y[s+769|0];d=y[s+768|0];d=d>>>0<q>>>0?q:d;while(1){if((d|0)!=(q|0)){v[((q<<1)+s|0)+771|0]=0;q=q+1|0;continue}break}}else{if((i|0)==(q|0)){j=y[h|0]+88752|0;i=y[h+2|0]+q|0;m=y[h+1|0];h=h+3|0}e=q<<1;d=y[se(f,m)+j|0];v[(e+g|0)+770|0]=d;l=y[g+769|0];if(l>>>0>q>>>0){d=y[se(f,m)+j|0];l=y[g+769|0]}v[((e|1)+g|0)+770|0]=l?d:0;q=q+1|0;continue}break}h=0;g=Tb(s+3840|0,0,4608);I=G+2304|0;k=s+8608|0;q=0;Z:{while(1){if((q|0)==3){break Z}F=g+(h<<2)|0;C=s+17136|0;f=0;l=x[n+48>>2]|1;o=(l|0)>0?l:0;e=576;while(1){if((f|0)!=4){m=F+(D(f,l)<<2)|0;j=0;while(1){if(y[s+768|0]<<1>>>0>j>>>0){_:{i=y[(j+s|0)+770|0];if(!i){break _}if(i>>>0<=16){r=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(o|0)){break _}ra=(d<<2)+m|0,ta=E(se(C,i)+r|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=se(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;r=d|1;d=0;while(1){if((d|0)==(o|0)){break _}K=i;i=(i>>>0)/(r>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(r,i)|0)|0;d=d+1|0;continue}}j=j+1|0;m=(e<<2)+m|0;e=18-e|0;continue}break}f=f+1|0;continue}break}h=(l<<2)+h|0;if((h|0)==12){d=(q<<2)+s|0;h=g;e=y[s+769|0];f=g+D(e,72)|0;yc(f+2304|0,f,D(y[s+768|0]-e|0,72));m=0;while(1){if(y[s+768|0]>m>>>0){f=0;while(1){if((f|0)!=12){e=(f<<2)+h|0;B[e>>2]=B[d>>2]*B[e>>2];e=e+2304|0;B[e>>2]=B[d+12>>2]*B[e>>2];f=f+1|0;continue}break}d=d+24|0;h=h+72|0;m=m+1|0;continue}break}NL(I,g,12,x[n+40>>2],W,k);Tb(g,0,4608);W=D(x[n+40>>2],768)+W|0;h=0}q=q+1|0;if(x[s+17140>>2]<=x[s+17144>>2]){continue}break}tB(G);q=0;break l}h=1}q=D($y(y[G+6153|0]),h)}fb=s+17152|0;d=x[n+32>>2];if((d|0)<0|!d){break h}h=x[n+44>>2];if((h|0)!=(_|0)?_:0){break h}d=x[n+40>>2];if((d|0)!=(A|0)?A:0){break h}if(d-3>>>0<4294967294|(h|0)<=0){break i}x[n+16>>2]=0;ra=n,sa=Fc(V,ca),x[ra+12>>2]=sa;g=x[ak(n+32|0,n+16|0,n+12|0)>>2];x[n+16>>2]=0;ra=n,sa=Fc(V,ca),x[ra+12>>2]=sa;e=x[ak(n+32|0,n+16|0,n+12|0)>>2];f=e>>31;$:{if(!q){break $}A=x[ba>>2];x[31721]=0;U(597,O|0,A|0,A+(D(d,q)<<1)|0)|0;A=x[31721];x[31721]=0;if((A|0)!=1){break $}c=T(124984)|0;if((gb|0)==($(124984)|0)){Y(c|0)|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;A=d;_=h;if((c|0)!=1){break h}c=N()|0}ld(ba);break k}if((Yc(x[O>>2],x[O+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+g|0;_=h;A=d;h=ca-(f+(e>>>0>V>>>0)|0)|0;ca=h;V=V-e|0;if(!!V&(h|0)>=0|(h|0)>0){continue}break}break h}c=N()|0}AT(aa);break j}c=N()|0}ld(O);Ic(n+76|0);Q(c|0);p()}A=d;_=h}h=0;aa:{if(!_|!A){break aa}c=x[O>>2];d=x[O+4>>2];if(kc(c,d)){break aa}if((Yc(c,d)>>>0)/(A>>>0)>>>0>268435456){break aa}Eu(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Yc(x[O>>2],x[O+4>>2])>>>0)/(A>>>0)|0,x[ra>>2]=sa;d=b+484414|0;c=z[d>>1];w[d>>1]=(A|0)==2?c|65:c&65470|1;Bh(a);c=b+484400|0;h=ge(x[a>>2],x[c>>2]);if(!h){break aa}d=wb(x[O>>2]);h=wb(x[O+4>>2]);b=fb-16|0;fb=b;IU(b+8|0,d,h,x[c>>2]);fb=b+16|0;h=ge(x[a>>2],x[a+20>>2])}ld(ba);AT(aa);ld(O);Ic(n+76|0)}fb=n+96|0;return h|0}function IC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=E(0);r=fb-1520|0;fb=r;e=r+8|0;M=Tb(e,0,1512),N=-1,x[M+1420>>2]=N;v[r+56|0]=1;x[r+48>>2]=a+b;x[r+40>>2]=a;n=fb-1024|0;fb=n;v[e+1377|0]=1;a:{if(!xt(e)){break a}b=y[e+1375|0];if(!(b&2)){ec(e,34);break a}if(b&4){ec(e,34);break a}if(b&1){ec(e,34);break a}if(x[e+1116>>2]!=1){ec(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Wy(e,n+1018|0,6)|y[n+1018|0]!=102|(y[n+1019|0]!=105|y[n+1020|0]!=115)){break b}if(y[n+1021|0]!=104|y[n+1022|0]!=101|y[n+1023|0]!=97){break b}if((df(e)|0)!=100){break b}if(df(e)){break b}ec(e,38);break a}ec(e,34);break a}if((df(e)|0)!=1){ec(e,34);break a}if(!Wy(e,n+1018|0,6)){ec(e,10);break a}if(!Uy(n+1018|0)){ec(e,34);break a}if(wj(e)){ec(e,34);break a}b=df(e);x[e+4>>2]=b;if(!b){ec(e,34);break a}if(b>>>0>=17){ec(e,5);break a}b=wj(e);x[e>>2]=b;if(!b){ec(e,34);break a}wj(e);wj(e);wj(e);b=df(e);g=b>>>4|0;x[e+116>>2]=1<<g;h=b&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){ec(e,20);break a}if(b+32<<24>>24>=0){ec(e,20);break a}c:{if(g>>>0<h>>>0){ec(e,20);break c}if(!(df(e)&1)){ec(e,34);break c}if(!xt(e)){break a}if(!Vy(e)){break a}if(!Xy(e)){break a}if((Kh(e)|0)==3){while(1){if((f|0)!=6){M=(n+1018|0)+f|0,N=Kh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Uy(n+1018|0)){ec(e,20);break c}b=Ty(e);h=re(e,b+1|0);x[e+20>>2]=h;if(h){f=0;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){g=Kh(e);v[x[e+20>>2]+f|0]=g;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=Ty(e);x[e+28>>2]=0;x[e+24>>2]=b;d:{if((b|0)<=0){break d}b=re(e,b<<2);x[e+28>>2]=b;if(b){break d}ec(e,3);break c}while(1){e:{f:{if(x[e+24>>2]>(k|0)){b=Ty(e);f=re(e,b+1|0);h=k<<2;x[h+x[e+28>>2]>>2]=f;if(!x[h+x[e+28>>2]>>2]){break f}f=0;g=(b|0)>0?b:0;while(1){if((f|0)==(g|0)){break e}i=Kh(e);v[x[h+x[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(Kh(e)&1)){ec(e,20);break c}yL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=Xy(e);yL(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!Vy(e)){break a}if(!GL(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){h=b<<24;i=0;while(1){if((i|0)!=8){h=h>>31&79764919^h<<1;i=i+1|0;continue}break}x[(b<<2)+495776>>2]=h;b=b+1|0;continue}break}if((Kh(e)|0)==5){while(1){if((f|0)!=6){M=(n+1018|0)+f|0,N=Kh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Uy(n+1018|0)){ec(e,20);break c}b=pc(e,8)+1|0;x[e+120>>2]=b;b=re(e,D(b,2096));x[e+124>>2]=b;if(!b){ec(e,3);break c}Tb(b,0,D(x[e+120>>2],2096));g:{h:{while(1){i:{if(x[e+120>>2]>(j|0)){b=x[e+124>>2];if((pc(e,8)&255)!=66){ec(e,20);break c}if((pc(e,8)&255)!=67){ec(e,20);break c}if((pc(e,8)&255)!=86){ec(e,20);break c}g=b+D(j,2096)|0;M=g,N=pc(e,8)&255|pc(e,8)<<8,x[M>>2]=N;M=g,N=pc(e,8)&255|(pc(e,8)<<8&65280|pc(e,8)<<16),x[M+4>>2]=N;m=g+4|0;f=0;k=pc(e,1);if(!k){f=pc(e,1)}v[g+23|0]=f;h=x[m>>2];if(x[g>>2]){b=h;break i}b=0;if(!h){break i}ec(e,20);break c}b=pc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!pc(e,16)){continue}break}ec(e,20);break c}b=pc(e,6)+1|0;x[e+128>>2]=b;b=re(e,D(b,1596));x[e+260>>2]=b;k:{l:{if(b){l=0;h=0;m:while(1){if(x[e+128>>2]<=(h|0)){break l}b=pc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(e,20);break c}if(!b){b=x[e+260>>2]+D(h,1596)|0;M=b,N=pc(e,8),v[M|0]=N;M=b,N=pc(e,16),w[M+2>>1]=N;M=b,N=pc(e,16),w[M+4>>1]=N;M=b,N=pc(e,6),v[M+6|0]=N;M=b,N=pc(e,8),v[M+7|0]=N;j=pc(e,4)+1|0;v[b+8|0]=j;f=0;while(1){if((j&255)>>>0>f>>>0){M=b+f|0,N=pc(e,8),v[M+9|0]=N;f=f+1|0;j=y[b+8|0];continue}break}ec(e,4);break c}f=x[e+260>>2]+D(h,1596)|0;b=pc(e,5);v[f|0]=b;i=0;j=-1;while(1)if((b&255)>>>0<=i>>>0){k=j+1|0;b=0;while(1){if((b|0)!=(k|0)){g=b+f|0;M=g,N=pc(e,3)+1|0,v[M+33|0]=N;j=pc(e,2);v[g+49|0]=j;i=0;if(j&255){j=pc(e,8);v[g+65|0]=j;if(x[e+120>>2]<=(j&255)){break k}}while(1){if(1<<y[g+49|0]>(i|0)){j=pc(e,8)-1|0;w[((f+(b<<4)|0)+(i<<1)|0)+82>>1]=j;i=i+1|0;if(x[e+120>>2]>j<<16>>16){continue}break k}break}b=b+1|0;continue}break}j=2;M=f,N=pc(e,2)+1|0,v[M+1588|0]=N;b=pc(e,4);x[f+1592>>2]=2;k=0;w[f+338>>1]=0;v[f+1589|0]=b;w[f+340>>1]=1<<b;g=f+338|0;b=0;while(1){if(y[f|0]>b>>>0){m=f+y[(b+f|0)+1|0]|0;i=0;while(1){if(y[m+33|0]>i>>>0){j=pc(e,y[f+1589|0]);w[(f+(x[f+1592>>2]<<1)|0)+338>>1]=j;j=x[f+1592>>2]+1|0;x[f+1592>>2]=j;i=i+1|0;continue}break}b=b+1|0;continue}break}while(1){if((k|0)<(j|0)){b=z[(f+(k<<1)|0)+338>>1];i=(n+16|0)+(k<<2)|0;w[i+2>>1]=k;w[i>>1]=b;k=k+1|0;j=x[f+1592>>2];continue}break}xL(n+16|0,j,1176);j=x[f+1592>>2];k=((j|0)<=1?1:j)-1|0;i=0;b=0;while(1){if((b|0)!=(k|0)){m=n+16|0;o=z[m+(b<<2)>>1];b=b+1|0;if((o|0)!=z[m+(b<<2)>>1]){continue}break k}break}while(1){if((i|0)<(j|0)){v[(f+i|0)+838|0]=y[((n+16|0)+(i<<2)|0)+2|0];i=i+1|0;j=x[f+1592>>2];continue}break}i=2;while(1){if((i|0)<(j|0)){x[n+12>>2]=0;x[n+8>>2]=0;b=0;s=(i|0)>0?i:0;j=g+(i<<1)|0;m=65536;o=-1;while(1){if((b|0)!=(s|0)){q=g+(b<<1)|0;k=z[q>>1];if(!((o|0)>=(k|0)|z[j>>1]<=k>>>0)){x[n+12>>2]=b;k=z[q>>1];o=k}if(!((k|0)>=(m|0)|z[j>>1]>=k>>>0)){x[n+8>>2]=b;m=z[q>>1]}b=b+1|0;continue}break}b=f+(i<<1)|0;v[b+1088|0]=x[n+12>>2];v[b+1089|0]=x[n+8>>2];i=i+1|0;j=x[f+1592>>2];continue}break}l=(j|0)>(l|0)?j:l;h=h+1|0;continue m}else{b=pc(e,4);v[(f+i|0)+1|0]=b;b=b&255;j=(b|0)>(j|0)?b:j;i=i+1|0;b=y[f|0];continue}}}ec(e,3);break c}b=pc(e,6)+1|0;x[e+264>>2]=b;b=re(e,D(b,24));x[e+396>>2]=b;if(!b){ec(e,3);break c}k=0;Tb(b,0,D(x[e+264>>2],24));n:{o:{while(1){if(x[e+264>>2]>(k|0)){b=x[e+396>>2];h=pc(e,16);w[((k<<1)+e|0)+268>>1]=h;j=20;if((h&65535)>>>0>2){break n}g=b+D(k,24)|0;M=g,N=pc(e,24),x[M>>2]=N;b=pc(e,24);x[g+4>>2]=b;if(b>>>0<A[g>>2]){break n}M=g,N=pc(e,24)+1|0,x[M+8>>2]=N;M=g,N=pc(e,6)+1|0,v[M+12|0]=N;b=pc(e,8);v[g+13|0]=b;if(x[e+120>>2]<=(b&255)){break n}f=0;while(1){b=y[g+12|0];if(b>>>0>f>>>0){h=(n+16|0)+f|0;i=pc(e,3);if(pc(e,1)){b=pc(e,5)}else{b=0}v[h|0]=i+(b<<3);f=f+1|0;continue}break}b=re(e,b<<4);x[g+20>>2]=b;if(!b){break o}h=0;while(1){if(y[g+12|0]>h>>>0){b=y[(n+16|0)+h|0];f=0;while(1){if((f|0)!=8){p:{if(b>>>f&1){i=pc(e,8);o=f<<1;m=h<<4;w[o+(m+x[g+20>>2]|0)>>1]=i;if(x[e+120>>2]<=w[o+(m+x[g+20>>2]|0)>>1]){break n}break p}w[(x[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=re(e,x[(x[e+124>>2]+D(y[g+13|0],2096)|0)+4>>2]<<2);x[g+16>>2]=h;if(!h){break o}b=0;Tb(h,0,x[(x[e+124>>2]+D(y[g+13|0],2096)|0)+4>>2]<<2);while(1){h=x[e+124>>2]+D(y[g+13|0],2096)|0;if(x[h+4>>2]>(b|0)){f=x[h>>2];i=re(e,f);h=b<<2;x[h+x[g+16>>2]>>2]=i;i=b;if(!x[h+x[g+16>>2]>>2]){break o}while(1){if((f|0)>0){f=f-1|0;v[f+x[h+x[g+16>>2]>>2]|0]=(i|0)%y[g+12|0];i=(i|0)/y[g+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=pc(e,6)+1|0;x[e+400>>2]=b;b=re(e,D(b,40));x[e+404>>2]=b;if(!b){ec(e,3);break c}Tb(b,0,D(x[e+400>>2],40));h=0;while(1){if(x[e+400>>2]>(h|0)){b=x[e+404>>2];if(pc(e,16)){ec(e,20);break c}g=b+D(h,40)|0;b=re(e,D(x[e+4>>2],3));x[g+4>>2]=b;if(!b){ec(e,3);break c}if(pc(e,1)){b=pc(e,4)+1|0}else{b=1}v[g+8|0]=b;q:{if(pc(e,1)){b=pc(e,8)+1|0;w[g>>1]=b;f=0;j=x[e+4>>2];if((j|0)<(b&65535)){ec(e,20);break c}while(1){if(z[g>>1]<=f>>>0){break q}i=pc(e,Gm(j-1|0));b=D(f,3);v[b+x[g+4>>2]|0]=i;i=pc(e,Gm(x[e+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=i;j=x[e+4>>2];b=b+x[g+4>>2]|0;i=y[b|0];if((j|0)<=(i|0)){ec(e,20);break c}b=y[b+1|0];if((b|0)>=(j|0)){ec(e,20);break c}f=f+1|0;if((b|0)!=(i|0)){continue}break}ec(e,20);break c}w[g>>1]=0}if(pc(e,2)){ec(e,20);break c}j=0;b=0;f=0;r:{if(y[g+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break r}f=pc(e,4);i=D(b,3);v[(i+x[g+4>>2]|0)+2|0]=f;b=b+1|0;if(y[(i+x[g+4>>2]|0)+2|0]<y[g+8|0]){continue}break}ec(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break r}v[(x[g+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}s:{while(1){if(y[g+8|0]<=j>>>0){break s}pc(e,8);b=g+j|0;M=b,N=pc(e,8),v[M+9|0]=N;f=pc(e,8);v[b+24|0]=f;if(x[e+128>>2]<=y[b+9|0]){ec(e,20);break c}j=j+1|0;if(x[e+264>>2]>(f&255)){continue}break}ec(e,20);break c}h=h+1|0;continue}break}M=e,N=pc(e,6)+1|0,x[M+408>>2]=N;h=e+412|0;i=0;t:{while(1){if(x[e+408>>2]<=(i|0)){break t}b=h+D(i,6)|0;M=b,N=pc(e,1),v[M|0]=N;M=b,N=pc(e,16),w[M+2>>1]=N;M=b,N=pc(e,16),w[M+4>>1]=N;f=pc(e,8);v[b+1|0]=f;if(z[b+2>>1]){ec(e,20);break c}if(z[b+4>>1]){ec(e,20);break c}i=i+1|0;if(x[e+400>>2]>(f&255)){continue}break}ec(e,20);break c}EL(e);x[e+992>>2]=0;h=l<<1;f=0;while(1){if(x[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=re(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=b,N=re(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;g=re(e,h);x[b+996>>2]=g;i=x[b+800>>2];if(g?!i|!x[b+928>>2]:1){ec(e,3);break c}Tb(i,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!wL(e,0,x[e+112>>2])){break a}if(!wL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];h=x[e+116>>2];x[e+108>>2]=h;b=x[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;j=0;while(1){if((f|0)!=(i|0)){g=x[e+396>>2]+D(f,24)|0;k=x[g+4>>2];l=b>>>0>k>>>0?k:b;k=x[g>>2];g=(l-(b>>>0>k>>>0?k:b)>>>0)/A[g+8>>2]|0;j=(g|0)>(j|0)?g:j;f=f+1|0;continue}break}b=h<<1&2147483646;h=D(x[e+4>>2],(j<<2)+4|0);b=b>>>0>h>>>0?b:h;x[e+12>>2]=b;u:{v:{if(!x[e+80>>2]){break v}h=x[e+92>>2];if((h|0)!=x[e+84>>2]){break u}if(h>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break v}ec(e,3);break c}w:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break w}x[e+52>>2]=0}f=1;break a}_(7344,13258,4196,8829);p()}j=3}ec(e,j);break c}ec(e,20);break c}x:{if(f&255){i=io(e,b);break x}i=re(e,b);x[g+8>>2]=i}if(!i){ec(e,3);break c}h=0;y:{if(!k){f=0;while(1){b=x[m>>2];if((f|0)>=(b|0)){break y}z:{A:{if(y[g+23|0]){if(!pc(e,1)){break A}}b=pc(e,5)+1|0;v[f+i|0]=b;if((b&255)!=32){h=h+1|0;break z}ec(e,20);break c}v[f+i|0]=255}f=f+1|0;continue}}k=pc(e,5);f=0;while(1){b=x[m>>2];if((f|0)>=(b|0)){break y}l=pc(e,Gm(b-f|0));k=k+1|0;if((k|0)>=32){ec(e,20);break c}b=f+l|0;if((b|0)>x[m>>2]){ec(e,20);break c}else{Tb(f+i|0,k,l);f=b;continue}}}B:{C:{D:{if(y[g+23|0]){if(b>>2>(h|0)){break D}if(x[e+16>>2]<(b|0)){x[e+16>>2]=b;b=x[m>>2]}b=re(e,b);x[g+8>>2]=b;if(!b){ec(e,3);break c}yc(b,i,x[m>>2]);vj(e,i,x[m>>2]);i=x[g+8>>2];v[g+23|0]=0;b=x[m>>2]}k=0;h=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(h|0)){k=((y[f+i|0]-11&255)>>>0<244)+k|0;f=f+1|0;continue}break}x[g+2092>>2]=k;b=re(e,b<<2);x[g+32>>2]=b;if(b){k=g+2092|0;f=0;break C}ec(e,3);break c}x[g+2092>>2]=h;k=g+2092|0;E:{if(!h){f=0;h=0;break E}b=re(e,h);x[g+8>>2]=b;if(!b){ec(e,3);break c}b=io(e,x[k>>2]<<2);x[g+32>>2]=b;if(!b){ec(e,3);break c}f=io(e,x[k>>2]<<2);if(!f){break B}b=x[m>>2];h=x[k>>2]}b=(h<<3)+b|0;if(b>>>0<=A[e+16>>2]){break C}x[e+16>>2]=b}o=x[m>>2];b=0;h=fb-128|0;fb=h;q=Tb(h,0,128);h=(o|0)>0?o:0;while(1){F:{G:{if((b|0)!=(h|0)){if(y[b+i|0]==255){break G}h=b}if((h|0)==(o|0)){b=1;if(!x[g+2092>>2]){break F}_(15766,13258,1103,7588);p()}b=h+i|0;l=y[b|0];if(l>>>0<32){uL(g,0,h,0,l,f);s=1;l=y[b|0]+1|0;b=1;H:{while(1){if((b|0)==(l|0)){I:while(1){J:{b=1;h=h+1|0;if((o|0)<=(h|0)){break F}C=h+i|0;l=y[C|0];if((l|0)==255){continue}b=l;if(b>>>0>=32){break J}while(1){if((b|0)<=0){b=0;break F}G=q+(b<<2)|0;H=x[G>>2];if(!H){b=b-1|0;continue}break}x[G>>2]=0;uL(g,Em(H),h,s,l,f);s=s+1|0;l=y[C|0];if((l|0)==(b|0)){continue}while(1){if((b|0)>=(l|0)){continue I}C=q+(l<<2)|0;if(x[C>>2]){break H}x[C>>2]=H+(1<<32-l);l=l-1|0;continue}}break}}else{x[q+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}_(15225,13258,1118,7588);p()}_(15810,13258,1133,7588);p()}_(15232,13258,1104,7588);p()}b=b+1|0;continue}break}fb=q+128|0;if(!b){if(y[g+23|0]){vj(e,f,0)}ec(e,20);break c}b=x[k>>2];if(b){b=re(e,(b<<2)+4|0);x[g+2084>>2]=b;if(!b){ec(e,3);break c}b=re(e,(x[k>>2]<<2)+4|0);x[g+2088>>2]=b;if(!b){ec(e,3);break c}x[g+2088>>2]=b+4;x[b>>2]=-1;b=0;l=0;K:{L:{M:{if(y[g+23|0]){while(1){l=x[g+2092>>2];if((l|0)<=(b|0)){break M}h=b<<2;M=h+x[g+2084>>2]|0,N=Em(x[h+x[g+32>>2]>>2]),x[M>>2]=N;b=b+1|0;continue}}while(1){if(x[g+4>>2]>(b|0)){if(tL(y[g+23|0],y[b+i|0])){M=x[g+2084>>2]+(l<<2)|0,N=Em(x[x[g+32>>2]+(b<<2)>>2]),x[M>>2]=N;l=l+1|0}b=b+1|0;continue}break}if(x[g+2092>>2]!=(l|0)){break L}}xL(x[g+2084>>2],l,1177);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;b=x[g+(y[g+23|0]?2092:4)>>2];H=(b|0)>0?b:0;N:{while(1){if((h|0)!=(H|0)){b=h;l=y[g+23|0];b=l?x[(b<<2)+f>>2]:b;C=y[b+i|0];O:{if(!tL(l,C)){break O}G=h<<2;o=Em(x[G+x[g+32>>2]>>2]);b=x[g+2092>>2];l=0;while(1){if((b|0)>=2){q=b>>>1|0;K=q+l|0;s=o>>>0<A[x[g+2084>>2]+(K<<2)>>2];b=s?q:b-q|0;l=s?l:K;continue}break}b=l<<2;if((o|0)!=x[b+x[g+2084>>2]>>2]){break N}if(y[g+23|0]){x[b+x[g+2088>>2]>>2]=x[f+G>>2];v[x[g+8>>2]+l|0]=C;break O}x[b+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break K}_(12299,13258,1230,9982);p()}_(7529,13258,1200,9982);p()}}if(y[g+23|0]){vj(e,f,x[k>>2]<<2);vj(e,x[g+32>>2],x[k>>2]<<2);vj(e,i,x[m>>2]);x[g+32>>2]=0}b=0;f=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){P:{if(y[x[g+8>>2]+f|0]>10){break P}Q:{if(y[g+23|0]){b=Em(x[x[g+2084>>2]+(f<<2)>>2]);break Q}b=x[x[g+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break P}w[(g+(b<<1)|0)+36>>1]=f;b=(1<<y[x[g+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=pc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){ec(e,20);break c}if(b){M=g,O=vL(pc(e,32)),B[M+12>>2]=O;M=g,O=vL(pc(e,32)),B[M+16>>2]=O;M=g,N=pc(e,4)+1|0,v[M+20|0]=N;M=g,N=pc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[m>>2];R:{if(y[g+21|0]==1){u=J(Rs(+E(E(Yp(+E(h|0)))/E(f|0))));S:{if(F(u)<2147483648){b=~~u;break S}b=-2147483648}u=+(f|0);L=J(ok(+E(E(b|0)+E(1)),u));T:{if(F(L)<2147483648){f=~~L;break T}f=-2147483648}b=((f|0)<=(h|0))+b|0;t=E(b|0);if(ok(+E(t+E(1)),u)<=+(h|0)){f=-1}else{u=J(ok(+t,u));U:{if(F(u)<2147483648){f=~~u;break U}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break R}ec(e,20);break c}f=D(f,h)}x[g+24>>2]=f;if(!f){ec(e,20);break c}l=io(e,f<<1);if(!l){break h}f=0;while(1){i=x[g+24>>2];if((i|0)>(f|0)){b=pc(e,y[g+20|0]);if((b|0)==-1){vj(e,l,x[g+24>>2]<<1);ec(e,20);break c}else{w[l+(f<<1)>>1]=b;f=f+1|0;continue}}break}V:{W:{if(y[g+21|0]==1){o=y[g+23|0];X:{if(o){f=x[k>>2];if(f){break X}break V}f=x[m>>2]}b=re(e,D(x[g>>2],f)<<2);x[g+28>>2]=b;if(!b){vj(e,l,x[g+24>>2]<<1);ec(e,3);break c}h=0;b=x[(o?k:m)>>2];q=(b|0)>0?b:0;s=g+2088|0;t=E(0);while(1){if((h|0)==(q|0)){break W}k=o?x[x[s>>2]+(h<<2)>>2]:h;i=x[g>>2];f=0;b=1;while(1){if((f|0)<(i|0)){I=E(t+E(E(E(z[l+(((k>>>0)/(b>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(D(h,i)+f<<2)>>2]=I;t=y[g+22|0]?I:t;f=f+1|0;i=x[g>>2];if((f|0)>=(i|0)){continue}m=x[g+24>>2];zua(m,0,b,0);if(hb){vj(e,l,m<<1);ec(e,20);break c}else{b=D(b,m);continue}}break}h=h+1|0;continue}}b=re(e,i<<2);x[g+28>>2]=b;if(!b){break g}f=0;t=E(0);while(1){i=x[g+24>>2];if((i|0)<=(f|0)){break V}I=E(t+E(E(E(z[l+(f<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(f<<2)>>2]=I;t=y[g+22|0]?I:t;f=f+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}vj(e,l,i<<1)}j=j+1|0;continue}break}ec(e,3);break c}ec(e,3);break c}vj(e,l,x[g+24>>2]<<1);ec(e,3);break c}ec(e,20);break c}ec(e,3);break c}v[b+x[x[e+28>>2]+(k<<2)>>2]|0]=0;k=k+1|0;continue}}ec(e,3);break c}ec(e,20)}f=0}fb=n+1024|0;Y:{Z:{if(!f){x[d>>2]=x[r+104>>2]?1:x[r+108>>2];break Z}b=re(r+8|0,1512);if(b){M=c,N=x[yc(b,r+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break Y}}HL(r+8|0);b=0}fb=r+1520|0;return b}function uK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;r=fb-48|0;fb=r;a:{if(c>>>0<=2){c=c<<2;H=x[c+95708>>2];I=x[c+95696>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=vd(b)}if(ql(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=vd(b)}e:{f:{while(1){if(v[g+4952|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=vd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=fb-16|0;fb=l;i=(q(E(E(o|0)*E(Infinity))),j(2));b=i&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=i<<25;d=i>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);Wf(l,c,0,0,0,b+81|0);k=x[l>>2];h=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=h;x[r+8>>2]=c;x[r+12>>2]=i&-2147483648|d;fb=l+16|0;k=x[r+8>>2];h=x[r+12>>2];i=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9978|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=vd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=vd(b)}if((g&-33)==88){g=0;f=fb-432|0;fb=f;p:{q:{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break q}c=0;break p}c=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!c){g=vd(b);break y}if((g|0)!=48){m=1073676288;c=0;if((g|0)==46){break w}break v}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break x}s=1;x[b+4>>2]=c+1;g=y[c|0]}c=1;continue}s=1;break s}g=x[b+4>>2];z:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break z}g=vd(b)}if((g|0)==48){break u}e=1}break t}while(1){g=t;t=g-1|0;u=u-!g|0;e=1;g=x[b+4>>2];A:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break A}g=vd(b)}if((g|0)==48){continue}break}s=1}B:{while(1){C:{J=g|32;D:{E:{K=g-48|0;if(K>>>0<10){break E}if((g|0)!=46&J-97>>>0>5){break B}if((g|0)!=46){break E}if(e){break C}e=1;t=k;u=h;break D}g=(g|0)>57?J-87|0:K;F:{if((h|0)<=0&k>>>0<=7|(h|0)<0){c=g+(c<<4)|0;break F}if(!h&k>>>0<=28){ih(f+48|0,g);Sd(f+32|0,C,F,i,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];i=x[f+40>>2];m=x[f+44>>2];Sd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,i,m);Qg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,z,B);z=x[f+8>>2];B=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break F}if(!g|n){break F}Sd(f+80|0,C,F,i,m,0,0,0,1073610752);Qg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,z,B);z=x[f+72>>2];B=x[f+76>>2];n=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;h=k?h:h+1|0;s=1}g=x[b+4>>2];if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0]}else{g=vd(b)}continue}break}g=46}if(!s){c=x[b+116>>2];G:{H:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break H}x[b+4>>2]=c-2;if(!e){break G}x[b+4>>2]=c-3;break G}if(d){break G}}Fi(b,0,0)}ij(f+96|0,+(o|0)*0);k=x[f+104>>2];h=x[f+108>>2];l=x[f+96>>2];p=x[f+100>>2];break r}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;m=h;while(1){c=c<<4;i=i+1|0;m=i?m:m+1|0;if((i|0)!=8|m){continue}break}}I:{J:{K:{if((g&-33)==80){i=tK(b,d);m=hb;if(i|(m|0)!=-2147483648){break I}if(d){d=x[b+116>>2];if((d|0)>0|(d|0)>=0){break K}break J}l=0;p=0;Fi(b,0,0);k=0;h=0;break r}i=0;m=0;if(x[b+116>>2]<0){break I}}x[b+4>>2]=x[b+4>>2]-1}i=0;m=0}if(!c){ij(f+112|0,+(o|0)*0);k=x[f+120>>2];h=x[f+124>>2];l=x[f+112>>2];p=x[f+116>>2];break r}b=e?t:k;h=(e?u:h)<<2|b>>>30;d=i+(b<<2)|0;b=h+m|0;b=d>>>0<i>>>0?b+1|0:b;k=d-32|0;h=b-(d>>>0<32)|0;b=h;if(k>>>0>0-H>>>0&(b|0)>=0|(b|0)>0){x[31596]=68;ih(f+160|0,o);Sd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Sd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);k=x[f+136>>2];h=x[f+140>>2];l=x[f+128>>2];p=x[f+132>>2];break r}b=H-226|0;d=b>>31;if((h|0)>=(d|0)&b>>>0<=k>>>0|(d|0)<(h|0)){if((c|0)>=0){while(1){Qg(f+416|0,l,p,z,B,0,0,0,-1073807360);b=sU(l,p,z,B,1073610752);d=(b|0)>=0;b=d;Qg(f+400|0,l,p,z,B,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=k;k=b-1|0;h=h-!b|0;z=x[f+408>>2];B=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];c=d|c<<1;if((c|0)>=0){continue}break}}b=h-((H>>31)+(k>>>0<H>>>0)|0)|0;d=(k-H|0)+32|0;b=d>>>0<32?b+1|0:b;d=d>>>0<I>>>0&(b|0)<=0|(b|0)<0?(d|0)>0?d:0:I;L:{if((d|0)>=113){ih(f+384|0,o);t=x[f+392>>2];u=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];i=0;b=0;break L}ij(f+352|0,nk(1,144-d|0));ih(f+336|0,o);C=x[f+336>>2];F=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];wK(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,t,u);w=x[f+376>>2];L=x[f+380>>2];i=x[f+372>>2];b=x[f+368>>2]}d=!(c&1)&(($m(l,p,z,B,0,0,0,0)|0)!=0&(d|0)<32);Nn(f+320|0,d+c|0);Sd(f+304|0,C,F,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Qg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,i,w,L);b=d;Sd(f+288|0,C,F,t,u,b?0:l,b?0:p,b?0:z,b?0:B);Qg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);Ry(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,i,w,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];i=x[f+252>>2];if(!$m(b,d,c,i,0,0,0,0)){x[31596]=68}vK(f+224|0,b,d,c,i,k);k=x[f+232>>2];h=x[f+236>>2];l=x[f+224>>2];p=x[f+228>>2];break r}x[31596]=68;ih(f+208|0,o);Sd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Sd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);k=x[f+184>>2];h=x[f+188>>2];l=x[f+176>>2];p=x[f+180>>2];break r}c=0;continue}break}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=k;x[r+28>>2]=h;fb=f+432|0;k=x[r+24>>2];h=x[r+28>>2];i=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;w=o;f=d;b=0;o=0;e=fb-8976|0;fb=e;K=0-H|0;L=K-I|0;M:{N:{while(1){if((c|0)!=48){O:{if((c|0)!=46){break M}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break O}x[g+4>>2]=c+1;c=y[c|0];break N}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=vd(g)}b=1;continue}break}c=vd(g)}n=1;if((c|0)!=48){break M}while(1){b=k;k=b-1|0;h=h-!b|0;b=x[g+4>>2];P:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break P}c=vd(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;Q:{R:{d=(c|0)==46;l=c-48|0;S:{T:{U:{if(d|l>>>0<=9){while(1){V:{if(d&1){if(!n){k=i;h=m;n=1;break V}d=!b;break U}i=i+1|0;m=i?m:m+1|0;if((o|0)<=2044){J=(c|0)==48?J:i;b=(e+784|0)+(o<<2)|0;if(s){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=s+1|0;c=(d|0)==9;s=c?0:d;o=c+o|0;break V}if((c|0)==48){break V}x[e+8960>>2]=x[e+8960>>2]|1;J=18396}c=x[g+4>>2];W:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break W}c=vd(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=n?k:i;h=n?h:m;if(!(!b|(c&-33)!=69)){l=tK(g,f);b=hb;p=b;X:{if(l|(b|0)!=-2147483648){break X}if(!f){break S}l=0;p=0;if(x[g+116>>2]<0){break X}x[g+4>>2]=x[g+4>>2]-1}h=h+p|0;k=k+l|0;h=k>>>0<l>>>0?h+1|0:h;break R}d=!b;if((c|0)<0){break T}}if(x[g+116>>2]<0){break T}x[g+4>>2]=x[g+4>>2]-1}if(!d){break R}x[31596]=28}i=0;m=0;Fi(g,0,0);c=0;b=0;break Q}b=x[e+784>>2];if(!b){ij(e,+(w|0)*0);i=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break Q}if(!((k|0)!=(i|0)|(h|0)!=(m|0)|(i>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>I|0?(I|0)<=30:0))){ih(e+48|0,w);Nn(e+32|0,b);Sd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);i=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break Q}if(k>>>0>K>>>1>>>0&(h|0)>=0|(h|0)>0){x[31596]=68;ih(e+96|0,w);Sd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Sd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);i=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break Q}b=H-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){x[31596]=68;ih(e+144|0,w);Sd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Sd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);i=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break Q}if(s){if((s|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);s=s+1|0;if((s|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}n=k;Y:{if((k|0)<(J|0)|(J|0)>8|(k|0)>17){break Y}if((n|0)==9){ih(e+192|0,w);Nn(e+176|0,x[e+784>>2]);Sd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);i=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break Q}if((n|0)<=8){ih(e+272|0,w);Nn(e+256|0,x[e+784>>2]);Sd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);ih(e+224|0,x[(0-n<<2)+95696>>2]);IQ(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);i=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break Q}b=(D(n,-3)+I|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}ih(e+352|0,w);Nn(e+336|0,c);Sd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);ih(e+304|0,x[(n<<2)+95624>>2]);Sd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);i=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break Q}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){s=0;d=0;break Z}s=0;b=(n|0)<0?b+9|0:b;_:{if(!c){d=0;c=0;break _}k=x[(0-b<<2)+95696>>2];h=1e9/(k|0)|0;l=0;g=0;d=0;while(1){i=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];o=(m>>>0)/(k>>>0)|0;i=i+o|0;x[l>>2]=i;i=!i&(d|0)==(g|0);d=i?d+1&2047:d;n=i?n-9|0:n;l=D(h,m-D(k,o)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break _}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}n=(n-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;f=(n|0)<36;$:{while(1){aa:{if(f){break aa}if((n|0)!=36){break $}if(A[g>>2]<=10384592){break aa}n=36;break $}o=c+2047|0;l=0;b=c;while(1){c=b;i=o&2047;o=(e+784|0)+(i<<2)|0;b=x[o>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;h=k>>>0<l>>>0?b+1|0:b;if(!h&k>>>0<1000000001){l=0}else{l=Bua(k,h,1e9,0);b=zua(l,hb,-1e9,-1);k=b+k|0}x[o>>2]=k;b=(i|0)!=(c-1&2047)?c:(d|0)==(i|0)?c:k?c:i;o=i-1|0;if((d|0)!=(i|0)){continue}break}s=s-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;g=c;h=x[c>>2];c=b-1&2047;x[g>>2]=h|x[k+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){i=(n|0)>45?9:1;da:{while(1){b=d;g=0;ea:{while(1){fa:{d=b+g&2047;if((d|0)==(c|0)){break fa}d=x[(e+784|0)+(d<<2)>>2];h=x[(g<<2)+95648>>2];if(d>>>0<h>>>0){break fa}if(d>>>0>h>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[((c<<2)+e|0)+780>>2]=0}Nn(e+768|0,x[(e+784|0)+(d<<2)>>2]);Sd(e+752|0,k,h,i,m,0,0,1342177280,1075633366);Qg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);i=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];h=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}ih(e+720|0,w);Sd(e+704|0,k,h,i,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);i=x[e+712>>2];m=x[e+716>>2];k=0;h=0;l=x[e+704>>2];p=x[e+708>>2];f=s+113|0;g=f-H|0;o=(g|0)<(I|0);d=o?(g|0)>0?g:0:I;if((d|0)<=112){break da}break ba}s=i+s|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>i|0;o=-1<<i^-1;g=0;d=b;while(1){h=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];h=h+(f>>>i|0)|0;x[g>>2]=h;h=!h&(b|0)==(d|0);d=h?d+1&2047:d;n=h?n-9|0:n;g=D(m,f&o);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}x[l>>2]=x[l>>2]|1;continue}break}break}ij(e+656|0,nk(1,225-d|0));wK(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,i,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];ij(e+640|0,nk(1,113-d|0));iQ(e+672|0,l,p,i,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];h=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];Ry(e+624|0,l,p,i,m,k,h,t,u);Qg(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);i=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}n=b+4&2047;ga:{if((n|0)==(c|0)){break ga}n=x[(e+784|0)+(n<<2)>>2];ha:{if(n>>>0<=499999999){if(!n&(b+5&2047)==(c|0)){break ha}ij(e+496|0,+(w|0)*.25);Qg(e+480|0,k,h,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];k=x[e+480>>2];h=x[e+484>>2];break ha}if((n|0)!=5e8){ij(e+592|0,+(w|0)*.75);Qg(e+576|0,k,h,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];k=x[e+576>>2];h=x[e+580>>2];break ha}M=+(w|0);if((b+5&2047)==(c|0)){ij(e+528|0,M*.5);Qg(e+512|0,k,h,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];k=x[e+512>>2];h=x[e+516>>2];break ha}ij(e+560|0,M*.75);Qg(e+544|0,k,h,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];k=x[e+544>>2];h=x[e+548>>2]}if((d|0)>111){break ga}iQ(e+464|0,k,h,t,u,0,0,0,1073676288);if($m(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break ga}Qg(e+448|0,k,h,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];k=x[e+448>>2];h=x[e+452>>2]}Qg(e+432|0,l,p,i,m,k,h,t,u);Ry(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);i=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ia:{if((L-2|0)>=(f&2147483647)){break ia}x[e+408>>2]=i;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Sd(e+384|0,l,p,i,m,0,0,0,1073610752);c=sU(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(c|0)>=0;i=b?x[e+392>>2]:i;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;s=b+s|0;if(!(o&((d|0)!=(g|0)|(c|0)<0)&($m(k,h,t,u,0,0,0,0)|0)!=0)&(s+110|0)<=(L|0)){break ia}x[31596]=68}vK(e+368|0,l,p,i,m,s);i=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=i;x[r+36>>2]=m;fb=e+8976|0;k=x[r+40>>2];h=x[r+44>>2];i=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ja:{c=x[b+4>>2];ka:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ka}c=vd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];la:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break la}c=vd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[31596]=28;Fi(b,0,0)}h=0}x[a>>2]=i;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=h;fb=r+48|0}function $qa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=fb-416|0;fb=d;vc(b);i=d+411|0;e=fE(b,i);if(!e){EY(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!e){break j}if(!FY(d+411|0)){break j}if(!c){B=1;break j}H=Fe(d+388|0,b);x[31721]=0;O(511,d+376|0,H|0);b=x[31721];x[31721]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31721]=0;S(512,d+356|0,d+376|0,20041);b=x[31721];x[31721]=0;if((b|0)==1){break t}x[31721]=0;e=R(175,x[d+356>>2])|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}if(!e){break k}x[31721]=0;e=P(513,d+356|0,d+265|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}if(!e){break k}x[31721]=0;O(249,a|0,16384);b=x[31721];x[31721]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31721]=0;e=U(269,a+1074312|0,9,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;e=U(269,e|0,114,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;e=P(270,e|0,21)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;P(270,e|0,30)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;e=P(1,d+252|0,8280)|0;b=x[31721];x[31721]=0;if((b|0)==1){break q}yb(a+1298344|0,e);tb(e);x[31721]=0;e=P(1,d+240|0,10751)|0;b=x[31721];x[31721]=0;if((b|0)==1){break p}yb(a+1298356|0,e);tb(e);x[31721]=0;g=P(1,d+228|0,18119)|0;b=x[31721];x[31721]=0;if((b|0)==1){break o}e=15036;b=y[d+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}f=N()|0;break a}f=N()|0;break b}e=15017;break m}if(!b){break n}e=22250;break m}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}e=13322}x[31721]=0;i=P(1,d+216|0,e|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;S(2,d+192|0,g|0,i|0);b=x[31721];x[31721]=0;if((b|0)==1){break f}e=d+192|0;yb(a+1298368|0,e);tb(e);tb(i);tb(g);I=a+1298404|0,J=x[Ec(e,4)>>2],x[I>>2]=J;b=d+84|0;Te(b,3,d+265|0);x[31721]=0;O(221,e|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}e=d+192|0;yb(a+1298308|0,e);tb(e);b=d+84|0;si(b,3,d+297|0);x[31721]=0;S(372,e|0,4,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break h}b=d+192|0;yb(a+1298320|0,b);tb(b);x[a+480200>>2]=y[d+321|0]+1;I=a,J=Hd(y[d+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Hd(y[d+323|0],4,255),1e4),x[I+480204>>2]=J;i=x[a+484360>>2];e=a+484376|0;b=y[e|0];x[31721]=0;aa(351,Wb(i,b)|0,d+356|0,y[d+317|0]|y[d+318|0]<<8,65535,65535);b=x[31721];x[31721]=0;if((b|0)==1){break l}Ze(Wb(x[a+484360>>2],y[e|0]),y[d+319|0]|y[d+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[31721]=0;S(512,d+192|0,d+376|0,17741);b=x[31721];x[31721]=0;if((b|0)!=1){b=d+192|0;i=gd(d+356|0,b);ub(b);b=x[i>>2];x[31721]=0;e=R(157,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;V(339,a+1298332|0,i|0,e|0,0);b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;S(512,d+192|0,d+376|0,21321);b=x[31721];x[31721]=0;if((b|0)!=1){b=d+192|0;j=gd(i,b);ub(b);b=x[j>>2];x[31721]=0;e=R(175,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}u:{v:{if(e){x[31721]=0;S(512,d+192|0,d+376|0,16723);b=x[31721];x[31721]=0;if((b|0)==1){break u}x[31721]=0;g=R(200,j|0)|0;b=x[31721];x[31721]=0;w:{if((b|0)!=1){i=c&2;G=a+480190|0;h=0;while(1){if(g>>>0<=(h&255)>>>0){break w}x[31721]=0;q=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}if(!q){break w}e=x[j+8>>2];b=x[j>>2];x[31721]=0;e=U(153,b|0,e|0,56)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}if(!e){break w}if(q>>>0>z[G>>1]){w[G>>1]=q}x[31721]=0;n=D(q,104)+a|0;k=n+484380|0;O(282,k|0,0);b=x[31721];x[31721]=0;if((b|0)==1){break v}_o(k);x[31721]=0;S(320,j|0,((q<<5)+a|0)+946304|0,32);b=x[31721];x[31721]=0;if((b|0)==1){break v}x[31721]=0;O(323,j|0,n+484423|0);b=x[31721];x[31721]=0;if((b|0)==1){break v}x:{if(y[d+415|0]<=15){x[31721]=0;f=R(192,j|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break x}break v}x[31721]=0;f=R(154,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}}x[n+484404>>2]=f<<1;x[31721]=0;e=R(154,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}x[k>>2]=e;x[31721]=0;e=R(154,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}C=n+484384|0;x[C>>2]=e;x[31721]=0;e=R(154,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}m=n+484388|0;x[m>>2]=e;if(e){b=n+484414|0;w[b>>1]=z[b>>1]|2;x[m>>2]=e+x[C>>2]}x[31721]=0;e=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}if(y[d+415|0]<=15){w[n+484410>>1]=e}x[31721]=0;q=R(200,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}b=n+484414|0;e=z[b>>1];B=8;if(q&1){e=e|1;w[b>>1]=e;x[k>>2]=x[k>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[m>>2]=x[m>>2]>>>1;B=16}w[b>>1]=e&65531|q<<1&4;b=Wc(d+84|0,B,1,0,((q&12)!=0)<<3);y:{if(!i){break y}x[31721]=0;U(218,b|0,k|0,d+192|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break y}break v}h=h+1|0;continue}}break v}ub(d+192|0)}x[31721]=0;S(512,d+192|0,d+376|0,18761);b=x[31721];x[31721]=0;z:{if((b|0)!=1){b=d+192|0;l=gd(j,b);ub(b);b=x[l>>2];x[31721]=0;e=R(175,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break l}if(!e){break z}r=Nb(d+84|0);u=Nb(d+180|0);s=Nb(d+168|0);x[31721]=0;S(512,d+148|0,d+376|0,17750);b=x[31721];x[31721]=0;A:{if((b|0)==1){break A}b=x[d+160>>2];x[d+56>>2]=x[d+156>>2];x[d+60>>2]=b;x[d- -64>>2]=x[d+164>>2];x[31721]=0;b=x[d+152>>2];x[d+48>>2]=x[d+148>>2];x[d+52>>2]=b;O(514,d+48|0,r|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[31721]=0;S(512,d+128|0,d+376|0,17744);b=x[31721];x[31721]=0;if((b|0)==1){break A}b=x[d+140>>2];x[d+32>>2]=x[d+136>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+144>>2];x[31721]=0;b=x[d+132>>2];x[d+24>>2]=x[d+128>>2];x[d+28>>2]=b;O(514,d+24|0,u|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[31721]=0;S(512,d+108|0,d+376|0,17734);b=x[31721];x[31721]=0;if((b|0)==1){break A}b=x[d+120>>2];x[d+8>>2]=x[d+116>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+124>>2];x[31721]=0;b=x[d+112>>2];x[d>>2]=x[d+108>>2];x[d+4>>2]=b;O(514,d|0,s|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[31721]=0;n=R(200,l|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break A}k=a+480190|0;B=0;while(1){if(n>>>0<=(B&255)>>>0){Ro(s);Ro(u);Ro(r);break z}x[31721]=0;O(201,d+72|0,l|0);b=x[31721];x[31721]=0;B:{if((b|0)!=1){F=Hc(d+72|0);C:{D:{if(!y[d+72|0]){break D}i=x[l+8>>2];e=x[l>>2];b=y[F|0];x[31721]=0;e=U(153,e|0,i|0,D(b,14)+32|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break A}if(!e){break D}x[31721]=0;o=U(254,a|0,y[d+72|0],0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break A}if(o){break C}}b=y[F|0];x[31721]=0;P(186,l|0,D(b,14)+32|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break B}break A}x[31721]=0;S(320,l|0,o+492|0,32);b=x[31721];x[31721]=0;if((b|0)==1){break A}C=o+88|0;m=o+68|0;q=o+48|0;G=o+236|0;b=0;h=0;while(1){if(y[F|0]<=(h&255)>>>0){break B}x[31721]=0;O(515,l|0,d+192|0);e=x[31721];x[31721]=0;if((e|0)==1){break A}e=y[d+192|0];E:{if(!e|e>>>0>z[k>>1]){break E}if(y[d+193|0]>=129){v[d+193|0]=128}while(1){i=b&255;g=y[d+193|0];if(i>>>0>g>>>0){e=x[r+4>>2];b=x[r>>2];x[31721]=0;V(516,q|0,y[d+195|0],b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}e=x[u+4>>2];b=x[u>>2];x[31721]=0;V(516,m|0,y[d+197|0],b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}e=x[s+4>>2];b=x[s>>2];x[31721]=0;V(516,C|0,y[d+205|0],b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[o>>2]=(y[d+198|0]|y[d+199|0]<<8)+1>>>1;e=y[d+192|0];F:{if(y[d+195|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+194|0];break F}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+106>>1]=y[d+196|0]<<1;w[d+104>>1]=254;t=D(e,104)+a|0;I=t+484408|0,J=z[Lc(d+106|0,d+104|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[d+203|0]&3)+25012|0];e=t+484419|0;j=y[d+202|0];v[e|0]=j;i=y[d+201|0]+3>>>2|0;v[t+484420|0]=i;v[t+484421|0]=y[d+200|0];b=g+1|0;if(j){g=ui(Bc(((i<<8|j>>>1)>>>0)/(j>>>0)|0,0))}else{g=255}v[e|0]=g;if(!(y[d+197|0]&64)){break E}e=t+484414|0;w[e>>1]=z[e>>1]|32}else{e=y[d+192|0];I=Zb(G,i),J=e,w[I>>1]=J;b=b+1|0;continue}break}}h=h+1|0;continue}}break A}B=B+1|0;continue}}f=N()|0;Ro(s);Ro(u);Ro(r);break c}f=N()|0;break c}B=1;o=Nb(d+180|0);G:{if(!(c&1)){break G}x[31721]=0;S(512,d+192|0,d+376|0,21076);b=x[31721];x[31721]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){g=gd(l,d+192|0);b=x[g>>2];x[31721]=0;c=R(175,b|0)|0;b=x[31721];x[31721]=0;N:{O:{P:{if((b|0)!=1){ub(d+192|0);if(!c){break N}x[31721]=0;e=R(192,g|0)|0;c=x[31721];x[31721]=0;b=1;if((c|0)==1){break P}x[31721]=0;i=e+1|0;O(517,o|0,i|0);c=x[31721];x[31721]=0;if((c|0)==1){break P}while(1){if((b|0)==(i|0)){break N}x[31721]=0;e=R(192,g|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break O}x[31721]=0;S(188,d+84|0,g|0,e|0);c=x[31721];x[31721]=0;if((c|0)==1){break O}c=d+84|0;e=hc(d+192|0,c);gd($g(x[o>>2],b),e);ub(e);b=b+1|0;ub(c);continue}}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0;break H}x[31721]=0;S(512,d+192|0,d+376|0,16720);b=x[31721];x[31721]=0;if((b|0)==1){break J}E=gd(g,d+192|0);b=x[E>>2];x[31721]=0;c=R(175,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break K}ub(d+192|0);if(!c){break M}x[31721]=0;F=R(200,E|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break I}c=0;Q:{R:{S:while(1){T:{if(F>>>0<=(c&65535)>>>0){x[31721]=0;P(152,E|0,1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break T}break I}h=32;U:{if(y[d+415|0]<16){break U}x[31721]=0;O(518,E|0,d+192|0);b=x[31721];x[31721]=0;if((b|0)==1){break Q}h=y[d+192|0];if(h>>>0<=z[a+480188>>1]|h>>>0>32){break U}w[a+480188>>1]=h}b=0;while(1){g=b&65535;if(g>>>0>=h>>>0){c=c+1|0;continue S}x[31721]=0;i=R(192,E|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break R}if(!(!i|g>>>0>31|g>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31721]=0;r=a+484344|0;O(226,r|0,F|0);b=x[31721];x[31721]=0;if((b|0)==1){break I}q=d+194|0;l=0;while(1){if((l|0)==(F|0)){break M}u=Fb(d+84|0);V:{if(y[d+415|0]<16){j=32;i=64;break V}x[31721]=0;O(518,E|0,d+192|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}c=y[d+193|0];j=y[d+192|0];b=d+72|0;$e(b,q,16,3);x[31721]=0;O(221,d+168|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}b=d+168|0;yb(u,b);tb(b);i=c+1|0}x[31721]=0;c=U(199,r|0,l&65535,i|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break L}W:{if(!c){x[31721]=0;P(186,E|0,j<<1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break W}break L}b=x[r>>2];x[31721]=0;O(286,Vb(b,l)|0,u|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}G=i-1|0;n=0;while(1){s=n&65535;if(s>>>0>=j>>>0){break W}x[31721]=0;c=R(192,E|0)|0;b=x[31721];x[31721]=0;X:{if((b|0)!=1){if(!c){break X}b=x[o>>2];if(Mf(b,x[o+4>>2])>>>0<=c>>>0|s>>>0>=z[a+480188>>1]){break X}A=$g(b,c);vc(A);c=0;Y:while(1){e=c;if(i>>>0<=e>>>0){break X}c=x[A+8>>2];b=x[A>>2];x[31721]=0;c=U(153,b|0,c|0,1)|0;b=x[31721];x[31721]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!c){break X}b=Vb(x[r>>2],l);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],e,s);x[31721]=0;g=R(200,A|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break L}k=g<<24>>24;f=(k&252)>>>2|0;switch((k&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Vb(x[r>>2],l);h=jd(x[c>>2],x[x[c+48>>2]+12>>2],e-1|0,s);while(1){c=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(G|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break Z}c=Vb(x[r>>2],l);g=jd(x[c>>2],x[x[c+48>>2]+12>>2],f,s);c=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[g+4|0]|y[g+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;break Z}if(f&1){x[31721]=0;g=R(200,A|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break L}v[b|0]=g>>>0>120?-1:g}if(f&2){x[31721]=0;g=R(200,A|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break L}v[b+1|0]=g}c=0;h=0;ca:{if(f&4){x[31721]=0;h=R(200,A|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break ca}}t=0;if(f&8){x[31721]=0;g=R(200,A|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ca}t=g>>>4|0;c=g&15}C=0;m=0;if(f&16){x[31721]=0;m=R(200,A|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break ca}}if((k|0)<0){x[31721]=0;C=R(200,A|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break ca}}g=h;f=fb-16|0;fb=f;h=f+14|0;CY(h,c,m);k=Hc(h);c=f+12|0;CY(c,((t-1&255)>>>0<6?t+15|0:t)&255,C);m=Hc(c);da:{ea:{fa:{if(y[f+14|0]==10){h=y[m|0];c=y[k|0]&15;v[k|0]=c?-1:h;c=h|c<<8;h=y[f+12|0];if((h|0)!=10){break fa}h=0;v[f+12|0]=0;break fa}if(y[f+12|0]!=10){break ea}c=y[m|0]&15;v[m|0]=c?-1:0;c=c<<8;h=y[f+14|0]}if(c-256>>>0>4294967038){break ea}if(Th(h)>>>0>=Th(10)>>>0){break ea}v[b+5|0]=c;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=c>>>8;break da}if(g){v[b+2|0]=1;v[b+4|0]=g+2>>>2}fw(f+14|0,k,f+12|0,m);c=y[f+12|0];ga:{ha:{h=y[f+14|0];if(h){if((h|0)==20|(h|0)!=(c&255)){break ha}c=h}break ga}if(!(c&255)){v[b+5|0]=y[k|0];v[b+3|0]=h;break da}if(!g){un(f+10|0,b,h,y[k|0],c&255,y[m|0]);break da}if(Th(h)>>>0>Th(c&255)>>>0){v[b+5|0]=y[k|0];v[b+3|0]=h;break da}}v[b+5|0]=y[m|0];v[b+3|0]=c}fb=f+16|0;break Z}break L}c=e+1|0;continue}}break L}n=n+1|0;continue}}tb(u);l=l+1|0;continue}}f=N()|0;break H}f=N()|0;break H}f=N()|0;break H}x[31721]=0;S(512,d+192|0,d+376|0,20048);b=x[31721];x[31721]=0;ia:{ja:{if((b|0)!=1){i=gd(E,d+192|0);b=x[i>>2];x[31721]=0;c=R(175,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ja}ub(d+192|0);if(!c){break G}e=a+484348|0;while(1){if(!aj(x[a+484344>>2],x[e>>2])){break G}c=x[i+8>>2];b=x[i>>2];x[31721]=0;c=U(153,b|0,c|0,16)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ia}if(!c){break G}x[31721]=0;O(398,i|0,d+192|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=x[a+484344>>2];x[31721]=0;O(399,Vb(b,0)|0,d+192|0);b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}f=N()|0;break H}f=N()|0;break H}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0;tb(u);break H}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0}Pc(o);break c}Pc(o);break k}f=N()|0;ub(d+192|0);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}h=(b<<5)+a|0;g=h+480280|0;Ue(g);i=v[(b+d|0)+324|0];e=i<<1&254;w[h+480284>>1]=(e|0)==254?256:e;ka:{if((i|0)<0){x[g>>2]=x[g>>2]|1024;break ka}w[a+480188>>1]=b+1}x[31721]=0;O(519,d+356|0,h+480289|0);e=x[31721];x[31721]=0;if((e|0)==1){break i}b=b+1|0;continue}}f=N()|0;break c}ub(d+356|0);fe(d+376|0);ub(H)}fb=d+416|0;return B|0}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i);break d}f=N()|0}tb(g)}ub(d+356|0)}fe(d+376|0)}ub(H);Q(f|0);p()}function eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-240|0;fb=d;vc(b);f=fb-16|0;fb=f;h=d+218|0;Mv(f+8|0,h);g=x[f+12>>2];jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(g|0)){Ub(b,x[f+12>>2])}fb=f+16|0;f=(g|0)==(j|0);if(!f){t_(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!u_(d+218|0)){break n}if(!c){e=1;break n}Ad(a,1024);bg(a);x[a+480208>>2]=x[a+480208>>2]|12;Zf(a+1074312|0,21);e=Cb(y[d+234|0]|y[d+235|0]<<8);if(e){x[a+480204>>2]=D(e,1e4)}e=Cb(y[d+232|0]|y[d+233|0]<<8);if(e){x[a+480196>>2]=e}if(!y[d+228|0]){Uh(a,1)}cE(b,a+1298308|0,_b(y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24))-14|0);b=Fe(d+112|0,b);x[31721]=0;O(349,d+204|0,b|0);e=x[31721];x[31721]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){ub(b);x[31721]=0;S(350,d+112|0,d+204|0,1395544366);b=x[31721];x[31721]=0;if((b|0)==1){break s}x[31721]=0;b=R(280,x[d+112>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break y}if(!b){break r}x[31721]=0;b=R(276,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break y}x[31721]=0;e=R(276,d+112|0)|0;f=x[31721];x[31721]=0;A:{if((f|0)==1){break A}x[31721]=0;P(186,d+112|0,4)|0;f=x[31721];x[31721]=0;if((f|0)==1){break A}f=a+484376|0;g=y[f|0];h=x[a+484360>>2];x[31721]=0;aa(351,Wb(h,g)|0,d+112|0,b|0,65535,65535);b=x[31721];x[31721]=0;if((b|0)!=1){break z}}break y}e=N()|0;ub(b);break a}Ze(Wb(x[a+484360>>2],y[f|0]),e);b=d+112|0;ub(b);x[31721]=0;S(350,b|0,d+204|0,1346458708);b=x[31721];x[31721]=0;if((b|0)==1){break x}x[31721]=0;f=R(280,x[d+112>>2])|0;b=x[31721];x[31721]=0;if((b|0)==1){break w}e=0;b=0;if(!f){break t}x[31721]=0;f=R(276,d+112|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break w}w[a+480188>>1]=f;if((f-33&65535)>>>0<65504){break t}x[31721]=0;b=R(276,d+112|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break w}x[31721]=0;O(226,a+484344|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break w}b=0;x[31721]=0;n=R(284,d+112|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break w}switch(n-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+112|0);break b}if(n){break t}}b=1}ub(d+112|0);if(!b){break o}x[31721]=0;S(350,d+184|0,d+204|0,1398157625);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;b=R(280,x[d+184>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}if(!b){break q}x[31721]=0;P(186,d+184|0,2)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;b=R(284,d+184|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}H=a,I=Xe((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[H+480204>>2]=I;b=0;x[31721]=0;P(352,d+184|0,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){H=d,I=Cb(z[(d+112|0)+(b<<1)>>1]),x[H+48>>2]=I;x[d+32>>2]=180;e=x[qd(d+48|0,d+32|0)>>2]-90|0;h=e>>31<<7|e>>>25;H=((b<<5)+a|0)+480284|0,I=Fc(Aua(e<<7|45,h,90,0),hb)+128|0,w[H>>1]=I;b=b+1|0;continue}else{B:{x[31721]=0;P(186,d+184|0,16)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break B}break c}}break}x[31721]=0;b=U(153,x[d+184>>2],x[d+192>>2],2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}C:{if(b){x[31721]=0;b=R(276,d+184|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;H=a,I=z[Lc(d+48|0,d+32|0)>>1],x[H+480200>>2]=I}x[31721]=0;P(186,d+184|0,128)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;b=P(352,d+184|0,d+48|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){H=d,I=Cb(z[(d+48|0)+(b<<1)>>1]),x[H+32>>2]=I;x[d+20>>2]=128;H=((b<<5)+a|0)+480286|0,I=x[qd(d+32|0,d+20|0)>>2]/2&255,w[H>>1]=I;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}e=N()|0;break b}ub(d+112|0);break p}ub(d+184|0);x[31721]=0;S(350,d+112|0,d+204|0,1413830740);b=x[31721];x[31721]=0;D:{E:{if((b|0)!=1){x[31721]=0;b=R(280,x[d+112>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}if(!b){break D}x[31721]=0;O(353,d+112|0,d+48|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}if((Cb(y[d+58|0]|y[d+59|0]<<8)|0)!=65535){break E}x[31721]=0;P(186,d+112|0,1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break E}break e}e=N()|0;break b}x[31721]=0;b=R(205,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}x[31721]=0;V(339,a+1298332|0,d+112|0,b|0,2);b=x[31721];x[31721]=0;if((b|0)==1){break e}}ub(d+112|0);x[31721]=0;S(350,d+48|0,d+204|0,1229869908);b=x[31721];x[31721]=0;if((b|0)==1){break h}x[31721]=0;b=R(280,x[d+48>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}F:{if(!b){break F}x[31721]=0;b=R(276,d+48|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31721]=0;e=U(153,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31721]=0;b=R(276,d+48|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break I}break g}M:{if(j){o=b}else{x[31721]=0;e=R(276,d+48|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break M}o=e+1|0}w[d+20>>1]=o;x[31721]=0;O(354,d+48|0,d+112|0);e=x[31721];x[31721]=0;if((e|0)==1){break L}e=z[d+20>>1];if((e-4e3&65535)>>>0>=61537){H=a,I=z[oe(g,d+20|0)>>1],w[H+480190>>1]=I;k=y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24);x[31721]=0;V(355,d+112|0,(D(e,104)+a|0)+484380|0,_b(k)|0,n|0);e=x[31721];x[31721]=0;if((e|0)==1){break K}e=d+32|0;Wk(e,2,h);x[31721]=0;O(221,d+184|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break J}e=d+184|0;xc(((z[d+20>>1]<<5)+a|0)+946304|0,e);tb(e)}b=b+1|0;continue}break}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+184>>1]=255;h=a+480192|0;b=d+184|0;H=h,I=z[Lc(d+112|0,b)>>1],w[H>>1]=I;x[31721]=0;S(350,b|0,d+204|0,1229278806);b=x[31721];x[31721]=0;if((b|0)==1){break j}N:while(1){O:{x[31721]=0;b=U(153,x[d+48>>2],x[d+56>>2],15)|0;e=x[31721];x[31721]=0;if((e|0)==1){break O}if(!b){break G}x[31721]=0;O(356,d+48|0,d+32|0);b=x[31721];x[31721]=0;if((b|0)==1){break k}b=Cb(z[d+32>>1]);if(b>>>0>=z[h>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[31721]=0;b=b+1&65535;e=U(254,a|0,b|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break k}if(!e){continue}H=d,I=Cb(y[d+37|0]|y[d+38|0]<<8),w[H+112>>1]=I;w[d+20>>1]=4095;H=e,I=z[Lc(d+112|0,d+20|0)>>1],x[H>>2]=I;b=y[d+35|0];if((b|0)==255){continue}x[31721]=0;b=P(152,d+184|0,D(b,34)+2|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}if(!b){continue}x[31721]=0;O(357,d+184|0,d+112|0);b=x[31721];x[31721]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+24>>2]=16;x[d+28>>2]=240;H=d,I=Cb(b),x[H+20>>2]=I;b=_D(d+20|0);x[31721]=0;O(296,e+48|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break k}g=x[e+52>>2];f=x[e+48>>2];b=0;while(1){j=Pd(f,g);if(j>>>0<=b>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(kc(f,g)){continue N}b=j-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+20|0]=64;j=(d+112|0)+(b<<1)|0;v[d+16|0]=y[j+2|0];k=Sb(d+20|0,d+16|0);i=xb(f,b);v[i+2|0]=y[k|0];w[i>>1]=y[j+3|0];b=b+1|0;continue}}}break}break k}ub(d+48|0);break p}ub(d+184|0)}ub(d+48|0);x[31721]=0;S(358,d+184|0,d+204|0,1145131092);b=x[31721];x[31721]=0;if((b|0)==1){break m}H=d,I=wb(x[d+184>>2]),x[H+20>>2]=I;h=a+484344|0;u=c&1;r=d+48|4;B=wb(x[d+188>>2]);s=(n|0)!=841887798;C=a+480188|0;E=(n|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{f=x[d+20>>2];if(!Ib(f,B)){Pc(d+184|0);x[31721]=0;S(350,d+112|0,d+204|0,1346458702);b=x[31721];x[31721]=0;if((b|0)!=1){break aa}e=N()|0;break b}x[31721]=0;P(186,f|0,4)|0;b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;j=R(276,f|0)|0;b=x[31721];x[31721]=0;ba:{if((b|0)!=1){x[31721]=0;k=R(276,f|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break R}k=s?k:(k>>>0)/A[a+480196>>2]|0;if(!u|j>>>0>255){break P}x[31721]=0;b=U(199,h|0,j|0,k|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break R}if(b){break ba}break P}e=N()|0;break Q}if(!s){q=0;x[31721]=0;P(186,f|0,4)|0;b=x[31721];x[31721]=0;if((b|0)==1){break R}while(1){t=q&65535;if(t>>>0>=z[C>>1]){break P}x[31721]=0;b=R(276,f|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break $}x[31721]=0;S(188,d+48|0,f|0,b+(b&1)&65535);b=x[31721];x[31721]=0;if((b|0)==1){break S}b=d+48|0;g=hc(d+112|0,b);ub(b);x[d+48>>2]=0;x[d+52>>2]=0;e=0;ca:{while(1){b=x[g>>2];x[31721]=0;b=U(153,b|0,x[d+120>>2],6)|0;i=x[31721];x[31721]=0;if((i|0)==1){break ca}i=x[d+48>>2];if(b&i>>>0<k>>>0){b=Vb(x[h>>2],j);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],i,t);x[31721]=0;O(359,d+32|0,g|0);i=x[31721];x[31721]=0;da:{ea:{if((i|0)!=1){i=d+32|0;l=Hc(i);F=Ye(i);G=cj(i);o=dc(i);m=v[d+32|0];if((m-1&255)>>>0>95){break ea}v[b|0]=m+13;if(!x[d+52>>2]){break da}v[b+3|0]=19;x[d+16>>2]=15;H=b,I=y[qd(r,d+16|0)|0]|208,v[H+5|0]=I;break da}break T}if((m|0)>=0){break da}if(x[d+52>>2]){v[b+3|0]=19;x[d+16>>2]=15;H=b,I=y[qd(r,d+16|0)|0]|192,v[H+5|0]=I;break da}v[b|0]=254}if(y[l|0]){v[b+2|0]=1;v[d+16|0]=64;H=b,I=y[Sb(l,d+16|0)|0],v[H+4|0]=I}l=y[F|0];if(l){v[b+1|0]=l}l=y[G|0];m=y[o|0];if(l|m){xf(b,l,m)}i=v[i+5|0];b=i&255;l=d+48|0;if((i|0)<0){x[31721]=0;i=R(200,g|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break T}b=i|b<<8&32512}e=b+e|0;OD(l,e,x[a+480196>>2]);continue}break}ub(g);q=q+1|0;continue}break}break T}b=Vb(x[h>>2],j);H=d,I=wb(x[b>>2]),x[H+48>>2]=I;i=wb(x[b+4>>2]);while(1){b=x[d+48>>2];if(!Ib(b,i)){break P}x[31721]=0;O(360,d+32|0,f|0);e=x[31721];x[31721]=0;if((e|0)!=1){v[d+15|0]=0;fa:{if(!E){e=x[d+32>>2];x[d+112>>2]=e;g=d+112|0;j=Hc(g);k=Ye(g);g=cj(g);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[j|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[j|0]}v[b+1|0]=e<<4&48|y[k|0]>>>4;e=y[k|0]&15;v[d+15|0]=e;g=y[g|0];v[b+5|0]=g;break fa}e=x[d+32>>2];x[d+8>>2]=e;x[d+4>>2]=e;e=d+16|0;Zo(e,d+4|0,b);g=d+112|0;DD(g,d+15|0,b+5|0);CD(g,e);e=vb(d+32|0,0);v[b+1|0]=y[b+1|0]|y[e|0]&48;g=y[b+5|0];e=y[d+15|0]}xf(b,e&255,g);e=y[b+3|0];ga:{if(e>>>0>11){break ga}e=1<<e;ha:{if(!(e&2240)){if(!(e&12)){break ga}if(!y[b+5|0]){break ha}break ga}e=y[b+5|0];g=e&240;if(g){v[b+5|0]=g;break ga}if(e){break ga}}v[b+3|0]=0}qg(d+48|0);continue}break}e=N()|0;break Q}e=N()|0;break Q}x[31721]=0;b=R(280,x[d+112>>2])|0;e=x[31721];x[31721]=0;ia:{ja:{ka:{la:{ma:{if((e|0)!=1){if(b){f=Fb(d+48|0);e=a+484348|0;b=0;na:{while(1){oa:{x[31721]=0;g=U(153,x[d+112>>2],x[d+120>>2],1)|0;j=x[31721];x[31721]=0;if((j|0)==1){break oa}if(!g){break na}if(aj(x[a+484344>>2],x[e>>2])>>>0<=b>>>0){break na}x[31721]=0;S(361,d+112|0,f|0,32);g=x[31721];x[31721]=0;if((g|0)==1){break oa}g=x[h>>2];x[31721]=0;O(286,Vb(g,b)|0,f|0);g=x[31721];x[31721]=0;if((g|0)==1){break oa}b=b+1|0;continue}break}e=N()|0;tb(f);break ma}tb(f)}b=d+112|0;ub(b);x[31721]=0;S(350,b|0,d+204|0,1414679374);b=x[31721];x[31721]=0;if((b|0)==1){break la}x[31721]=0;b=R(280,x[d+112>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break V}if(!b){break ia}f=Fb(d+48|0);e=a+480188|0;b=0;while(1){x[31721]=0;g=U(153,x[d+112>>2],x[d+120>>2],1)|0;h=x[31721];x[31721]=0;if((h|0)==1){break ka}if(!(g&z[e>>1]>b>>>0)){break ja}x[31721]=0;S(361,d+112|0,f|0,32);g=x[31721];x[31721]=0;if((g|0)==1){break ka}Tk(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=N()|0}ub(d+112|0);break b}e=N()|0;break b}e=N()|0;tb(f);break U}tb(f)}b=d+112|0;ub(b);x[31721]=0;S(358,b|0,d+204|0,1145129300);b=x[31721];x[31721]=0;if((b|0)==1){break W}H=d,I=wb(x[d+112>>2]),x[H+48>>2]=I;e=c&2;f=wb(x[d+116>>2]);g=a+480190|0;pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=x[d+48>>2];if(!Ib(b,f)){Pc(d+112|0);b=Fb(d+48|0);if((n|0)!=841887798){break ta}x[31721]=0;c=P(1,d+112|0,9490)|0;e=x[31721];x[31721]=0;if((e|0)==1){break ua}yb(b,c);tb(c);break sa}x[31721]=0;c=R(276,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break X}va:{if(!(!e|c>>>0>=z[g>>1])){c=D(c,104)+a|0;h=z[c+484518>>1];h=Wc(d+184|0,h&1?16:8,h&64?2:1,1,0);x[31721]=0;U(218,h|0,c+484484|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break va}}Yf(d+48|0);continue}break}break X}e=N()|0;break Y}x[31721]=0;S(350,d+112|0,d+204|0,1447383635);c=x[31721];x[31721]=0;wa:{xa:{ya:{za:{Aa:{if((c|0)!=1){x[31721]=0;c=R(280,x[d+112>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break ra}if(!c){break xa}x[31721]=0;c=R(284,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Aa}x[31721]=0;O(271,d+32|0,4292);e=x[31721];x[31721]=0;if((e|0)==1){break za}x[d+20>>2]=c>>>4;x[31721]=0;x[d+16>>2]=c&15;V(362,d+184|0,d+32|0,d+20|0,d+16|0);c=x[31721];x[31721]=0;if((c|0)==1){break ya}c=d+184|0;yb(b,c);tb(c);Eb(d+32|0);break wa}e=N()|0;break Y}e=N()|0;break Z}e=N()|0;break Z}e=N()|0;Eb(d+32|0);break Z}x[31721]=0;c=P(1,d+184|0,8509)|0;e=x[31721];x[31721]=0;if((e|0)==1){break _}yb(b,c);tb(c)}ub(d+112|0)}x[31721]=0;c=P(1,d+32|0,8509)|0;e=x[31721];x[31721]=0;if((e|0)==1){break qa}yb(a+1298344|0,c);tb(c);x[31721]=0;c=P(1,d+20|0,10133)|0;e=x[31721];x[31721]=0;if((e|0)==1){break pa}yb(a+1298356|0,c);tb(c);yb(a+1298368|0,b);H=a+1298404|0,I=x[Ec(d+16|0,28)>>2],x[H>>2]=I;tb(b);e=1;break o}e=N()|0;break Z}e=N()|0;break Y}e=N()|0;break Y}e=N()|0;break Q}e=N()|0}ub(d+112|0)}tb(b);break b}e=N()|0;Pc(d+112|0);break b}e=N()|0;break b}e=N()|0}ub(d+112|0);break b}e=N()|0;ub(g);break Q}e=N()|0;break Q}e=N()|0}Pc(d+184|0);break b}Yf(d+20|0);continue}}e=0}fe(d+204|0)}fb=d+240|0;return e|0}e=N()|0;break b}e=N()|0;break f}e=N()|0;ub(d+184|0);break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break b}e=N()|0}ub(d+48|0);break b}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+184|0)}fe(d+204|0)}Q(e|0);p()}function gua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=fb-416|0;fb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!yi(b,d+408|0)){break F}if(!N$(d+408|0)){break F}if(!c){o=1;break F}q=Fe(d+388|0,b);x[31721]=0;O(266,d+376|0,q|0);b=x[31721];x[31721]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[31721]=0;S(267,d+208|0,d+376|0,1229866575);b=x[31721];x[31721]=0;if((b|0)==1){break da}x[31721]=0;o=P(268,d+208|0,d+366|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break fa}ub(d+208|0);if(!o){break G}x[31721]=0;O(249,a|0,524288);b=x[31721];x[31721]=0;ga:{if((b|0)==1){break ga}bg(a);x[a+480208>>2]=12;C=a+480188|0,E=Hd(Cb(z[d+374>>1]),1,127),w[C>>1]=E;C=d,E=Cb(z[d+366>>1]),w[C+208>>1]=E;w[d+320>>1]=255;C=a+480192|0,E=z[Lc(d+208|0,d+320|0)>>1],w[C>>1]=E;C=d,E=Cb(z[d+368>>1]),w[C+208>>1]=E;w[d+320>>1]=3999;C=a+480190|0,E=z[Lc(d+208|0,d+320|0)>>1],w[C>>1]=E;x[31721]=0;b=U(269,a+1074312|0,6,1)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ga}x[31721]=0;b=P(270,b|0,21)|0;f=x[31721];x[31721]=0;if((f|0)==1){break ga}x[31721]=0;P(270,b|0,13)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break ea}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31721]=0;b=P(1,d+352|0,9282)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,d+340|0,10317)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}yb(a+1298356|0,b);tb(b);x[31721]=0;O(271,d+320|0,4336);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;O(272,d+300|0,d+412|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}x[31721]=0;O(272,d+264|0,d+413|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}x[31721]=0;V(92,d+208|0,d+320|0,d+300|0,d+264|0);b=x[31721];x[31721]=0;if((b|0)==1){break j}b=d+208|0;yb(a+1298368|0,b);tb(b);tb(d+264|0);tb(d+300|0);f=d+320|0;Eb(f);C=a+1298404|0,E=x[Ec(b,28)>>2],x[C>>2]=E;x[31721]=0;S(267,f|0,d+376|0,1312902469);b=x[31721];x[31721]=0;if((b|0)==1){break k}x[31721]=0;b=R(157,x[d+320>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break m}x[31721]=0;g=a+1298308|0;S(273,d+320|0,g|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break m}x[31721]=0;S(267,d+300|0,d+376|0,1397706311);b=x[31721];x[31721]=0;if((b|0)==1){break n}e=a+484360|0;f=a+484376|0;gj(Wb(x[e>>2],y[f|0]));h=Cb(z[d+370>>1]);m=a+1298319|0;i=a+1298312|0;while(1){ha:{if(h>>>0<=(j&65535)>>>0){break ha}x[31721]=0;b=U(153,x[d+300>>2],x[d+308>>2],46)|0;l=x[31721];x[31721]=0;ia:{if((l|0)!=1){if(!b){break ha}x[31721]=0;O(274,d+300|0,d+208|0);b=x[31721];x[31721]=0;if((b|0)!=1){if(!zd(x[i>>2],y[m|0])){break ia}x[31721]=0;O(275,g|0,d+208|0);b=x[31721];x[31721]=0;if((b|0)!=1){break ia}}b=N()|0;break o}b=N()|0;break o}x[31721]=0;l=R(276,d+300|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ca}b=Wb(x[a+484360>>2],y[f|0]);if(!kc(x[b>>2],x[b+4>>2])){x[31721]=0;b=R(277,e|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ca}if((b|0)==255){break ha}b=Wb(x[a+484360>>2],y[f|0])}x[31721]=0;O(278,d+288|0,d+208|0);k=x[31721];x[31721]=0;if((k|0)==1){break ca}k=b;b=d+288|0;hp(k,b);tb(b);b=y[f|0];k=x[a+484360>>2];x[31721]=0;S(279,Wb(k,b)|0,d+300|0,l|0);b=x[31721];x[31721]=0;if((b|0)==1){break ca}j=j+1|0;continue}break}_j(e,0);x[31721]=0;S(267,d+264|0,d+376|0,1229869908);b=x[31721];x[31721]=0;if((b|0)==1){break ba}x[31721]=0;b=R(280,x[d+264>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break p}ja:{if(!b){break ja}e=a+480192|0;j=1;ka:{while(1){b=j&65535;if(b>>>0>z[e>>1]){x[31721]=0;S(267,d+188|0,d+376|0,1447382614);b=x[31721];x[31721]=0;if((b|0)!=1){break ka}break p}x[31721]=0;O(281,d+264|0,d+208|0);f=x[31721];x[31721]=0;if((f|0)==1){break p}f=y[d+238|0]|y[d+239|0]<<8;x[31721]=0;b=U(254,a|0,b|0,Cb(f)|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break p}la:{ma:{if(!b){break ma}if(Cb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break ma}f=d+112|0;bE(f,2,d+208|0);x[31721]=0;O(221,d+132|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break la}f=d+132|0;xc(b+492|0,f);tb(f);g=d+112|0;bE(g,2,d+208|0);x[31721]=0;O(221,f|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break p}f=d+132|0;xc(((Cb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,f);tb(f);x[b>>2]=0;C=b,E=we((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[C+8>>2]=E;uc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31721]=0;b=D(Cb(b),104)+a|0;O(282,b+484380|0,0);f=x[31721];x[31721]=0;if((f|0)==1){break p}C=d,E=Cb(y[d+240|0]|y[d+241|0]<<8),w[C+132>>1]=E;w[d+112>>1]=64;C=b+484410|0,E=z[Lc(d+132|0,d+112|0)>>1]<<2,w[C>>1]=E;g=b+484404|0;f=_b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));h=zua(f,f>>31,8303,0);f=hb;h=h+4181|0;f=h>>>0<4181?f+1|0:f;C=g,E=Fc(Aua(h,f,8363,0),hb),x[C>>2]=E;f=_b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!f){break ma}g=Cb(y[d+256|0]|y[d+257|0]<<8);if(!(g&3)){break ma}h=f;f=_b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=h+f;x[b+484384>>2]=f;b=b+484414|0;f=z[b>>1];w[b>>1]=f|2;if(!(g&2)){break ma}w[b>>1]=f|6}j=j+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31721]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(283,d+24|0,0,a|0,0);b=x[31721];x[31721]=0;if((b|0)==1){break p}x[31721]=0;S(267,d+168|0,d+376|0,1346719318);b=x[31721];x[31721]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31721]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(283,d|0,1,a|0,y[d+412|0]>2|0);b=x[31721];x[31721]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break ja}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}ub(d+264|0);x[31721]=0;S(267,d+208|0,d+376|0,1346458708);b=x[31721];x[31721]=0;if((b|0)==1){break q}x[31721]=0;b=R(175,x[d+208>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){x[31721]=0;S(267,d+264|0,d+376|0,1347305805);b=x[31721];x[31721]=0;if((b|0)==1){break t}x[31721]=0;P(186,d+264|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break v}b=z[d+372>>1];x[31721]=0;k=a+484344|0;O(226,k|0,Cb(b)|0);b=x[31721];x[31721]=0;if((b|0)==1){break v}l=Nb(d+152|0);t=a+480188|0;f=0;m=0;while(1){if(Cb(z[d+372>>1])>>>0<=f>>>0){ld(l);g=m;ub(d+264|0);if(!(c&4)){break $}e=0;if(!u){break aa}f=z[a+480188>>1];b=0;e=1;while(1){if((b|0)==(f|0)){break aa}h=(b<<5)+a|0;v[h+480288|0]=1;h=h+480280|0;x[h>>2]=x[h>>2]|67108864;b=b+1|0;continue}}x[31721]=0;b=R(276,d+208|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break x}x[31721]=0;e=R(284,d+208|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break y}x[31721]=0;S(188,d+112|0,d+208|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break z}e=d+112|0;i=hc(d+132|0,e);ub(e);x[31721]=0;e=U(199,k|0,f&65535,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break B}na:{if(e){n=Fb(d+100|0);x[31721]=0;O(285,d+264|0,n|0);e=x[31721];x[31721]=0;if((e|0)==1){break C}e=x[k>>2];x[31721]=0;O(286,Vb(e,f)|0,n|0);e=x[31721];x[31721]=0;if((e|0)==1){break C}j=0;e=Vb(x[k>>2],f);_e(d+88|0,x[e>>2],x[x[e+48>>2]+12>>2],0);gj(l);A=(b>>>0<=1?1:b)-1|0;oa:while(1){b=x[i>>2];x[31721]=0;b=U(153,b|0,x[d+140>>2],1)|0;e=x[31721];x[31721]=0;if((e|0)==1){break na}pa:{if(!b){break pa}x[31721]=0;b=R(200,i|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}if(!b){C=d,E=wb(x[l>>2]),x[C+84>>2]=E;e=wb(x[l+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,e)){xe(Vb(x[k>>2],f),Ve(Le(d+112|0,y[b|0],y[b+1|0]),j));Od(d+84|0);continue}else{gj(l);if((j|0)==(A|0)){break pa}b=Vb(x[k>>2],f);j=j+1|0;_e(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],j);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue oa}}}w[d+116>>1]=0;x[d+112>>2]=0;h=d+112|0;if(b>>>0<=z[t>>1]){h=Vc(x[d+88>>2],b-1|0)}x[31721]=0;b=R(200,i|0)|0;e=x[31721];x[31721]=0;qa:{ra:{if((e|0)!=1){sa:{if(!(b&1)){break sa}x[31721]=0;e=R(200,i|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break C}if((e|0)!=31){if((e-1&255)>>>0>252){break sa}e=(D(e>>>4|0,12)+(e&15)|0)+13|0}else{e=255}v[h|0]=e}if(!(b&2)){break qa}x[31721]=0;e=R(200,i|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break ra}}break C}v[h+1|0]=e}if(!(b&60)){continue}r=0;s=0;if(b&4){x[31721]=0;s=R(200,i|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}}if(b&8){x[31721]=0;r=R(200,i|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}}g=0;e=0;if(b&16){x[31721]=0;e=R(200,i|0)|0;B=x[31721];x[31721]=0;if((B|0)==1){break C}}if(b&32){x[31721]=0;g=R(200,i|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break C}}b=d+84|0;K$(b,e,g);e=Hc(b);b=d+82|0;K$(b,s,r);g=Hc(b);b=y[d+82|0];ta:{if((b|0)!=13){if(b){break ta}b=0;if(y[d+84|0]==13){break ta}}pg(d+84|0,d+82|0);pg(e,g);b=y[d+82|0]}un(d+80|0,h,y[d+84|0],y[e|0],b&255,y[g|0]);if(J$(y[d+80|0],y[d+81|0])){b=x[zb(d+76|0,wb(x[l>>2]))>>2];x[31721]=0;S(287,l|0,b|0,d+80|0);b=x[31721];x[31721]=0;if((b|0)==1){break C}}b=y[h+3|0];if((b|0)==43){u=1;continue}if((b|0)!=31){continue}m=1;continue}break}tb(n)}ub(i);f=f+1|0;continue}break}break C}g=0;e=0;if(c&4){break aa}break H}b=N()|0;break b}b=N()|0;break o}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[31721]=0;S(267,d+264|0,d+376|0,1146310725);b=x[31721];x[31721]=0;if((b|0)==1){break E}x[31721]=0;b=R(280,x[d+264>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break D}if(b){x[31721]=0;m=R(276,d+264|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break D}j=a+480188|0;b=0;f=e;while(1){ua:{if((b|0)==(m|0)){x[31721]=0;O(288,d+264|0,d+152|0);b=x[31721];x[31721]=0;if((b|0)!=1){break ua}break D}x[31721]=0;h=R(200,d+264|0)|0;i=x[31721];x[31721]=0;va:{wa:{if((i|0)!=1){if(z[j>>1]<=b>>>0){break va}if(!e){break wa}i=((b<<5)+a|0)+480280|0;x[i>>2]=x[i>>2]&-67108865|((h|0)!=0)<<26;break va}break D}if(h){break va}f=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=f&1}ub(d+264|0);if(!e){break $}b=sd(a+906300|0,0);x[31721]=0;W(289,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break _}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+264>>2]=0;e=b+48|0;G$(b+32|0,e,d+264|0);x[31721]=0;f=P(37,d+132|0,9571)|0;h=x[31721];x[31721]=0;if((h|0)==1){break Z}aE(e,f);tb(f);x[31721]=0;f=P(37,d+112|0,9535)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Y}bw(b+80|0,f);tb(f);x[31721]=0;O(290,b+4|0,8);f=x[31721];x[31721]=0;if((f|0)==1){break _}F$(d+264|0,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);f=x[d+268>>2];b=x[b+4>>2];e=x[d+264>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(!g){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+88>>2]=D(b,127)>>>5;x[31721]=0;O(291,d+152|0,4093);e=x[31721];x[31721]=0;if((e|0)==1){break X}x[31721]=0;O(292,d+100|0,d+88|0);e=x[31721];x[31721]=0;if((e|0)==1){break W}x[31721]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)==1){break V}e=d+264|0;ve(d+68|0,e);pf(Me(f,b),x[d+68>>2],x[d+72>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31721]=0;O(291,e|0,4075);e=x[31721];x[31721]=0;if((e|0)==1){break T}x[31721]=0;O(292,d+100|0,d+88|0);e=x[31721];x[31721]=0;if((e|0)==1){break S}x[31721]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)==1){break R}e=d+264|0;ve(d+60|0,e);pf(Me(f,b+32|0),x[d+60>>2],x[d+64>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31721]=0;O(291,e|0,4066);e=x[31721];x[31721]=0;if((e|0)==1){break P}x[31721]=0;O(292,d+100|0,d+88|0);e=x[31721];x[31721]=0;if((e|0)==1){break O}x[31721]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)==1){break N}e=d+264|0;ve(d+52|0,e);pf(Me(f,b- -64|0),x[d+52>>2],x[d+56>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31721]=0;O(291,e|0,4039);e=x[31721];x[31721]=0;if((e|0)==1){break L}x[31721]=0;O(292,d+100|0,d+88|0);e=x[31721];x[31721]=0;if((e|0)==1){break K}x[31721]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31721];x[31721]=0;if((e|0)==1){break J}e=d+264|0;ve(d+44|0,e);pf(Me(f,b+96|0),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(e);tb(d+100|0);Eb(d+152|0);continue}}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break U}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break Q}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break M}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break I}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}x[31721]=0;S(267,d+264|0,d+376|0,1397575756);b=x[31721];x[31721]=0;xa:{if((b|0)!=1){x[31721]=0;b=R(175,x[d+264>>2])|0;f=x[31721];x[31721]=0;if((f|0)!=1){ya:{j=1;if(!(c&2)|b^1){break xa}c=a+480190|0;while(1){f=j&65535;if(f>>>0>z[c>>1]){break xa}x[31721]=0;b=R(284,d+264|0)|0;e=x[31721];x[31721]=0;za:{if((e|0)!=1){x[31721]=0;e=R(284,d+264|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break ya}if(!(b&7)){break za}f=(D(f,104)+a|0)+484380|0;x[f>>2]=e;b=Wc(d+152|0,b&4?32:b&2?16:8,1,1,0);x[31721]=0;U(218,b|0,f|0,d+264|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break za}break ya}break ya}j=j+1|0;continue}}}b=N()|0;ub(d+264|0);break r}b=N()|0;break r}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}fe(d+376|0);ub(q)}fb=d+416|0;return o|0}b=N()|0;break r}b=N()|0;ub(d+264|0);break r}b=N()|0;tb(n);break A}b=N()|0}ub(i);break w}b=N()|0;break w}b=N()|0;break w}b=N()|0}ld(l);break u}b=N()|0}ub(d+264|0);break r}b=N()|0;break r}b=N()|0}ub(d+208|0);break o}b=N()|0;break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}fe(d+376|0)}ub(q);Q(b|0);p()}function apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-336|0;fb=d;vc(b);a:{if(!$o(b,d+324|0)){break a}if(!aX(d+324|0)){break a}q=Fe(d+304|0,b);o=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!c){x[31721]=0;O(667,d+40|0,q|0);b=x[31721];x[31721]=0;if((b|0)==1){break v}break x}x[31721]=0;O(668,d+40|0,q|0);b=x[31721];x[31721]=0;if((b|0)==1){break w}}b=d+40|0;lv(o,b);fe(b);x[31721]=0;S(669,b|0,o|0,1413891155);b=x[31721];x[31721]=0;y:{z:{if((b|0)!=1){x[31721]=0;e=P(670,d+40|0,14138)|0;b=x[31721];x[31721]=0;if((b|0)==1){break z}ub(d+40|0);if((c|0)!=0&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31721]=0;O(249,a|0,4194304);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31721]=0;S(669,d+272|0,o|0,1280592212);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(157,x[d+272>>2])|0;k=x[31721];x[31721]=0;if((k|0)==1){break g}x[31721]=0;S(459,d+272|0,a+1298308|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}f=a+484360|0;h=a+484376|0;gj(Wb(x[f>>2],y[h|0]));k=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31721]=0;S(671,d+244|0,o|0,1196314451);b=x[31721];x[31721]=0;if((b|0)==1){break i}t=d,u=wb(x[d+244>>2]),x[t+240>>2]=u;j=d+228|0;r=wb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,r)){break A}m=Fe(d+40|0,b);x[31721]=0;e=P(672,m|0,d+28|0)|0;b=x[31721];x[31721]=0;B:{C:{if((b|0)!=1){b=1;if(!(e&y[d+37|0]==1)){break B}t=a,u=Hd(y[d+38|0],z[a+480188>>1],127),w[t+480188>>1]=u;x[31721]=0;l=R(673,d+184|0)|0;b=x[31721];x[31721]=0;D:{E:{F:{if((b|0)!=1){b=d+172|0;$e(b,d+28|0,9,1);x[31721]=0;O(221,d+136|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break F}b=d+16|0;fc(b,j,10);e=b;b=d+136|0;km(e,b);tb(b);b=Wb(x[a+484360>>2],y[h|0]);if(kc(x[b>>2],x[b+4>>2])){break D}x[31721]=0;b=R(277,f|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Wb(x[a+484360>>2],y[h|0])}x[31721]=0;O(674,d+160|0,j|0);e=x[31721];x[31721]=0;if((e|0)==1){break m}e=b;b=d+160|0;hp(e,b);tb(b);x[31721]=0;O(668,d+172|0,m|0);b=x[31721];x[31721]=0;if((b|0)!=1){t=d,u=wb(x[d+172>>2]),x[t+156>>2]=u;s=wb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,s)){fp(d+136|0,b);ti(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31721]=0;i=U(153,x[d+136>>2],x[d+144>>2],2)|0;g=x[31721];x[31721]=0;if((g|0)==1){break I}if(!i){break G}x[31721]=0;O(201,d+8|0,d+136|0);i=x[31721];x[31721]=0;if((i|0)!=1){lC(l,e,y[d+8|0],y[Hc(d+8|0)|0],d+259|0,k);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[h|0];e=x[a+484360>>2];x[31721]=0;W(675,Wb(e,b)|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=0;x[31721]=0;O(676,k|0,l|0);e=x[31721];x[31721]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31721]=0;P(186,d+136|0,2)|0;b=x[31721];x[31721]=0;i=65535;L:{if((b|0)!=1){while(1){x[31721]=0;b=U(153,x[d+136>>2],x[d+144>>2],1)|0;g=x[31721];x[31721]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){if(!b){break G}x[31721]=0;g=R(200,d+136|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break I}b=4;switch(g|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Wb(x[a+484360>>2],y[h|0]);if(z[d+220>>1]==65535){t=d,u=fm(x[b>>2],x[b+4>>2]),w[t+220>>1]=u}b=fm(x[b>>2],x[b+4>>2]);x[31721]=0;w[d+222>>1]=b;b=P(677,d+136|0,d+258|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}g=y[h|0];n=x[a+484360>>2];x[31721]=0;O(540,Wb(n,g)|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break I}i=(i&65535)==65535?e:i;break M}x[31721]=0;b=R(192,d+136|0)|0;n=x[31721];x[31721]=0;if((n|0)!=1){_:{if(b>>>0<(i&65535)>>>0){b=z[d+224>>1];break _}b=b-i|0;w[d+224>>1]=b}Ze(Wb(x[a+484360>>2],y[h|0]),b&65535);if((g|0)!=3){break M}x[31721]=0;P(186,d+136|0,1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break M}}break I}x[31721]=0;O(201,d+8|0,d+136|0);b=x[31721];x[31721]=0;if((b|0)!=1){lC(l,y[d+8|0],y[Hc(d+8|0)|0],-1,d+259|0,k);break M}break I}b=1}x[31721]=0;P(186,d+136|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break M}break I}x[31721]=0;b=R(200,d+136|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break I}v[d+227|0]=b;break M}x[31721]=0;b=R(200,d+136|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break I}v[d+226|0]=b;break M}x[31721]=0;b=P(643,d+136|0,d+8|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31721]=0;O(552,d+8|0,d+136|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=d+8|0;g=Hc(b);lC(l,y[d+8|0],y[Ye(b)|0],y[g|0],d+259|0,k);break M}break I}x[31721]=0;O(201,d+8|0,d+136|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}b=x[d+196>>2];n=Rc(b,x[d+200>>2]);g=y[d+8|0];if(n>>>0<=g>>>0){break M}n=Hc(d+8|0);t=vb(b,g),u=(y[n|0]>>>2|0)+1|0,v[t|0]=u}e=e+1|0;continue}}break I}break I}fe(d+172|0);break C}b=N()|0;ub(d+136|0)}fe(d+172|0);break l}ub(d+136|0);tn(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}kv(l)}ub(m);if(!b){Yf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;_j(f,0);b=x[k>>2];if(kc(b,x[k+4>>2])){break s}if(!(c&2)){break t}x[31721]=0;S(671,d+136|0,o|0,1347244868);b=x[31721];x[31721]=0;$:{if((b|0)!=1){t=d,u=wb(x[d+136>>2]),x[t+16>>2]=u;e=a+480190|0;i=d+53|0;h=d+57|0;l=wb(x[d+140>>2]);m=y[d+258|0];while(1){b=x[d+16>>2];if(!Ib(b,l)){Pc(d+136|0);b=x[k>>2];break t}aa:{ba:{ca:{if(!m){x[31721]=0;f=P(678,b|0,d+40|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break aa}if(!f){break ba}f=y[d+92|0]|y[d+93|0]<<8;j=f+1|0;w[d+8>>1]=j;if(f>>>0>3998){break ca}t=a,u=z[oe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31721]=0;O(679,d+40|0,(D(j&65535,104)+a|0)+484380|0);f=x[31721];x[31721]=0;if((f|0)==1){break aa}f=d+28|0;$W(f,i);x[31721]=0;O(221,d+172|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break u}f=d+172|0;xc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f);break ca}x[31721]=0;f=P(680,b|0,d+40|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break u}if(!f){break ba}f=y[d+96|0]|y[d+97|0]<<8;j=f+1|0;w[d+8>>1]=j;if(f>>>0>3998){break ca}t=a,u=z[oe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31721]=0;O(681,d+40|0,(D(j&65535,104)+a|0)+484380|0);f=x[31721];x[31721]=0;if((f|0)==1){break u}f=d+28|0;$W(f,h);x[31721]=0;O(221,d+172|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break $}f=d+172|0;xc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f)}f=z[d+8>>1];if((f-1&65535)>>>0>3998){break ba}j=Wc(d+40|0,8,1,0,2);x[31721]=0;U(218,j|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break ba}break u}Yf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Pc(d+136|0);break j}b=kC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);Ze(Wb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;i=e+480280|0;Ue(i);h=kC(x[k>>2],0);t=e+480286|0,u=y[vb(x[h+12>>2],b)|0],w[t>>1]=u;t=e+480284|0,u=y[vb(x[h>>2],b)|0],w[t>>1]=u;Kb(d+40|0,x[h+24>>2],b);t=i,u=x[i>>2]&-257|(Hb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[t>>2]=u;b=b+1|0;continue}break}x[31721]=0;b=P(1,d+172|0,(y[d+258|0]?17152:17009)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,d+28|0,10137)|0;e=x[31721];x[31721]=0;if((e|0)==1){break o}yb(a+1298356|0,b);tb(b);t=a+1298404|0,u=x[Ec(d+40|0,4)>>2],x[t>>2]=u;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31721]=0;S(671,d+16|0,o|0,1146045008);b=x[31721];x[31721]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31721]=0;l=a+484344|0;O(226,l|0,Mf(c,b)&65535);b=x[31721];x[31721]=0;if((b|0)==1){break r}t=d,u=wb(x[d+16>>2]),x[t+240>>2]=u;j=wb(x[d+20>>2]);while(1){h=x[d+240>>2];if(!Ib(h,j)){da:{ea:{b=x[k>>2];e=x[k+4>>2];if(jv(b,e)>>>0<2){break ea}m=a+484348|0;f=y[d+259|0];c=0;while(1){if(jv(b,e)>>>0<=c>>>0){break ea}g=x[a+484344>>2];n=x[m>>2];h=Sj(x[a+484360>>2],c&255);r=x[h>>2];i=kC(b,c);j=z[i+36>>1];if(Ge(g,n,z[Zb(r,j)>>1])){x[31721]=0;e=P(371,h|0,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break da}fa:{if(!f){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}j=jC(x[i+24>>2],b);h=Vb(x[l>>2],e);ga:{if(j){xe(h,Vh(ap(Ve(Le(d+40|0,20,145),0),b&65535)));break ga}xe(h,Vh(ap(Ve(Le(d+40|0,9,y[vb(x[i>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;xe(Vb(x[l>>2],e),Vh(Ve(Le(b,16,y[i+43|0]),0)));xe(Vb(x[l>>2],e),Vh(Ve(Le(b,17,y[i+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}c=c+1|0;continue}}Pc(d+16|0);e=1;break s}b=N()|0;break q}b=x[h>>2];x[31721]=0;b=R(157,b|0)|0;c=x[31721];x[31721]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31721]=0;c=R(154,h|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[h>>2];x[31721]=0;b=P(682,b|0,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break na}if(!b){break ha}x[31721]=0;m=P(677,h|0,d+258|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ia}x[31721]=0;f=R(192,h|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break ja}x[31721]=0;b=U(199,l|0,m|0,f|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ja}if(!b){break ha}i=0;while(1){if((f|0)==(i|0)){break ha}b=Vb(x[l>>2],m);_e(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],i);x[31721]=0;b=R(192,h|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31721]=0;S(188,d+136|0,h|0,b-2|0);b=x[31721];x[31721]=0;if((b|0)==1){break ka}b=d+136|0;e=hc(d+40|0,b);ub(b);while(1){b=x[e>>2];x[31721]=0;b=U(153,b|0,x[d+48>>2],3)|0;c=x[31721];x[31721]=0;if((c|0)==1){break oa}if(b){x[31721]=0;O(201,d+136|0,e|0);b=x[31721];x[31721]=0;pa:{qa:{ra:{sa:{if((b|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;t=d,u=y[Hc(d+136|0)|0],w[t+6>>1]=u;c=Vc(x[d+8>>2],z[Lc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31721]=0;b=R(200,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31721]=0;b=R(200,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31721]=0;b=R(200,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break la}v[d+156|0]=b;v[c+2|0]=1;v[d+6|0]=127;t=c,u=y[Sb(d+156|0,d+6|0)|0]+1>>>1|0,v[t+4|0]=u;b=y[d+136|0]}if(!(b&16)){continue}x[31721]=0;O(201,d+156|0,e|0);b=x[31721];x[31721]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((b|0)!=1){b=y[Hc(d+156|0)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;t=c,u=iv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=2;t=c,u=iv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=iv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=iv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31721]=0;b=R(200,e|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31721]=0;P(186,e|0,1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}i=i+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Yf(d+240|0);continue}}Pc(d+244|0);_W(k);ub(d+272|0);break b}b=N()|0}Pc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}kv(l)}ub(m)}Pc(d+244|0);break h}b=N()|0}_W(k);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}fe(o);ub(q);Q(b|0);p()}fe(o);ub(q)}fb=d+336|0;return e|0}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-304|0;fb=e;vc(b);a:{if(!mv(b,e+208|0)){break a}if(!JW(e+208|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(IW(e+208|0),hb))){break a}b:{if(!c){break b}Ad(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;i=Fb(e+196|0);d=y[e+248|0]|y[e+249|0]<<8;l=(d|0)==20479?y[e+262|0]|y[e+263|0]<<8:d-16464|0;c:{d:{e:{f:{g:{h:{i:{j:{switch(d>>>12|0){case 0:if((d|0)!=520){break e}x[31721]=0;d=P(1,e+184|0,12377)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);break f}f=N()|0;break c;case 1:k:{if((d|0)!=4896){break k}d=y[e+270|0]|y[e+271|0]<<8;if(d){break k}if(!((y[e+246|0]|y[e+247|0]<<8)&65455|(y[e+260|0]|y[e+240|0]&15))){l:{if(v[e+259|0]<0){x[a+1074308>>2]=18219008;x[31721]=0;d=P(1,e+184|0,14766)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break l}f=N()|0;break c}x[a+1074308>>2]=16777216;x[31721]=0;d=P(1,e+184|0,13445)|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}}yb(i,d);tb(d);x[31721]=0;f=1;U(269,a+1074312|0,81,1)|0;d=x[31721];x[31721]=0;g=1;if((d|0)!=1){break e}break d}if(y[e+260|0]|d|(y[e+261|0]|(y[e+246|0]|y[e+247|0]<<8))){break k}x[31721]=0;d=P(1,e+184|0,9476)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);break f}f=N()|0;break c}x[31721]=0;d=P(1,e+184|0,8494)|0;f=x[31721];x[31721]=0;j=1;if((f|0)!=1){yb(i,d);tb(d);break g}f=N()|0;break c;case 2:x[31721]=0;d=P(1,e+184|0,6808)|0;f=x[31721];x[31721]=0;g=1;if((f|0)!=1){yb(i,d);tb(d);break g}f=N()|0;break c;case 3:m:{n:{o:{p:{if(d>>>0<=12820){x[31721]=0;f=P(1,e+184|0,8557)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,f);tb(f);break p}f=N()|0;break c}x[31721]=0;O(449,e+184|0,4015);f=x[31721];x[31721]=0;if((f|0)==1){break o}x[31721]=0;x[e+172>>2]=(y[e+248|0]|y[e+249|0]<<8)-12820;S(450,e+48|0,e+184|0,e+172|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}f=e+48|0;yb(i,f);tb(f);Eb(e+184|0)}f=y[e+248|0]|y[e+249|0]<<8;if(f>>>0<12807){break h}g=y[e+264|0]|y[e+265|0]<<8|(y[e+266|0]<<16|y[e+267|0]<<24);if(g){break m}break h}f=N()|0;break c}f=N()|0;Eb(e+184|0);break c}f=nF(f,g);g=cp(e+48|0);x[g+32>>2]=f;x[31721]=0;O(451,a+1298412|0,g|0);f=x[31721];x[31721]=0;if((f|0)!=1){break h}f=N()|0;break c;case 4:if((d|0)==16640){x[31721]=0;d=P(1,e+184|0,8340)|0;j=x[31721];x[31721]=0;g=1;if((j|0)!=1){yb(i,d);tb(d);x[31721]=0;U(269,a+1074312|0,81,1)|0;d=x[31721];x[31721]=0;j=0;if((d|0)==1){break d}break e}f=N()|0;break c}x[31721]=0;S(446,e+48|0,d|0,y[e+262|0]|y[e+263|0]<<8);d=x[31721];x[31721]=0;q:{r:{s:{if((d|0)!=1){d=e+48|0;yb(i,d);tb(d);x[a+480260>>2]=1;if((l|0)<4201){break s}x[31721]=0;U(269,a+1074312|0,7,1)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}break r}f=N()|0;break c}if((l|0)<2386){break q}}x[31721]=0;U(269,a+1074312|0,38,1)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}}x[31721]=0;P(270,a+1074312|0,118)|0;d=x[31721];x[31721]=0;g=1;h=1;if((d|0)==1){break d}break e;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+262|0]|y[e+263|0]<<8:0)&65535;x[31721]=0;d=P(1,e+184|0,18232)|0;f=x[31721];x[31721]=0;t:{u:{v:{if((f|0)!=1){f=x[a+1074308>>2];x[31721]=0;O(137,e+172|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break v}f=0;x[31721]=0;S(2,e+48|0,d|0,e+172|0);g=x[31721];x[31721]=0;if((g|0)==1){break u}g=e+48|0;yb(i,g);tb(g);tb(e+172|0);break f}f=N()|0;break c}f=N()|0;break t}f=N()|0;tb(e+172|0)}tb(d);break c}x[31721]=0;d=P(1,e+184|0,8541)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);break f}f=N()|0;break c;case 6:x[31721]=0;d=P(1,e+184|0,8340)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);tb(d);x[31721]=0;U(269,a+1074312|0,81,1)|0;d=x[31721];x[31721]=0;g=0;if((d|0)==1){break d}break e}f=N()|0;break c;case 7:x[31721]=0;d=P(1,e+184|0,8352)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);break f}f=N()|0;break c;default:break j}}if((d|0)!=51712){break e}x[31721]=0;d=P(1,e+184|0,9275)|0;g=x[31721];x[31721]=0;if((g|0)!=1){yb(i,d);break f}f=N()|0;break c}f=N()|0;break c}x[31721]=0;f=U(269,a+1074312|0,7,1)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;f=U(269,f|0,23,1)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;f=U(269,f|0,38,1)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;U(269,f|0,107,1)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}g=1;x[a+480260>>2]=1;f=0;if(d>>>0>12820){break e}}x[31721]=0;W(698,e+172|0);d=x[31721];x[31721]=0;w:{x:{y:{if((d|0)!=1){d=y[e+248|0]|y[e+249|0]<<8;x[e+148>>2]=d>>>8&15;x[31721]=0;x[e+132>>2]=d&255;O(448,e+160|0,e+132|0);d=x[31721];x[31721]=0;if((d|0)==1){break y}f=0;x[31721]=0;aa(699,e+48|0,e+172|0,i|0,e+148|0,e+160|0);d=x[31721];x[31721]=0;if((d|0)==1){break x}d=e+48|0;yb(i,d);tb(d);tb(e+160|0);Eb(e+172|0);break e}f=N()|0;break c}f=N()|0;break w}f=N()|0;tb(e+160|0)}Eb(e+172|0);break c}tb(d);g=0}x[31721]=0;d=P(1,e+172|0,15021)|0;m=x[31721];x[31721]=0;z:{A:{B:{C:{D:{E:{F:{G:{if((m|0)!=1){yb(a+1298344|0,d);tb(d);x[31721]=0;d=P(1,e+160|0,10474)|0;m=x[31721];x[31721]=0;if((m|0)==1){break G}yb(a+1298356|0,d);tb(d);o=yb(a+1298368|0,i);B=a+1298404|0,C=x[Ec(e+48|0,x[a+1074308>>2]?22:4)>>2],x[B>>2]=C;if(g){x[31721]=0;d=P(270,a+1074312|0,77)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;d=P(270,d|0,78)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;d=P(270,d|0,79)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;d=P(270,d|0,80)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;d=P(270,d|0,82)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;d=P(270,d|0,96)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[31721]=0;P(270,d|0,113)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}}d=y[e+248|0]|y[e+249|0]<<8;if(d>>>0<=4865){x[31721]=0;P(270,a+1074312|0,118)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}d=y[e+248|0]|y[e+249|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31721]=0;d=a+901404|0;W(700,d|0);g=x[31721];x[31721]=0;if((g|0)==1){break d}if(!f){_q(d)}d=e+148|0;Zi(d,1,e+208|0);x[31721]=0;O(221,e+48|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break D}d=e+48|0;yb(a+1298308|0,d);tb(d);d=y[e+246|0]|y[e+247|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=y[e+248|0]|y[e+249|0]<<8;if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+257|0];x[a+480196>>2]=d;if(!(!j|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+258|0];x[a+480204>>2]=d>>>0<33?j?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+256|0];v[e+148|0]=64;d=y[Sb(e+48|0,e+148|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+259|0];if((y[e+250|0]|y[e+251|0]<<8)!=1|g>>>0>7){break F}x[e+48>>2]=(g<<4)+16;x[e+148>>2]=127;f=x[qd(e+48|0,e+148|0)>>2];break E}f=N()|0;break c}f=N()|0;break c}f=32;if((g|16)==18){break E}d=g&127;f=48;if(!d){break E}x[e+48>>2]=d;x[e+148>>2]=16;f=x[We(e+48|0,e+148|0)>>2]}x[a+480228>>2]=f;d=0;m=x[a+1074308>>2]!=0|g<<24>>24<0;if(!m){B=a,C=Bc(Bua(f<<3|5,f>>>29|0,11,0),hb),x[B+480228>>2]=C}r=a+480188|0;w[r>>1]=4;x[a+480232>>2]=h?(l|0)<3299?64:36:36;f=qc(e+144|0);while(1){if((d|0)==32){d=a+480188|0;if(!z[d>>1]){w[d>>1]=1}d=y[a+484376|0];g=x[a+484360>>2];x[31721]=0;aa(351,Wb(g,d)|0,b|0,y[e+240|0]|y[e+241|0]<<8,255,254);d=x[31721];x[31721]=0;if((d|0)!=1){m=Nb(e+148|0);x[31721]=0;U(216,b|0,m|0,y[e+242|0]|y[e+243|0]<<8)|0;d=x[31721];x[31721]=0;if((d|0)!=1){r=Nb(e+132|0);x[31721]=0;U(216,b|0,r|0,y[e+244|0]|y[e+245|0]<<8)|0;d=x[31721];x[31721]=0;H:{if((d|0)!=1){if(y[e+261|0]!=252){break C}d=0;x[31721]=0;O(701,b|0,e+48|0);g=x[31721];x[31721]=0;if((g|0)==1){break H}while(1){if((d|0)==32){break C}g=y[(e+48|0)+d|0];I:{if(!(g&32)){break I}if(j){Oc(e+36|0,f,d);if(Hb(x[x[e+36>>2]>>2],x[e+40>>2])){break I}}w[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}f=N()|0;break B}f=N()|0;break B}f=N()|0;break A}f=N()|0;break c}g=(d<<5)+a|0;l=g+480280|0;Ue(l);h=y[(e+d|0)+272|0];q=h&126;J:{if((h|0)!=255){h=h<<24>>24;w[r>>1]=d+1;if(m){w[g+480284>>1]=h&8?204:51}if((h|0)>=0){break J}}x[l>>2]=1024}if((q-16&255)>>>0<=13){w[g+480284>>1]=128;g=e+48|0;Oc(g,f,d);Vo(g)}d=d+1|0;continue}}f=N()|0;break c}w[e+48>>1]=y[e+242|0]|y[e+243|0]<<8;w[e+36>>1]=3999;f=z[Lc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;q=c&2;s=e+96|0;d=0;h=0;g=0;l=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{while(1){if((f&65535)>>>0<=d>>>0){if(!(!(h&j)|l&65535)&(y[e+248|0]|y[e+249|0]<<8)!=4864){break Q}if(!j){break P}x[31721]=0;d=l&65535;f=U(269,a+1074312|0,79,d>>>0>1|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break N}x[31721]=0;d=d>>>0<2;f=U(269,f|0,107,d|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break N}x[31721]=0;U(269,f|0,38,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break N}x[31721]=0;d=l&65535;P(130,o|0,(d>>>0>1?17196:17203)|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break N}if(d>>>0<2){break P}x[a+480228>>2]=48;break P}f=Zb(x[m>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31721]=0;f=P(152,b|0,f<<4)|0;n=x[31721];x[31721]=0;if((n|0)==1){break L}T:{U:{if(!f){break U}x[31721]=0;f=P(702,b|0,e+48|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break L}if(!f){break U}x[31721]=0;f=d+1|0;n=(D(f,104)+a|0)+484380|0;S(703,e+48|0,n|0,j|0);k=x[31721];x[31721]=0;if((k|0)==1){break L}k=e+24|0;Zi(k,1,s);x[31721]=0;O(221,e+36|0,k|0);k=x[31721];x[31721]=0;if((k|0)==1){break T}k=((f<<5)+a|0)+946304|0;f=e+36|0;xc(k,f);tb(f);if(y[e+48|0]>1){break U}V:{if(!q|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break V}f=GW(e+48|0);x[31721]=0;f=P(152,b|0,f|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break S}if(!f){break V}f=e+36|0;FW(f,y[e+78|0],y[e+79|0],(y[e+250|0]|y[e+251|0]<<8)==1);x[31721]=0;U(218,f|0,n|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break R}g=y[e+39|0]==10|g;h=1}l=y[e+88|0]|y[e+89|0]<<8|l}d=d+1|0;f=z[a+480190>>1];continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}x[31721]=0;d=P(1,e+48|0,9750)|0;f=x[31721];x[31721]=0;if((f|0)==1){break O}yb(o,d);tb(d)}if(g&1){break M}break K}f=N()|0;break B}f=N()|0;break B}x[31721]=0;d=P(1,e+36|0,17136)|0;f=x[31721];x[31721]=0;W:{if((f|0)!=1){x[31721]=0;P(77,o|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break W}tb(d);break K}f=N()|0;break B}f=N()|0;tb(d);break B}f=N()|0;break B}if(!(c&1)){break z}c=y[e+248|0]|y[e+249|0]<<8;w[e+24>>1]=y[e+244|0]|y[e+245|0]<<8;w[e+16>>1]=255;s=z[Lc(e+24|0,e+16|0)>>1];x[31721]=0;j=a+484344|0;O(226,j|0,s|0);d=x[31721];x[31721]=0;if((d|0)!=1){n=c>>>0<4896;u=a+480188|0;h=0;o=0;q=0;X:{Y:{while(1){if((h|0)==(s|0)){if(!n){break z}a=z[a+480188>>1];if((a|0)>(o+q|0)|(a|0)<=(o-q|0)){break z}c=fb-16|0;fb=c;a=wb(x[j>>2]);x[c+12>>2]=a;d=wb(x[j+4>>2]);while(1){if(Ib(a,d)){b=wb(x[a>>2]);f=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,f)){if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}b=x[qg(a+12|0)>>2];continue}break}fb=a+16|0;a=x[kn(c+12|0)>>2];continue}else{fb=c+16|0}break}break z}x[31721]=0;c=U(199,j|0,h&65535,64)|0;d=x[31721];x[31721]=0;Z:{if((d|0)==1){break Z}_:{if(!c){break _}c=Zb(x[r>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break _}x[31721]=0;c=P(152,b|0,c<<4)|0;d=x[31721];x[31721]=0;if((d|0)==1){break Z}if(!c){break _}x[31721]=0;P(186,b|0,2)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Z}d=0;c=Vb(x[j>>2],h);_e(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break _}f=d;x[31721]=0;c=R(200,b|0)|0;d=x[31721];x[31721]=0;$:{if((d|0)!=1){d=c<<24>>24;if(d){break $}d=64;if(f>>>0>62){continue}c=Vb(x[j>>2],h);d=f+1|0;_e(e+16|0,x[c>>2],x[x[c+48>>2]+12>>2],d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}f=N()|0;break B}g=Ig(e+16|0);k=d&31;if(k>>>0<z[u>>1]){g=Vc(x[e+24>>2],k)}t=d&255;if(t&32){x[31721]=0;O(201,e+14|0,b|0);c=x[31721];x[31721]=0;aa:{ba:{ca:{if((c|0)!=1){A=Hc(e+14|0);c=y[e+14|0];if(c>>>0>239){break ca}c=EW((D(c>>>4|0,12)+(c&15)|0)+13|0);break ba}f=N()|0;break B}da:{switch(c-254|0){case 0:break ba;case 1:break da;default:break aa}}c=0}v[g|0]=c}v[g+1|0]=y[A|0]}if(t&64){x[31721]=0;c=R(200,b|0)|0;t=x[31721];x[31721]=0;if((t|0)==1){break Y}c=c<<24>>24;v[e+14|0]=c;ea:{if((c|0)<=-64){v[g+2|0]=2;c=c^-128;break ea}v[g+2|0]=1;v[e+13|0]=64;c=y[Sb(e+14|0,e+13|0)|0]}v[g+4|0]=c}fa:{if((d|0)>=0){break fa}x[31721]=0;O(201,e+14|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break X}eD(g,y[e+14|0],y[Hc(e+14|0)|0],0);c=y[g+3|0];ga:{if((c|0)!=10){if((c|0)!=31){if((c|0)!=20){break fa}c=y[g+5|0];if((c&240)!=160|(y[e+248|0]|y[e+249|0]<<8)>>>0>4895){break fa}if((l&65535)>>>0>1){break ga}d=y[(e+k|0)+272|0]&127;if(d>>>0>=16){break ga}ha:{switch(c-160|0){case 0:case 2:v[g+5|0]=d&8?-116:-125;break fa;case 1:case 3:v[g+5|0]=d&8?-125:-116;break fa;default:break ha}}if(c>>>0>167){break ga}v[g+5|0]=136;break fa}c=y[g+5|0];if(c>>>0>15){n=0;break fa}if(c>>>0<=7){q=q+1|0;break fa}o=((c|0)!=8)+o|0;break fa}if(y[g+5|0]|(y[e+248|0]|y[e+249|0]<<8)>>>0>4865){break fa}}v[g+3|0]=37}d=f;continue}}h=h+1|0;continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}f=N()|0}ld(r)}ld(m);break c}ld(r);ld(m);tb(i);break b}f=N()|0}tb(i);Q(f|0);p()}d=1}fb=e+304|0;return d|0}function xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0;d=fb-480|0;fb=d;vc(b);j=fb-16|0;fb=j;e=d+276|0;pW(j+8|0,e);h=x[j+12>>2];l=b;jc(j,x[b>>2],x[b+8>>2],x[j+8>>2],x[j+12>>2]);b=x[j+4>>2];if((b|0)==(h|0)){Ub(l,x[j+12>>2])}fb=j+16|0;b=(b|0)==(h|0);if(!b){oW(e)}a:{if(!b){break a}if(!qW(d+276|0)){break a}if(!c){n=1;break a}Ad(a,134217728);b=d+8|0;dg(b,3953);x[31721]=0;S(706,d+116|0,b|0,y[d+280|0]|y[d+281|0]<<8);b=x[31721];x[31721]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+116|0;yb(a+1298344|0,b);tb(b);Eb(d+8|0);j=rc(b,8974);yb(a+1298356|0,j);tb(j);T=a+1298404|0,V=x[Ec(b,28)>>2],x[T>>2]=V;x[a+480188>>2]=4;T=a,V=Cb(y[d+412|0]|y[d+413|0]<<8),x[T+480196>>2]=V;b=y[d+416|0]|y[d+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;T=a,V=nW(Cb(b)),x[T+480204>>2]=V;Zv(Wb(x[a+484360>>2],y[a+484376|0]),d+284|0,y[d+282|0]);r=a+480190|0;m=a+480188|0;q=Nb(d+264|0);t=Nb(d+252|0);h:{i:{j:{k:{l:{while(1){if(Cb(y[d+476|0]|y[d+477|0]<<8)>>>0<=(f&65535)>>>0){break k}x[31721]=0;b=R(276,l|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break g}w[d+228>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}n=Cb(y[d+478|0]|y[d+479|0]<<8);if((Cb(y[d+280|0]|y[d+281|0]<<8)|0)==2){x[31721]=0;b=R(284,l|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break h}n=b-2|0}x[31721]=0;S(188,d+8|0,l|0,n|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}b=d+8|0;e=hc(d+116|0,b);ub(b);B=z[oe(r,d+228|0)>>1];w[r>>1]=B;x[31721]=0;g=D(z[d+228>>1],104)+a|0;h=g+484380|0;O(282,h|0,1);b=x[31721];x[31721]=0;m:{n:{o:{if((b|0)==1){break o}if(Cb(y[d+280|0]|y[d+281|0]<<8)>>>0>1){break n}x[31721]=0;O(707,e|0,g+484423|0);b=x[31721];x[31721]=0;if((b|0)==1){break o}x[31721]=0;P(186,e|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break o}x[31721]=0;S(334,e|0,((z[d+228>>1]<<5)+a|0)+946304|0,30);b=x[31721];x[31721]=0;if((b|0)!=1){break m}}h=N()|0;break f}b=Fb(d+8|0);x[31721]=0;S(361,e|0,b|0,257);j=x[31721];x[31721]=0;p:{q:{if((j|0)==1){break q}ye(g+484423|0,b);x[31721]=0;P(186,e|0,1)|0;j=x[31721];x[31721]=0;if((j|0)==1){break q}x[31721]=0;S(361,e|0,b|0,31);j=x[31721];x[31721]=0;if((j|0)==1){break q}xc(((z[d+228>>1]<<5)+a|0)+946304|0,b);if(!(v[d+124|0]&1)){break p}x[31721]=0;P(186,e|0,1)|0;j=x[31721];x[31721]=0;if((j|0)!=1){break p}}h=N()|0;tb(b);break f}tb(b)}x[31721]=0;O(708,e|0,d+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break l}k=fb-16|0;fb=k;j=_b(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24));x[h>>2]=j;v[k+15|0]=y[d+12|0];v[k+14|0]=64;T=h,V=y[Sb(k+15|0,k+14|0)|0]<<2,w[T+30>>1]=V;i=_b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24));x[h+4>>2]=i;b=_b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24))+_b(y[d+18|0]|y[d+19|0]<<8|(y[d+20|0]<<16|y[d+21|0]<<24))|0;x[h+8>>2]=b;if(i>>>0>=j>>>0){i=j-1|0;x[h+4>>2]=i}if(b>>>0>j>>>0){x[h+8>>2]=j;b=j}r:{if(b>>>0<i>>>0){x[h+4>>2]=0;x[h+8>>2]=0;break r}if(b>>>0<=i>>>0){break r}w[h+34>>1]=z[h+34>>1]|2;T=xb(h+68|0,0),V=i,x[T>>2]=V}fb=k+16|0;s:{t:{u:{switch(Cb(y[d+280|0]|y[d+281|0]<<8)|0){case 2:v[g+484417|0]=y[d+26|0]<<3;break;case 0:break t;default:break u}}x[31721]=0;O(213,t|0,B|0);b=x[31721];x[31721]=0;if((b|0)==1){break l}x[31721]=0;O(709,q|0,B|0);b=x[31721];x[31721]=0;if((b|0)==1){break l}j=Dd(x[q>>2],z[d+228>>1]-1|0);kW(j);x[31721]=0;b=R(276,l|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break j}h=x[l+8>>2];k=x[l>>2];x[31721]=0;h=U(153,k|0,h|0,b<<3)|0;k=x[31721];x[31721]=0;if((k|0)==1){break j}if(!h){break s}x[31721]=0;O(710,j|0,b|0);h=x[31721];x[31721]=0;if((h|0)==1){break j}n=0;x[d+248>>2]=0;if(!(!(y[g+484414|0]&2)|b)){b=x[g+484384>>2];x[d+240>>2]=b;h=x[g+484388>>2];x[31721]=0;x[d+244>>2]=h-b;O(711,j|0,d+240|0);b=x[31721];x[31721]=0;if((b|0)!=1){break t}h=N()|0;break f}while(1){if(b>>>0<=(n&65535)>>>0){break t}x[31721]=0;h=R(284,l|0)|0;g=x[31721];x[31721]=0;v:{if((g|0)==1){break v}x[31721]=0;x[d+240>>2]=h;h=R(284,l|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break v}x[31721]=0;x[d+244>>2]=h;O(711,j|0,d+240|0);h=x[31721];x[31721]=0;if((h|0)==1){break v}n=n+1|0;continue}break}h=N()|0;break f}ub(e);f=f+1|0;continue}break}ub(e);break c}h=N()|0;break f}w:{x:{y:{z:{if(Cb(y[d+280|0]|y[d+281|0]<<8)){u=y[d+283|0];w[d+238>>1]=4;C=128;break z}x[31721]=0;C=R(276,l|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){h=N()|0;break e}b=y[d+280|0]|y[d+281|0]<<8;u=y[d+283|0];w[d+238>>1]=4;if(!Cb(b)){break y}}j=x[l+8>>2];h=0;while(1){A:{if((h&65535)>>>0>=C>>>0){break A}x[31721]=0;b=R(276,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break x}if((b|0)==65535){break A}x[31721]=0;u=R(276,l|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break x}x[31721]=0;b=R(276,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break x}w[d+238>>1]=b;if(b>>>0>127){break c}T=m,V=z[oe(m,d+238|0)>>1],w[T>>1]=V;x[31721]=0;P(186,l|0,D(b,u)<<2)|0;b=x[31721];x[31721]=0;if((b|0)==1){break x}h=h+1|0;continue}break}x[31721]=0;P(152,l|0,j|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break w}}b=z[m>>1];x[31721]=0;E=P(712,d+240|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){J=a+484344|0;M=c&1;F=Cb(y[d+414|0]|y[d+415|0]<<8);b=0;j=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=C>>>0){break E}F:{if(!Cb(y[d+280|0]|y[d+281|0]<<8)){n=z[d+238>>1];h=b;break F}x[31721]=0;h=R(276,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break B}if((h|0)==65535){break E}x[31721]=0;u=R(276,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break B}x[31721]=0;n=R(276,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break B}w[d+238>>1]=n}e=x[l+8>>2];g=x[l>>2];x[31721]=0;f=e;G=u&65535;e=G<<2;g=U(153,g|0,f|0,D(e,n&65535)|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break B}if(!g){break E}if(!M){break D}x[31721]=0;K=h&65535;h=U(199,J|0,K|0,G|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break B}if(!h){break D}s=0;G:while(1){if((s|0)==(G|0)){break C}h=Vb(x[J>>2],K);_e(d+228|0,x[h>>2],x[x[h+48>>2]+12>>2],s);h=0;H=0;n=0;H:{I:{J:{switch((F&3)-1|0){case 0:n=!(s&3);break I;case 1:n=!(s&1);break I;case 2:break J;default:break H}}n=(s&3)!=3}}while(1){if(z[d+238>>1]<=h>>>0){s=s+1|0;continue G}e=x[E>>2];g=Vc(x[d+228>>2],h);x[31721]=0;O(360,d+224|0,l|0);f=x[31721];x[31721]=0;if((f|0)==1){break B}k=D(h,9)+e|0;e=d+224|0;f=Hc(e);o=Ye(e);v[g+1|0]=y[d+224|0];i=y[f|0];v[g|0]=i;f=y[cj(e)|0];v[g+5|0]=f;m=g+5|0;if(i){v[g|0]=i+25;v[k+8|0]=0;v[k|0]=0;v[k+1|0]=0;v[k+2|0]=0;v[k+3|0]=0;v[k+4|0]=0;v[k+5|0]=0;v[k+6|0]=0;v[k+7|0]=0;f=y[g+5|0]}i=f&255;o=y[o|0];K:{L:{if(o>>>0>=240){e=i|(o&15)<<8;if(e){v[g+3|0]=17;T=g,V=$l(+(nW(e)>>>0)/1e4),v[T+5|0]=V;i=0;break K}break L}I=i>>>4|0;L=i<<4;e=I|L;M:{switch(o|0){case 0:if(f&255){v[g+3|0]=1;i=0;break K}break L;case 1:v[g+3|0]=2;i=0;break K;case 2:v[g+3|0]=3;i=0;break K;case 3:v[d+220|0]=15;T=k,V=y[Sb(m,d+220|0)|0]|16,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break L;case 4:v[d+220|0]=15;T=k,V=y[Sb(m,d+220|0)|0]|32,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break L;case 5:v[k+7|0]=0;v[k+2|0]=0;v[k+1|0]=f;v[k|0]=0;break L;case 6:v[k+7|0]=0;v[k+2|0]=f;v[k|0]=0;v[k+1|0]=0;break L;case 7:v[g+3|0]=23;i=0;j=0;break K;case 8:v[g+3|0]=0;i=1;j=e;break K;case 9:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Sb(m,d+220|0)|0]|16,v[T+5|0]=V;i=0;break K;case 10:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Sb(m,d+220|0)|0]|32,v[T+5|0]=V;i=0;break K;case 11:v[k+3|0]=e;break L;case 12:v[g+4|0]=f;i=1;v[g+2|0]=1;v[k+3|0]=0;v[g+3|0]=0;break K;case 13:N:{O:{if((f&255)>>>0>=16){v[g+2|0]=4;f=(f&240)>>>4|0;break O}if(!(i&15)){break N}v[g+2|0]=3}v[g+4|0]=f}v[k+3|0]=0;break L;case 14:v[g+3|0]=19;v[g+5|0]=!(f&255);i=0;break K;case 15:v[g+3|0]=16;v[g+5|0]=(f&240)>>>4;F=f&15;i=0;break K;case 16:v[k+5|0]=0;v[k+4|0]=f;break L;case 17:v[k+6|0]=i&15?f:0;break L;case 18:v[g+3|0]=14;i=0;break K;case 19:v[k+8|0]=0;v[k+7|0]=f;v[k+2|0]=0;v[k|0]=0;v[k+1|0]=0;break L;case 20:v[g+3|0]=12;i=0;break K;case 22:e=y[g+1|0];P:{if(!e){break P}i=x[q>>2];if(Rd(i,x[q+4>>2])>>>0<e>>>0){break P}f=f-1|0;v[m|0]=f;x[31721]=0;R(713,d+116|0)|0;o=x[31721];x[31721]=0;if((o|0)==1){break B}x[d+220>>2]=9;e=Dd(i,e-1|0);T=d,V=Rd(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]<=(f&255)>>>0){break P}v[g+2|0]=15;v[g+4|0]=y[g+5|0]}break L;case 23:e=y[g+1|0];Q:{if(!e){break Q}i=x[q>>2];if(Rd(i,x[q+4>>2])>>>0<e>>>0){break Q}f=f-1|0;v[m|0]=f;e=Dd(i,e-1|0);i=x[e>>2];o=Rd(i,x[e+4>>2]);e=f&255;if(o>>>0<=e>>>0){break Q}e=Dd(i,e);f=z[e+8>>1];R:{if(f){break R}f=0;i=z[r>>1];if(!ri(i)){break R}f=i+1|0;w[r>>1]=f;w[e+8>>1]=f}v[g+1|0]=f}break L;case 24:e=y[g+1|0];S:{if(!e){break S}i=x[q>>2];if(Rd(i,x[q+4>>2])>>>0<e>>>0){break S}f=f-1|0;v[m|0]=f;x[31721]=0;R(713,d+8|0)|0;o=x[31721];x[31721]=0;if((o|0)==1){break B}x[d+220>>2]=9;e=Dd(i,e-1|0);T=d,V=Rd(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]>(f&255)>>>0){v[g+2|0]=15;v[g+4|0]=y[g+5|0]}e=Zb(x[t>>2],y[g+1|0]-1|0);f=z[e>>1];T:{if(f){break T}f=0;i=z[r>>1];if(!ri(i)){break T}f=i+1|0;w[r>>1]=f;w[e>>1]=f}v[g+1|0]=f}break L;case 25:e=y[g+1|0];U:{if(!e){break U}i=x[q>>2];if(Rd(i,x[q+4>>2])>>>0<e>>>0){break U}f=f-1|0;v[m|0]=f;e=Dd(i,e-1|0);i=x[e>>2];o=Rd(i,x[e+4>>2]);e=f&255;if(o>>>0<=e>>>0){break U}e=Dd(i,e);f=z[e+10>>1];V:{if(f){break V}f=0;i=z[r>>1];if(!ri(i)){break V}f=i+1|0;w[r>>1]=f;w[e+10>>1]=f}v[g+1|0]=f}break L;case 29:v[g+5|0]=e;v[g+3|0]=11;if(i&15){v[m|0]=L|15;i=0;break K}i=0;if((f&255)>>>0<16){break K}v[m|0]=I|240;break K;case 32:if((f&255)>>>0>=16){v[k+3|0]=I;break L}v[g+3|0]=19;v[g+5|0]=f|192;i=0;break K;case 33:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Sb(m,d+220|0)|0]|208,v[T+5|0]=V;i=0;break K;case 34:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Sb(m,d+220|0)|0]|144,v[T+5|0]=V;i=0;break K;case 73:v[g+3|0]=10;i=0;break K;case 78:if((f&112|128)==224){v[g+3|0]=19;i=0;break K}break L;case 79:if((f&255)>>>0<=31){v[g+3|0]=16;i=0;F=0;break K}v[g+3|0]=17;i=0;break K;default:break M}}}v[g+3|0]=0;i=1}o=0;e=y[k+3|0];if(!(y[g+2|0]|!e)){f=e;o=e>>>4|0;e=e>>>0<16;v[g+4|0]=e?f:o;v[g+2|0]=e?6:5;o=1}W:{if(!i){break W}f=y[k+1|0];X:{if(f){v[g+3|0]=2;break X}f=y[k+2|0];if(f){v[g+3|0]=3;break X}f=y[k|0];if(f){v[g+3|0]=19;break X}f=y[k+7|0];if(f){v[g+3|0]=4;v[k+8|0]=f;break X}f=y[k+4|0];if(f){v[g+3|0]=5;v[k+5|0]=f;break X}e=y[k+3|0];if(!(!e|o)){v[g+5|0]=e;v[g+3|0]=11;if(e&15){f=e|-16;break X}if(e>>>0<16){break W}f=e|15;break X}f=y[k+6|0];if(f){v[g+3|0]=8;break X}if(n){v[g+3|0]=20;n=0;f=97;break X}n=0;e=j&255;if(!e|H){break W}v[g+5|0]=j;v[g+3|0]=24;if(j&15){f=j|-16}else{H=1;if(e>>>0<16){break W}f=j|15}H=1}v[m|0]=f}h=h+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];i=1;Uh(a,1);if(Cb(y[d+280|0]|y[d+281|0]<<8)){Y:{while(1){b=x[l+8>>2];j=x[l>>2];x[31721]=0;b=U(153,j|0,b|0,2)|0;j=x[31721];x[31721]=0;if((j|0)==1){break B}if(!b){break Y}x[31721]=0;b=R(276,l|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break B}if((b|0)==65535){break Y}x[31721]=0;P(186,l|0,2)|0;b=x[31721];x[31721]=0;if((b|0)==1){break B}x[31721]=0;b=R(284,l|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){x[31721]=0;P(186,l|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break B}x[31721]=0;P(186,l|0,34)|0;b=x[31721];x[31721]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=i&65535;if(b>>>0>B>>>0){break Z}_:{h=(D(b,104)+a|0)+484380|0;if(!x[h>>2]){break _}c=Wc(d+228|0,8,1,0,0);x[31721]=0;U(218,c|0,h|0,l|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break B}c=x[q>>2];if(Rd(c,x[q+4>>2])>>>0<b>>>0){break _}k=b-1|0;g=Dd(c,k);c=0;b=0;n=fb-112|0;fb=n;$:{f=x[h>>2];if(!ge(f,x[h+20>>2])){break $}r=x[g>>2];j=Rd(r,x[g+4>>2]);if(j>>>0<2){break $}e=Po(n+8|0,h);x[e+20>>2]=0;x[e>>2]=0;aa:{while(1){if((c|0)==(j|0)){break aa}ba:{m=Dd(r,c);s=x[m>>2];if(s>>>0>=f>>>0){break ba}m=x[m+4>>2];if(m>>>0>f-s>>>0|268435456-m>>>0<b>>>0){break ba}b=b+m|0;x[e>>2]=b;c=c+1|0;continue}break}j=c}if(!Bh(e)){break $}m=e+68|0;b=0;c=0;while(1){if((c|0)==(j|0)){jn(h);b=Po(h,e);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break $}o=x[e+20>>2]+b|0;r=x[h+20>>2];f=Dd(x[g>>2],c);yc(o,r+x[f>>2]|0,x[f+4>>2]);x[f>>2]=b;if(c-10>>>0>=4294967287){T=xb(m,c-1|0),V=b,x[T>>2]=V}c=c+1|0;b=x[f+4>>2]+b|0;continue}}fb=n+112|0;b=z[Zb(x[t>>2],k)>>1];if(b){eC(h,(D(b,104)+a|0)+484380|0,0,x[h>>2],0)}b=Dd(x[q>>2],k);T=d,V=wb(x[b>>2]),x[T+228>>2]=V;c=wb(x[b+4>>2]);while(1){b=x[d+228>>2];if(!Ib(b,c)){break _}j=z[b+8>>1];if(j){eC(h,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}j=z[b+10>>1];if(j){eC(h,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}Uq(d+228|0);continue}}i=i+1|0;continue}}mW(E);n=1;break b}x[31721]=0;P(186,l|0,D(e,z[d+238>>1])|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){break C}break B}b=b+1|0;continue}break}h=N()|0;mW(E);break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break f}h=N()|0;break e}h=N()|0;break e}h=N()|0;Eb(d+8|0);break d}h=N()|0;break e}ub(e)}ld(t);lW(q)}Q(h|0);p()}n=0}ld(t);lW(q)}fb=d+480|0;return n|0}function Fna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-576|0;fb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!fD(b,d+496|0)){break l}if(!jV(d+496|0)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(iV(d+496|0),hb))){break l}if(!c){e=1;break l}Ad(a,4);bg(a);v[a+1074368|0]=4;l=Fb(d+484|0);k=d+534|0;m:{if(!(hd(k,18405,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){q=41128;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=gD(d+513|0,0,20)?1154:34;break m}q=41128;if(!hd(k,18384,20)){e=1;break m}f=d+104|0;si(f,3,k);x[31721]=0;S(372,d+192|0,4,f|0);f=x[31721];x[31721]=0;n:{if((f|0)!=1){f=d+192|0;yb(l,f);tb(f);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break n}e=1048;break m}b=N()|0;break a}if(!hd(k,18132,12)){e=16;if((y[d+546|0]|y[d+547|0]<<8|(y[d+548|0]<<16|y[d+549|0]<<24))==538976288&(y[d+550|0]|y[d+551|0]<<8|(y[d+552|0]<<16|y[d+553|0]<<24))==538976288){break m}v[a+1074368|0]=5;break m}if(!hd(k,11657,20)){e=48;break m}if(!hd(k,25440,15)){x[31721]=0;f=P(270,a+1074312|0,54)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;P(270,f|0,51)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}q=41120;e=16;break m}o:{if(hd(k,25456,14)){if(hd(k,25471,14)){break o}}x[31721]=0;f=P(270,a+1074312|0,57)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;P(270,f|0,51)|0;f=x[31721];x[31721]=0;e=16;if((f|0)!=1){break m}break b}e=hd(k,18220,11)?16:256}f=d+104|0;u=d+513|0;si(f,3,u);x[31721]=0;O(221,d+192|0,f|0);f=x[31721];x[31721]=0;p:{q:{r:{s:{t:{if((f|0)!=1){f=d+192|0;yb(a+1298308|0,f);tb(f);x[a+480260>>2]=1;x[a+480264>>2]=31999;Ze(Wb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;H=a+480192|0,I=z[Lc(f,d+104|0)>>1],w[H>>1]=I;f=y[d+572|0]|y[d+573|0]<<8;if(f){x[a+480196>>2]=f}f=y[d+574|0]|y[d+575|0]<<8;if(f){f=D(f,1e4);f=f>>>0>=1e7?1e7:f;x[a+480204>>2]=f>>>0<=32e4?32e4:f}f=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=f<<4&16|f<<3&32768;g=y[a+484376|0];m=x[a+484360>>2];x[31721]=0;aa(351,Wb(m,g)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);g=x[31721];x[31721]=0;if((g|0)==1){break b}g=f>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|g>>>0>1023)){f=y[a+484376|0];e=x[a+484360>>2];x[31721]=0;W(766,Wb(e,f)|0);f=x[31721];x[31721]=0;if((f|0)==1){break b}}x[31721]=0;P(152,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31721]=0;S(767,b|0,d+496|0,a|0);f=x[31721];x[31721]=0;if((f|0)==1){break b}}v[d+483|0]=0;B=c&2;F=d+122|0;n=d+225|0;m=Nb(d+468|0);G=a+480192|0;r=1;f=-1;while(1){e=r&65535;if(e>>>0>z[G>>1]){if(!(!(g&2)|s&255)){g=gD(u,0,20)?g|16:g}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31721]=0;S(767,b|0,d+496|0,a|0);c=x[31721];x[31721]=0;if((c|0)==1){break q}}if(!B){break r}n=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>z[n>>1]){break r}i=x[m>>2];x[31721]=0;U(218,xb(i,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31721]=0;i=R(154,b|0)|0;h=x[31721];x[31721]=0;u:{v:{if((h|0)!=1){Dh(b,4);x[31721]=0;S(768,b|0,d+192|0,(i?i:263)|0);i=x[31721];x[31721]=0;if((i|0)==1){break s}w:{if((g|0)==1){i=x[d+192>>2];if((i|0)!=263){g=16;if((i|0)!=245){break w}x[a+1074308>>2]=16777381;x[31721]=0;g=P(1,d+180|0,13445)|0;i=x[31721];x[31721]=0;if((i|0)!=1){yb(l,g);tb(g);g=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31721]=0;g=P(1,d+168|0,13336)|0;i=x[31721];x[31721]=0;if((i|0)!=1){yb(l,g);tb(g);g=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}i=x[d+192>>2];if(!(!(g&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(i|0)!=263)){g=g|16;break w}if(!(!(g&256)|(i|0)==29)){g=g&-257;break w}if(!(g&160)){break w}g=(i|0)==33?g:0}x[31721]=0;i=U(254,a|0,e|0,0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break s}if(!i){break u}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[31721]=0;O(769,d+192|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((f|0)==-1){f=e;break x}if(!(g&32)|(e|0)==(f|0)){break x}g=g&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31721]=0;h=y[d+439|0];j=y[d+435|0]|y[d+436|0]<<8;o=y[d+434|0];t=y[d+433|0];S(770,d+156|0,a|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break t}g=h|(j|(o|t))?g&-4:g;i=x[i>>2]+236|0;e=12;h=x[d+156>>2];j=Yc(h,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Hf(m)}e=0;x[31721]=0;i=P(771,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;h=x[31721];x[31721]=0;if((h|0)!=1){break z}b=N()|0;break y}if(j>>>0>z[Zb(i,e)>>1]){o=z[Zb(h,z[Zb(i,e)>>1])>>1];H=Zb(i,e),I=o,w[H>>1]=I}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){h=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=h>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=h>>>0){break v}j=y[xb(x[m>>2],e)+3|0];h=x[xb(x[i>>2],e)>>2];x[31721]=0;S(188,d+72|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[31721];x[31721]=0;if((h|0)!=1){j=d+72|0;h=hc(d+104|0,j);ub(j);j=x[d+156>>2];if(!(!B|Yc(j,x[d+160>>2])>>>0<=e>>>0)){o=z[Zb(j,e)>>1];j=xb(x[m>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[31721]=0;x[d+68>>2]=j;x[d+8>>2]=j;j=ba(772,(D(o,104)+a|0)+484380|0,d+8|0,h|0,d+483|0)|0;o=x[31721];x[31721]=0;if((o|0)==1){break E}C=j^1|C}ub(h);e=e+1|0;h=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(h);break A}x[31721]=0;O(773,b|0,d+104|0);h=x[31721];x[31721]=0;if((h|0)==1){break B}h=d+72|0;j=y[d+118|0];F:{if(!(j&48|y[d+121|0]!=173)){Wc(h,8,1,0,10);break F}Wc(h,j&16?16:8,j&32?3:1,0,2)}x[31721]=0;O(774,m|0,h|0);h=x[31721];x[31721]=0;if((h|0)!=1){H=xb(x[i>>2],e),I=x[d+104>>2],x[H>>2]=I;o=y[d+121|0];h=x[d+156>>2];if(Yc(h,x[d+160>>2])>>>0>e>>>0){j=z[Zb(h,e)>>1];x[31721]=0;h=(D(j,104)+a|0)+484380|0;O(775,d+104|0,h|0);t=x[31721];x[31721]=0;if((t|0)==1){break D}v[h+38|0]=y[n+202|0];v[h+39|0]=y[n+203|0];v[h+40|0]=y[n+204|0];v[h+41|0]=y[n+205|0];h=d+92|0;Wk(h,3,F);x[31721]=0;O(221,d+72|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break C}h=d+72|0;xc(((j<<5)+a|0)+946304|0,h);tb(h);g=(y[d+118|0]&3)==3?(g&2)>>>1|0?g|4:g:g}s=o|s;e=e+1|0;E=y[pi(x[m+4>>2])+3|0]==10|E;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}sc(i)}ld(d+156|0);break c}b=N()|0;break c}sc(i);ld(d+156|0)}r=r+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(C&1)){break G}x[31721]=0;c=P(1,d+104|0,16657)|0;e=x[31721];x[31721]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31721]=0;S(389,e|0,2,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31721]=0;c=P(416,b|0,5558)|0;e=x[31721];x[31721]=0;if((e|0)==1){break q}if(c){x[31721]=0;c=R(154,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break q}x[31721]=0;V(339,a+1298332|0,b|0,c|0,0);c=x[31721];x[31721]=0;if((c|0)==1){break q}g=g|16}x[31721]=0;n=P(416,b|0,14118)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(n){x[31721]=0;c=R(154,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}x[31721]=0;e=a+901404|0;S(776,b|0,e|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}hD(e);g=g|16}x[31721]=0;c=P(416,b|0,13890)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}if(!c){break p}x[31721]=0;c=R(154,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;H=d,I=aj(x[a+484344>>2],x[a+484348>>2]),w[H+72>>1]=I;c=z[Lc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break p}x[31721]=0;O(583,b|0,d+192|0);i=x[31721];x[31721]=0;I:{if((i|0)==1){break I}i=x[a+484344>>2];x[31721]=0;O(584,Vb(i,e)|0,d+192|0);i=x[31721];x[31721]=0;if((i|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31721]=0;c=P(416,b|0,13895)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31721]=0;c=R(154,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=z[Lc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break J}x[31721]=0;S(428,b|0,((e<<5)+a|0)+480289|0,20);i=x[31721];x[31721]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31721]=0;c=U(153,e|0,c|0,8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31721]=0;S(429,d+192|0,a|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break h}g=(c|0)==x[b+8>>2]?g:g|16}K:{if(!(g&16)){break K}if(g&4){x[a+1074308>>2]=17367040;x[31721]=0;c=P(1,d+192|0,14674)|0;e=x[31721];x[31721]=0;if((e|0)!=1){yb(l,c);tb(c);break K}b=N()|0;break c}if(!(g&2)){break K}x[a+1074308>>2]=18219008;x[31721]=0;c=P(1,d+192|0,14853)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}yb(l,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[31721]=0;c=U(396,d+72|0,d+542|0,12)|0;e=x[31721];x[31721]=0;if((e|0)==1){break R}x[31721]=0;S(261,d+156|0,1,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break Q}x[31721]=0;e=R(777,d+156|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break P}x[a+1074308>>2]=e;tb(d+156|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);g=24}if(!(!x[a+1074308>>2]|g&8)){v[a+1074368|0]=0;Dv(a+1074312|0)}c=g&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!n){_q(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31721]=0;U(269,a+1074312|0,4,1)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}}if(!zd(x[l+4>>2],y[l+11|0])){break L}if(!(g&256)|s&255|f+1>>>0>1){break M}x[31721]=0;c=P(1,d+156|0,8292)|0;f=x[31721];x[31721]=0;if((f|0)==1){break N}yb(l,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31721]=0;c=P(1,d+156|0,12069)|0;f=x[31721];x[31721]=0;if((f|0)!=1){yb(l,c);tb(c);break L}b=N()|0;break c}x[31721]=0;c=P(1,d+156|0,9750)|0;f=x[31721];x[31721]=0;if((f|0)==1){break f}yb(l,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31721]=0;c=P(439,a|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}v[d+67|0]=c}x[31721]=0;ba(440,a|0,b|0,1,d+67|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31721]=0;c=P(1,d+52|0,18232)|0;b=x[31721];x[31721]=0;if((b|0)==1){break da}b=x[a+1074308>>2];x[31721]=0;O(778,d+40|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break ca}x[31721]=0;S(2,d+92|0,c|0,d+40|0);b=x[31721];x[31721]=0;if((b|0)==1){break ba}b=d+92|0;yb(l,b);tb(b);tb(d+40|0);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];g=x[a+484348>>2];if(!Ge(b,g,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31721]=0;W(779,Wb(c,b)|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}g=x[a+484348>>2];b=x[a+484344>>2]}if(Ge(b,g,255)){break ga}AC(Wb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31721]=0;O(780,d+40|0,4102);b=x[31721];x[31721]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31721]=0;x[d+24>>2]=b&255;O(448,d+28|0,d+24|0);b=x[31721];x[31721]=0;if((b|0)==1){break _}x[31721]=0;V(434,d+92|0,d+40|0,d+12|0,d+28|0);b=x[31721];x[31721]=0;if((b|0)==1){break Z}b=d+92|0;c=yb(a+1298344|0,b);tb(b);tb(d+28|0);Eb(d+40|0);f=yb(a+1298368|0,l);H=a+1298404|0,I=x[Ec(b,x[(x[a+1074308>>2]?41120:q)>>2])>>2],x[H>>2]=I;if(!y[d+483|0]){break U}yb(a+1298380|0,c);x[31721]=0;b=P(1,d+92|0,15273)|0;e=x[31721];x[31721]=0;if((e|0)==1){break X}yb(c,b);tb(b);x[31721]=0;b=P(1,d+40|0,10101)|0;c=x[31721];x[31721]=0;if((c|0)==1){break W}yb(a+1298356|0,b);tb(b);x[31721]=0;b=P(1,d+28|0,10102)|0;c=x[31721];x[31721]=0;if((c|0)==1){break V}yb(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31721]=0;b=P(1,d+92|0,10102)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}yb(a+1298356|0,b)}tb(b);e=1;if(E&1){x[31721]=0;a=P(1,d+12|0,17136)|0;b=x[31721];x[31721]=0;if((b|0)==1){break k}x[31721]=0;P(77,f|0,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break j}tb(a)}sc(m);tb(l)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}sc(m);break a}b=N()|0}tb(l);Q(b|0);p()}function bR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;a:{if((Nf(x[x[a+48>>2]+12>>2])|0)!=(Nf(x[x[b+48>>2]+12>>2])|0)){break a}if((a|0)!=(b|0)){c=fb-16|0;fb=c;h=x[b>>2];d=x[b+4>>2];g=Kk(h,d);b:{if(Sv(a)>>>0>=g>>>0){f=d;i=x[a>>2];e=Kk(i,x[a+4>>2]);o=e>>>0>=g>>>0;if(!o){x[c+12>>2]=h;x[c+12>>2]=x[c+12>>2]+D(e,6);f=x[c+12>>2]}k=fb-16|0;fb=k;q=k+8|0;e=fb-32|0;fb=e;Xl(e+24|0,h,f);j=fb-16|0;fb=j;p=x[e+28>>2];m=x[e+24>>2];l=p-m|0;if((m|0)!=(p|0)){$h(i,m,l)}l=D((l|0)/6|0,6);x[j+12>>2]=l+i;Ud(e+16|0,l+m|0,j+12|0);fb=j+16|0;h=Tq(h,x[e+16>>2]);r=e,s=Tq(i,x[e+20>>2]),x[r+12>>2]=s;Ud(q,h,e+12|0);fb=e+32|0;e=x[k+12>>2];fb=k+16|0;if(!o){fu(a,f,d,g-Kk(x[a>>2],x[a+4>>2])|0);break b}$C(a,e);break b}cR(a);gZ(a,XC(a,g));fu(a,h,d,g)}fb=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];aR(a+24|0,b+24|0);ew(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=wb(x[a>>2]);x[n+12>>2]=c;m=wb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];e=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((e|0)==(h|0)){break c}f=y[c+3|0];d:{e:{if((e|0)!=16){break e}i=y[c+5|0];if(!((f|0)!=19|(i|0)!=144)){v[c+3|0]=0;e=1;break d}d=5;e=1;if((f|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(f|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((f|0)!=46){d=f;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}l=(e|0)==32|(e|0)==16777216|(e|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){f=9;j=1;i=tD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;f=9;i=tD(h);if((d&255)!=9){break k}if((e|0)!=2){break h}f=y[c+5|0];if((f|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){f=d;break h}d=x[i+84>>2];if(Yi(d,32)){break i}f=31;if(!Yi(d,31)){break i}v[c+3|0]=31;break h}r=c,s=ui(f<<1),v[r+5|0]=s;break g}f=32}l:{if((e|0)==16777216){d=y[c|0];m:{if(!Sg(d)){d=f;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!Yi(j,d)){d=Yi(j,31)?31:0}w[g+4>>1]=999;r=g,s=Hj(f,y[c+5|0]),w[r+110>>1]=s;r=c,s=(D(z[Lc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[r+5|0]=s;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{f=d&255;switch(f-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((f|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;f=-128-j|0;d=3;break r}f=128;if((j|0)==-128){break q}v[c+3|0]=2;f=j^-128;d=2}v[c+5|0]=f;if((f&255)>>>0>30){break q}v[c+5|0]=f+1>>>1|224;break g}v[g+4|0]=(f&255)+7>>>3;v[g+110|0]=15;r=c,s=y[Sb(g+4|0,g+110|0)|0]|240,v[r+5|0]=s;break g}d=f;s:{switch(e-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}Ar(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}pg(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];f=(d&240)-16>>>4|0;if(f>>>0>9){break f}if(!(1<<f&880)){if(!f){break t}if((f|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;r=c,s=y[Sb(g+4|0,g+110|0)|0]|240,v[r+5|0]=s;break f}v[g+4|0]=14;v[g+110|0]=d;r=c,s=y[Sb(g+4|0,g+110|0)|0]<<4|15,v[r+5|0]=s;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!l){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{f=d&255;switch(f-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((f|0)!=29){break f}d=y[c+5|0];f=d&15;if((f|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch((d&240)-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}f=y[c+5|0];j=f&15;if(!((j|0)==15&f>>>0>=16)&(!j|(f&240)!=240)){break O}f=11;$:{switch((d&255)-6|0){case 1:f=8;case 0:v[c+2|0]=f;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];f=d&15;if(!((f|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!f|(d&240)!=240){break f}v[c+5|0]=f|176;v[c+3|0]=19;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|16;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+5|0]=d|16;v[c+3|0]=28;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|32;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+5|0]=d|32;v[c+3|0]=28;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!f|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(f){v[c+5|0]=240;break f}if(d>>>0>=16){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((e|0)!=16777216&(e|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];f=d&240;if((f|0)!=144){if((f|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;r=c,s=y[Sb(g+4|0,c+5|0)|0]+1>>>1|0,v[r+5|0]=s}da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{if(!((e|0)!=16777216&(e|0)!=32)){if((h|0)!=4){break na}d=y[c+3|0];if((d|0)==23){break ma}if((d|0)!=5){break ka}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break la}if((e|0)!=4){break na}oa:{switch(h-1|0){case 1:case 2:break ia;case 0:case 3:break la;default:break oa}}if((h|0)!=16777216&(h|0)!=32){break ia}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break na}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;r=c,s=y[Sb(g+4|0,g+110|0)|0]|d&240,v[r+5|0]=s;break na}v[g+4|0]=64;r=c,s=y[Sb(g+4|0,c+5|0)|0]<<1,v[r+5|0]=s}switch(h-1|0){case 0:case 3:break la;default:break ja}}v[g+4|0]=128;r=c,s=y[Sb(g+4|0,c+5|0)|0]+1>>>1|0,v[r+5|0]=s}d=y[c+3|0]}pa:{switch((d&255)-16|0){case 0:v[g+4|0]=31;r=c,s=y[Sb(c+5|0,g+4|0)|0],v[r+5|0]=s;break ja;case 1:break pa;default:break ja}}v[g+4|0]=32;r=c,s=y[af(c+5|0,g+4|0)|0],v[r+5|0]=s}qa:{if((e|0)!=1){break qa}ra:{sa:{ta:{ua:{va:{wa:{xa:{d=y[c+3|0];switch(d-2|0){case 2:case 3:case 6:case 7:case 8:break qa;case 0:case 1:case 9:break ua;case 5:break va;case 4:break wa;default:break xa}}switch(d-19|0){case 1:break sa;case 0:break ta;default:break qa}}if(y[c+5|0]){break qa}d=4;break ra}if(y[c+5|0]){break qa}d=5;break ra}if(y[c+5|0]){break qa}d=0;break ra}f=y[c+5|0];d=(f<<4|(f<<24)+1610612736>>>28)&255;if(!(d>>>0>8|!(1<<d&387))){v[c+3|0]=0}d=0;if(f>>>0>239){break ra}break qa}d=0;if(y[c+5|0]<240){break qa}}v[c+3|0]=d}if((h|0)!=1){break ia}if(!El(y[c|0])){e=y[c+3|0];break ha}v[c|0]=0;e=y[c+3|0];if((e|0)!=19){if(e){break ha}v[c+5|0]=0;e=13;v[c+3|0]=13;break ea}f=y[c+5|0];if((f&240)!=208){break ga}v[c+5|0]=f&15|192;e=19;break ea}d=y[c+3|0];if(!(d|(h|0)!=2)){e=0;ya:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];e=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;e=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;e=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;e=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;e=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;e=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;e=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];e=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;e=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;e=29;break da;case 7:break ya;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];e=29;break da}if((h|0)==4){e=19;za:{if((d&255)!=19){f=y[c|0];e=d;break za}f=y[c|0];if(f|(y[c+5|0]&240)!=208){break za}e=0;v[c+5|0]=0;v[c+3|0]=0;f=0}Aa:{if(El(f)){v[c+1|0]=0;d=e&255;if(!d){break Aa}if((d|0)!=19){break da}e=19;d=y[c+5|0];if((d&240)!=208){break da}v[c|0]=0;v[c+5|0]=d&15;e=25;v[c+3|0]=25;break da}if(e&255){break da}}e=0;Ba:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;e=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;e=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ba;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42192|0];e=4;break da}Ca:{if((h|0)!=16777216&(h|0)!=32){break Ca}Da:{if(d&255|((e|0)==32|(e|0)==16777216)){break Da}d=0;Ea:{Fa:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;f=y[c+4|0]<<4;d=29;break Ea;case 3:v[c+3|0]=29;f=y[c+4|0];d=29;break Ea;case 0:v[c+3|0]=5;f=y[c+4|0]<<4;d=5;break Ea;case 4:break Fa;default:break Da}}v[c+3|0]=4;f=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=f}f=y[c+2|0];if(f>>>0>15|!(1<<f&47480)){break Ca}v[g+4|0]=9;r=c,s=y[Sb(c+4|0,g+4|0)|0],v[r+4|0]=s}e=d;break da}Ga:{Ha:{Ia:{d=e&255;switch(d-15|0){case 4:break Ga;case 0:break Ha;case 1:case 2:case 3:break ea;default:break Ia}}if(!d){break fa}break ea}e=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break ea}f=y[c+5|0]}e=19;if(f>>>0<240){break ea}v[c+3|0]=0}e=0;Ja:{switch(y[c+2|0]-1|0){case 0:e=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break ea;case 1:e=9;v[c+3|0]=9;d=y[c+4|0];v[c+5|0]=d>>>0>=64?-1:d<<2;break ea;case 3:e=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break ea;case 2:e=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break ea;case 5:e=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break ea;case 4:e=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break ea;case 12:e=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break ea;case 11:e=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break ea;case 10:e=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break ea;case 7:e=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break ea;case 6:break Ja;default:break ea}}e=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0}Ka:{if(y[c+2|0]!=15){break Ka}if(Kv(x[i+88>>2],15)){break Ka}d=e&255;if(!(!d|(d|0)==10)){if(Yi(x[i+84>>2],e&255)){break Ka}}v[c+2|0]=0;v[c+3|0]=10;La:{Ma:{e=y[c+1|0];if(!e){break Ma}f=y[c+5|0];if(z[k+480192>>1]>=e>>>0){h=y[c|0];Na:{if(!Sc(h)){break Na}j=x[(k+(e<<2)|0)+900380>>2];if(!j){break Na}e=z[Zb(j+236|0,h-1|0)>>1]}if(!(e&65535)){break Ma}}if(z[k+480190>>1]<(e&65535)>>>0){break Ma}h=y[c+4|0];Jv(g+4|0);if(h>>>0>9){break Ma}d=(d|0)==10?f:0;f=qi(k,e&65535);e=y[c+4|0];if(!e){f=zua(x[f>>2],0,d&255,0);d=hb;f=f+32768|0;d=f>>>0<32768?d+1|0:d;d=ui(Bc((d&65535)<<16|f>>>16,d>>>16|0));break La}d=ui((x[xb(f+68|0,e-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break La}d=y[c+4|0]<<3}v[c+5|0]=d;e=y[c+3|0]}Oa:{Pa:{d=e&255;switch(d-42|0){case 0:case 2:break Pa;default:break Oa}}if(Yi(x[i+84>>2],d)){break Oa}e=10;v[c+3|0]=10}f=y[c|0];Qa:{if(f>>>0>=y[i+8|0]){d=1;if(f>>>0<=y[i+9|0]){break Qa}}if(El(f)){Ra:{switch(f-253|0){case 1:d=y[i+70|0]!=0;break Qa;case 2:d=y[i+71|0]!=0;break Qa;case 0:d=y[i+72|0]!=0;break Qa;default:break Ra}}d=x[i>>2]==16777216;break Qa}d=!f}if(!d){v[c|0]=0}if(!Yi(x[i+84>>2],e&255)){v[c+3|0]=0}if(Kv(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[qg(n+12|0)>>2];continue}}fb=n+16|0;return a}function Xja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=E(0),H=E(0),I=0,J=0;g=fb-32|0;fb=g;b=x[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Zf(a+1074312|0,0)}b=g+12|0;h=a+1074312|0;Kb(b,h,0);c=Hb(x[x[g+12>>2]>>2],x[g+16>>2]);f=a+480180|0;d=x[f>>2];Kb(b,h,0);m=c&(d&16777248)!=0;u=Hb(x[x[g+12>>2]>>2],x[g+16>>2]);B=x[f>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}c=a+480192|0;d=1;while(1){b:{b=d&65535;if(b>>>0<=z[c>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[g+12>>2]=D(y[b+20|0],100)>>>6;x[g+24>>2]=100;I=b,J=x[Gb(g+12|0,g+24|0)>>2],v[I+20|0]=J;if(A[a+1074308>>2]>18350079&m){break b}e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2;if(A[a+1074308>>2]>18285313&m){break b}iD(Wh(b,2),x[f>>2]);e=x[a+1074308>>2];c:{if(e>>>0<18284544){break c}if(e>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Nj(y[b+31|0])){break c}Lb(h,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(h,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&m){break d}b=z[a+480190>>1]+1&65535;d=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(d|0)){break d}c=D(b,104)+a|0;f=c+484419|0;if(!(y[f|0]|!(y[c+484421|0]|y[c+484420|0]))){v[f|0]=255}b=b+1|0;continue}}c=a+901404|0;b=c+288|0;d=$U(b);while(1){if((b|0)==(d|0)){e:{b=c+800|0;c=cC(b);while(1){if((b|0)==(c|0)){break e}_U(b);b=b+32|0;continue}}}else{_U(b);b=b+32|0;continue}break}c=x[a+1074308>>2];break a}d=d+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break f}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;e=0;b=1;while(1){if((b|0)==(f|0)){if(!(e&1)){break f}Lb(h,3,1);c=x[a+1074308>>2]}else{d=x[((b<<2)+a|0)+900380>>2];if(!(!d|!y[d+31|0])){v[d+33|0]=13;e=1}b=b+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break g}Kb(g+12|0,h,0);if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){Kb(g+24|0,h,1);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break g}}b=z[a+480192>>1]+1&65535;d=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(d|0)){break g}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}h:{if(A[a+1074308>>2]>19007232){break h}b=a+906300|0;f=Dj(b);while(1){if((b|0)==(f|0)){break h}d=g+12|0;c=fb-32|0;fb=c;e=c+8|0;i=b+80|0;OR(e,i);x[31721]=0;S(126,c+20|0,22,e|0);e=x[31721];x[31721]=0;i:{j:{k:{if((e|0)!=1){x[31721]=0;S(247,d|0,0,c+20|0);e=x[31721];x[31721]=0;if((e|0)==1){break k}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break i}a=N()|0;break j}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}bw(i,d);b=b+160|0;tb(d);continue}}l:{m:{n:{o:{p:{q:{if(x[a+480180>>2]!=4){break q}d=x[a+1074308>>2];if(d>>>0<19007257){break o}if(d>>>0>19071235){break p}if(y[a+1074368|0]!=4){break q}CA(a,5)}d=x[a+1074308>>2]}if(d>>>0>19202054){break n}c=19202048;if((d|0)==19202048){break m}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;c=1;while(1){if((c|0)==(e|0)){break n}f=x[((c<<2)+a|0)+900380>>2];r:{if(!f|!y[f+20|0]|!y[f+31|0]){break r}b=f+236|0;i=gr(b);while(1){if((b|0)!=(i|0)){k=z[b>>1];b=b+2|0;if(!k){continue}break r}break}v[f+20|0]=0}c=c+1|0;continue}}c=d;if(c>>>0>19267583){break l}}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(f|0)){break l}d=x[((b<<2)+a|0)+900380>>2];s:{if(!d){break s}c=v[d+26|0];v[d+26|0]=((c>>31|1)+c|0)/2;c=x[a+1074308>>2];if(c>>>0>18350079&m){break s}v[d+19|0]=y[d+19|0]+3>>>2}b=b+1|0;continue}}t:{if(c>>>0>19398673){break t}d=z[a+480192>>1];b=1;while(1){f=b&65535;if(f>>>0>d>>>0){break t}f=x[((f<<2)+a|0)+900380>>2];if(!f|y[f+65|0]==255){b=b+1|0;continue}else{Lb(h,94,1);c=x[a+1074308>>2]}break}}u:{if(c>>>0>19399427){break u}d=z[a+480192>>1];b=1;while(1){f=b&65535;if(f>>>0>d>>>0){break u}f=x[((f<<2)+a|0)+900380>>2];if(!f|y[f+36|0]>1){b=b+1|0;continue}else{Lb(h,101,1);c=x[a+1074308>>2]}break}}v:{if(c>>>0>19923027){break v}d=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break v}c=D(c,104)+a|0;if(!ge(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Lb(h,116,1)}break}}b=fb-16|0;fb=b;w[g+4>>1]=0;x[g>>2]=a;Kb(b+8|0,a+1074312|0,0);I=g,J=Hb(x[x[b+8>>2]>>2],x[b+12>>2]),v[I+6|0]=J;fb=b+16|0;b=x[g>>2];t=x[g+4>>2];f=fb-32|0;fb=f;c=a+484344|0;e=wb(x[c>>2]);x[f+28>>2]=e;C=wb(x[c+4>>2]);while(1){if(Ib(e,C)){c=wb(x[e>>2]);F=wb(x[e+4>>2]);x[f+16>>2]=b;x[f+20>>2]=t;x[f>>2]=b;x[f+4>>2]=t;o=fb-16|0;fb=o;x[o+12>>2]=c;while(1){if(Ib(c,F)){s=z[f+4>>1];d=s+1|0;w[f+4>>1]=d;e=x[f>>2];w[f+4>>1]=z[e+480188>>1]>(d&65535)>>>0?d:0;w:{if(Sg(y[c|0])){break w}i=x[e+1074308>>2];x:{k=x[e+480180>>2];y:{z:{if((k|0)==2){if(i>>>0>18415615){break z}if(y[c+3|0]!=23){break y}Jf(c+5|0,64);break y}A:{if(k&16777248){B:{C:{if(i>>>0>=18285314){if(y[f+6|0]){break C}d=0;e=0;if(i>>>0>18874367){break B}}D:{switch(y[c+3|0]-20|0){case 3:Jf(c+5|0,128);break C;case 0:break D;default:break C}}d=y[c+5|0];if((d|0)!=208){if((d|0)!=192){break C}v[c|0]=254;v[c+3|0]=0;break C}v[c+3|0]=0}E:{F:{G:{if(i>>>0>=18350080){if(y[f+6|0]){break G}d=0;e=0;if(i>>>0>18874367){break B}}e=y[c+3|0];if(e>>>0>29){break F}d=1;if(!(1<<e&536873152)){break F}break E}d=0;e=0;if(i>>>0>18874367){break B}e=y[c+3|0]}d=0}e=(e|0)==24|(e|0)==22}H:{if(!(d|e)){break H}e=y[c+5|0];d=e&15;if(!d|(d|0)==15){break H}e=e&240;if(!e|(e|0)==240){break H}v[c+5|0]=y[c+3|0]==24?e:d}I:{if((i|0)==19005440|i>>>0>19005699){break I}d=z[x[f>>2]+480192>>1];if(y[f+6|0]|(!d|d>>>0>=y[c+1|0])){break I}v[c+4|0]=0;v[c+2|0]=1}if(y[c+3|0]!=18|y[c+5|0]!=17){break z}if(i>>>0>19468801){break x}if(!Ob(x[f>>2]+1074312|0,22)|y[x[f>>2]+480208|0]&4){break z}d=c+5|0;break A}if((k|0)!=4){break z}d=!y[f+6|0];J:{if((d|i>>>0<18285314)&i>>>0<=18874367){break J}if(i>>>0>19137025){break x}if(y[c+3|0]!=23|y[c+5|0]<65){break J}v[c+3|0]=0}K:{L:{M:{if(!(!(d&i>>>0<18874368)&i>>>0>=18415616)){d=y[c+3|0];e=y[c+2|0];if((d|0)!=10|(e|0)!=11){break M}d=0;v[c+3|0]=0;break K}if(i>>>0>18874639){break L}d=y[c+3|0];e=y[c+2|0]}if((e|0)!=11|(d|0)!=4){break K}e=y[c+4|0];if(!(e|y[f+6|0])){d=4;break K}d=4;n=y[c+5|0];if(!n){break K}v[c+2|0]=0;I=c,J=Qv(n+(e<<4)|0),v[I+5|0]=J;break K}if(i>>>0>19007240){break x}d=y[c+3|0]}if(y[c+5|0]|(d|0)!=16){break z}d=c+3|0}v[d|0]=0}if(i>>>0>18874367){break x}}d=y[c+3|0];e=y[c+5|0]&240;N:{O:{if((d|0)!=28|(e|0)!=96){n=0}else{if(!y[f+6|0]|(k|0)!=4){break O}n=i>>>0<18350080}if(!(n|(d|0)==20&(e|0)==96)){break N}}d=D(s,-6)+c|0;while(1){if(c>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}d=y[c+3|0]}if((d|0)!=20|(e|0)!=224){break x}d=D(s,-6)+c|0;while(1){if(c>>>0<=d>>>0){break x}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=y[c+2|0];if(!((d|0)!=8|i>>>0>19333174|(i|0)==19333120)){e=y[c+4|0];d=y[c+3|0];if(!(!e|(d|0)!=7)){v[c+3|0]=11;break w}P:{Q:{switch(d-5|0){default:if((d|0)!=26){break w}break;case 1:break w;case 2:break P;case 0:break Q}}i=y[c+5|0];if(!(i&15)){v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=i|e&15;break w}R:{switch(d-5|0){case 1:break w;case 0:case 2:break P;default:break R}}if((d|0)!=26){break w}}v[c+2|0]=0;break w}S:{if(!((k|0)==16777216|(d|0)!=15)){d=y[c+3|0];if(d){break S}v[c+2|0]=0;v[c+3|0]=10;v[c+5|0]=y[c+4|0]<<3;break w}if((d|0)!=15){break w}d=y[c+3|0]}if((d&255)!=10|i>>>0>19922963){break w}if(y[c+4|0]?y[c+5|0]:1){v[c+2|0]=0;break w}v[c+3|0]=0}c=x[qg(o+12|0)>>2];continue}break}c=x[f+4>>2];x[f+8>>2]=x[f>>2];x[f+12>>2]=c;fb=o+16|0;e=x[kn(f+28|0)>>2];continue}else{fb=f+32|0}break}T:{b=A[a+1074308>>2]<19267584;if(b&m){b=40288;while(1){if((b|0)==40632){break T}c=x[a+1074308>>2];d=x[b+4>>2];Lb(h,x[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(b&((B|0)==4&u))){break T}b=40640;while(1){if((b|0)==40880){break T}Lb(h,x[b>>2],A[a+1074308>>2]>=A[b+4>>2]);b=b+8|0;continue}}U:{V:{c=x[a+480180>>2];if(c&16777248){b=40880;while(1){if((b|0)==40952){break V}c=x[a+1074308>>2];d=x[b+4>>2];f=d&-65536;if(!(c>>>0>=f>>>0&(c>>>0<=f>>>0|c>>>0>=d>>>0))){Zf(h,x[b>>2])}b=b+8|0;continue}}b=41024;d=40960;W:{switch(c-2|0){case 2:while(1){if((d|0)==41024){break V}if(A[a+1074308>>2]<A[d+4>>2]){Zf(h,x[d>>2])}d=d+8|0;continue};case 0:break W;default:break U}}while(1){if((b|0)==41120){break V}if(A[a+1074308>>2]<A[b+4>>2]){Zf(h,x[b>>2])}b=b+8|0;continue}}c=x[a+480180>>2]}X:{if((c|0)==4){b=x[a+1074308>>2];if(b>>>0>18415615){break X}Lb(h,98,1)}b=x[a+1074308>>2]}d=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Kb(g+12|0,h,c);Zf(Lb(h,b+86|0,Hb(x[x[g+12>>2]>>2],x[g+16>>2])),c);b=b+1|0;continue}break}b=x[a+1074308>>2]}Y:{if(b>>>0>=18284544){if(b>>>0>18874627){break Y}d=6;if((b|0)==18874368){break Y}}Lb(h,d,1)}b=x[a+1074308>>2];Z:{if(y[a+480208|0]&16){if(b>>>0<=19136511){Zf(h,7);break Z}if(!(x[a+480180>>2]&16777248)|b>>>0>19267583){break Z}Lb(h,7,1);break Z}if((b|0)==19922944|b>>>0>19922997){break Z}Zf(h,7)}Kb(g+12|0,h,31);_:{if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){break _}b=x[a+1074308>>2];if(b>>>0<19071234|b>>>0>19398722){break _}d=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break _}$:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break $}f=y[c+65|0];if(!(y[c+60|0]&4)|(f|0)==255|f>>>0<=y[c- -64|0]){break $}Lb(h,97,1);break _}b=b+1|0;continue}}c=x[a+480180>>2];aa:{if(!(c&16777218)){break aa}d=z[a+480190>>1];b=1;while(1){f=b&65535;if(f>>>0>d>>>0){break aa}b=b+1|0;if(!(y[(D(f,104)+a|0)+484415|0]&2)){continue}break}ba:{ca:{da:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[a+1074308>>2];if(b>>>0<19398688){break ca}if(b>>>0>19464277){break da}Lb(h,109,1)}b=x[a+1074308>>2]}if((b|0)==19922944|b>>>0>19922996){break ba}}Zf(h,111);b=x[a+1074308>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Lb(h,108,1);break aa}if((c|0)==2){break aa}Zf(h,108)}e=x[a+1074308>>2];ea:{fa:{if(e>>>0<19333186){break fa}if(e>>>0<=19923013){if(!(x[a+480180>>2]&16777252)){break fa}b=a+906300|0;c=Dj(b);while(1){if((b|0)!=(c|0)){ga:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break ga}if((Rc(x[b+4>>2],x[b+8>>2])|0)!=32){break ga}d=Cc(g+12|0,16857);bw(b+80|0,d);tb(d)}b=b+160|0;continue}break}e=x[a+1074308>>2]}if(e>>>0>19988488){break ea}}if(!(x[a+480180>>2]&16777252)){break ea}b=a+906300|0;d=Dj(b);while(1){if((b|0)==(d|0)){break ea}c=b;b=b+160|0;if(!Pi(x[c+16>>2],x[c+20>>2])){continue}break}Lb(h,117,1);e=x[a+1074308>>2]}ha:{if(!(x[a+480180>>2]&16777252)|e-19333120>>>0>591359){break ha}a=a+906300|0;d=Dj(a);while(1){if((a|0)==(d|0)){break ha}ia:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break ia}b=x[a+4>>2];if((Rc(b,x[a+8>>2])|0)!=24){break ia}G=Ld(E(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));H=Ld(E(E(E((l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(G),j(2));v[b+12|0]=c;v[b+13|0]=c>>>8;v[b+14|0]=c>>>16;v[b+15|0]=c>>>24;b=x[a+4>>2];c=(q(H),j(2));v[b+16|0]=c;v[b+17|0]=c>>>8;v[b+18|0]=c>>>16;v[b+19|0]=c>>>24}a=a+160|0;continue}}fb=g+32|0}function oP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-32|0;fb=g;a:{b:{c:{d:{e:{f:{if(ke(b,22250)){Fb(a);break f}if(ke(b,9893)){b=fb-96|0;fb=b;f=Fb(a);x[31721]=0;W(131,b- -64|0);a=x[31721];x[31721]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31721]=0;x[b+40>>2]=0;O(1125,b+52|0,b+40|0);a=x[31721];x[31721]=0;if((a|0)==1){break C}x[31721]=0;a=P(844,f|0,b+52|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break B}tb(b+52|0);x[31721]=0;a=P(993,a|0,16776)|0;c=x[31721];x[31721]=0;if((c|0)==1){break A}x[31721]=0;x[b+40>>2]=7;O(1125,b+52|0,b+40|0);c=x[31721];x[31721]=0;if((c|0)==1){break z}x[31721]=0;a=P(844,a|0,b+52|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break y}tb(b+52|0);x[31721]=0;a=P(993,a|0,16776)|0;c=x[31721];x[31721]=0;if((c|0)==1){break A}x[31721]=0;x[b+40>>2]=2;O(1125,b+52|0,b+40|0);c=x[31721];x[31721]=0;if((c|0)==1){break x}x[31721]=0;a=P(844,a|0,b+52|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break w}tb(b+52|0);x[31721]=0;a=P(993,a|0,15678)|0;c=x[31721];x[31721]=0;if((c|0)==1){break A}c=Nb(b+52|0);d=x[b+76>>2];if(d){x[31721]=0;x[b+16>>2]=d;O(1125,b+28|0,b+16|0);d=x[31721];x[31721]=0;if((d|0)==1){break v}x[31721]=0;S(1019,b+40|0,8964,b+28|0);d=x[31721];x[31721]=0;if((d|0)==1){break u}x[31721]=0;O(181,c|0,b+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break t}tb(b+40|0);tb(b+28|0)}if(!Bd(y[b+80|0])){break p}x[31721]=0;d=P(37,b+40|0,12838)|0;e=x[31721];x[31721]=0;if((e|0)==1){break r}x[31721]=0;O(181,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break q}tb(d);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(d);break j}if(!Bd(y[b+81|0])){break o}x[31721]=0;d=P(37,b+40|0,12609)|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}x[31721]=0;O(181,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break m}tb(d)}if(Bd(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(d);break j}x[31721]=0;d=P(37,b+28|0,11128)|0;e=x[31721];x[31721]=0;D:{if((e|0)!=1){x[31721]=0;O(181,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break D}tb(d);break k}a=N()|0;break j}a=N()|0;tb(d);break j}if(kc(x[c>>2],x[c+4>>2])){break g}x[31721]=0;a=P(993,a|0,16806)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;d=P(37,b+4|0,16776)|0;e=x[31721];x[31721]=0;E:{F:{G:{if((e|0)!=1){x[31721]=0;S(1126,b+16|0,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break G}x[31721]=0;P(844,a|0,b+16|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break F}tb(b+16|0);tb(d);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(d);break j}a=N()|0}Qd(c)}ug(b- -64|0)}tb(f);break a}Qd(c);ug(b- -64|0);fb=b+96|0;break f}if(ke(b,8132)){x[g>>2]=0;Pq(a,g);break f}if(ke(b,8110)){x[g>>2]=7;Pq(a,g);break f}if(ke(b,10853)){x[g>>2]=2;Pq(a,g);break f}if(ke(b,10625)){Cc(a,15678);break f}if(ke(b,11403)){Cc(a,15839);break f}if(ke(b,7412)){b=fb-48|0;fb=b;wG(b+24|0);x[31721]=0;W(148,b+12|0);c=x[31721];x[31721]=0;H:{I:{J:{K:{if((c|0)!=1){x[31721]=0;S(149,b+36|0,b+24|0,b+12|0);c=x[31721];x[31721]=0;if((c|0)==1){break K}x[31721]=0;O(1067,a|0,b+36|0);a=x[31721];x[31721]=0;if((a|0)==1){break J}tb(b+36|0);tb(b+12|0);tb(b+24|0);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(ke(b,9909)){b=fb-16|0;fb=b;e=fb-16|0;fb=e;x[e+12>>2]=101;i=b+4|0;c=fb-96|0;fb=c;f=Nb(c+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{d=x[e+12>>2];if(d&1){x[31721]=0;O(137,c+52|0,19988993);d=x[31721];x[31721]=0;if((d|0)==1){break _}x[31721]=0;O(104,f|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break Z}tb(c+52|0);d=x[e+12>>2]}if(!(d&4)){break X}x[31721]=0;d=ca(138)|0;h=x[31721];x[31721]=0;if((h|0)==1){break W}if(!d){break Y}break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}x[31721]=0;W(139,c+52|0);d=x[31721];x[31721]=0;$:{if((d|0)!=1){x[31721]=0;O(104,f|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break $}tb(c+52|0);break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}aa:{d=x[e+12>>2];if(!(d&32)){break aa}x[31721]=0;W(131,c+52|0);d=x[31721];x[31721]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((d|0)!=1){x[31721]=0;O(140,c+40|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break ca}d=zd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31721]=0;W(141,c+28|0);d=x[31721];x[31721]=0;if((d|0)==1){break ta}x[31721]=0;O(140,c+16|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break sa}x[31721]=0;S(142,c+40|0,c+28|0,c+16|0);d=x[31721];x[31721]=0;if((d|0)==1){break ra}x[31721]=0;O(104,f|0,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break qa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}d=Cp(c+52|0);if(!zd(x[d+4>>2],y[d+11|0])){x[31721]=0;W(143,c+28|0);h=x[31721];x[31721]=0;if((h|0)==1){break na}x[31721]=0;S(144,c+40|0,c+28|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break ma}x[31721]=0;O(104,f|0,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break la}tb(c+40|0);Eb(c+28|0)}x[31721]=0;O(145,c+40|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break ja}d=zd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31721]=0;W(141,c+28|0);d=x[31721];x[31721]=0;if((d|0)==1){break ia}x[31721]=0;O(145,c+16|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break ha}x[31721]=0;S(142,c+40|0,c+28|0,c+16|0);d=x[31721];x[31721]=0;if((d|0)==1){break ga}x[31721]=0;O(104,f|0,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break fa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}ug(c+52|0);d=x[e+12>>2];break aa}d=N()|0;break M}d=N()|0;break ba}d=N()|0;break oa}d=N()|0;break pa}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ka}d=N()|0;tb(c+40|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ba}d=N()|0;break da}d=N()|0;break ea}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0}ug(c+52|0);break M}ua:{if(!(d&64)){break ua}x[31721]=0;d=ca(138)|0;h=x[31721];x[31721]=0;if((h|0)==1){break W}if(d){break ua}d=c+52|0;Fb(d);x[31721]=0;O(104,f|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break N}tb(c+52|0)}if(y[e+12|0]&128){x[31721]=0;W(146,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break V}x[31721]=0;O(104,f|0,c+52|0);d=x[31721];x[31721]=0;if((d|0)==1){break U}tb(c+52|0)}x[31721]=0;h=P(1,c+52|0,22250)|0;d=x[31721];x[31721]=0;if((d|0)==1){break T}x[31721]=0;S(147,c+4|0,f|0,h|0);d=x[31721];x[31721]=0;if((d|0)==1){break S}x[31721]=0;W(148,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break R}x[31721]=0;S(149,i|0,c+4|0,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break Q}tb(c+40|0);tb(c+4|0);tb(h);Qd(f);fb=c+96|0;break L}d=N()|0;break M}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}d=N()|0;break M}d=N()|0;break O}d=N()|0;break P}d=N()|0;tb(c+40|0)}tb(c+4|0)}tb(h);break M}d=N()|0;tb(c+52|0)}Qd(f);Q(d|0);p()}fb=e+16|0;x[31721]=0;O(1067,a|0,i|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10525)){b=fb-48|0;fb=b;c=b+4|0;gs(c);x[31721]=0;O(140,b+36|0,c|0);c=x[31721];x[31721]=0;va:{wa:{if((c|0)!=1){x[31721]=0;O(1067,a|0,b+36|0);a=x[31721];x[31721]=0;if((a|0)==1){break wa}tb(b+36|0);ug(b+4|0);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}ug(b+4|0);break a}if(ke(b,11366)){b=fb-32|0;fb=b;gs(b);x[31721]=0;O(1127,a|0,Cp(b)|0);a=x[31721];x[31721]=0;if((a|0)!=1){ug(b);fb=b+32|0;break f}a=N()|0;ug(b);break a}if(ke(b,9922)){b=fb-48|0;fb=b;gs(b+16|0);c=x[b+28>>2];xa:{if(c){x[31721]=0;x[b+12>>2]=c;O(1125,a|0,b+12|0);a=x[31721];x[31721]=0;if((a|0)!=1){break xa}a=N()|0;ug(b+16|0);break a}Fb(a)}ug(b+16|0);fb=b+48|0;break f}if(ke(b,12828)){gs(g);b=y[g+16|0];x[31721]=0;P(37,a|0,(Bd(b)?15523:15839)|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break e}ug(g);break f}if(ke(b,9938)){gs(g);b=y[g+17|0];x[31721]=0;P(37,a|0,(Bd(b)?15523:15839)|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){ug(g);break f}break e}if(ke(b,12281)){gs(g);b=y[g+18|0];x[31721]=0;P(37,a|0,(Bd(b)?15523:15839)|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){ug(g);break f}break e}if(ke(b,12583)){b=fb-16|0;fb=b;c=fb-32|0;fb=c;f=b+4|0;d=Fb(f);x[31721]=0;W(131,c|0);e=x[31721];x[31721]=0;ya:{za:{if((e|0)!=1){x[31721]=0;O(132,d|0,Cp(c)|0);e=x[31721];x[31721]=0;if((e|0)==1){break za}ug(c);fb=c+32|0;break ya}a=N()|0;break b}a=N()|0;ug(c);break b}x[31721]=0;O(1067,a|0,f|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,8253)){b=fb-16|0;fb=b;c=fb-48|0;fb=c;f=b+4|0;d=Fb(f);x[31721]=0;O(134,c+24|0,4135);e=x[31721];x[31721]=0;Aa:{Ba:{Ca:{Da:{if((e|0)!=1){x[c+20>>2]=17;x[c+16>>2]=0;x[31721]=0;x[c+12>>2]=0;aa(135,c+36|0,c+24|0,c+20|0,c+16|0,c+12|0);e=x[31721];x[31721]=0;if((e|0)==1){break Da}x[31721]=0;P(77,d|0,c+36|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Ca}tb(c+36|0);Eb(c+24|0);fb=c+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(c+36|0)}Eb(c+24|0);break b}x[31721]=0;O(1067,a|0,f|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,6857)){b=fb-16|0;fb=b;d=b+4|0;c=fb-32|0;fb=c;f=c+8|0;Cc(f,20185);x[31721]=0;S(126,c+20|0,0,f|0);f=x[31721];x[31721]=0;Ea:{Fa:{Ga:{if((f|0)!=1){x[31721]=0;O(12,d|0,c+20|0);f=x[31721];x[31721]=0;if((f|0)==1){break Ga}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Rb(c+20|0)}tb(c+8|0);break a}x[31721]=0;O(1067,a|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,6455)){b=fb-48|0;fb=b;c=rc(b+24|0,18269);x[31721]=0;O(1128,b+12|0,2);d=x[31721];x[31721]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){x[31721]=0;S(2,b+36|0,c|0,b+12|0);d=x[31721];x[31721]=0;if((d|0)==1){break Ka}x[31721]=0;O(1067,a|0,b+36|0);a=x[31721];x[31721]=0;if((a|0)==1){break Ja}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(c);break a}if(ke(b,11389)){b=fb-16|0;fb=b;c=fb-16|0;fb=c;Cc(c+4|0,18585);e=b+4|0;f=Fb(e);h=y[c+15|0];i=x[c+8>>2];x[31721]=0;O(96,f|0,vh(i,h)|0);h=x[31721];x[31721]=0;La:{if((h|0)!=1){Ma:{while(1){if(vh(x[c+8>>2],y[c+15|0])>>>0>d>>>0){h=y[bc(c+4|0,d)|0];x[31721]=0;O(98,f|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break Ma}d=d+1|0;continue}break}tb(c+4|0);fb=c+16|0;break La}}a=N()|0;tb(f);tb(c+4|0);break a}x[31721]=0;O(1067,a|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10532)){b=fb-16|0;fb=b;c=b+4|0;cs(c,0);x[31721]=0;O(1067,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10507)){b=fb-16|0;fb=b;c=b+4|0;cs(c,2);x[31721]=0;O(1067,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10492)){b=fb-16|0;fb=b;c=b+4|0;cs(c,3);x[31721]=0;O(1067,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}Fb(a)}fb=g+32|0;break d}a=N()|0;ug(g);break a}return}a=N()|0;tb(b+4|0);break a}tb(d)}Q(a|0);p()}function pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=fb-416|0;fb=e;vc(b);f=e+399|0;g=e0(b,f);if(!g){lE(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!B_(e+399|0)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}if(!c){d=1;break f}Ad(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;j=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=j;g:{h:{i:{while(1){if((j&65535)>>>0<=d>>>0){j:{Tb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){rE(b,a+1298308|0);C_(e+312|0,b);o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31721]=0;f=U(329,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[31721];x[31721]=0;if((g|0)==1){break k}if(!f){break j}le(e+272|0,x[d>>2],x[d+4>>2]);f=Jd(e+264|0);x[31721]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=eg(330,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[31721];x[31721]=0;if((g|0)==1){break o}g=x[d+4>>2];j=x[d>>2];x[31721]=0;U(216,f|0,o|0,Rc(j,g)>>>1|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break n}ub(f);cc(d)}m=Nb(e+252|0);x[31721]=0;O(331,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31721];x[31721]=0;if((d|0)==1){break i}d=0;while(1){f=d&65535;d=y[e+411|0]|y[e+412|0]<<8;if(f>>>0>=d>>>0){break l}x[e+212>>2]=d-f;x[e+160>>2]=2e3;d=e+212|0;g=x[qd(d,e+160|0)>>2];d=Nb(d);x[31721]=0;g=U(329,b|0,d|0,g<<8)|0;j=x[31721];x[31721]=0;if((j|0)==1){break d}if(!g){break m}g=zb(e+248|0,wb(x[m+4>>2]));j=wb(x[d>>2]);i=wb(x[e+216>>2]);g=x[g>>2];x[31721]=0;V(332,m|0,g|0,j|0,i|0);g=x[31721];x[31721]=0;if((g|0)==1){break d}cc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;kd(g,1);h=f+(e+320|0)|0;f=Xd(b);v[h|0]=f;if(f<<24>>24>=0){C=g,E=y_(b)<<1,x[C>>2]=E}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}cc(d);d=0;break h}le(e+232|0,x[m>>2],x[m+4>>2]);jf(e+240|0,x[e+232>>2],x[e+236>>2]);q=a+484376|0;d=y[q|0];f=x[a+484360>>2];x[31721]=0;O(333,Wb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31721];x[31721]=0;if((d|0)==1){break e}r=a+484344|0;t=c&1;i=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=i>>>0){g=c&2;j=1;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{while(1){c=j&65535;if(c>>>0>z[a+480190>>1]){break w}x[31721]=0;d=y[c+(e+320|0)|0];S(334,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[31721];x[31721]=0;if((f|0)==1){break u}B:{C:{if(d<<24>>24<0){break C}x[31721]=0;d=R(335,b|0)|0;f=x[31721];x[31721]=0;D:{E:{F:{G:{H:{I:{J:{K:{if((f|0)==1){break K}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[31721]=0;d=R(335,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break J}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[31721]=0;d=R(200,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break t}v[e+80|0]=d;v[e+180|0]=64;C=c+484410|0,E=y[Sb(e+80|0,e+180|0)|0]<<2,w[C>>1]=E;x[31721]=0;d=R(200,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break K}v[c+484417|0]=d<<4;c=c+484380|0;_o(c);if(!x[c>>2]){break C}x[31721]=0;f=R(200,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break E}d=0;switch(f|0){case 4:case 5:break D;case 2:case 3:break G;case 1:break H;case 0:break I;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+80|0);i=x[b+8>>2];h=x[b>>2];k=x[c>>2];x[31721]=0;i=U(153,h|0,i|0,k|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break s}if(!i){break x}d=x[c>>2];x[31721]=0;S(336,b|0,f|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break s}C=e,E=wb(x[f>>2]),x[C+180>>2]=E;i=wb(x[e+84>>2]);while(1){d=x[e+180>>2];if(Ib(d,i)){h=d;d=y[d|0];v[h|0]=d<<7|(d^-1)>>>1&127;je(e+180|0);continue}break}le(e+200|0,x[f>>2],x[e+84>>2]);d=Jd(e+192|0);x[31721]=0;i=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=i;d=eg(330,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);i=x[31721];x[31721]=0;L:{if((i|0)!=1){i=Wc(e+180|0,16,1,0,16);x[31721]=0;U(218,i|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break L}ub(d);cc(f);break C}a=N()|0;break p}a=N()|0;ub(d);break p}c=x[c>>2];break F}f=Nb(e+80|0);d=x[c>>2];x[31721]=0;S(337,e+180|0,b|0,d|0);d=x[31721];x[31721]=0;M:{N:{O:{if((d|0)!=1){d=e+180|0;i=rn(f,d);cc(d);if(g){le(e+152|0,x[i>>2],x[e+84>>2]);d=Jd(e+144|0);x[31721]=0;h=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=h;d=eg(330,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);h=x[31721];x[31721]=0;if((h|0)==1){break O}h=Wc(e+180|0,8,1,0,2);x[31721]=0;U(218,h|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break N}ub(d)}cc(i);break C}a=T(28832)|0;if((gb|0)!=($(28832)|0)){break M}Y(a|0)|0;d=0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){break v}a=N()|0;break M}a=N()|0;break M}a=N()|0;ub(d)}cc(f);break c}if(g){d=Wc(e+80|0,(f|0)==2?8:16,1,0,0);x[31721]=0;U(218,d|0,c|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break C}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[31721]=0;P(186,b|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break C}}a=N()|0;break c}i=Nb(e+80|0);d=x[c>>2];x[31721]=0;S(338,e+180|0,b|0,d|0);d=x[31721];x[31721]=0;P:{Q:{if((d|0)!=1){h=e+180|0;d=rn(i,h);cc(h);if(!g){break P}if((f|0)!=5){break Q}C=e,E=wb(x[d>>2]),x[C+180>>2]=E;k=wb(x[e+84>>2]);while(1){h=x[e+180>>2];if(!Ib(h,k)){break Q}l=h;h=y[h|0];v[l|0]=y[(h>>>7|0)+24705|0]^h;je(e+180|0);continue}}a=T(28832)|0;if((gb|0)!=($(28832)|0)){break y}Y(a|0)|0;d=0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){break B}a=N()|0;break y}le(e+112|0,x[d>>2],x[e+84>>2]);h=Jd(e+104|0);x[31721]=0;k=x[h+4>>2];x[e+32>>2]=x[h>>2];x[e+36>>2]=k;h=eg(330,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);k=x[31721];x[31721]=0;if((k|0)==1){break A}f=(f|0)==5;f=Wc(e+180|0,f?16:8,1,0,f?16:1);x[31721]=0;U(218,f|0,c|0,h|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break z}ub(h)}cc(d)}j=j+1|0;continue}break}cc(i);break h}a=N()|0;break y}a=N()|0;ub(h)}cc(i);break c}cc(f);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=y[vb(e+80|0,d)|0];C=vb(e+180|0,d),E=c,v[C|0]=E;d=d+1|0;continue}break}R:{S:{T:{U:{d=$f(e+180|0);if(d){c=Nb(e+180|0);x[31721]=0;b=U(329,b|0,c|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break r}if(!b){break S}le(e+72|0,x[c>>2],x[c+4>>2]);b=Jd(e- -64|0);x[31721]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=eg(330,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31721];x[31721]=0;if((f|0)==1){break U}x[31721]=0;V(339,a+1298332|0,b|0,d|0,1);d=x[31721];x[31721]=0;if((d|0)==1){break T}ub(b);cc(c)}x[31721]=0;W(340,e+52|0);b=x[31721];x[31721]=0;if((b|0)!=1){break R}a=N()|0;break c}a=N()|0;break q}a=N()|0;ub(b);break q}cc(c);d=0;break h}x[31721]=0;S(341,e+180|0,e+52|0,y[e+407|0]);b=x[31721];x[31721]=0;V:{W:{if((b|0)!=1){b=e+180|0;yb(a+1298344|0,b);tb(b);Eb(e+52|0);x[31721]=0;b=P(1,b|0,10096)|0;c=x[31721];x[31721]=0;if((c|0)==1){break W}yb(a+1298356|0,b);tb(b);x[31721]=0;b=P(1,e+52|0,5101)|0;c=x[31721];x[31721]=0;if((c|0)==1){break V}yb(a+1298368|0,b);tb(b);C=a+1298404|0,E=x[Ec(e+48|0,24)>>2],x[C>>2]=E;d=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}cc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break p}a=N()|0}cc(c);break c}cc(f);break c}C=Zb(x[Wb(x[a+484360>>2],y[q|0])>>2],i),E=i,w[C>>1]=E;X:{Y:{if(!t){break Y}x[31721]=0;s=i&65535;d=U(199,r|0,s|0,64)|0;f=x[31721];x[31721]=0;if((f|0)==1){break X}if(!d){break Y}f=z[a+480188>>1];h=0;while(1){d=f&65535;if(d>>>0<=h>>>0){break Y}d=Zb(x[o>>2],D(d,i)+h|0);d=y[d|0]|y[d+1|0]<<8;Z:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break Z}j=0;u=0-h|0;A=d<<8;d=Vb(x[r>>2],i);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,h&65535);while(1){if((j|0)==64){break Z}kr(e+212|0,x[e+240>>2],x[e+244>>2],(j<<2)+A|0,4);f=x[e+212>>2];g=vb(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;k=vb(f,1);v[d+1|0]=y[k|0]<<2&60|y[g|0]>>>6;l=y[k|0];g=vb(f,2);k=y[vb(f,3)|0];f=y[g|0];g=k<<4|f>>>4;w[e+80>>1]=g;B=l>>>6|0;l=f<<2&60;f=B|l;_:{if(!(y[vb(e+312|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|g)){break _}v[d+5|0]=g;l=k>>>4|0;v[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:xf(d,f&15,g&255);if(!y[d+4|0]){break _}v[d+2|0]=f>>>0<32?3:4;break _;case 9:v[d+3|0]=10;v[d+5|0]=g>>>1;if(g>>>0<512){break _}v[d+2|0]=15;v[d+4|0]=k>>>5;break _;case 10:case 42:if(g>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}xf(d,f,g&255);break _}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(g&240)>>>4;break _}v[d+2|0]=4;v[d+4|0]=g&15;break _}v[d+3|0]=(f|0)==11?12:16;C=d,E=Qv(g),v[C+5|0]=E;break _}v[d+3|0]=14;if((g&255)>>>0<64){break _}v[d+5|0]=0;break _}v[d+3|0]=19;v[d+5|0]=g&15|f<<4;break _}v[d+3|0]=19;w[e+160>>1]=15;C=d,E=y[Lc(e+80|0,e+160|0)|0]|f<<4,v[C+5|0]=E;break _}v[d+3|0]=19;if(g&255){v[d+5|0]=g&15|((f|0)==17?16:(f|0)==26?16:32);if(k>>>0<16){break _}v[d+2|0]=f>>>0>25?6:5;break _}v[d+5|0]=l|(f>>>0>25?-80:-96);break _}if(!g){break $}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=g+4;C=d,E=Zg(x[We(e+160|0,e+124|0)>>2]/8|0),v[C+5|0]=E;break _}v[d+3|0]=14;k=D(u,6)+d|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break _}g=k+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;C=g,E=Qv(s),v[C+5|0]=E}f=f+1|0;continue}}v[d+3|0]=9;f=g&7;if(f){v[d+5|0]=y[f+24697|0];break _}f=g>>>4|0;if((f|0)==128){break $}v[d+5|0]=f;if(g>>>0<=2047){v[d+5|0]=f^128;break _}v[d+5|0]=f^-1;break _}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break _}v[d+3|0]=25;break _}v[d+3|0]=0}j=j+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}h=h+1|0;continue}}i=i+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{ID(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;j=z[a+480188>>1];continue}break}cc(d);d=0;break g}a=N()|0;break c}cc(m)}ld(o)}fb=e+416|0;return d|0}a=N()|0;break c}a=N()|0;cc(d)}cc(m);break a}cc(d)}ld(o);Q(a|0);p()}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=ek(b,13869);if(!n){break a}o=a+480192|0;b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}g=Mg(b);if(!(!((g|0)==(zn(13719)|0)|!(g&1616928864)|g&-2139062144)&(g|0)!=70791730)){Dh(b,4);break a}l=1;c=dh(b);while(1){e=l&65535;if(e>>>0>z[o>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{f=0;if((zn(16760)|0)==(g|0)){Ub(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(g-1349079874|0){default:if((g|0)==1095062094){break t}if((g|0)==1095126087){break q}if((g|0)==1129524782){break z}if((g|0)==1145263150){break W}if((g|0)==1145979182){break V}if((g|0)==1179463214){break x}if((g|0)==1851469358){break D}if((g|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((g|0)!=1196830254){if((g|0)==1229341486){break S}if((g|0)==1229345326){break R}if((g|0)==1264266798){break E}if((g|0)==1296182830){break Q}if((g|0)==1296248366){break O}if((g|0)==1297100334){break P}if((g|0)==1297110852){break o}if((g|0)==1298747438){break B}if((g|0)==1313692462){break F}if((g|0)==1313751342){break X}if((g|0)==1345203758){break ha}if((g|0)==1346711086){break j}if((g|0)==1346720334){break u}if((g|0)==1346722606){break H}if((g|0)==1346784327){break r}if((g|0)==1347175726){break ba}if((g|0)==1347179310){break ca}if((g|0)==1347437358){break M}if((g|0)==1347441454){break N}if((g|0)==1347443502){break K}if((g|0)==1347628590){break U}if((g|0)==1347633710){break aa}if((g|0)==1347634478){break $}if((g|0)==1347703884){break m}if((g|0)==1347831112){break w}if((g|0)==1347833672){break v}if((g|0)==1349076270){break i}if((g|0)==1349076315){break G}if((g|0)==1349078085){break Z}if((g|0)==1349078099){break _}if((g|0)==1349079131){break J}if((g|0)==1378758190){break n}if((g|0)==1381183022){break y}if((g|0)==1447374382){break k}if((g|0)==1447383630){break s}if((g|0)==1447385902){break I}if((g|0)==1447447623){break p}if((g|0)==1447839022){break fa}if((g|0)==1447842606){break ga}if((g|0)==1448106798){break L}if((g|0)==1448226350){break A}if((g|0)==1448291886){break T}if((g|0)==1448297006){break ea}if((g|0)==1448297774){break da}if((g|0)!=1682320942){if((g|0)==1718508334){break C}if((g|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Aw(b,c),x[q>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+15|0]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Aw(b,c),x[q+4>>2]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Aw(b,c),x[q+8>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+61|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+62|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+63|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e- -64|0,r=Gd(b,c),v[q|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+81|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+82|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+83|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+84|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+101|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+102|0]=r;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+103|0]=r;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+104|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+16|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+17|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+18|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+19|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+20|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+21|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+22|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=mF(b,c),w[q+28>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+30|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+31|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=lF(b,c),v[q+26|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+27|0]=r;break e}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,0);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(195,i|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break h}d=x[j>>2];q=xb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,1);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(195,i|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[j>>2];q=xb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,2);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(195,i|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[j>>2];q=xb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,0);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(196,i|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[j>>2];q=xb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,1);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(196,i|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[j>>2];q=xb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);j=Wh(e,2);d=x[j>>2];while(1){if(Pd(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31721]=0;k=R(196,i|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[j>>2];q=xb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>128){break d}j=e+108|0;d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);while(1){if((f|0)==128){ub(i);break e}x[31721]=0;d=R(196,i|0)|0;k=x[31721];x[31721]=0;if((k|0)!=1){q=vb(j,f),r=d,v[q|0]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>256){break d}j=e+236|0;d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);while(1){if((f|0)==128){ub(i);break e}x[31721]=0;d=R(195,i|0)|0;k=x[31721];x[31721]=0;if((k|0)!=1){q=Zb(j,f),r=d,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>32){break d}j=e+492|0;d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);d=Fb(d);while(1){if((c|0)==(f|0)){break f}x[31721]=0;k=R(197,i|0)|0;m=x[31721];x[31721]=0;ia:{if((m|0)==1){break ia}x[31721]=0;P(198,d|0,k|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ia}f=f+1|0;continue}break}f=N()|0;tb(d);break g}if(c>>>0>32){break d}j=e+524|0;d=h+8|0;ce(d,b,c);i=hc(h+28|0,d);ub(d);d=Fb(d);ja:{while(1){if((c|0)!=(f|0)){x[31721]=0;k=R(197,i|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break ja}x[31721]=0;P(198,d|0,k|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break ja}f=f+1|0;continue}break}xc(j,d);tb(d);ub(i);break e}f=N()|0;tb(d);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+34|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=mF(b,c),w[q+12>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+23|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+24|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+25|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+35|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+36|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+105|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+85|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+65|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+100|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+80|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+60|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=lF(b,c),v[q+33|0]=r;break e}f=1;i=mp(b,c);if(!lp(i)){break d}v[e+14|0]=i;break d}q=e,r=D(yw(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[q+40>>2]=r;break e}d=(yw(b,c)>>>0)%1e4|0;f=x[e+40>>2];x[e+40>>2]=d+f-(f>>>0)%1e4;break e}x[h+28>>2]=240;q=h,r=mp(b,c),x[q+8>>2]=r;ch(e+48|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=mp(b,c),x[q+8>>2]=r;ch(e+68|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=mp(b,c),x[q+8>>2]=r;ch(e+88|0,x[Gb(h+28|0,h+8|0)>>2]);break e}f=N()|0}ub(i);Q(f|0);p()}xc(j,d);tb(d);ub(i)}f=1}fb=h+48|0;if(!f){Ub(b,c);break c}if((zn(16765)|0)==(g|0)){f=y[e+15|0];v[e+15|0]=0;v[e+100|0]=y[e+100|0]&224|(f>>>5&4|f>>>6&1);v[e+60|0]=f>>>1&2|(f<<1&4|(y[e+60|0]&240|f&1));v[e+80|0]=y[e+80|0]&240|(f>>>4&2|(f>>>2&4|f>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Ed(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[31597];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+126428|0;d=x[a+126436>>2];a=x[d+8>>2];o:{if((b|0)==(a|0)){m=126388,n=Cua(-2,c)&g,x[m>>2]=n;break o}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[31599];if(k>>>0>=h>>>0){break n}if(b){a=2<<c;a=(0-a|a)&b<<c;d=yua(0-a&a);a=d<<3;b=a+126428|0;e=x[a+126436>>2];a=x[e+8>>2];p:{if((b|0)==(a|0)){g=Cua(-2,d)&g;x[31597]=g;break p}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+126428|0;f=x[31602];a=1<<(k>>>3);q:{if(!(a&g)){x[31597]=a|g;a=b;break q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[31602]=c;x[31599]=d;break a}j=x[31598];if(!j){break n}c=x[(yua(0-j&j)<<2)+126692>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){r:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break r}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break m}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[31598];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+126692>>2];t:{u:{v:{if(!b){a=0;break v}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=b;f=e;if(e){break w}f=0;a=b;break u}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(yua(a&0-a)<<2)+126692>>2]}if(!a){break t}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31599]-h>>>0<=f>>>0){break n}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break l}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[31599];if(a>>>0>=h>>>0){d=x[31602];b=a-h|0;x:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break x}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[31599]=b;x[31602]=c;a=d+8|0;break a}i=x[31600];if(i>>>0>h>>>0){b=i-h|0;x[31600]=b;c=x[31603];a=c+h|0;x[31603]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[31715]){c=x[31717]}else{x[31718]=-1;x[31719]=-1;x[31716]=4096;x[31717]=4096;x[31715]=l+12&-16^1431655768;x[31720]=0;x[31708]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[31707];if(d){c=x[31705];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}y:{if(!(y[126832]&4)){z:{A:{B:{C:{d=x[31603];if(d){a=126836;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}c=Xo(0);if((c|0)==-1){break z}g=b;d=x[31716];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[31707];if(d){a=x[31705];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=Xo(g);if((c|0)!=(a|0)){break B}break y}g=f&e-i;c=Xo(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=c}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){c=a;break y}c=x[31717];c=c+(j-g|0)&0-c;if((Xo(c)|0)==-1){break z}g=c+g|0;c=a;break y}if((c|0)!=-1){break y}}x[31708]=x[31708]|4}c=Xo(b);a=Xo(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break i}g=a-c|0;if(g>>>0<=h+40>>>0){break i}}a=x[31705]+g|0;x[31705]=a;if(a>>>0>A[31706]){x[31706]=a}D:{e=x[31603];if(e){a=126836;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[31601];if(!(a>>>0<=c>>>0?a:0)){x[31601]=c}a=0;x[31710]=g;x[31709]=c;x[31605]=-1;x[31606]=x[31715];x[31712]=0;while(1){d=a<<3;b=d+126428|0;x[d+126436>>2]=b;x[d+126440>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31600]=b;a=a+c|0;x[31603]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31604]=x[31719];break j}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break k}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[31603]=c;b=x[31600]+g|0;a=b-a|0;x[31600]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[31604]=x[31719];break j}d=0;break b}c=0;break c}if(A[31601]>c>>>0){x[31601]=c}b=c+g|0;a=126836;E:{F:{G:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=126836;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[31603]=i;a=x[31600]+a|0;x[31600]=a;x[i+4>>2]=a|1;break d}if(x[31602]==(g|0)){x[31602]=i;a=x[31599]+a|0;x[31599]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=126388,n=x[31597]&Cua(-2,f>>>3|0),x[m>>2]=n;break f}x[b+12>>2]=c;x[c+8>>2]=b;break f}h=x[g+24>>2];c=x[g+12>>2];if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break g}b=g+20|0;f=x[b>>2];if(!f){f=x[g+16>>2];if(!f){break h}b=g+16|0}while(1){d=b;c=f;b=c+20|0;f=x[b>>2];if(f){continue}b=c+16|0;f=x[c+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31600]=b;a=a+c|0;x[31603]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31604]=x[31719];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[31712];x[d+16>>2]=x[31711];x[d+20>>2]=a;a=x[31710];x[d+8>>2]=x[31709];x[d+12>>2]=a;x[31711]=d+8;x[31710]=g;x[31709]=c;x[31712]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+126428|0;c=x[31597];a=1<<(f>>>3);H:{if(!(c&a)){x[31597]=a|c;a=b;break H}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126692|0;I:{d=x[31598];c=1<<a;J:{if(!(d&c)){x[31598]=c|d;x[b>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break I}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[31600];if(a>>>0<=h>>>0){break i}b=a-h|0;x[31600]=b;c=x[31603];a=c+h|0;x[31603]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[31596]=48;a=0;break a}c=0}if(!h){break f}d=x[g+28>>2];b=(d<<2)+126692|0;K:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break K}m=126392,n=x[31598]&Cua(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break f}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break f}x[c+20>>2]=b;x[b+24>>2]=c}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+126428|0;c=x[31597];a=1<<(a>>>3);L:{if(!(c&a)){x[31597]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+126692|0;M:{d=x[31598];c=1<<f;N:{if(!(d&c)){x[31598]=c|d;x[b>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break M}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}b=x[d+28>>2];a=(b<<2)+126692|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=Cua(-2,b)&j;x[31598]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+126428|0;c=x[31597];a=1<<(f>>>3);R:{if(!(c&a)){x[31597]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126692|0;S:{c=1<<a;T:{if(!(c&j)){x[31598]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+126692|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=126392,n=Cua(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+126428|0;e=x[31602];a=1<<(k>>>3);X:{if(!(a&g)){x[31597]=a|g;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[31602]=d;x[31599]=f}a=c+8|0}fb=l+16|0;return a}function wua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=fb-272|0;fb=e;vc(b);if(Dr(b,18426)){o=Fb(e+260|0);x[31721]=0;g=P(233,b|0,o|0)|0;d=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[31721]=0;g=P(248,b|0,e+253|0)|0;d=x[31721];x[31721]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!b0(y[e+253|0],y[e+254|0])){break a}i=Bc(a0(e+253|0),hb);g=x[b+8>>2];d=x[b>>2];x[31721]=0;g=U(153,d|0,g|0,i|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[31721]=0;O(249,a|0,4096);d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;O(250,a+1298308|0,o|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Uh(a,1);x[31721]=0;f=P(1,e+240|0,9476)|0;d=x[31721];x[31721]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){yb(a+1298344|0,f);tb(f);x[31721]=0;f=P(1,e+228|0,7105)|0;d=x[31721];x[31721]=0;if((d|0)==1){break p}yb(a+1298356|0,f);tb(f);x[31721]=0;W(251,e+32|0);d=x[31721];x[31721]=0;if((d|0)==1){break o}v[e+204|0]=y[e+254|0];x[31721]=0;v[e|0]=y[e+253|0];O(252,e+216|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break n}x[31721]=0;V(253,e+80|0,e+32|0,e+204|0,e+216|0);d=x[31721];x[31721]=0;if((d|0)==1){break m}d=e+80|0;yb(a+1298368|0,d);tb(d);tb(e+216|0);Eb(e+32|0);s=a+1298404|0,t=x[Ec(d,4)>>2],x[s>>2]=t;if(y[e+253|0]<2){break i}w[e+80>>1]=8192;x[31721]=0;f=R(192,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break k}w[e+32>>1]=f;s=a,t=D(z[oe(e+80|0,e+32|0)>>1],1e4)>>>8|0,x[s+480204>>2]=t;x[31721]=0;v[e+80|0]=1;f=R(200,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break j}v[e+32|0]=f;s=a,t=y[af(e+80|0,e+32|0)|0],x[s+480196>>2]=t;x[31721]=0;P(186,b|0,3)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;f=R(192,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break h}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break l}b=N()|0;tb(e+216|0)}Eb(e+32|0);break c}b=N()|0;break c}b=N()|0;break c}v[e+80|0]=32;x[31721]=0;f=R(200,b|0)|0;d=x[31721];x[31721]=0;q:{if((d|0)!=1){v[e+32|0]=f;s=a,t=D(y[af(e+80|0,e+32|0)|0],1e4),x[s+480204>>2]=t;x[31721]=0;v[e+80|0]=1;f=R(200,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break q}v[e+32|0]=f;s=a,t=y[af(e+80|0,e+32|0)|0],x[s+480196>>2]=t;x[31721]=0;f=R(200,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break h}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[a+480208>>2]=f>>>2&16|12;m=Nb(e+216|0);k=e+80|12;n=Nb(e+204|0);q=a+480190|0;r=1;while(1){r:{s:{d=r&65535;if(d>>>0>z[a+480192>>1]){break s}x[31721]=0;h=U(254,a|0,d|0,0)|0;d=x[31721];x[31721]=0;t:{if((d|0)==1){break t}if(!h){break s}x[31721]=0;f=P(243,b|0,h+492|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break t}if(!f){break s}x[31721]=0;l=R(200,b|0)|0;d=x[31721];x[31721]=0;u:{v:{w:{if((d|0)!=1){Tb(e+80|0,0,120);if(!l){break r}x:{if(y[e+253|0]){x[31721]=0;f=P(255,b|0,e+80|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+253|0]){break x}}d=fc(e+72|0,k,96);f=x[d>>2];d=x[d+4>>2];x[31721]=0;Sn(162,e+32|0,b,f,d);d=x[31721];x[31721]=0;if((d|0)==1){break v}if(!x[e+36>>2]){break r}}i=h+236|0;f=0;break u}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}while(1){if((f|0)!=120){g=z[q>>1];d=y[(e+80|0)+f|0];s=Zb(i,f),t=(d+g|0)+1|0,w[s>>1]=t;f=f+1|0;continue}break}x[31721]=0;f=h+48|0;S(256,e|0,f|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;j=h+68|0;S(256,e+16|0,j|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;i=h+88|0;S(256,e- -64|0,i|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;O(257,b|0,e+56|0);d=x[31721];x[31721]=0;if((d|0)==1){break f}x[h>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;gE(y[e+59|0]|y[e+60|0]<<8,f,0);gE(y[e+59|0]|y[e+60|0]<<8,j,1);gE(y[e+59|0]|y[e+60|0]<<8,i,2);s=e,t=wb(x[f>>2]),x[s+32>>2]=t;f=d>>>12|0;d=wb(x[h+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;s=g,t=y[Sb(e+28|0,e+54|0)|0],v[s+2|0]=t;Pe(e+32|0);continue}else{s=e,t=wb(x[j>>2]),x[s+32>>2]=t;d=wb(x[h+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;s=g,t=y[Sb(e+28|0,e+54|0)|0],v[s+2|0]=t;Pe(e+32|0);continue}break}s=e,t=wb(x[i>>2]),x[s+32>>2]=t;j=f&3;i=wb(x[h+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,i)){g=v[f+2|0];d=g>>31^-1;g=g^-128;h=j&31;if((j&63)>>>0>=32){d=g<<h;h=0}else{d=(1<<h)-1&g>>>32-h|d<<h;h=g<<h}y:{if((d|0)>=-1&h>>>0>=4294967292|(d|0)>=0){g=h+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break y}g=0-((h>>>0>3)+d|0)|0;d=3-h|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}s=f,t=Fc(d,g)^128,v[s+2|0]=t;Pe(e+32|0);continue}else{d=z[q>>1]+1|0;w[e+54>>1]=d;f=0;j=d&65535;d=4e3-j|0;i=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(l|0)){break A}if((f|0)==(i|0)){x[31721]=0;P(186,b|0,20)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break A}b=N()|0;break d}x[31721]=0;g=f+j|0;P(243,b|0,((g<<5)+a|0)+946304|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break z}x[31721]=0;O(258,b|0,e+32|0);d=x[31721];x[31721]=0;C:{if((d|0)==1){break C}x[31721]=0;O(259,e+32|0,(D(g,104)+a|0)+484380|0);d=x[31721];x[31721]=0;if((d|0)==1){break C}x[31721]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(260,n|0,e+28|0);d=x[31721];x[31721]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31721]=0;O(260,m|0,e+54|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=l+z[q>>1];s=q,t=x[qd(e+32|0,e+28|0)>>2],w[s>>1]=t;break r}b=N()|0;break d}b=N()|0;break d}}}b=N()|0;break d}g=Fb(e+80|0);x[31721]=0;f=P(233,b|0,g|0)|0;d=x[31721];x[31721]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[31721]=0;S(261,e+32|0,21,g|0);d=x[31721];x[31721]=0;if((d|0)==1){break I}d=e+32|0;yb(a+1298320|0,d);tb(d)}tb(g);f=0;J:{while(1){if((f|0)==32){x[31721]=0;f=P(262,b|0,e+16|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[31721]=0;f=U(153,d|0,f|0,g-11|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Ue(d+480280|0);x[31721]=0;O(234,b|0,d+480289|0);d=x[31721];x[31721]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break d}d=x[e+16>>2]-11|0;x[e+64>>2]=d;k=Nb(e+80|0);x[31721]=0;S(237,b|0,k|0,d|0);d=x[31721];x[31721]=0;K:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;s=e,t=D(x[Gb(e- -64|0,d)>>2],85),x[s+56>>2]=t;l=Fb(d);x[e>>2]=x[e+20>>2];d=x[Gb(e+56|0,e)>>2];x[31721]=0;O(117,l|0,d|0);d=x[31721];x[31721]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break M}j=x[k>>2];g=y[vb(j,f)|0];h=d;d=f+1|0;if(!((g|0)!=255|h-d>>>0<2)){i=v[vb(j,d)|0];g=y[vb(j,f+2|0)|0];d=x[zb(e+12|0,zf(l))>>2];x[31721]=0;V(240,l|0,d|0,g|0,i|0);d=x[31721];x[31721]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[31721]=0;O(118,l|0,g<<24>>24);g=x[31721];x[31721]=0;f=d;if((g|0)!=1){continue}break}break L}x[31721]=0;S(238,e|0,21,l|0);d=x[31721];x[31721]=0;if((d|0)!=1){N:{i=yb(l,e);tb(e);g=Jb(i);f=y[i+11|0];d=x[i+4>>2];x[31721]=0;aa(239,a+1298332|0,g|0,Xc(d,f)|0,74,0);d=x[31721];x[31721]=0;if((d|0)==1){break N}tb(i);cc(k);break H}}}b=N()|0;tb(l);break K}b=N()|0}cc(k);break d}}b=N()|0;tb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[31721]=0;S(241,Wb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31721];x[31721]=0;if((d|0)==1){break G}i=c&1;if(i){x[31721]=0;O(226,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31721];x[31721]=0;if((d|0)==1){break G}}j=a+484344|0;d=b;f=0;while(1){O:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[d+8>>2];b=x[d>>2];x[31721]=0;g=U(153,b|0,g|0,4)|0;b=x[31721];x[31721]=0;if((b|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;g=a+480190|0;while(1){b=z[g>>1];if(f>>>0>=b>>>0){f=0;i=a+480190|0;while(1){if(b>>>0<=f>>>0){break F}g=z[Zb(x[n>>2],f)>>1];c=g&255;P:{if(!c){break P}d=x[m>>2];c=c-1&65535;if(Yc(d,x[m+4>>2])>>>0<=c>>>0){break P}h=b;b=z[Zb(d,c)>>1]+(g>>>8&127)&65535;if(h>>>0<b>>>0){break P}c=D(b,104);b=c+a|0;j=b+484380|0;g=x[j>>2];if(!ge(g,x[b+484400>>2])){break P}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!Bh(d)){break P}yc(x[d+20>>2],x[c+20>>2],Sk(x[j>>2],z[j+34>>1]))}f=f+1|0;b=z[i>>1];continue}}b=z[Zb(x[n>>2],f)>>1];if(b&255){f=f+1|0;continue}f=f+1|0;c=D(f,104)+a|0;b=Wc(e+80|0,w[c+484414>>1]&1?16:8,1,0,b<<16>>16<0?6:0);x[31721]=0;U(218,b|0,c+484380|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}break}b=N()|0;break d}x[31721]=0;g=R(154,d|0)|0;b=x[31721];x[31721]=0;Q:{R:{S:{T:{if((b|0)!=1){x[31721]=0;S(188,e+32|0,d|0,g|0);b=x[31721];x[31721]=0;if((b|0)==1){break T}b=e+32|0;k=hc(e+80|0,b);ub(b);if(!i){break R}x[31721]=0;g=R(200,k|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Q}x[31721]=0;P(186,k|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Q}x[31721]=0;g=U(199,j|0,f&65535,g+1|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break Q}if(!g){break R}x[31721]=0;g=P(235,k|0,e+32|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break E}if(!g){break S}b=x[j>>2];x[31721]=0;O(236,Vb(b,f)|0,e+32|0);b=x[31721];x[31721]=0;if((b|0)!=1){break S}break E}b=N()|0;break d}b=N()|0;break d}b=x[j>>2];x[31721]=0;S(242,Vb(b,f)|0,1,k|0);b=x[31721];x[31721]=0;if((b|0)==1){break E}}ub(k);f=f+1|0;continue}break}break E}b=N()|0;break d}ld(n);ld(m);break b}b=N()|0;ub(k);break d}b=N()|0;break d}r=r+1|0;continue}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break d}b=N()|0}ld(n);ld(m)}tb(o);Q(b|0);p()}f=1}tb(o)}fb=e+272|0;return f|0}function rK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=fb-144|0;fb=e;d=Tb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1201;x[d+84>>2]=a;s=c;a=0;j=fb-304|0;fb=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Ly(d);if(x[d+4>>2]){break d}break c}h=y[b|0];if(!h){break a}e:{f:{g:{h:{while(1){i:{c=h&255;j:{if(ql(c)){while(1){h=b;b=b+1|0;if(ql(y[h+1|0])){continue}break}Fi(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=vd(d)}if(ql(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;g=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?g+1|0:g)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;break j}l:{m:{n:{if((c|0)==37){e=y[b+1|0];if((e|0)==42){break n}if((e|0)!=37){break m}}Fi(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break p}h=vd(d)}if(ql(h)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break o}h=vd(d)}if(y[b|0]!=(h|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((h|0)>=0){break a}f=0;if(t){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;i=c;m=m+x[d+124>>2]|0;e=c>>31;c=n+x[d+120>>2]|0;f=e+(c>>>0<n>>>0?m+1|0:m)|0;n=c+i|0;m=n>>>0<c>>>0?f+1|0:f;h=b;break j}l=0;b=b+2|0;break l}if(!(!Jh(e)|y[b+2|0]!=36)){c=fb-16|0;x[c+12>>2]=s;f=c;c=e-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+s|0;x[f+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[s>>2];s=s+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Jh(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){p=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}h=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;h=b?e:h;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;h=b?e:h;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;h=b}e=y[h|0];b=(e&47)==3;u=b?1:k;q=b?e|32:e;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}sK(l,u,n,m);break j}Fi(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=vd(d)}if(ql(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;i=b;g=m+x[d+124>>2]|0;e=b>>31;b=n+x[d+120>>2]|0;m=e+(b>>>0<n>>>0?g+1|0:g)|0;n=b+i|0;m=n>>>0<b>>>0?m+1|0:m}i=c;o=c>>31;Fi(d,c,o);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((vd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:uK(j+8|0,d,u,0);c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-c|0)|x[d+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Tb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}g=y[h+1|0];e=(g|0)==94;Tb(j+32|0,e,257);v[j+32|0]=0;b=e?h+2|0:h+1|0;B:{C:{D:{e=y[(e?2:1)+h|0];if((e|0)!=45){if((e|0)==93){break D}k=(g|0)!=94;break B}k=(g|0)!=94;v[j+78|0]=k;break C}k=(g|0)!=94;v[j+126|0]=k}b=b+1|0}h=b;while(1){e=y[h|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[h+1|0];if(!f|(f|0)==93){break E}g=h+1|0;b=y[h-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;e=y[g|0];if(e>>>0>b>>>0){continue}break}}h=g}v[(e+j|0)+33|0]=k;h=h+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}i=0;g=0;e=0;f=0;A=0;z=fb-16|0;fb=z;G:{if((b|0)==1){x[31596]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=vd(d)}if(ql(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}A=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=vd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=vd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=vd(d)}if(y[c+95377|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Fi(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+95377|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Fi(d,0,0);x[31596]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=vd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}i=b}R:{if(e>>>0>9){break R}b=zua(i,0,10,0);k=hb;f=e;while(1){g=k;i=b+f|0;g=i>>>0<f>>>0?g+1|0:g;b=(g|0)==429496729&i>>>0>=2576980378|g>>>0>429496729;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=vd(d)}e=c-48|0;if(b|e>>>0>9){break R}b=zua(i,g,10,0);f=e;k=hb;if((k|0)==-1&(e^-1)>>>0>=b>>>0|(k|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=y[c+95377|0];if(f>>>0<b>>>0){while(1){e=D(b,e)+f|0;i=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=vd(d)}f=y[c+95377|0];if(i&f>>>0<b>>>0){continue}break}i=e}if(b>>>0<=f>>>0){break L}o=b;while(1){e=zua(i,g,o,0);k=hb;f=f&255;if((k|0)==-1&(f^-1)>>>0<e>>>0){break L}g=k;i=e+f|0;g=i>>>0<f>>>0?g+1|0:g;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=vd(d)}f=y[c+95377|0];if(b>>>0<=f>>>0){break L}If(z,o,0,0,0,i,g,0,0);if(!(x[z+8>>2]|x[z+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+95633|0];e=y[c+95377|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;i=f>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=vd(d)}e=y[c+95377|0];if(i&e>>>0<b>>>0){continue}break}i=f}if(b>>>0<=e>>>0){break L}o=k&31;if((k&63)>>>0>=32){f=0;o=-1>>>o|0}else{f=-1>>>o|0;o=f|(1<<o)-1<<32-o}if(!f&i>>>0>o>>>0){break L}while(1){F=e&255;c=i;e=k&31;if((k&63)>>>0>=32){g=c<<e;c=0}else{g=(1<<e)-1&c>>>32-e|g<<e;c=c<<e}i=F|c;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=vd(d)}e=y[c+95377|0];if(b>>>0<=e>>>0){break L}if((g|0)==(f|0)&i>>>0<=o>>>0|g>>>0<f>>>0){continue}break}}if(y[c+95377|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=vd(d)}if(y[c+95377|0]<b>>>0){continue}break}x[31596]=68;i=-1;g=-1;A=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=A;e=b^i;i=e-b|0;c=b>>31;g=(c^g)-((b>>>0>e>>>0)+c|0)|0}fb=z+16|0;c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-c|0)&x[d+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=i;break w}sK(l,u,i,g);break w}if(!l){break w}c=x[j+16>>2];i=x[j+20>>2];b=x[j+8>>2];e=x[j+12>>2];Y:{switch(u|0){case 0:G=l,H=tG(b,e,c,i),B[G>>2]=H;break w;case 1:G=l,I=jx(b,e,c,i),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=b;x[l+4>>2]=e;x[l+8>>2]=c;x[l+12>>2]=i;break w}k=(q|0)!=99;c=k?31:c+1|0;Z:{if((u|0)==1){e=l;if(r){e=Ed(c<<2);if(!e){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=vd(d)}if(!y[(e+j|0)+33|0]){break _}v[j+27|0]=e;e=it(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}p=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}f=1;b=c;c=b<<1|1;e=rv(a,c<<2);if(e){continue}break e}break}p=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(r){b=0;e=Ed(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=vd(d)}if(!y[(e+j|0)+33|0]){c=0;p=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=rv(a,c);if(e){continue}break}p=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=vd(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;p=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=vd(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;p=0;c=0}e=x[d+4>>2];g=x[d+116>>2];if((g|0)>0|(g|0)>=0){e=e-1|0;x[d+4>>2]=e}e=e-x[d+44>>2]|0;g=e+x[d+120>>2]|0;f=x[d+124>>2]+(e>>31)|0;f=e>>>0>g>>>0?f+1|0:f;if(!(f|g)|!(k|(g|0)==(i|0)&(f|0)==(o|0))){break i}if(r){x[l>>2]=a}da:{if((q|0)==99){break da}if(c){x[(b<<2)+c>>2]=0}if(!p){p=0;break da}v[b+p|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;m=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?m+1|0:m)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;t=((l|0)!=0)+t|0}b=h+1|0;h=y[h+1|0];if(h){continue}break a}break}a=c;break g}f=1;p=0;a=0;break e}f=r;break b}f=r}if(t){break b}}t=-1}if(!f){break a}Db(p);Db(a)}fb=j+304|0;fb=d+144|0;return t}function foa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-192|0;fb=i;if(!_u(a)){e=i+40|0;QV(e,a);f=i+168|0;$e(f,e,128,2);e=i+180|0;Ac(e,f);xc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;k=i+180|0;h=fb-32|0;fb=h;a:{b:{switch(y[a+128|0]-4|0){default:x[h+28>>2]=0;Qj(k,0,h+28|0);break a;case 0:case 4:break b}}v[h+28|0]=y[a+129|0];v[h+24|0]=100;e=h+24|0;f=y[Sb(h+28|0,e)|0];v[h+24|0]=y[a+130|0];v[h+20|0]=100;e=y[Sb(e,h+20|0)|0];x[h+28>>2]=e;c:{if(y[a+140|0]&16){g=Cb(y[a+150|0]|y[a+151|0]<<8);n=Cb(y[a+152|0]|y[a+153|0]<<8);j=x[c>>2];s=+(j>>>0)/6553600;f=hr(s*+((g|f<<16)>>>0));x[h+24>>2]=j-f;t=h,u=hr(s*+((n|e<<16)>>>0)),x[t+20>>2]=u;t=h,u=x[Gb(h+24|0,h+20|0)>>2],x[t+28>>2]=u;break c}g=x[c>>2];n=x[c+20>>2];if(!ge(g,n)){break c}j=g>>>7|0;f=D(j,(f<<7>>>0)/100|0);x[h+24>>2]=g-f;x[h+20>>2]=D(j,(e<<7>>>0)/100|0);e=x[Gb(h+24|0,h+20|0)>>2];j=z[c+34>>1];g=D(Yd(j),g);d:{if(j&1){ac(h+12|0,n,g);n=x[h+12>>2];j=Yd(z[c+34>>1]);g=n+(D(j,e+f|0)<<1)|0;m=w[n+(D(f,j)<<1)>>1];j=0-j<<1;while(1){e:{f:{if(e){o=w[g>>1]-m|0;n=o>>31;if((n^o)-n>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;g=g+j|0;continue}break}break d}ac(h+4|0,n,g);n=x[h+4>>2];j=Yd(z[c+34>>1]);m=0-j|0;g=n+D(j,e+f|0)|0;j=v[n+D(f,j)|0];while(1){g:{h:{if(e){o=v[g|0]-j|0;n=o>>31;if((n^o)-n>>>0>=6){break h}}else{e=0}break g}e=e-1|0;g=g+m|0;continue}break}}x[h+28>>2]=e}Qj(k,f,h+28|0)}fb=h+32|0;n=dc(k);if(!(!x[n>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;e=x[i+180>>2];x[c+4>>2]=e;x[c+8>>2]=e+x[n>>2]}e=y[a+134|0];if((e-1&255)>>>0<=198){v[i+40|0]=e;v[i+168|0]=100;e=(y[Sb(i+40|0,i+168|0)|0]<<7>>>0)/100|0}else{e=128}v[i+39|0]=e;v[i+40|0]=64;e=i+39|0;f=i+40|0;t=c,u=y[af(e,f)|0]>>>1|0,w[t+32>>1]=u;v[i+40|0]=64;t=b,u=y[Sb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;am(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){gk(b,127,1);fk(b,0,1)}i:{if(!ge(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];e=x[c+20>>2];j:{if(!ge(b,e)|b>>>0<2){break j}k:{l:{switch(bl(z[c+34>>1])-1|0){case 3:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){wc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){wR(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){pg(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}Mj(c,d)}b=y[a+140|0]}if(b&4){m:{e=x[c>>2];b=x[c+20>>2];if(!ge(e,b)){break m}f=z[c+34>>1];e=D(Yd(f),e);n:{o:{switch(Dn(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){g=b+(f<<1)|0;w[g>>1]=z[g>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){g=b+f|0;v[g|0]=y[g|0]^-1;f=f+1|0;continue}break}}Mj(c,d)}}b=0;b=y[a+170|0]!=2|y[a+171|0]>100?b:y[a+172|0]<101;e=z[c+34>>1];if(!(!(b|y[a+160|0]!=0|y[a+141|0])|e&1)){f=Zu(x[c>>2],Yd(e)<<1&254);if(!f){break i}e=f;g=x[c>>2];h=z[c+34>>1];j=D(Yd(h),g);k=x[c+20>>2];g=Sk(g,h);h=fb-16|0;fb=h;x[h+12>>2]=j;uc(h+12|0,g);g=x[h+12>>2];while(1){if(g){w[e>>1]=v[k|0]<<8;k=k+1|0;e=e+2|0;g=g-1|0;continue}break}fb=h+16|0;w[c+34>>1]=z[c+34>>1]|1;OV(c,f,x[c>>2],d)}p:{if(v[a+141|0]>=0){break p}ac(i+40|0,x[c+20>>2],D(x[c>>2],Yd(z[c+34>>1])));e=0;q:while(1){if((0-v[a+141|0]|0)<=(e|0)){break p}g=x[i+40>>2];f=w[g>>1];t=i,u=wb(g),x[t+168>>2]=u;h=an(x[i+40>>2],x[i+44>>2]);while(1){g=x[i+168>>2];if(Ib(g,h)){f=od(w[g>>1]-od(f,1)|0,1);w[g>>1]=f;Od(i+168|0);continue}else{e=e+1|0;continue q}}}}r:{if(!b){break r}ac(i+40|0,x[c+20>>2],D(x[c>>2],Yd(z[c+34>>1])));f=x[i+44>>2];b=(f|0)/2|0;e=b;k=e>>31;h=y[a+172|0];g=y[a+171|0];b=h-g|0;l=e;e=0-(g>>>0>h>>>0)<<24|b>>>8;j=b<<24;h=l+j|0;b=e+k|0;f=Fc(Aua(h,h>>>0<j>>>0?b+1|0:b,f,f>>31),hb);t=i,u=wb(x[i+40>>2]),x[t+168>>2]=u;k=f>>31;b=g<<24;e=b>>31;j=an(x[i+40>>2],x[i+44>>2]);while(1){g=x[i+168>>2];if(!Ib(g,j)){break r}h=w[g>>1];m=zua(b,e,h,h>>31);h=hb;m=m+838860800|0;h=m>>>0<838860800?h+1|0:h;t=g,u=Fc(Aua(m,h,1677721600,0),hb),w[t>>1]=u;e=e+k|0;b=b+f|0;e=b>>>0<f>>>0?e+1|0:e;Od(i+168|0);continue}}s:{if(!y[a+160|0]){break s}ac(i+168|0,x[c+20>>2],D(x[c>>2],Yd(z[c+34>>1])));f=y[a+163|0];j=y[a+162|0];b=0;k=0;g=0;if(y[a+161|0]>=2){g=x[i+172>>2];e=(g|0)/2|0;h=e;m=e>>31;e=y[a+164|0];k=0-(e>>>0<j>>>0)|0;e=e-j|0;l=h;h=k<<23|e>>>9;o=e<<23;k=l+o|0;e=h+m|0;k=Fc(Aua(k,k>>>0<o>>>0?e+1|0:e,g,g>>31),hb);g=x[i+172>>2];e=(g|0)/2|0;h=e;o=e>>31;e=y[a+165|0];m=0-(e>>>0<f>>>0)|0;e=e-f|0;p=h;h=m<<23|e>>>9;l=e<<23;m=p+l|0;e=h+o|0;g=Fc(Aua(m,m>>>0<l>>>0?e+1|0:e,g,g>>31),hb)}f=f<<23;h=j<<23;e=y[a+160|0];t=i,u=wb(x[i+168>>2]),x[t+32>>2]=u;m=(i+40|0)+((e&2)<<2)|0;o=an(x[i+168>>2],x[i+172>>2]);e=0;while(1){j=x[i+32>>2];if(!Ib(j,o)){break s}l=(w[j>>1]>>1)-e|0;x[i+48>>2]=l;p=l;l=(h|0)/8388608|0;b=od(D(p,l),8)+b|0;x[i+44>>2]=b;e=od(D(b,l),6)+e|0;e=od(od(D(e,(f|0)/8388608|0),6)+e|0,2);x[i+40>>2]=e;t=j,u=dd(x[m>>2]),w[t>>1]=u;f=f+g|0;h=h+k|0;Od(i+32|0);continue}}t:{if(v[a+141|0]<=0){break t}ac(i+40|0,x[c+20>>2],D(x[c>>2],Yd(z[c+34>>1])));e=0;u:while(1){if(v[a+141|0]<=(e|0)){break t}b=x[i+40>>2];f=w[b>>1];t=i,u=wb(b),x[t+168>>2]=u;g=an(x[i+40>>2],x[i+44>>2]);while(1){b=x[i+168>>2];if(Ib(b,g)){f=((w[b>>1]<<1)+f|0)/3|0;w[b>>1]=f;Od(i+168|0);continue}else{e=e+1|0;continue u}}}}b=x[c+20>>2];f=z[c+34>>1];e=D(x[c>>2],Yd(f));v:{if(f&1){ac(i+24|0,b,e);p=x[i+28>>2];b=fb-16|0;fb=b;o=x[i+24>>2];e=wb(o);m=an(o,p);l=fb-16|0;fb=l;j=fb-16|0;fb=j;x[j+12>>2]=e;fc(j+4|0,l+15|0,l+14|0);q=b+8|0;g=Qj(q,e,j+12|0);w:{if(kc(e,m)){break w}r=Od(j+12|0);e=x[r>>2];if(kc(e,m)){break w}f=x[g>>2];h=Sl(e,f);x[(h?0:4)+g>>2]=e;f=h?e:f;k=g+4|0;while(1){h=Od(r);e=x[h>>2];if(!Ib(e,m)){break w}h=x[Od(h)>>2];if(kc(h,m)){if(!Sl(e,f)){g=k;if(Sl(e,x[g>>2])){break w}}x[g>>2]=e;break w}x:{if(Sl(h,e)){if(Sl(h,f)){x[g>>2]=h;f=h}if(Sl(e,x[k>>2])){continue}break x}if(Sl(e,f)){x[g>>2]=e;f=e}e=h;if(Sl(e,x[k>>2])){continue}}x[k>>2]=e;continue}}fb=j+16|0;fb=l+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[dc(q)>>2]>>1],x[t>>2]=u;y:{e=x[We(b+4|0,b)>>2];if((e|0)>32766|!e){break y}f=wb(o);x[b+4>>2]=f;g=an(o,p);while(1){if(!Ib(f,g)){break y}w[f>>1]=(D(w[f>>1],32767)|0)/(e|0);f=x[Od(b+4|0)>>2];continue}}break v}ac(i+16|0,b,e);p=x[i+20>>2];b=fb-16|0;fb=b;o=x[i+16>>2];e=wb(o);m=Vk(o,p);l=fb-16|0;fb=l;j=fb-16|0;fb=j;x[j+12>>2]=e;fc(j+4|0,l+15|0,l+14|0);q=b+8|0;g=Qj(q,e,j+12|0);z:{if(kc(e,m)){break z}r=je(j+12|0);e=x[r>>2];if(kc(e,m)){break z}f=x[g>>2];h=Tl(e,f);x[(h?0:4)+g>>2]=e;f=h?e:f;k=g+4|0;while(1){h=je(r);e=x[h>>2];if(!Ib(e,m)){break z}h=x[je(h)>>2];if(kc(h,m)){if(!Tl(e,f)){g=k;if(Tl(e,x[g>>2])){break z}}x[g>>2]=e;break z}A:{if(Tl(h,e)){if(Tl(h,f)){x[g>>2]=h;f=h}if(Tl(e,x[k>>2])){continue}break A}if(Tl(e,f)){x[g>>2]=e;f=e}e=h;if(Tl(e,x[k>>2])){continue}}x[k>>2]=e;continue}}fb=j+16|0;fb=l+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[dc(q)>>2]],x[t>>2]=u;B:{e=x[We(b+4|0,b)>>2];if((e|0)>126|!e){break B}f=wb(o);x[b+4>>2]=f;g=Vk(o,p);while(1){if(!Ib(f,g)){break B}v[f|0]=(D(v[f|0],127)|0)/(e|0);f=x[je(b+4|0)>>2];continue}}}fb=b+16|0;C:{if((y[a+134|0]-101&255)>>>0>98){break C}f=z[c+34>>1];e=D(x[c>>2],Yd(f));b=x[c+20>>2];if(f&1){x[i+8>>2]=b;x[i+12>>2]=(b+(e<<1)|0)-b>>1;g=x[i+12>>2];b=y[a+134|0];h=fb-16|0;fb=h;k=x[i+8>>2];f=wb(k);x[h+12>>2]=f;b=(3276800-(b<<14)|0)/100|0;j=0-b|0;e=32768-b|0;k=an(k,g);while(1){if(Ib(f,k)){g=w[f>>1];D:{if((g|0)>(b|0)){l=e+((D(b,g-b|0)|0)/(e|0)|0)|0;break D}l=((D(b,b+g|0)|0)/(e|0)|0)-e|0;if((g|0)<(j|0)){break D}l=(D(e,g)|0)/(b|0)|0}t=f,u=dd(l),w[t>>1]=u;f=x[Od(h+12|0)>>2];continue}break}fb=h+16|0;break C}b=mo(i,b,b+e|0);g=x[b>>2];k=x[b+4>>2];b=y[a+134|0];h=fb-16|0;fb=h;f=wb(g);x[h+12>>2]=f;b=(3276800-(b<<14)|0)/100|0;j=0-b|0;e=32768-b|0;k=Vk(g,k);while(1){if(Ib(f,k)){g=v[f|0]<<8;E:{if((g|0)>(b|0)){l=e+((D(b,g-b|0)|0)/(e|0)|0)|0;break E}l=((D(b,b+g|0)|0)/(e|0)|0)-e|0;if((g|0)<(j|0)){break E}l=(D(e,g)|0)/(b|0)|0}t=f,u=TX((l|0)/256|0),v[t|0]=u;f=x[je(h+12|0)>>2];continue}break}fb=h+16|0}NV(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}e=x[n>>2];if(!e){break i}f=x[i+180>>2];t=xb(c+68|0,0),u=f+D(e,b+1|0)|0,x[t>>2]=u;b=x[i+180>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[n>>2];h=x[n>>2];g=y[a+131|0];if(h>>>0>268435456/(g>>>0)>>>0){break i}f=x[c>>2];e=D(g,h);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=bl(z[c+34>>1]);j=Zu(f,e);if(!j){break i}k=b+D(h,g+1|0)|0;x[c>>2]=f;b=j;j=x[c+20>>2];g=x[i+180>>2];h=yc(b,j,D(e,g+x[n>>2]|0));m=j+D(e,g)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){yc(h+D(e,k)|0,j+D(e,g+x[n>>2]|0)|0,D(e,f-k|0));OV(c,h,f,d)}else{b=b+1|0;o=x[n>>2];yc(h+D(e,g+D(b,o)|0)|0,m,D(e,o));continue}break}}fb=i+192|0}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-720|0;fb=d;vc(b);a:{b:{c:{d:{if(!yi(b,d+712|0)){break d}if(!kR(x[d+712>>2],x[d+716>>2])){break d}if(!Er(b,d+708|0)){break d}g=x[d+708>>2];if(!jR(g)){break d}e:{if((g|0)==1179012417){f=1;e=1313423693;break e}if((g|0)!=538987841){break d}f=2;e=1414090313}m=Fe(d+688|0,b);j=Nb(d+676|0);f:{g:{h:{i:{j:{k:{l:{if(!c){x[31721]=0;V(900,d+112|0,m|0,f|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){break l}a=N()|0;break a}x[31721]=0;S(901,d+112|0,m|0,f|0);b=x[31721];x[31721]=0;if((b|0)==1){break k}}b=d+112|0;lv(j,b);fe(b);x[31721]=0;S(902,d+656|0,j|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;b=R(175,x[d+656>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}f=0;if(!b){break f}x[31721]=0;b=P(903,d+656|0,d+583|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}if(!b){break f}b=y[d+648|0];if(!b){break f}x[31721]=0;f=U(153,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break j}if(!((c|0)!=0&f)){break f}x[31721]=0;O(249,a|0,8388608);b=x[31721];x[31721]=0;if((b|0)==1){break j}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;q=a,r=z[Lc(d+112|0,d+464|0)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31721]=0;O(133,a+1298344|0,((g|0)!=1179012417?16941:16975)|0);b=x[31721];x[31721]=0;if((b|0)==1){break j}x[31721]=0;b=P(1,d+568|0,13318)|0;e=x[31721];x[31721]=0;if((e|0)==1){break h}yb(a+1298356|0,b);tb(b);b=d+112|0;q=a+1298404|0,r=x[Ec(b,4)>>2],x[q>>2]=r;e=d+464|0;rC(e,2,d+583|0);x[31721]=0;O(221,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}b=d+112|0;yb(a+1298308|0,b);tb(b);k=(g|0)==1179012417;b=0;while(1){m:{n:{o:{if(z[a+480188>>1]<=b>>>0){b=wb(x[j>>2]);f=wb(x[j+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){p:{if(!Ib(b,f)){break p}if(V_(1380209231,x[b>>2],x[b+4>>2])){break p}b=x[tn(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,wb(x[j+4>>2]))){break o}break g}f=(b<<5)+a|0;l=f+480280|0;Ue(l);x[31721]=0;e=R(200,d+656|0)|0;h=x[31721];x[31721]=0;q:{r:{if((h|0)!=1){if(k){break q}if(e>>>0<129){break r}break n}a=N()|0;break b}w[f+480284>>1]=e<<1;break m}if(e<<24>>24<0){break n}x[d+112>>2]=e<<2;x[d+464>>2]=256;q=f+480284|0,r=x[qd(d+112|0,d+464|0)>>2],w[q>>1]=r;break m}x[31721]=0;S(902,d+112|0,j|0,1380209231);b=x[31721];x[31721]=0;s:{if((b|0)!=1){x[31721]=0;b=R(200,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break s}e=y[a+484376|0];f=x[a+484360>>2];x[31721]=0;aa(351,Wb(f,e)|0,d+112|0,b+1&255,255,254);b=x[31721];x[31721]=0;if((b|0)==1){break s}ub(d+112|0);break g}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[l>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}t:{if(!(c&1)){break t}w[d+48>>1]=0;x[31721]=0;S(904,d+528|0,j|0,1414807888);b=x[31721];x[31721]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31721]=0;f=a+484344|0;O(226,f|0,Mf(e,b)&65535);b=x[31721];x[31721]=0;u:{if((b|0)!=1){q=d,r=wb(x[d+528>>2]),x[q+76>>2]=r;k=wb(x[d+532>>2]);l=(g|0)!=1179012417;v:{w:{x:{y:{z:{while(1){b=x[d+76>>2];if(!Ib(b,k)){k=a+484348|0;b=0;break v}b=Fe(d+112|0,b);x[31721]=0;e=R(200,b|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;w[d+452>>1]=e;e=R(154,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break z}x[31721]=0;S(188,d+464|0,b|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break y}e=hc(d+548|0,d+464|0);x[31721]=0;h=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=h;x[d+16>>2]=x[e+16>>2];h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;V(905,d|0,z[d+452>>1],l|0,a|0);e=x[31721];x[31721]=0;if((e|0)==1){break x}ub(d+464|0);q=d,r=z[oe(d+48|0,d+452|0)>>1],w[q+48>>1]=r;ub(b);Yf(d+76|0);continue}break}a=N()|0;break w}a=N()|0;break w}a=N()|0;break w}a=N()|0;ub(d+464|0)}ub(b);break u}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Pc(d+528|0);break t}A:{if(!Ge(x[a+484344>>2],x[k>>2],e)){x[31721]=0;U(199,f|0,e|0,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break A}}b=b+1|0;continue}break}a=N()|0;break u}a=N()|0}Pc(d+528|0);break b}B:{C:{D:{if((g|0)==1179012417){x[31721]=0;S(904,d+76|0,j|0,1414745673);b=x[31721];x[31721]=0;if((b|0)==1){break C}q=d,r=wb(x[d+76>>2]),x[q+100>>2]=r;g=c&2;k=d+472|0;l=wb(x[d+80>>2]);e=a+480190|0;while(1){b=x[d+100>>2];if(!Ib(b,l)){Pc(d+76|0);break B}c=Fe(d+528|0,b);x[31721]=0;b=P(906,c|0,d+112|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){E:{if(!b){break E}b=y[d+113|0];if((b|0)==255){break E}x[31721]=0;f=U(254,a|0,b+1|0,0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break D}if(!f){break E}h=z[e>>1];b=0;x[31721]=0;S(907,d+112|0,f|0,h|0);f=x[31721];x[31721]=0;if((f|0)==1){break D}while(1){if(y[d+142|0]<=b>>>0){break E}F:{if(!ri(z[e>>1])){break F}x[31721]=0;f=P(908,c|0,d+464|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break D}if(!f){break F}f=z[e>>1]+1|0;w[e>>1]=f;if(x[d+464>>2]!=1347240275){break F}h=d+452|0;Zi(h,2,k);x[31721]=0;O(221,d+48|0,h|0);h=x[31721];x[31721]=0;G:{if((h|0)!=1){f=f&65535;h=d+48|0;xc(((f<<5)+a|0)+946304|0,h);tb(h);x[31721]=0;f=(D(f,104)+a|0)+484380|0;S(909,d+464|0,d+112|0,f|0);h=x[31721];x[31721]=0;if((h|0)==1){break D}if(!g){break G}h=d+48|0;iR(h,z[d+502>>1]);x[31721]=0;U(218,h|0,f|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break F}break D}break D}h=z[f+34>>1];f=x[f>>2];x[31721]=0;P(186,c|0,Sk(f,h)|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break D}}b=b+1|0;continue}}ub(c);Yf(d+100|0);continue}break}break D}x[31721]=0;S(904,d+452|0,j|0,1179011410);b=x[31721];x[31721]=0;if((b|0)!=1){q=d,r=wb(x[d+452>>2]),x[q+448>>2]=r;k=c&2;l=d+468|0;h=wb(x[d+456>>2]);f=a+480190|0;H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+448>>2];if(!Ib(b,h)){Pc(d+452|0);break B}c=Fe(d+528|0,b);x[31721]=0;b=R(154,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[31721]=0;b=P(910,c|0,d+440|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break P}if(!(b&x[d+440>>2]==1414745673)){break S}x[31721]=0;b=P(911,c|0,d+112|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+117|0];if((b|0)==255){break S}x[31721]=0;b=U(254,a|0,b+1|0,0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break N}if(!b){break S}e=z[f>>1];x[31721]=0;S(912,d+112|0,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break N}x[31721]=0;S(901,d+464|0,c|0,2);b=x[31721];x[31721]=0;if((b|0)==1){break R}x[31721]=0;S(904,d+100|0,d+464|0,1179011410);b=x[31721];x[31721]=0;if((b|0)==1){break M}fe(d+464|0);q=d,r=wb(x[d+100>>2]),x[q+96>>2]=r;n=wb(x[d+104>>2]);T:{U:{while(1){b=x[d+96>>2];if(!Ib(b,n)){break T}b=Fe(d+76|0,b);x[31721]=0;e=R(154,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[f>>1];if(!ri(e)){break W}g=y[d+436|0]|y[d+437|0]<<8;i=g-1|0;v[d+436|0]=i;v[d+437|0]=i>>>8;if(!g){ub(b);break T}i=e+1|0;w[f>>1]=i;x[31721]=0;e=P(910,b|0,d+68|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break K}if(!(e&x[d+68>>2]==1347240275)){break U}x[31721]=0;S(188,d+464|0,b|0,x[d+72>>2]);e=x[31721];x[31721]=0;X:{if((e|0)!=1){g=d+464|0;e=hc(d+48|0,g);ub(g);x[31721]=0;g=P(913,e|0,g|0)|0;o=x[31721];x[31721]=0;if((o|0)==1){break V}if(g){break X}ub(e);ub(b);break T}a=N()|0;break I}g=d+24|0;Te(g,2,l);x[31721]=0;O(221,d+36|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break J}g=i&65535;i=d+36|0;xc(((g<<5)+a|0)+946304|0,i);tb(i);x[31721]=0;g=(D(g,104)+a|0)+484380|0;S(914,d+464|0,d+112|0,g|0);i=x[31721];x[31721]=0;if((i|0)==1){break V}Y:{if(!k){break Y}x[31721]=0;P(152,e|0,x[d+464>>2]+4|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break V}i=d+36|0;iR(i,z[d+504>>1]);x[31721]=0;U(218,i|0,g|0,e|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break Y}break J}ub(e)}ub(b);Yf(d+96|0);continue}break}break J}ub(b)}Pc(d+100|0)}ub(c);Yf(d+448|0);continue}break}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;fe(d+464|0);break H}a=N()|0;break I}a=N()|0;break I}a=N()|0;ub(e)}ub(b);Pc(d+100|0)}ub(c);Pc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Pc(d+76|0);break b}a=N()|0;break b}f=1}ub(d+656|0);fe(j);ub(m)}fb=d+720|0;return f|0}a=N()|0}ub(d+656|0)}fe(j);ub(m);Q(a|0);p()}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-208|0;fb=e;vc(b);a:{if(!Er(b,e+204|0)){break a}x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;x[e+168>>2]=0;x[e+172>>2]=0;x[e+160>>2]=0;x[e+164>>2]=0;b:{c:{if(!NE(e+204|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}qw(b,e+160|0);break b}m=1;if(!ME(e+204|0)){break a}}j=e+155|0;f=LE(y[e+207|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=hf(b)}l=d+8|0;bk(l,j);k=fc(d+16|0,x[d+8>>2],f);h=x[k>>2];jc(d,x[b>>2],x[b+8>>2],h,x[k+4>>2]);bk(l,j);Tb(x[d+8>>2]+f|0,0,5-f|0);Ub(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!KE(e+155|0,y[e+207|0])){break a}if(!c){n=1;break a}j=e+207|0;Ad(a,2048);bg(a);d:{e:{f:{g:{h:{i:{j:{k:{l:{if(m){d=fb-16|0;fb=d;f=e+4|0;l=rc(d+4|0,3893);Zc(f,l);tb(l);fb=d+16|0;x[31721]=0;S(212,e+72|0,f|0,j|0);d=x[31721];x[31721]=0;if((d|0)==1){break j}d=e+72|0;yb(a+1298344|0,d);tb(d);Eb(e+4|0);f=rc(d,11144);yb(a+1298356|0,f);break l}d=e+4|0;Te(d,2,e+160|0);f=e+72|0;Ac(f,d);yb(a+1298308|0,f);tb(f);l=fb-16|0;fb=l;k=rc(l+4|0,3944);Zc(d,k);tb(k);fb=l+16|0;x[31721]=0;S(212,f|0,d|0,j|0);d=x[31721];x[31721]=0;if((d|0)==1){break k}d=e+72|0;yb(a+1298344|0,d);tb(d);Eb(e+4|0);f=rc(d,11148);yb(a+1298356|0,f)}tb(f);B=a+1298404|0,C=x[Ec(e+72|0,4)>>2],x[B>>2]=C;d=a+480188|0;w[d>>1]=y[e+159|0];w[a+480190>>1]=y[e+155|0];m:{f=y[e+207|0];if(f>>>0>8){break m}w[d>>1]=4;d=0;while(1){if((d|0)==4){break m}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}n:{if(f>>>0>=11){f=(f|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break n}j=zw(b);o:{if((j|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break o}x[e+72>>2]=(j<<1)+128;x[e+4>>2]=0;x[e+140>>2]=256;B=((d<<5)+a|0)+480284|0,C=x[ak(e+72|0,e+4|0,e+140|0)>>2],w[B>>1]=C}d=d+1|0;continue}}if(f>>>0<9){break n}Ub(b,16);d=0;while(1){if((d|0)==16){break n}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}p:{if(y[e+207|0]>=13){d=e+72|0;ww(d,b);f=Hc(d);d=y[e+72|0];if(d>>>0<=31){v[e+72|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break p}x[a+480196>>2]=6;x[a+480204>>2]=125e4}sg(Wb(x[a+484360>>2],y[a+484376|0]),y[e+156|0]);l=Nb(e+140|0);f=y[e+207|0];t=x[b+8>>2]+((f>>>0>13)<<1)|0;d=0;q:{if(f>>>0<14){break q}x[31721]=0;O(213,l|0,y[e+156|0]);f=x[31721];x[31721]=0;if((f|0)!=1){break q}d=N()|0;break g}while(1){if(y[e+156|0]<=d>>>0){j=0;if(y[e+207|0]!=10){break h}h=x[b+8>>2];g=a+480190|0;d=1;while(1){j=z[g>>1]>=(d&65535)>>>0;if(!j){break i}x[31721]=0;f=P(214,b|0,e+72|0)|0;k=x[31721];x[31721]=0;if((k|0)!=1){if(f){f=0;r:{if(y[e+155|0]<(y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24))>>>0|y[e+72|0]>1){break r}k=y[e+122|0]|y[e+123|0]<<8|(y[e+124|0]<<16|y[e+125|0]<<24);if(k>>>0>1048576|y[e+128|0]>64|k>>>0<(y[e+129|0]|y[e+130|0]<<8|(y[e+131|0]<<16|y[e+132|0]<<24))>>>0){break r}f=k>>>0>=(y[e+133|0]|y[e+134|0]<<8|(y[e+135|0]<<16|y[e+136|0]<<24))>>>0}if(!f){break i}}d=d+1|0;continue}break}d=N()|0;break g}B=Zb(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],d),C=d,w[B>>1]=C;s:{if(y[e+207|0]>=14){x[31721]=0;f=R(192,b|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break s}B=Zb(x[l>>2],d),C=f,w[B>>1]=C}f=z[a+480188>>1];x[31721]=0;P(186,b|0,f<<1)|0;f=x[31721];x[31721]=0;if((f|0)==1){break s}d=d+1|0;continue}break}d=N()|0;break g}d=N()|0;Eb(e+4|0);break f}d=N()|0;Eb(e+4|0);break f}x[31721]=0;P(152,b|0,h|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break h}d=N()|0;break g}n=a+480190|0;d=z[n>>1];x[31721]=0;x[e+72>>2]=0;k=U(215,e+60|0,d|0,e+72|0)|0;d=x[31721];x[31721]=0;t:{u:{v:{w:{if((d|0)!=1){i=j?59:65;h=e+73|0;d=1;x:{while(1){f=d&65535;if(f>>>0>z[n>>1]){j=Nb(e+48|0);x[31721]=0;n=U(216,b|0,j|0,y[e+157|0]|y[e+158|0]<<8)|0;d=x[31721];x[31721]=0;y:{if((d|0)!=1){if(!n){break d}d=0;f=0;h=x[j>>2];if(!kc(h,x[j+4>>2])){f=wb(h);i=wb(x[j+4>>2]);h=fb-16|0;fb=h;z:{if(!Ib(f,i)){break z}x[h+12>>2]=f;while(1){g=x[Od(h+12|0)>>2];if(!Ib(g,i)){break z}f=al(y[f|0]|y[f+1|0]<<8,y[g|0]|y[g+1|0]<<8)?g:f;continue}}fb=h+16|0;f=y[f|0]|y[f+1|0]<<8}x[31721]=0;g=P(217,e+24|0,f|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break y}A:{while(1){if((d|0)==(f|0)){if(!(c&2)){break w}o=Wc(e+4|0,8,1,0,m?2:1);q=a+480190|0;d=z[q>>1];i=1;B:{C:{D:while(1){s=i&65535;if(s>>>0>(d&65535)>>>0){break w}d=x[b+8>>2];h=x[b>>2];x[31721]=0;d=U(153,h|0,d|0,1)|0;h=x[31721];x[31721]=0;if((h|0)==1){break B}if(!d){break w}u=x[b+8>>2];h=0;E:while(1){d=z[q>>1];if(h>>>0>=d>>>0){i=i+1|0;continue D}if(x[xb(x[k>>2],h)>>2]!=(s|0)){h=h+1|0;continue}x[31721]=0;P(152,b|0,u|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;h=h+1|0;d=D(h,104)+a|0;r=d+484380|0;U(218,o|0,r|0,b|0)|0;A=x[31721];x[31721]=0;if((A|0)==1){break C}if(!m){continue}ac(e+72|0,x[d+484400>>2],x[r>>2]);B=e,C=wb(x[e+72>>2]),x[B>>2]=C;r=Vk(x[e+72>>2],x[e+76>>2]);while(1){d=x[e>>2];if(!Ib(d,r)){continue E}v[d|0]=y[d|0]^128;je(e);continue}}break}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break v}x[31721]=0;h=R(192,b|0)|0;i=x[31721];x[31721]=0;F:{if((i|0)==1){break F}x[31721]=0;P(186,b|0,1)|0;i=x[31721];x[31721]=0;if((i|0)==1){break F}if(h){x[31721]=0;S(188,e+4|0,b|0,D(h,3)+(y[e+207|0]==1?3:0)|0);h=x[31721];x[31721]=0;if((h|0)==1){break A}i=e+4|0;h=hc(e+72|0,i);gd($g(x[g>>2],d),h);ub(h);ub(i)}d=d+1|0;continue}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break u}d=N()|0;break u}G:{H:{if(y[e+207|0]<=9){x[31721]=0;O(219,b|0,e+72|0);g=x[31721];x[31721]=0;I:{J:{if((g|0)==1){break J}x[31721]=0;O(220,e+72|0,(D(f,104)+a|0)+484380|0);g=x[31721];x[31721]=0;if((g|0)==1){break J}g=e+48|0;Te(g,2,h);x[31721]=0;O(221,e+4|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break I}g=e+4|0;xc(((f<<5)+a|0)+946304|0,g);tb(g);B=xb(x[k>>2],f-1|0),C=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[B>>2]=C;break H}d=N()|0;break t}d=N()|0;break t}if(m){x[31721]=0;O(222,b|0,e+72|0);g=x[31721];x[31721]=0;K:{L:{if((g|0)==1){break L}x[31721]=0;O(223,e+72|0,(D(f,104)+a|0)+484380|0);g=x[31721];x[31721]=0;if((g|0)==1){break L}x[31721]=0;g=P(37,e+36|0,22250)|0;o=x[31721];x[31721]=0;if((o|0)==1){break K}xc(((f<<5)+a|0)+946304|0,g);tb(g);B=xb(x[k>>2],f-1|0),C=y[e+74|0]|y[e+75|0]<<8|(y[e+76|0]<<16|y[e+77|0]<<24),x[B>>2]=C;break H}d=N()|0;break t}d=N()|0;break t}x[31721]=0;S(224,b|0,e+72|0,i|0);g=x[31721];x[31721]=0;if((g|0)==1){break G}x[31721]=0;S(225,e+72|0,(D(f,104)+a|0)+484380|0,j|0);g=x[31721];x[31721]=0;if((g|0)==1){break G}g=e+48|0;Te(g,2,h);x[31721]=0;O(221,e+4|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break x}g=e+4|0;xc(((f<<5)+a|0)+946304|0,g);tb(g);B=xb(x[k>>2],f-1|0),C=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[B>>2]=C}d=d+1|0;continue}break}d=N()|0;break t}d=N()|0;break t}d=N()|0;break g}if(!(c&1)){break e}x[31721]=0;m=a+484344|0;O(226,m|0,y[e+156|0]);c=x[31721];x[31721]=0;M:{if((c|0)!=1){h=a+480188|0;a=0;while(1){N:{if(y[e+156|0]<=a>>>0){break e}d=64;c=x[l>>2];if(Yc(c,x[l+4>>2])>>>0>a>>>0){d=z[Zb(c,a)>>1]}x[31721]=0;c=U(199,m|0,a&65535,d&65535)|0;d=x[31721];x[31721]=0;if((d|0)==1){break M}O:{if(c){c=z[h>>1];x[31721]=0;P(152,b|0,D(((y[e+207|0]>13)<<1)+(c<<1)|0,a)+t|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break M}c=Nb(e+72|0);d=z[h>>1];x[31721]=0;i=U(216,b|0,c|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break O}d=0;P:{if(!i){break P}while(1){if(z[h>>1]<=d>>>0){break P}Q:{i=Zb(x[c>>2],d);i=(y[i|0]|y[i+1|0]<<8)-1|0;if((i&65535)>>>0>=(y[e+157|0]|y[e+158|0]<<8)>>>0){break Q}i=Zb(x[j>>2],i);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=f>>>0){break Q}o=x[m>>2];q=x[g>>2];x[31721]=0;S(227,Vb(o,a)|0,d&65535,$g(q,i)|0);i=x[31721];x[31721]=0;if((i|0)!=1){break Q}break N}d=d+1|0;continue}}ld(c)}a=a+1|0;continue}}break}d=N()|0;ld(c);break v}d=N()|0;break v}d=N()|0}Pc(g)}ld(j)}sc(k)}ld(l)}Q(d|0);p()}Pc(g)}ld(j);sc(k);ld(l)}fb=e+208|0;return n|0}function Q1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;vc(b);Ap(a);a:{b:{c:{if(!bs(b,e+1432|0)){break c}if(!sG(e+1432|0)){break c}if(!c){j=1;break c}if(!tm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!tm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}ex(a);w=e,B=dx(),x[w+68>>2]=B;c=e+68|0;cx(hj(x[a+4>>2])+32|0,c);as(c);m=x[hj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=gh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Gb(d,e+1136|0)>>2],20),x[w+68>>2]=B;lo(m,x[Gb(e+1428|0,c)>>2]);Tb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{j=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!j){x[31721]=0;c=P(152,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31721]=0;c=U(153,d|0,c|0,4)|0;d=x[31721];x[31721]=0;if((d|0)==1){break r}if(!c){break h}x[31721]=0;c=R(154,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break q}x[31721]=0;d=P(152,b|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break q}if(!d){break h}x[31721]=0;d=P(155,b|0,e+1136|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break p}if(!d){break h}x[31721]=0;d=U(156,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;f=x[31721];x[31721]=0;if((f|0)==1){break p}if(!d){break h}f=x[s>>2];g=x[b>>2];x[31721]=0;d=y[e+1148|0]|y[e+1149|0]<<8;g=R(157,g|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break o}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=y[e+1148|0]|y[e+1149|0]<<8;g=i+(f<<3)|0;d=0;i=y[e+1150|0]|y[e+1151|0]<<8;if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31721]=0;f=ba(158,i|0,f|0,m|0,x[e+1428>>2])|0;i=x[31721];x[31721]=0;s:{if((i|0)==1){break s}if(!f){break h}x[31721]=0;f=P(152,b|0,g|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break s}if(!f){break h}f=fc(e+1128|0,vb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f>>2];f=x[f+4>>2];x[31721]=0;Sn(159,e+68|0,b,i,f);f=x[31721];x[31721]=0;if((f|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=y[e+1148|0]|y[e+1149|0]<<8;continue}break}j=N()|0;break a}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31721]=0;d=ba(158,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break m}if(!d){break h}n=vb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[31721]=0;f=y[e+1154|0]|y[e+1155|0]<<8;d=P(152,b|0,g+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[31721]=0;d=U(153,g|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break l}if(!d){break h}x[31721]=0;S(160,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}d=e+48|0;k=$r(e+68|0,d);ub(d);r=0;i=0;while(1){g=0;u:{while(1){if((i&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31721]=0;d=P(161,k|0,f+1|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+24336>>1];v:{w:{if(o>>>0<=d>>>0){x[31721]=0;h=y[h+24384|0];q=P(161,k|0,h|0)|0;u=x[31721];x[31721]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[31721]=0;d=P(161,k|0,4)|0;h=x[31721];x[31721]=0;if((h|0)==1){break u}if((d|0)==15){x[31721]=0;h=P(161,k|0,1)|0;d=x[31721];x[31721]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31721]=0;g=ba(158,g|0,l|0,m|0,x[e+1428>>2])|0;l=x[31721];x[31721]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=vb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(28832)|0;if((gb|0)==($(28832)|0)){Y(j|0)|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){break e}j=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31721]=0;d=ba(158,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}if(!d){break h}r=vb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[e+1154|0]|y[e+1155|0]<<8;x[31721]=0;d=P(152,b|0,g|0)|0;g=x[31721];x[31721]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=fc(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);g=x[d>>2];d=x[d+4>>2];x[31721]=0;Sn(162,e+68|0,b,g,d);d=x[31721];x[31721]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[31721]=0;d=U(153,i|0,g|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break y}}j=N()|0;break a}j=N()|0;break a}if(!d){break h}x[31721]=0;S(160,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31721];x[31721]=0;if((d|0)==1){break f}d=e+48|0;k=$r(e+68|0,d);ub(d);l=0;i=0;while(1){g=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31721]=0;d=P(161,k|0,f+1|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break A}h=f&7;o=y[h+24368|0];B:{C:{if(o>>>0<=d>>>0){x[31721]=0;h=y[h+24376|0];q=P(161,k|0,h|0)|0;u=x[31721];x[31721]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[31721]=0;d=P(161,k|0,3)|0;h=x[31721];x[31721]=0;if((h|0)==1){break A}if((d|0)==7){x[31721]=0;h=P(161,k|0,1)|0;d=x[31721];x[31721]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+i|0;q=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31721]=0;g=ba(158,g|0,n|0,m|0,x[e+1428>>2])|0;n=x[31721];x[31721]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=vb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(28832)|0;if((gb|0)==($(28832)|0)){Y(j|0)|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){break g}j=N()|0}ub(k);break a}ub(k);break h}le(e+24|0,x[m>>2],x[m+4>>2]);jf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Jd(e+16|0);x[31721]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=eg(163,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31721];x[31721]=0;if((c|0)==1){break i}gd(hj(x[a+4>>2])+12|0,b);ub(b);break h}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}ub(k);break h}j=N()|0;break a}ze(s);break c}ub(k);break d}j=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return j|0}j=N()|0}ze(s);Q(j|0);p()}function Spa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=fb-368|0;fb=e;a:{if(!bd(b,1080)){break a}if(!Yq(b,e+364|0)){break a}l=QX(e+344|0);if(!PX(e+364|0,l)){break a}d=z[l+10>>1];if(!d|d>>>0>127){break a}if(!c){K=1;break a}L=1;Ad(a,1);t=a+480188|0;g=z[l+10>>1];w[t>>1]=g;s=y[l+14|0];M=y[l+13|0];i=y[l+12|0];if(!me(e+364|0,25226)){L=me(e+364|0,25231)}if(y[l+15|0]){Lb(a+1074312|0,5,1);g=z[a+480188>>1]}d=e+364|0;u=me(d,16750);m=1;if(!me(d,17512)){m=me(e+364|0,13686)}B=(g&65535)==8&(M|0)!=0;bd(b,0);d=y[l+16|0];h=fb-16|0;fb=h;b:{g=e+324|0;if(!Ww(b,g)|!d){break b}Uw(h+8|0,g);d=0;while(1){if(d>>>0>=20){break b}n=x[h+8>>2];pg(vb(n,d),vb(n,d|1));d=d+2|0;continue}}fb=h+16|0;h=e+312|0;$e(h,g,20,3);d=e+180|0;Ac(d,h);yb(a+1298308|0,d);tb(d);w[a+480190>>1]=31;n=(i|0)!=0;r=a+480188|0;g=1;h=0;i=u;while(1)if((g|0)==32){K=A[l+4>>2]>=j>>>0;if(!K){break a}d=y[l+16|0];g=fb-16|0;fb=g;c:{k=e+180|0;if(!xC(b,k)|!d){break c}CC(g+8|0,k);d=0;while(1){if(d>>>0>=130){break c}k=x[g+8>>2];pg(vb(k,d),vb(k,d|1));d=d+2|0;continue}}fb=g+16|0;bd(b,z[l+8>>1]);g=y[e+181|0];d=128;k=a+484376|0;Zv(Wb(x[a+484360>>2],y[k|0]),e+182|0,128);i=!g&i;m=i?h:0;h=y[e+180|0];d:{if(h>>>0>128){break d}d=h;if(d){break d}h=x[Wb(x[a+484360>>2],y[a+484376|0])>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break d}g=d-1|0;if(!z[Zb(h,g)>>1]){continue}break}}j=NX(b,Wb(x[a+484360>>2],y[k|0]),d&65535,f,t,m,0);F=1;e:{if(!(i&z[a+480188>>1]==8)){F=(s|0)!=0;break e}x[l>>2]=11263}f:{if(!B){break f}f=Wb(x[a+484360>>2],y[a+484376|0]);aa=e,ba=wb(x[f>>2]),x[aa+312>>2]=ba;h=wb(x[f+4>>2]);while(1){f=x[e+312>>2];if(!Ib(f,h)){break f}w[f>>1]=z[f>>1]>>>1;Od(e+312|0);continue}}f=a+484376|0;Ze(Wb(x[a+484360>>2],y[f|0]),y[e+181|0]);T=d-1|0;d=y[e+181|0];g:{if((T&65535)>>>0>=d>>>0){g=z[t>>1];if((d|0)!=120|(g|0)!=4){break g}}Ze(Wb(x[a+484360>>2],y[f|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;q=0;x[a+480208>>2]=0;aa=a,ba=Xb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;Uh(a,0);v[e+179|0]=0;h:{if(n&1){s=1;k=1;break h}s=1;m=0;n=0;h=u;i:while(1){o=n&65535;if(o>>>0<j>>>0){k=0;g=0;while(1)if((g|0)==256){n=n+1|0;continue i}else{d=Ig(e+312|0);MX(e+160|0,b,!o&y[l+16|0]!=0);f=x[e+160>>2];x[e+172>>2]=f;x[e+64>>2]=f;f=e+92|0;Zo(f,e- -64|0,d);i=Hc(f);r=sD(y[d|0]);j:{k:{l:{m:{d=y[e+92|0];if((d-7&255)>>>0<3){h=0;break m}f=y[i|0];if(!((d|0)!=14|f>>>0<=1)){h=0;break l}if(!((d|0)==15&(f&255)>>>0>31)){h=r?h:0;if((d|0)!=13){break m}k=k+1|0;if((k&65535)>>>0<2){break j}}h=0;break j}if((d|0)==8){break k}if((d|0)!=14){break j}f=y[i|0]}if((f&240)!=128){break j}v[e+80|0]=f<<4;aa=e,ba=y[af(e+179|0,e+80|0)|0],v[aa+179|0]=ba;break j}aa=e,ba=y[af(e+179|0,i)|0],v[aa+179|0]=ba;d=v[i|0];if((d|0)>=0){q=1;break j}m=(d|0)!=-92&d>>>0>4294967183|m}s=r&s;g=g+1|0;continue}}break}d=q^-1;q=0;q=(d|m)&1?q:y[e+179|0]>47;k=h&1}bd(b,z[l+8>>1]);d=z[a+480188>>1];E=a+484344|0;O=j+B&65535;Of(E,O);V=B?4:d;r=a+1074312|0;$=c&1;m=0;n=0;o=0;n:{o:{p:{q:{while(1){if((m|0)==(O|0)){break p}r:{if(B){d=(m&65534)>>>1|0;f=m&1;if(!f){if(!Kg(E,d,64)){break p}}i=f<<2;d=Vb(x[E>>2],d);break r}if(!Kg(E,m&65535,64)){break p}i=0;d=Vb(x[E>>2],m)}h=0;i=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i);if(!$){o=0;G=0;break o}d=z[t>>1];v[e+92|0]=0;f=d;d=e+92|0;H=Uv(e+312|0,f,d);f=z[t>>1];x[31721]=0;v[e+92|0]=0;I=U(603,e+160|0,f|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){R=0;s:{t:while(1){u:{if((R|0)==64){break s}g=0;f=0;W=0;while(1){if((g|0)==(V|0)){R=R+1|0;o=f&W|o;i=D(z[t>>1],6)+i|0;continue t}d=y[l+16|0];x[31721]=0;S(604,e+92|0,b|0,!m&(d|0)!=0);d=x[31721];x[31721]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;j=e+80|0;h=D(g,6)+i|0;Zo(j,e+60|0,h);d=y[e+80|0];J=Hc(j);j=y[J|0];if(d|j){v:{if(!(!M|(d&255)!=14)){d=0;v[J|0]=0;v[e+80|0]=0;j=y[J|0];break v}if(!M|(d&255)!=15|(j&255)>>>0<32){break v}j=31;v[J|0]=31;d=y[e+80|0]}xf(h,d&255,j&255)}d=1;w:{x:{y:{z:{A:{j=y[h+3|0];switch(j-14|0){case 2:break w;case 0:break z;case 3:break A;default:break y}}n=y[h+5|0]<100|n;W=1;break x}if(!k){break x}v[h+5|0]=0;break x}if((j|0)==9&q){d=y[h+5|0];if((d|0)==164){v[h+3|0]=20;v[h+5|0]=145;break x}aa=h,ba=Zg(d<<1),v[aa+5|0]=ba;break x}if((j|0)!=19){break x}d=y[h+5|0];if(d>>>0>15){break x}j=!(d&1);d=(j^X)&1;X=d?j:X;G=d+G|0}d=f}B:{if(!y[h|0]){f=y[h+1|0];if(!f|B){break B}j=y[vb(x[H>>2],g)|0];if(!j|(f|0)==(j|0)){break B}j=vb(x[I>>2],g);f=y[j|0]+1|0;v[j|0]=f;if((f&255)>>>0<4){break B}x[31721]=0;U(269,r|0,85,1)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break B}break u}aa=vb(x[I>>2],g),ba=0,v[aa|0]=ba}f=y[h+1|0];if(f){aa=vb(x[H>>2],g),ba=f,v[aa|0]=ba}g=g+1|0;f=d;continue}break}}break}i=N()|0;cc(I);break q}cc(I);cc(H);m=m+1|0;continue}break}i=N()|0}cc(H);break n}h=n}C:{D:{E:{d=s^1;if((d|Y)&1){break E}F:{if(me(e+364|0,16750)){break F}if(me(e+364|0,17517)){break F}if(!me(e+364|0,13681)){break E}}x[a+480208>>2]=x[a+480208>>2]|2162688;f=Lb(Lb(Lb(r,85,1),91,1),92,1);G:{if(y[e+179|0]>47){break G}f=Lb(f,84,1);if(y[e+181|0]==127){break G}Lb(f,83,1)}if(!((G|0)>6|F)){break D}break C}if(!(s&1)){if(!(y[e+181|0]==127&(T&65535)>>>0<129&u)){break C}x[l>>2]=8494;break C}if((G|0)>6|F){break C}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((u|F)==1){Lb(r,89,1)}if(L){Lb(r,84,1)}i=0;H:{if(!(c&2)){break H}bd(b,z[l+8>>1]+(D(O,V)<<8)|0);f=(d|u^1|Z)&1;g=1;while(1){if((g|0)==32){i=i&1;break H}n=D(g,104)+a|0;c=n+484380|0;d=x[c>>2];if(d){j=2;if(!L){d=LX(b,13884);j=d?10:0;i=d?1:i;d=x[c>>2]}k=Wc(e+312|0,8,1,0,j);d=dD(k,d)+x[b+8>>2]|0;if(!f){aa=c,ba=x[$c(c,n+484388|0)>>2],x[aa>>2]=ba}ag(k,c,b);bd(b,d)}g=g+1|0;continue}}I:{J:{if(!u){if(!((me(e+364|0,17517)&h^-1|o)&1)){break J}break I}if((h^-1|o)&1){break I}}b=KX(e+128|0,0);c=x[b+20>>2];x[e+48>>2]=x[b+16>>2];x[e+52>>2]=c;c=x[b+12>>2];x[e+40>>2]=x[b+8>>2];x[e+44>>2]=c;c=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=c;b=e+312|0;pv(b,a,0,e+32|0);_=C[x[e+312>>2]>>3];Ui(b);if(!(_>=480)){break I}c=Lb(r,5,1);b=IX(e+104|0,_);d=x[b+20>>2];x[e+24>>2]=x[b+16>>2];x[e+28>>2]=d;d=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=d;d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;b=e+312|0;pv(b,a,0,e+8|0);d=y[x[e+312>>2]+26|0];Ui(b);if(d){Zf(c,5);break I}x[l>>2]=17084}f=e+364|0;d=f;b=dc(d);c=d;while(1){if((b|0)!=(d|0)){h=y[d|0];v[c|0]=h>>>0<=32?32:h;c=c+1|0;d=d+1|0;continue}break}dg(e+92|0,16837);x[31721]=0;b=U(45,e+68|0,f|0,b|0)|0;c=x[31721];x[31721]=0;K:{L:{M:{N:{O:{if((c|0)!=1){x[31721]=0;S(605,e+80|0,1,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break O}x[31721]=0;S(142,e+312|0,e+92|0,e+80|0);c=x[31721];x[31721]=0;if((c|0)==1){break N}c=e+312|0;yb(a+1298344|0,c);tb(c);tb(e+80|0);tb(b);Eb(e+92|0);b=rc(c,12386);yb(a+1298356|0,b);tb(b);b=x[l>>2];if(b){_h(a+1298368|0,b)}aa=a+1298404|0,ba=x[Ec(e+312|0,28)>>2],x[aa>>2]=ba;if(i){break K}break a}i=N()|0;break L}i=N()|0;break M}i=N()|0;tb(e+80|0)}tb(b)}Eb(e+92|0);break n}b=rc(e+312|0,17136);x[31721]=0;P(77,a+1298368|0,b|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){tb(b);break a}i=N()|0;tb(b)}Q(i|0);p()}else{d=y[l+16|0];k=fb-16|0;fb=k;P:{q=e+180|0;if(!FX(b,q)|!d){break P}qv(k+8|0,q);d=0;while(1){if(d>>>0>=30){break P}o=x[k+8>>2];pg(vb(o,d),vb(o,d|1));d=d+2|0;continue}}fb=k+16|0;k=D(g,104)+a|0;d=k+484380|0;q=DC(q,d,((g<<5)+a|0)+946304|0,z[r>>1]==4);d=x[d>>2];Q:{if(m){v[k+484417|0]=0-(y[e+204|0]<<3);break Q}n=d>>>0<65536&n}k=Cb(y[e+202|0]|y[e+203|0]<<8);R:{if(k){Y=!Cb(y[e+208|0]|y[e+209|0]<<8)|Y;break R}Z=y[e+205|0]==64|Z}o=i&1;i=0;S:{if(!o){break S}h=(k<<1)+h|0;o=y[e+204|0];i=!o;if(o|!k){break S}i=y[e+205|0]==64}j=j+q|0;f=d+f|0;g=g+1|0;continue}}fb=e+368|0;return K|0}function Ata(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;vc(a);a:{b:{if(b>>>0<=2){H=e,I=Xd(a),v[H+56|0]=I;Ub(a,2);b=dh(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Mg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}bp(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{q=d+484344|0;E=Hd(y[e+58|0]|y[e+59|0]<<8,1,1024);o=PD(q,E);if((o|0)==65535){break c}b=Vb(x[d+484344>>2],o);m=jd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];F=z[Lc(e+12|0,e+44|0)>>1];g=F+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;u=Uv(e+44|0,g,e+12|0);G=d+480188|0;d:while(1){if((k|0)==(E|0)){cc(u);break c}e:{f:{f=vb(x[u>>2],0);d=y[f|0];g:{if(!d){x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}H=vb(x[u>>2],0),I=f,v[H|0]=I}v[e+12|0]=0;h:{i:{f=g&63;if(!f){break i}x[31721]=0;i=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break h}v[e+12|0]=i;j:{k:{switch(f-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[af(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!i){break i}v[c+15|0]=i;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,i),15);break j;case 2:v[c+13|0]=i>>>4;if(i>>>0>=16){b=y[c+12|0];i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b){break g}break f}i=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b&1){break g}break f;case 3:s=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0>=256-i>>>0?-1:d+i|0;break j;case 6:break k;default:break i}}if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0<=i+1>>>0?1:d-i|0}i=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b&1){break g}break f}break e}v[f|0]=d-1;i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(!(b&1)){break f}}d=y[c+13|0];b=y[c+12|0];if(b){s=0;if(!d){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(d,y[c+15|0])<<1;d=x[We(e+12|0,e+32|0)>>2];break l}d=D(y[c+14|0],30)+30|0}b=255;f=0;m=0;while(1){m:{if(b){g=D(b,d);m=(g|0)/48|0;if(g-1536>>>0>=10752){break m}f=b}x[e+36>>2]=m;x[e+40>>2]=f;Ee(e+36|0,32,255);s=1;x[e+12>>2]=1;H=c,I=x[We(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}B=k-1|0;C=1;b=Vb(x[q>>2],o);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],k,1);while(1){h=C&65535;if(h>>>0>F>>>0){if(s){b=e+12|0;xe(Vb(x[q>>2],o),Vh(ap(Ve(Le(b,17,y[e+36|0]),k),0)));xe(Vb(x[q>>2],o),Vh(Ve(Le(b,16,y[e+40|0]),k)))}if(i>>>0>=16){xe(Vb(x[q>>2],o),d$(Ve(Le(e+12|0,20,i>>>4|224),k)))}b=i&15;if(b){xe(Vb(x[q>>2],o),d$(Ve(Le(e+12|0,20,Hd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),k)))}k=k+1|0;b=0;continue d}n:{o:{p:{q:{r:{f=vb(x[u>>2],h);d=y[f|0];if(!d){x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}H=vb(x[u>>2],h),I=f,v[H|0]=I}m=1;l=g&255;if(l&64){x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}v[b+1|0]=f;m=!f}if(!(l&32)){f=y[b|0];break r}x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}v[b|0]=f;if((f-1&255)>>>0<=107){d=dm(f+24|0);v[b|0]=d;H=Vc(x[c>>2],h),I=d,v[H+1|0]=I;f=y[b|0];break o}if((f+127&255)>>>0<=107){d=dm((f&127)+24|0);H=Vc(x[c>>2],h),I=d,v[H|0]=I;v[b|0]=0;break q}if((f|0)!=255){break r}f=254;break p}v[f|0]=d-1;break n}if(f&255){break o}}if(!y[b+1|0]){f=0;break o}f=y[Vc(x[c>>2],h)+1|0];v[b+1|0]=0}v[b|0]=f}if(Sc(f)){H=Vc(x[c>>2],h),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(l&16){v[b+2|0]=1;x[31721]=0;f=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}v[b+4|0]=f+2>>>2}f=0;A=0;t=0;s:{if(!(l&8)){break s}x[31721]=0;g=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;t=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}t:{switch(g-1|0){case 0:v[b|0]=254;break s;case 1:v[b|0]=255;break s;case 2:d=Vc(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 3:d=Tv(t,y[c+16|0]);t=d?d|-48:0;A=d?20:0;if(y[b|0]){break s}d=Vc(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 4:v[e+12|0]=1;H=e,I=Tv(t,y[c+16|0]),v[H+32|0]=I;t=y[af(e+12|0,e+32|0)|0];H=Vc(x[c>>2],h),I=0,v[H+5|0]=I;A=15;break s;case 5:case 6:case 7:case 8:u:{if(!k){break u}if((g|0)==y[Vc(x[c>>2],h)+4|0]){break u}if(!xe(Vb(x[q>>2],o),sn(ap(Ve(Le(e+12|0,20,(g+122|160)&255),B),h)))){break u}H=Vc(x[c>>2],h),I=g,v[H+4|0]=I}d=Vc(x[c>>2],h);if(!y[b|0]){v[b|0]=y[d+1|0]}v[d+5|0]=0;A=10;break s;case 9:break t;default:break s}}d=Vc(x[c>>2],h);g=y[d+5|0];v[d+5|0]=g^1;t=g?-98:-97;A=20}v:{w:{x:{if(!(l&4)){break x}x[31721]=0;r=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;j=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}v[e+31|0]=j;g=1;f=1;y:{switch(r-1|0){case 0:OD(e+12|0,j<<24>>24<<3,128);d=y[b|0];if(Sc(d)){H=b,I=dm(d+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;f=35;break x;case 1:d=Tv(j,y[c+16|0]);v[e+31|0]=d;if(!d){break w}v[e+31|0]=d|208;f=20;break v;case 3:case 4:H=e,I=c$(j,y[c+16|0],1),v[H+31|0]=I;f=(r|0)==4?2:3;break v;case 5:if(!y[b|0]){H=b,I=y[Vc(x[c>>2],h)|0],v[H|0]=I}H=e,I=c$(j,y[c+16|0],0),v[H+31|0]=I;f=4;break v;case 6:H=b,I=dm(j+25|0),v[H|0]=I;v[e+31|0]=255;f=4;break v;case 7:case 8:case 9:z:{if(!k){break z}if((r|0)==y[Vc(x[c>>2],h)+2|0]){break z}if(!xe(Vb(x[q>>2],o),sn(ap(Ve(Le(e+12|0,20,(r-8|48)&255),B),h)))){break z}H=Vc(x[c>>2],h),I=r,v[H+2|0]=I}H=e,I=ND(j,y[c+16|0]),v[H+31|0]=I;f=5;break v;case 10:H=e,I=b$(j,y[c+16|0]),v[H+31|0]=I;f=18;break v;case 11:d=Tv(j,y[c+16|0]);v[e+31|0]=d;if(d){v[e+31|0]=d|192;f=20;break v}v[b|0]=254;break w;case 2:break v;default:break y}}f=0}g=0;break v}f=0}n=0;r=1;A:{if(l&2){x[31721]=0;j=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;l=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}v[e+30|0]=l;n=9;r=0;d=0;B:{switch(j-1|0){case 0:case 1:d=1;H=e,I=a$(l,y[c+16|0],(j|0)==1),v[H+30|0]=I;n=11;break A;case 2:H=e,I=b$(l,y[c+16|0]),v[H+30|0]=I;d=1;n=18;break A;case 3:case 4:case 5:C:{if(!k){break C}if((j|0)==y[Vc(x[c>>2],h)+3|0]){break C}if(!xe(Vb(x[q>>2],o),sn(ap(Ve(Le(e+12|0,20,(j-4|64)&255),B),h)))){break C}H=Vc(x[c>>2],h),I=j,v[H+3|0]=I}H=e,I=ND(l,y[c+16|0]),v[H+30|0]=I;d=1;n=8;break A;case 7:case 8:H=e,I=a$(l,y[c+16|0],(j|0)==8),v[H+30|0]=I;d=1;n=29;break A;case 9:H=e,I=ND(l,y[c+16|0]),v[H+30|0]=I;d=1;n=27;break A;case 6:break A;default:break B}}n=0;r=1}d=0}if(g){$_(b,k,z[G>>1],f,e+31|0)}if(d){$_(b,k,z[G>>1],n,e+30|0)}D:{E:{F:{G:{H:{if(!m){break H}if(!Sc(y[b|0])){break H}if(!f){break G}if(!r|(f|0)==4){break H}v[e+30|0]=255;n=4}d=b+2|0;if(y[b+2|0]!=1){break D}if(f){break F}v[e+31|0]=y[b+4|0];f=13;break E}v[e+31|0]=255;d=b+2|0;f=4;if(y[b+2|0]!=1){break D}}if(n){break D}v[e+30|0]=y[b+4|0];n=13}v[d|0]=0}g=Ig(e+12|0);un(e+32|0,g,f,y[e+31|0],n,y[e+30|0]);I:{if(y[d|0]){break I}f=y[e+14|0];if(!f){break I}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}m=y[e+15|0];J:{if(A){un(e+32|0,g,m&255,y[e+17|0],A,t&255);K:{if(y[d|0]){break K}d=y[e+14|0];if(!d){break K}v[b+2|0]=d;v[b+4|0]=y[e+16|0]}m=y[e+15|0];break J}if(!(m&255)){break n}}v[b+3|0]=m;v[b+5|0]=y[e+17|0]}b=b+6|0;C=C+1|0;continue}}break}a=N()|0;cc(u);Q(a|0);p()}else{v[m+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return o|0}function HO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-32|0;fb=f;d=Cc(f+20|0,11600);e=nh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){jo(a,x[b+24>>2]+1298356|0);break e}d=Cc(f+20|0,11005);e=nh(c,d);tb(d);if(e){jo(a,x[b+24>>2]+1298344|0);break e}d=Cc(f+20|0,11430);e=nh(c,d);tb(d);if(e){jo(a,x[b+24>>2]+1298392|0);break e}d=Cc(f+20|0,10997);e=nh(c,d);tb(d);if(e){jo(a,x[b+24>>2]+1298380|0);break e}d=Cc(f+20|0,8243);e=nh(c,d);tb(d);if(e){d=f+20|0;c=x[x[b+24>>2]+480184>>2];b=31040;f:{g:{while(1){if((b|0)==31088){break g}if((c|0)!=x[b>>2]){b=b+12|0;continue}break}c=fb-32|0;fb=c;e=c+8|0;Dw(e,x[b+8>>2]);x[31721]=0;S(126,c+20|0,0,e|0);b=x[31721];x[31721]=0;h:{i:{j:{if((b|0)!=1){x[31721]=0;O(12,d|0,c+20|0);b=x[31721];x[31721]=0;if((b|0)==1){break j}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31721]=0;O(1067,a|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}tb(f+20|0);break e}d=Cc(f+20|0,10982);e=nh(c,d);tb(d);if(e){i=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;b=31040;h=mg(c+36|0);l=f+20|0;d=Fb(l);while(1){if((b|0)!=31088){if(x[b>>2]==(i|0)){x[31721]=0;e=P(1,c+24|0,x[b+4>>2])|0;g=x[31721];x[31721]=0;k:{l:{m:{n:{o:{p:{if((g|0)!=1){x[31721]=0;S(894,c+16|0,h|0,e|0);g=x[31721];x[31721]=0;if((g|0)==1){break n}if(!y[c+20|0]){break k}if(!zd(x[d+4>>2],y[d+11|0])){x[31721]=0;g=P(1,c+4|0,18380)|0;k=x[31721];x[31721]=0;if((k|0)==1){break p}x[31721]=0;P(77,d|0,g|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break o}tb(g)}x[31721]=0;P(77,d|0,e|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(g);break m}b=N()|0}tb(e)}tb(d);sR(h);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}sR(h);fb=c+48|0;x[31721]=0;O(1067,a|0,l|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,8309);e=nh(c,d);tb(d);if(e){jo(a,x[b+24>>2]+1298368|0);break e}d=Cc(f+20|0,5620);e=nh(c,d);tb(d);if(e){jo(a,x[b+24>>2]+1298320|0);break e}d=Cc(f+20|0,12004);e=nh(c,d);tb(d);if(e){c=f+20|0;gg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31721]=0;S(1061,a|0,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,11373);e=nh(c,d);tb(d);if(e){d=WL(x[b+24>>2]);c=x[d+4>>2];q:{if(!kc(x[d>>2],c)){e=VL(c);d=fb-32|0;fb=d;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;c=fb-48|0;fb=c;oF(c+24|0,e,e+4|0,e+8|0,e+12|0,e+16|0,e+24|0);oF(c,d,d+4|0,d+8|0,d+12|0,d+16|0,d+24|0);e=x[c+28>>2];h=x[c+4>>2];fb=c+48|0;fb=d+32|0;if(x[e>>2]==x[h>>2]&x[x[c+24>>2]>>2]==x[x[c>>2]>>2]&x[x[c+32>>2]>>2]==x[x[c+8>>2]>>2]&x[x[c+36>>2]>>2]==x[x[c+12>>2]>>2]&x[x[c+40>>2]>>2]==x[x[c+16>>2]>>2]){e=x[c+44>>2];h=x[c+20>>2];c=x[e>>2]==x[h>>2]&x[e+4>>2]==x[h+4>>2]}else{c=0}if(c^1){break q}}Fb(a);break e}h=f+20|0;b=x[b+24>>2];e=VL(x[WL(b)+4>>2]);g=x[b+1298408>>2];d=fb-512|0;fb=d;i=x[e+32>>2];r:{if(i){c=2147483647;j=De(+(i>>>0)/18.2);b=-1;s:{if(j>=0x8000000000000000){break s}c=-2147483648;b=0;if(j<=-0x8000000000000000){break s}if(F(j)<0x8000000000000000){c=F(j)>=1?~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~j>>>0;break s}b=0}if((g|0)==1){g=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=g;g=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=g;g=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=g;g=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=g;pu(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;g=KA(qS(d+128|0),hb);c=c+hb|0;i=b;b=b+g|0;c=i>>>0>b>>>0?c+1|0:c;oS(e,pS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;lN(h,d+96|0);break r}g=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=g;g=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=g;g=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=g;g=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=g;pu(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;g=KA(qS(d+256|0),hb);c=c+hb|0;i=b;b=b+g|0;c=i>>>0>b>>>0?c+1|0:c;oS(e,pS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;pu(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;mO(h,d+192|0);break r}if((g|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;pu(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;lN(h,d);break r}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;mO(h,d- -64|0)}fb=d+512|0;x[31721]=0;O(1067,a|0,h|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,12273);e=nh(c,d);tb(d);if(e){YU(f+20|0,x[b+24>>2]+1298332|0);t:{if(!zd(x[f+24>>2],y[f+31|0])){break t}c=x[x[b+24>>2]+480180>>2];u:{v:{if((c|0)==33554432){break v}d=1;if((c|0)==32){break u}if((c|0)==16384){break v}if((c|0)==16777216){break u}}d=2}w:{switch(d-1|0){case 0:x[31721]=0;O(1068,f+8|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){c=f+8|0;yb(f+20|0,c);tb(c);break t}break b;case 1:break w;default:break t}}x[31721]=0;O(1069,f+8|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=f+8|0;d=yb(f+20|0,c);tb(c);if(!zd(x[f+24>>2],y[f+31|0])){break t}x[31721]=0;O(1068,f+8|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=f+8|0;yb(d,c);tb(c)}b=x[b+24>>2];x[31721]=0;S(1061,a|0,b|0,f+20|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(f+20|0);break e}break b}d=Cc(f+20|0,5472);e=nh(c,d);tb(d);if(e){c=f+20|0;YU(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31721]=0;S(1061,a|0,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}i=c;c=Cc(f+20|0,7335);d=nh(i,c);tb(c);if(d){a=Fb(a);m=f,n=wb(x[b+68>>2]),x[m+20>>2]=n;b=wb(x[b+72>>2]);c=1;while(1){d=x[f+20>>2];if(!Ib(d,b)){break e}if(!(c&1)){x[31721]=0;P(993,a|0,22225)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}}x[31721]=0;P(844,a|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}Uq(f+20|0);c=0;continue}}Cc(a,22250)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function IQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=fb-336|0;fb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;Wf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;Wf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;If(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];If(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;If(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];If(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;If(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];If(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;If(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];If(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;If(k+160|0,i,d,0,0,h,e,0,0);d=h;If(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;If(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);If(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=zua(y,l,j,0);j=hb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=zua(s,p,y,q);d=j+H|0;h=hb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=zua(e,j,E,w);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=zua(F,p,y,q);d=e+d|0;j=hb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=zua(F,p,B,w);m=hb;h=e;e=zua(E,w,y,q);l=h+e|0;j=hb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=zua(i,0,E,w);h=hb;e=d;i=zua(z,r,s,r);d=d+i|0;j=hb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=zua(B,w,J,0);n=e+d|0;j=hb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=zua(F,p,H,r);I=hb;F=d;h=zua(y,q,J,r);d=d+h|0;j=hb+I|0;o=d;p=zua(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+hb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=zua(s,r,B,w);p=l+j|0;l=hb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=zua(z,r,J,r);z=hb;m=d;h=zua(s,r,H,r);d=d+h|0;j=hb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;If(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;If(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Wm(k- -64|0,d,e,h,i,1-b|0);Wf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];If(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;If(k+16|0,f,g,D,C,3,0,0,0);If(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;fb=k+336|0}function rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=fb-1328|0;fb=d;vc(b);e=fb-16|0;fb=e;mX(e+8|0,d+220|0);h=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){Ub(b,x[e+12>>2])}fb=e+16|0;a:{if((h|0)!=(j|0)){break a}if(!oX(d+220|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(nX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}if(!c){l=1;break a}vc(b);b=Fe(d+220|0,b);x[31721]=0;O(645,d+208|0,b|0);e=x[31721];x[31721]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){ub(b);x[31721]=0;S(646,d+196|0,d+208|0,1196314451);b=x[31721];x[31721]=0;if((b|0)==1){break i}x[31721]=0;S(646,d+184|0,d+208|0,1280331091);b=x[31721];x[31721]=0;if((b|0)==1){break h}if(kc(x[d+196>>2],x[d+200>>2])){break b}if(!kc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31721]=0;O(249,a|0,1);b=x[31721];x[31721]=0;j:{if((b|0)!=1){bg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;F=d,G=wb(x[d+184>>2]),x[F+52>>2]=G;f=c&2;m=wb(x[d+188>>2]);e=a+480190|0;k:{l:{while(1){h=x[d+52>>2];if(!Ib(h,m)){break l}b=z[e>>1];if(!ri(b)){break l}b=b+1|0;w[e>>1]=b;x[31721]=0;b=D(b&65535,104)+a|0;j=b+484380|0;O(282,j|0,1);i=x[31721];x[31721]=0;m:{n:{if((i|0)!=1){x[31721]=0;i=P(647,h|0,d+220|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break n}if(!i){break c}if(nv(d+220|0)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31721]=0;i=P(37,d+172|0,d+220|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break k}xc(((z[e>>1]<<5)+a|0)+946304|0,i);tb(i);i=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[j>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;o:{if(f){b=Wc(d+24|0,8,1,0,0);x[31721]=0;U(218,b|0,j|0,h|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break o}}Yf(d+52|0);continue}break}c=N()|0;break j}F=d,G=wb(x[d+196>>2]),x[F+168>>2]=G;q=a+484344|0;r=c&1;s=a+484360|0;C=wb(x[d+200>>2]);n=a+484376|0;o=a+480190|0;t=a+484380|0;u=a+946304|0;c=1;l=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,C)){break v}if(!(c&1)){x[31721]=0;c=R(277,s|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break u}if(!c){break v}}gj(Wb(x[a+484360>>2],y[n|0]));x[31721]=0;c=P(648,b|0,d+220|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break t}if(!(c&!(y[d+1306|0]|y[d+1307|0]<<8))|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}c=y[n|0];e=x[a+484360>>2];x[31721]=0;O(649,d+156|0,d+220|0);h=x[31721];x[31721]=0;if((h|0)==1){break t}e=Wb(e,c);c=d+156|0;hp(e,c);tb(c);w:{if(r){x[31721]=0;S(188,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31721];x[31721]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31721]=0;b=R(171,d+116|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break s}dG(d+52|0,b)}b=d+52|0;m=hc(d+136|0,b);ub(b);if(!r){ub(d+116|0)}Tb(d+52|0,0,64);c=1;x:{y:{z:{while(1){if((c|0)==32){break z}b=(D(c,34)+d|0)+186|0;e=b+32|0;An(d+8|0,e);A:{B:{if(Pj(y[x[d+8>>2]])){break B}h=y[b- -64|0];if(h>>>0>15){break y}b=y[b+65|0];if(b>>>0>64){break y}if(!nv(e)){break y}j=b<<2;i=h<<4;h=0;b=1;while(1){f=b&65535;e=z[o>>1];if(f>>>0<=e>>>0){x[31721]=0;S(650,d+24|0,x[d+8>>2],x[d+12>>2]);e=x[31721];x[31721]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;g=d+24|0;ve(e+24|0,g);iX(e+16|0,((f<<5)+a|0)+946304|0);k=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=k;k=mC(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(g);C:{if(k){break C}F=Zb(d+52|0,c),G=b,w[F>>1]=G;e=D(f,104)+a|0;f=e+484410|0;g=z[f>>1];if((g|0)!=255){h=b;if(y[e+484417|0]!=(i&255)|(g|0)!=(j|0)){break C}}v[e+484417|0]=i;w[f>>1]=j;break B}b=b+1|0;continue}break}h=h&65535;if(!h){break B}if(!ri(e)){break B}b=e+1|0;w[o>>1]=b;F=Zb(d+52|0,c),G=b,w[F>>1]=G;b=D(z[o>>1],104)+t|0;jn(b);e=D(h,104)+t|0;f=Po(b,e);w[b+30>>1]=j;v[b+37|0]=i;dY(f,e);e=(h<<5)+u|0;h=x[e+4>>2];b=(z[o>>1]<<5)+u|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break r}i=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;j=65535;E=y[d+1308|0]|y[d+1309|0]<<8;h=0;D:while(1){E:{if(h){break E}b=x[m>>2];x[31721]=0;b=U(153,b|0,x[d+144>>2],1)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}if(b){break E}c=j;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31721]=0;j=P(370,q|0,64)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}c=65535;if((j|0)==65535){break q}b=y[n|0];c=x[a+484360>>2];e=0;x[31721]=0;O(540,Wb(c,b)|0,j|0);b=x[31721];x[31721]=0;if((b|0)==1){break x}}b=0;c=Vb(x[q>>2],j&65535);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(E|0)){continue D}f=(d+24|0)+D(b,7)|0;g=y[f+6|0];G:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=h-1|0;break G}g=x[m>>2];x[31721]=0;g=U(153,g|0,x[d+144>>2],1)|0;k=x[31721];x[31721]=0;if((k|0)==1){break r}if(!g){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){i=Wb(x[a+484360>>2],y[n|0]);Ze(i,SD(x[i>>2],x[i+4>>2]));i=e}x[31721]=0;g=R(200,m|0)|0;k=x[31721];x[31721]=0;H:{if((k|0)!=1){g=g<<24>>24;if((g|0)>=0){break H}g=g&127;v[f+6|0]=g;k=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=k;v[c+5|0]=k>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=g+h|0;break G}break r}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[31721]=0;g=R(200,m|0)|0;k=x[31721];x[31721]=0;I:{J:{if((k|0)!=1){g=g<<24>>24;F=c,G=y[Zb(d+52|0,g&31)|0],v[F+1|0]=G;if((g|0)>=0){break J}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break I}break r}x[31721]=0;O(201,d+8|0,m|0);g=x[31721];x[31721]=0;K:{if((g|0)!=1){g=y[d+8|0];if(g>>>0>19){break I}A=g<<1;B=y[A+25296|0];v[c+3|0]=B;k=y[Hc(d+8|0)|0];v[c+5|0]=k;if((B|0)!=16|k>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>g&1){break I}v[c+5|0]=y[A+25297|0]|k&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}l=0;break p}break r}_j(s,0);x[31721]=0;b=P(1,d+220|0,6467)|0;c=x[31721];x[31721]=0;L:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,d+52|0,6804)|0;c=x[31721];x[31721]=0;if((c|0)==1){break L}yb(a+1298356|0,b);tb(b);F=a+1298404|0,G=x[Ec(d+24|0,4)>>2],x[F>>2]=G;l=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(m);break j}c=c&65535;if(!(!((i|0)!=0|b>>>0<63)|(c|0)==65535)){xe(Vb(x[q>>2],c),Vh(Ve(Le(d+8|0,14,i&255),b)))}c=32}ub(m);if(c>>>0<32){break b}Yf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Pc(d+184|0)}Pc(d+196|0)}fe(d+208|0)}Q(c|0);p()}l=0}Pc(d+184|0);Pc(d+196|0);fe(d+208|0)}fb=d+1328|0;return l|0}function oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=0,_=0,$=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];KP(a);if(g==B[a+4268>>2]){break a}Hz(a)}b:{if(!y[a+5045|0]){break b}if(!wi(a+44|0)){break b}i=x[a+44>>2];p=Gc(i,0);q=Gc(i,1);i=x[a+56>>2];l=Gc(i,0);m=Gc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;C=a+4628|0;D=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;_=Mc(x[a+4864>>2],x[W>>2],x[a+4880>>2]),$=g,B[_>>2]=$;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;_=Mc(x[a+4888>>2],x[X>>2],x[a+4904>>2]),$=g,B[_>>2]=$;g=E(E(E(E(E(li(t,x[a+4356>>2])*E(.6800000071525574))+E(li(t,x[a+4360>>2])*E(-.5)))-E(li(t,x[a+4364>>2])*E(.6200000047683716)))+E(li(t,x[a+4368>>2])*E(-.5)))-E(li(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Mc(x[a+4816>>2],x[T>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));_=Mc(x[a+4816>>2],x[T>>2],x[a+4832>>2]),$=E(e-E(g*E(.6180340051651001))),B[_>>2]=$}u=B[a+4280>>2];_=a,$=E(li(t,x[a+4352>>2])+B[a+5020>>2]),B[_+5020>>2]=$;e=E(li(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Mc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Mc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;P=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(P+E(f*h));_=Mc(x[a+4624>>2],x[C>>2],x[a+4640>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4976>>2]-B[Mc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Mc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));_=Mc(x[a+4600>>2],x[D>>2],x[a+4616>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Mc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Mc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));_=Mc(x[a+4576>>2],x[N>>2],x[a+4592>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4968>>2]-B[Mc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Mc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));_=Mc(x[a+4552>>2],x[O>>2],x[a+4568>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}_=Mc(x[a+4912>>2],x[Q>>2],x[a+4928>>2]),$=f,B[_>>2]=$;e=E(B[Mc(x[a+4912>>2],x[Q>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Mc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Mc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));_=Mc(x[a+4528>>2],x[F>>2],x[a+4544>>2]),$=E(f-E(o*h)),B[_>>2]=$;e=E(E(E(B[a+4960>>2]-B[Mc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Mc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));_=Mc(x[a+4504>>2],x[G>>2],x[a+4520>>2]),$=E(h-E(e*o)),B[_>>2]=$;B[a+5020>>2]=o;e=E(E(E(E(E(li(s,x[a+4380>>2])*E(.7070000171661377))+E(li(s,x[a+4384>>2])*E(-.6000000238418579)))-E(li(s,x[a+4388>>2])*E(.5)))+E(li(s,x[a+4392>>2])*E(-.6000000238418579)))-E(li(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Mc(x[a+4840>>2],x[S>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));_=Mc(x[a+4840>>2],x[S>>2],x[a+4856>>2]),$=E(f-E(e*E(.6180340051651001))),B[_>>2]=$}Y=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Mc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Mc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;P=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(P+E(f*j));_=Mc(x[a+4768>>2],x[H>>2],x[a+4784>>2]),$=E(f-E(j*k)),B[_>>2]=$;f=E(E(E(B[a+5e3>>2]-B[Mc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Mc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));_=Mc(x[a+4744>>2],x[I>>2],x[a+4760>>2]),$=E(k-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Mc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Mc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));_=Mc(x[a+4720>>2],x[L>>2],x[a+4736>>2]),$=E(f-E(j*h)),B[_>>2]=$;f=E(E(E(B[a+4992>>2]-B[Mc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Mc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));_=Mc(x[a+4696>>2],x[M>>2],x[a+4712>>2]),$=E(h-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*Y);_=Mc(x[a+4936>>2],x[R>>2],x[a+4952>>2]),$=f,B[_>>2]=$;g=E(B[Mc(x[a+4936>>2],x[R>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Mc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Mc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));_=Mc(x[a+4672>>2],x[J>>2],x[a+4688>>2]),$=E(e-E(f*g)),B[_>>2]=$;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Mc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Mc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));_=Mc(x[a+4648>>2],x[K>>2],x[a+4664>>2]),$=E(g-E(u*e)),B[_>>2]=$;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];Li(n,b,c,Gc(a,0),Gc(a,1),d)}}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=fb-256|0;fb=g;d=fb-112|0;fb=d;f=Fe(g+76|0,c);x[31721]=0;n=R(171,f+20|0)|0;c=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31721]=0;q=R(171,f+40|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break B}x[31721]=0;r=R(171,f+60|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break A}x[31721]=0;i=R(171,f+80|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break z}x[31721]=0;o=R(171,f+100|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break y}x[31721]=0;k=R(171,f+120|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}j=Nb(f+140|0);vc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31721]=0;e=P(812,f|0,d+100|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break w}if(!e){break n}e=x[d+100>>2];if((e|0)!=1414744396&(e|0)!=1179011410){break n}c=x[d+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(e|0)==1414744396;x[31721]=0;S(813,d+88|0,f|0,2);c=x[31721];x[31721]=0;if((c|0)==1){break v}h=x[d+88>>2];C:{if(vr(h,x[d+92>>2])>>>0<4){break C}c=hA(h,1);e=x[c>>2];c=x[c+4>>2];ti(d+36|0,e,c);if(x[d+36>>2]!=1635017060){break C}ti(d+60|0,e,c);if(!(v[d+64|0]&1)){break C}c=hA(h,2);ti(d+16|0,x[c>>2],x[c+4>>2]);if(y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24)){break C}c=hA(h,3);ti(d+80|0,x[c>>2],x[c+4>>2]);if(x[d+80>>2]){break C}x[31721]=0;P(152,f|0,12)|0;c=x[31721];x[31721]=0;if((c|0)==1){break u}x[31721]=0;S(813,d+36|0,f|0,1);c=x[31721];x[31721]=0;if((c|0)==1){break t}c=d+36|0;lv(d+88|0,c);fe(c)}x[31721]=0;S(814,d+60|0,d+88|0,544501094);c=x[31721];x[31721]=0;if((c|0)==1){break s}x[31721]=0;e=P(815,d+60|0,f+156|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}if(!e){break o}e=z[f+156>>1];if((e|0)!=1){break q}x[31721]=0;e=R(205,d+60|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break r}break k}e=N()|0;break b}e=N()|0;break c}e=N()|0;break d}e=N()|0;break e}e=N()|0;break f}e=N()|0;break g}e=N()|0;break h}e=N()|0;break h}e=N()|0;break i}e=N()|0;break i}e=N()|0;break i}if((e|0)==4){x[31721]=0;h=R(195,d+60|0)|0;c=x[31721];x[31721]=0;D:{if((c|0)!=1){x[31721]=0;e=R(195,d+60|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break D}if((h|0)!=2|(e|0)!=1){break p}v[f+177|0]=1;break p}e=N()|0;break j}e=N()|0;break j}e=z[f+156>>1]}if((e&65535)!=65534){break p}x[31721]=0;e=P(816,d+60|0,d+36|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break l}if(!e){break o}c=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);x[d+8>>2]=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);x[d+12>>2]=c;c=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);x[d>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[d+4>>2]=c;c=d+16|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);w[c+4>>1]=y[d+4|0]|y[d+5|0]<<8;w[c+6>>1]=y[d+6|0]|y[d+7|0]<<8;s=c,t=cA(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24),y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31721]=0;S(814,d+36|0,d+88|0,1635017060);c=x[31721];x[31721]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=d+36|0;m=gd(n,c);ub(c);c=x[m>>2];x[31721]=0;e=R(175,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}if(!e){x[31721]=0;S(814,d+36|0,d+88|0,544039792);c=x[31721];x[31721]=0;if((c|0)==1){break J}c=d+36|0;gd(m,c);ub(c)}x[31721]=0;S(814,d+36|0,d+88|0,1952670054);c=x[31721];x[31721]=0;if((c|0)==1){break I}x[31721]=0;e=R(154,d+36|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break H}x[f+152>>2]=e;ub(d+36|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];e=nR(h,z[f+170>>1]);if(!e){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<e<<1>>>0?c:0){break G}c=x[m>>2];x[31721]=0;e=R(157,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}c=nR(z[f+158>>1],z[f+170>>1]);break F}e=N()|0;break j}e=N()|0;break j}e=N()|0;break j}e=N()|0;ub(d+36|0);break j}c=x[m>>2];x[31721]=0;e=R(157,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(e>>>0)/((c&65535)>>>0)}x[31721]=0;e=P(817,f|0,d+88|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}w[f+174>>1]=e;x[31721]=0;O(818,f|0,d+88|0);c=x[31721];x[31721]=0;if((c|0)==1){break k}x[31721]=0;S(814,d+36|0,d+88|0,1886221175);c=x[31721];x[31721]=0;if((c|0)==1){break m}c=d+36|0;gd(o,c);ub(c)}ub(d+60|0);fe(d+88|0)}fb=d+112|0;break a}e=N()|0;break j}e=N()|0;break j}e=N()|0}ub(d+60|0)}fe(d+88|0)}fe(j);ub(k)}ub(o)}ub(i)}ub(r)}ub(q)}ub(n)}ub(f);Q(e|0);p()}c=x[f+20>>2];x[31721]=0;e=R(748,c|0)|0;c=x[31721];x[31721]=0;K:{L:{if((c|0)!=1){M:{if(!e|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Dk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Dk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}e=Dk(f);c=28592;while(1){Q:{R:{if((c|0)!=28616){if((e|0)!=x[c>>2]){break R}}else{c=28616}break Q}c=c+4|0;continue}break}if((c|0)==28616){break M}Eu(a,b);x[31721]=0;e=P(37,g- -64|0,22250)|0;c=x[31721];x[31721]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=xc(((b<<5)+a|0)+946304|0,e);tb(e);x[31721]=0;e=D(b,104)+a|0;i=e+484380|0;O(282,i|0,0);c=x[31721];x[31721]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[e+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31721]=0;V(749,f|0,i|0,c|0,h|0);c=x[31721];x[31721]=0;if((c|0)==1){break W}Fe(g+44|0,f+20|0);e=z[f+158>>1];j=Wc(g+40|0,8,e>>>0>1?2:1,0,0);c=Dk(f);if((c|0)!=17|e>>>0>2){break U}uc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((e|0)==2)<<6|1;if(Bh(i)){break V}break S}l=N()|0;break K}l=N()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=Fe(g+20|0,g+44|0);e=z[f+158>>1];c=z[f+168>>1];x[31721]=0;b=x[k+12>>2];x[g+8>>2]=x[k+8>>2];x[g+12>>2]=b;x[g+16>>2]=x[k+16>>2];b=x[k+4>>2];x[g>>2]=x[k>>2];x[g+4>>2]=b;aa(750,j|0,h|0,g|0,c|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break L}Mj(i,a);break T}if((c|0)==85){x[31721]=0;c=U(577,a|0,b|0,g+44|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(nV(z[f+156>>1])){break Z}_:{if(!Bd(y[f+177|0])){break _}if((Dk(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=e<<2){break _}ed(j,32);b=12;break Y}if((Dk(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=e<<2){break Z}ed(j,32);b=13;break Y}if((Dk(f)&65534)!=6){break X}ed(j,16);b=(Dk(f)|0)==6?17:16}tg(j,b);x[31721]=0;U(218,j|0,i|0,g+44|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break T}break L}e=z[f+170>>1];c=e-1|0;b=c&-8;h=b&31;ed(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&255);if(e>>>0<9){tg(j,1)}if((Dk(f)|0)==3){tg(j,3)}x[31721]=0;U(218,j|0,i|0,g+44|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break L}}OB(i,x[a+480180>>2]);Mj(i,a);l=1}ub(g+44|0)}mV(f);fb=g+256|0;return l|0}l=N()|0;break K}l=N()|0;ub(g+44|0)}mV(f);Q(l|0);p()}function Eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!g$(b,e+206|0)){break m}if(!i$(e+206|0)){break m}if(!c){d=1;break m}Ad(a,131072);d=fb-16|0;fb=d;i=e+120|0;f=rc(d+4|0,3910);Zc(i,f);tb(f);fb=d+16|0;x[31721]=0;S(212,e+160|0,i|0,e+210|0);d=x[31721];x[31721]=0;n:{o:{p:{if((d|0)!=1){d=e+160|0;yb(a+1298344|0,d);tb(d);i=e+120|0;Eb(i);f=rc(d,11144);yb(a+1298356|0,f);tb(f);o=a+1298404|0,q=x[Ec(d,4)>>2],x[o>>2]=q;bE(i,3,e+219|0);Ac(d,i);yb(a+1298308|0,d);tb(d);si(i,3,e+249|0);sr(d,4,i);yb(a+1298320|0,d);tb(d);d=cp(d);o=d,q=Hd(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Hd(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;i=a+1298412|0;Vv(i);TD(i,d);m=e+128|0;i=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31721]=0;d=U(153,f|0,d|0,8)|0;f=x[31721];x[31721]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31721]=0;O(313,b|0,e- -64|0);d=x[31721];x[31721]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{g=y[e+210|0];switch(g-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(g>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}g=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=g;x[31721]=0;S(188,e+100|0,b|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break s}hc(m,e+100|0);x[31721]=0;O(314,i|0,e+120|0);d=x[31721];x[31721]=0;if((d|0)==1){break r}Fd(e+120|0);ub(e+100|0);x[31721]=0;P(186,b|0,f|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Fd(e+120|0);ub(e+100|0);break b}x[31721]=0;m=R(171,e+120|0)|0;b=x[31721];x[31721]=0;z:{A:{B:{if((b|0)!=1){x[31721]=0;S(315,e+100|0,i|0,1431389523);b=x[31721];x[31721]=0;if((b|0)==1){break B}d=e+100|0;b=gd(m,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31721]=0;d=R(192,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31721]=0;d=R(192,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31721]=0;g=R(205,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}x[31721]=0;S(241,Wb(f,d)|0,b|0,g>>>1|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}d=Wb(x[a+484360>>2],y[a+484376|0]);d=SD(x[d>>2],x[d+4>>2]);Qf(e+98|0,d);Qf(e+96|0,d);x[31721]=0;S(315,e+100|0,i|0,1414807888);d=x[31721];x[31721]=0;if((d|0)==1){break e}d=e+100|0;b=gd(b,d);ub(d);d=x[b>>2];x[31721]=0;d=R(175,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31721]=0;O(316,b|0,e+8|0);d=x[31721];x[31721]=0;if((d|0)==1){break f}o=a+480188|0,q=Hd(y[e+10|0],1,32)+1|0,w[o>>1]=q;x[31721]=0;d=P(217,e+84|0,z[e+8>>1])|0;f=x[31721];x[31721]=0;if((f|0)==1){break g}o=e,q=wb(x[d>>2]),x[o+44>>2]=q;g=wb(x[d+4>>2]);C:{D:{E:{while(1){h=x[e+44>>2];if(!Ib(h,g)){f=z[a+480188>>1];x[31721]=0;f=P(317,e+100|0,f|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31721]=0;f=y[e+210|0]<3?9:8;P(186,b|0,f-4|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){x[31721]=0;j=R(154,b|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break E}Dh(b,f);x[31721]=0;S(188,e- -64|0,b|0,f+j|0);f=x[31721];x[31721]=0;if((f|0)==1){break D}j=h;f=e- -64|0;h=hc(e+100|0,f);gd(j,h);ub(h);ub(f);Yf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=a+484376|0;h=Wb(x[a+484360>>2],y[g|0]);h=fm(x[h>>2],x[h+4>>2]);x[31721]=0;l=a+484344|0;O(226,l|0,h|0);h=x[31721];x[31721]=0;if((h|0)!=1){g=Wb(x[a+484360>>2],y[g|0]);o=e,q=wb(x[g>>2]),x[o+64>>2]=q;h=wb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,h)){g=Wb(x[a+484360>>2],y[a+484376|0]);h=z[e+96>>1];F:{if(!_i(g,h)){break F}j=x[g>>2];k=z[e+98>>1];if(!k){if(SD(j,x[g+4>>2])>>>0<=h>>>0){break F}}g=Vb(x[l>>2],z[Zb(j,h)>>1]);xe(g,sn(Ve(Le(e- -64|0,12,k&255),x[g+12>>2]-1|0)))}Ok(f);Pc(d);break n}j=x[d>>2];n=Mf(j,x[d+4>>2]);k=z[g>>1];if(n>>>0>k>>>0){x[31721]=0;j=ba(318,$g(j,k)|0,y[e+210|0],f|0,a|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break p}w[g>>1]=j}Od(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Ok(f)}Pc(d);break c}x[31721]=0;S(315,e- -64|0,i|0,1196641603);d=x[31721];x[31721]=0;if((d|0)==1){break k}d=e- -64|0;b=gd(b,d);ub(d);d=x[b>>2];x[31721]=0;d=R(175,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}if(d){x[31721]=0;P(186,b|0,1)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}x[31721]=0;d=R(205,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}x[31721]=0;aa(319,a+1298332|0,b|0,d|0,40,0);d=x[31721];x[31721]=0;if((d|0)==1){break d}}x[31721]=0;S(315,e- -64|0,i|0,1146113363);d=x[31721];x[31721]=0;if((d|0)==1){break h}x[31721]=0;S(315,e+44|0,i|0,1229999443);d=x[31721];x[31721]=0;if((d|0)==1){break l}d=e+44|0;b=gd(b,d);ub(d);x[31721]=0;d=R(200,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break j}h=a+480190|0;w[h>>1]=d;j=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31721]=0;d=R(200,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break K}}x[31721]=0;S(320,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break K}x[31721]=0;O(321,b|0,e+28|0);d=x[31721];x[31721]=0;if((d|0)==1){break J}x[31721]=0;g=D(c,104)+a|0;l=g+484380|0;O(322,e+28|0,l|0);c=x[31721];x[31721]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31721]=0;O(323,b|0,g+484423|0);c=x[31721];x[31721]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31721]=0;P(186,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break J}x[31721]=0;c=R(154,e- -64|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;S(188,e+8|0,e- -64|0,c|0);c=x[31721];x[31721]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=hc(e+44|0,d);ub(d);d=x[c>>2];x[31721]=0;d=R(175,d|0)|0;k=x[31721];x[31721]=0;if((k|0)!=1){L:{if(j|d^1){break L}d=Wc(e+8|0,w[g+484414>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31721]=0;U(218,d|0,l|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[h>>1];continue}}break}b=N()|0;ub(c);break i}bg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31721]=0;d=1;U(269,a+1074312|0,114,1)|0;a=x[31721];x[31721]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);fe(i)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(m)}fe(i)}Q(b|0);p()}function fpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=fb-288|0;fb=d;vc(b);a:{b:{c:{d:{if(!mv(b,d+192|0)){break d}if(!eX(d+192|0)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(dX(d+192|0),hb))){break d}if(!c){h=1;break d}if(!bd(b,y[d+196|0])){break d}Ad(a,268435456);bg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+84|0;i=rc(f,15307);yb(a+1298344|0,i);tb(i);i=rc(f,10282);yb(a+1298356|0,i);tb(i);G=a+1298404|0,H=x[Ec(f,4)>>2],x[G>>2]=H;i=d+16|0;$e(i,d+198|0,48,3);Ac(f,i);yb(a+1298308|0,f);tb(f);f=y[d+246|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;f=d+180|0;x[f>>2]=0;x[f+4>>2]=0;qc(f+8|0);Nd(i+8|0,x[zb(i+4|0,f)>>2]);f:{g:{if(e){x[31721]=0;O(665,f|0,e|0);g=x[31721];x[31721]=0;if((g|0)==1){break g}TC(f,e)}e=i+8|0;Md(e);_g(e);fb=i+16|0;break f}a=N()|0;_g(i+8|0);Q(a|0);p()}x[31721]=0;i=f;S(660,b|0,f|0,y[d+286|0]|y[d+287|0]<<8);f=x[31721];x[31721]=0;if((f|0)==1){break b}A=Nb(d+168|0);s=Nb(d+156|0);x[31721]=0;U(424,b|0,A|0,y[d+285|0])|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;U(424,b|0,s|0,y[d+284|0])|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}t=c&2;u=d+122|0;n=d+90|0;f=0;h:{while(1){e=f;if(e>>>0>=y[d+284|0]){h=1;if(!(c&1)){break e}x[d+68>>2]=0;o=a+484376|0;gj(Wb(x[a+484360>>2],y[o|0]));G=d,H=wb(x[i>>2]),x[G+64>>2]=H;t=a+484344|0;B=wb(x[i+4>>2]);C=a+484348|0;break h}x[31721]=0;f=e+1|0;g=D(f,104)+a|0;j=g+484380|0;O(282,j|0,0);h=x[31721];x[31721]=0;i:{if((h|0)!=1){h=xb(x[s>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);if(!h){continue}x[31721]=0;h=P(152,b|0,h|0)|0;k=x[31721];x[31721]=0;j:{if((k|0)==1){break j}if(!h){continue}x[31721]=0;h=P(661,b|0,d+84|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break j}if(!h){continue}h=d+72|0;Te(h,2,n);x[31721]=0;O(221,d+16|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break c}h=d+16|0;xc(((f<<5)+a|0)+946304|0,h);tb(h);k=d+72|0;Mk(k,2,u);x[31721]=0;O(221,h|0,k|0);h=x[31721];x[31721]=0;if((h|0)==1){break c}h=d+16|0;ye(g+484423|0,h);tb(h);h=y[d+134|0];if(h>>>0<=15){w[g+484408>>1]=D(h,17);h=g+484414|0;w[h>>1]=z[h>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;G=g+484412|0,H=y[Sb(d+16|0,d+72|0)|0],w[G>>1]=H;x[g+484404>>2]=y[d+137|0]|y[d+138|0]<<8;q=g+484384|0;k=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[q>>2]=k;m=g+484388|0;h=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=h;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[j>>2]=l;o=y[d+136|0];if(o&1){k=k>>>1|0;x[q>>2]=k;h=h>>>1|0;x[m>>2]=h;x[j>>2]=l>>>1}k:{if(h>>>0<=k>>>0){break k}g=g+484414|0;h=z[g>>1];w[g>>1]=h|2;if(!(o&2)){break k}w[g>>1]=h|6}Zk(j);if(!t){continue}e=xb(x[s>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[31721]=0;P(152,b|0,e+y[d+88|0]|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break i}}break c}break c}e=Wc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31721]=0;U(218,e|0,j|0,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){continue}break}break c}while(1){l:{m:{k=x[d+64>>2];if(!Ib(k,B)){b=x[d+68>>2];c=b&63;if(!c){break m}f=Wb(x[a+484360>>2],y[a+484376|0]);b=b>>>6&65535;if(!_i(f,b)){break m}b=z[Zb(x[f>>2],b)>>1];f=x[t>>2];x[31721]=0;O(662,Vb(f,b)|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break m}break c}c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break l}c=xb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31721]=0;c=P(152,b|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}if(!c){break l}x[31721]=0;O(663,b|0,d+84|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break l}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];u=y[Sb(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;G=d,H=x[$c(d+68|0,d+60|0)>>2],x[G+68>>2]=H;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;g=c&63;n=c>>>6|0;q=0;while(1){if((e&255)>>>0<=q>>>0){break l}e=Wb(x[a+484360>>2],y[o|0]);j=g>>>0>63;n=j+n|0;c=n&65535;if(Yc(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[31721]=0;O(333,e|0,n+1&65535);f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;f=P(370,t|0,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}e=Wb(x[a+484360>>2],y[o|0]);G=Zb(x[e>>2],c),H=f,w[G>>1]=H}l=x[a+484344>>2];f=x[C>>2];m=z[Zb(x[e>>2],c)>>1];if(!Ge(l,f,m)){break l}f=0;c=Vb(l,m);l=j?0:g;e=jd(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);n:{while(1){if((f|0)==(u|0)){c=y[d+89|0];if(c>>>0<=u>>>0){break n}x[31721]=0;P(186,b|0,D(c-u|0,5)|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break n}break c}x[31721]=0;O(664,d+72|0,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){c=d+72|0;j=Hc(c);E=Ye(c);r=cj(c);F=dc(c);g=0;c=y[d+72|0];if((c-1&255)>>>0<=142){g=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+f|0]=g}v[e|0]=g;c=y[j|0];v[e+2|0]=1;v[e+1|0]=c;c=y[E|0];o:{if((c|0)!=255){v[e+4|0]=c;break o}v[e+2|0]=0}c=y[r|0];p:{if(c>>>0>22){break p}v[e+3|0]=y[c+25344|0];j=y[F|0];v[e+5|0]=j;c=e+5|0;q:{switch(y[r|0]-4|0){case 3:v[c|0]=j&3|64;break p;case 4:v[c|0]=j&3|48;break p;case 7:g=x[i>>2];if(nc(g,x[i+4>>2])>>>0<=j>>>0){break p}r=c;c=xb(g,j);c=y[c|0]|y[c+1|0]<<8;v[r|0]=c>>>6;g=Vb(x[a+484344>>2],m);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break p;case 8:r=c;c=x[d+60>>2];v[r|0]=c>>>6;g=Vb(x[a+484344>>2],m);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break p;case 10:v[c|0]=j&15|128;break p;case 12:v[d+15|0]=15;G=c,H=y[Sb(c,d+15|0)|0]|208,v[G|0]=H;break p;case 13:v[d+15|0]=15;G=c,H=y[Sb(c,d+15|0)|0]|192,v[G|0]=H;break p;case 14:v[d+15|0]=15;G=c,H=y[Sb(c,d+15|0)|0]|224,v[G|0]=H;break p;case 0:case 16:case 17:if(!(j&15)){break p}g=j&240;if(!g|(g|0)==240){break p}v[c|0]=j|15;break p;case 9:case 18:break q;default:break p}}if(g&255){break p}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}g=l+1|0;q=q+1|0;e=y[d+88|0];continue}}a=Wb(x[a+484360>>2],y[a+484376|0]);G=d,H=wb(x[a>>2]),x[G+84>>2]=H;b=wb(x[a+4>>2]);g=65535;while(1){a=x[d+84>>2];if(!Ib(a,b)){break e}if(z[a>>1]==65535){r:{if((g&65535)!=65535){break r}x[31721]=0;g=P(370,t|0,64)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break r}break c}w[a>>1]=g}Od(d+84|0);continue}}Pe(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}sc(s);sc(A);sc(i)}fb=d+288|0;return h|0}a=N()|0;sc(s);sc(A);break a}a=N()|0}sc(i);Q(a|0);p()}function SL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){of(i+196|0,f,32);x[31721]=0;U(545,i+184|0,f|0,32)|0;h=x[31721];x[31721]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Bt(c)){h=x[b+24>>2];j=x[h+484344>>2];if(Ge(j,x[h+484348>>2],c&65535)){break j}}x[31721]=0;S(1171,a|0,i+196|0,i+184|0);a=x[31721];x[31721]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Vb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31721]=0;S(1171,a|0,i+196|0,i+184|0);a=x[31721];x[31721]=0;if((a|0)!=1){break i}f=N()|0;break c}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);qf(i+196|0);qf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Sc(d)){if(!El(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31721]=0;V(1172,i+160|0,h|0,d|0,e|0);d=x[31721];x[31721]=0;e=1;if((d|0)==1){break y}x[31721]=0;O(1067,i+172|0,i+160|0);d=x[31721];x[31721]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31721]=0;P(37,i+172|0,16770)|0;d=x[31721];x[31721]=0;if((d|0)==1){break x}}x[31721]=0;d=P(844,i+196|0,i+172|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break w}tb(i+172|0);if(e){tb(i+160|0)}e=9968;h=y[c|0];if(!Sc(h)){e=El(h)?10278:16770}x[31721]=0;h=P(37,i+172|0,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break u}x[31721]=0;e=P(844,i+184|0,h|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31721]=0;h=P(37,i+148|0,18424)|0;j=x[31721];x[31721]=0;if((j|0)==1){break s}x[31721]=0;j=P(844,d|0,h|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break r}tb(h);x[31721]=0;h=P(37,i+136|0,18424)|0;l=x[31721];x[31721]=0;if((l|0)==1){break q}x[31721]=0;l=P(844,e|0,h|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31721]=0;O(562,i+124|0,h|0);k=x[31721];x[31721]=0;if((k|0)!=1){break B}break d}x[31721]=0;P(37,i+124|0,16775)|0;k=x[31721];x[31721]=0;if((k|0)==1){break d}}x[31721]=0;k=P(844,j|0,i+124|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break o}j=i+124|0;tb(j);h=y[h|0];x[31721]=0;h=P(37,j|0,(h?10801:16775)|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break n}x[31721]=0;l=P(844,l|0,h|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Sg(y[c|0]);O:{if(j){x[31721]=0;m=P(37,i+100|0,18424)|0;h=x[31721];x[31721]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31721]=0;o=i,q=Hj(n,h)&255,x[o+76>>2]=q;O(561,i+88|0,i+76|0);h=x[31721];x[31721]=0;if((h|0)==1){break M}h=0;x[31721]=0;S(1023,i+112|0,m|0,i+88|0);m=x[31721];x[31721]=0;if((m|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=fR(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31721]=0;h=U(545,i+100|0,1,h|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break E}x[31721]=0;O(562,i+88|0,c+4|0);m=x[31721];x[31721]=0;if((m|0)==1){break L}x[31721]=0;S(1023,i+112|0,h|0,i+88|0);m=x[31721];x[31721]=0;h=1;if((m|0)!=1){break O}f=N()|0;break J}h=0;x[31721]=0;P(37,i+112|0,16774)|0;m=x[31721];x[31721]=0;if((m|0)==1){break e}}x[31721]=0;k=P(844,k|0,i+112|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break K}tb(i+112|0);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5488;if(!Sg(y[c|0])){h=y[c+2|0]?5484:16774}x[31721]=0;h=P(37,i+112|0,h|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break D}x[31721]=0;j=P(844,l|0,h|0)|0;l=x[31721];x[31721]=0;if((l|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31721]=0;h=P(37,i+76|0,18424)|0;l=x[31721];x[31721]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[31721]=0;l=P(844,k|0,h|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break Z}tb(h);x[31721]=0;h=P(37,i- -64|0,18424)|0;k=x[31721];x[31721]=0;if((k|0)==1){break Y}x[31721]=0;j=P(844,j|0,h|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break X}tb(h);_:{if(Sg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[31721]=0;o=i,q=Hj(k,h)&4095,x[o+16>>2]=q;O(1173,i+52|0,i+16|0);h=x[31721];x[31721]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=eR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31721]=0;b=U(545,i+40|0,1,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break W}x[31721]=0;O(562,i+28|0,c+5|0);h=x[31721];x[31721]=0;if((h|0)==1){break V}x[31721]=0;S(1023,i+52|0,b|0,i+28|0);h=x[31721];x[31721]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31721]=0;P(37,i+52|0,16770)|0;h=x[31721];x[31721]=0;if((h|0)==1){break U}}x[31721]=0;P(844,l|0,i+52|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break T}tb(i+52|0);if(b){tb(i+28|0);tb(i+40|0)}b=11161;if(!Sg(y[c|0])){b=y[c+3|0]?11161:16770}x[31721]=0;b=P(37,i+52|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break Q}x[31721]=0;P(844,j|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Xc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31721]=0;V(124,i+16|0,d|0,0,f|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=i+16|0;yb(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31721]=0;b=U(545,i+16|0,f-b|0,32)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ca}x[31721]=0;P(844,d|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break ba}tb(b)}b=Xc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31721]=0;V(124,i+4|0,e|0,0,f|0);b=x[31721];x[31721]=0;if((b|0)==1){break aa}b=i+4|0;yb(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31721]=0;b=U(545,i+4|0,f-b|0,32)|0;c=x[31721];x[31721]=0;if((c|0)==1){break h}x[31721]=0;P(844,e|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break g}tb(b)}x[31721]=0;S(1171,a|0,d|0,e|0);a=x[31721];x[31721]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function Nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;d=fb-256|0;fb=d;vc(b);f=fb-16|0;fb=f;h=d+99|0;a_(f+8|0,h);i=x[f+12>>2];jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(i|0)){Ub(b,x[f+12>>2])}fb=f+16|0;f=(i|0)==(j|0);if(!f){$Z(h)}a:{if(!f){break a}if(!b_(d+99|0)){break a}if(!c){e=1;break a}Ad(a,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24736>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+36|0;f=rc(e,13171);yb(a+1298344|0,f);tb(f);f=rc(e,10313);yb(a+1298356|0,f);tb(f);f=fb-16|0;fb=f;i=d+4|0;h=rc(f+4|0,4389);Zc(i,h);tb(h);fb=f+16|0;x[31721]=0;V(232,e|0,i|0,y[d+178|0],d+175|0);e=x[31721];x[31721]=0;b:{if((e|0)!=1){e=d+36|0;yb(a+1298368|0,e);tb(e);f=d+4|0;Eb(f);_h(a+1298392|0,((y[d+215|0]|y[d+216|0]<<8)<<2)+24784|0);_h(a+1298380|0,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24832>>2]);A=a+1298404|0,B=x[Ec(e,4)>>2],x[A>>2]=B;Te(f,2,d+103|0);Ac(e,f);yb(a+1298308|0,e);tb(e);Te(f,2,d+135|0);Ac(e,f);c:{if(fr(e,9750)){x[31721]=0;S(261,d+4|0,4,d+36|0);e=x[31721];x[31721]=0;if((e|0)==1){break c}e=d+4|0;yb(a+1298320|0,e);tb(e)}tb(d+36|0);w[a+480188>>1]=32;d:{while(1){if((g|0)!=32){f=(g<<5)+a|0;i=f+480280|0;Ue(i);e=y[(d+g|0)+180|0];e:{if(e>>>0<=15){x[d+36>>2]=e<<4|8;x[d+4>>2]=256;A=f+480284|0,B=x[qd(d+36|0,d+4|0)>>2],w[A>>1]=B;break e}if((e|0)!=16){if((e|0)!=255){break e}w[a+480188>>1]=g;break d}w[f+480284>>1]=128;x[i>>2]=256}g=g+1|0;continue}break}g=z[a+480188>>1]}e=0;if(!(g&65535)){break a}x[d+36>>2]=y[d+212|0]<<2;x[d+4>>2]=256;A=a,B=x[Gb(d+36|0,d+4|0)>>2],x[A+480200>>2]=B;x[a+480196>>2]=y[d+213|0];x[a+480204>>2]=D(y[d+214|0],1e4);if(bd(b,y[d+217|0]|y[d+218|0]<<8|(y[d+219|0]<<16|y[d+220|0]<<24))){dk(Wb(x[a+484360>>2],y[a+484376|0]),b,y[d+221|0]+1|0,255,254)}if(!bd(b,y[d+227|0]|y[d+228|0]<<8|(y[d+229|0]<<16|y[d+230|0]<<24))){break a}l=a+480190|0;g=y[d+235|0]+1|0;w[l>>1]=g;n=d+68|0;m=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(g&65535)>>>0){break g}e=fb-16|0;fb=e;f=d+36|0;ac(e+8|0,f,62);g=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){Tb(f,0,62)}if(!e){break g}g=0;e=D(j,104)+a|0;k=e+484380|0;kd(k,0);h=d+24|0;Te(h,2,d+36|0);f=d+4|0;Ac(f,h);xc(((j<<5)+a|0)+946304|0,f);tb(f);Mk(h,2,n);Ac(f,h);ye(e+484423|0,f);tb(f);f=y[d+94|0]|y[d+95|0]<<8;x[e+484404>>2]=f;if(!qn(x[m>>2])){break f}while(1){if((g|0)==16){break f}if((f|0)==z[(g<<1)+24880>>1]){v[e+484417|0]=g<<4;break f}else{g=g+1|0;continue}}}h:{if(!(c&2)){break h}if(!bd(b,y[d+231|0]|y[d+232|0]<<8|(y[d+233|0]<<16|y[d+234|0]<<24))){break h}g=1;e=a+480190|0;while(1){f=g&65535;if(f>>>0>z[e>>1]){break h}f=D(f,104)+a|0;ag(Wc(d+36|0,w[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);g=g+1|0;continue}}o=a+484344|0;Of(o,y[d+226|0]+1|0);j=tD(er(a));bd(b,y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24));s=c&1;t=a+480188|0;u=a+480180|0;h=0;l=1;i:{j:{k:{while(1){if(y[d+226|0]<h>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{e=dh(b);if(e>>>0>=3){c=d+4|0;ce(c,b,e-2|0);i=hc(d+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31721]=0;c=R(175,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}if(!c){break m}x[31721]=0;c=U(199,o|0,h&65535,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}c=Vb(x[o>>2],h);_e(d+4|0,x[c>>2],x[x[c+48>>2]+12>>2],k);n:{o:while(1){x[31721]=0;c=R(200,i|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}if(!c){break n}e=c&31;if(e>>>0>=z[t>>1]){break n}g=Vc(x[d+4>>2],e);if(c&32){x[31721]=0;O(201,d+24|0,i|0);e=x[31721];x[31721]=0;if((e|0)==1){break i}f=Hc(d+24|0);e=y[d+24|0];if(e){e=(e&127)-1|0;v[d+24|0]=e;e=(D((e&240)>>>4|0,12)+(e&15)|0)+13|0;v[g|0]=e;l=sD(e)&l}v[g+1|0]=y[f|0]}if(!(c&64)){continue}v[g+2|0]=0;v[g+3|0]=0;n=g+5|0;while(1){c=x[i>>2];x[31721]=0;c=U(153,c|0,x[d+44>>2],2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}if(!c){continue o}q=y[g+5|0];c=y[g+3|0];x[31721]=0;O(201,d+24|0,i|0);e=x[31721];x[31721]=0;if((e|0)!=1){f=y[Hc(d+24|0)|0];v[g+5|0]=f;r=y[d+24|0];e=y[(r&31)+24912|0];v[g+3|0]=e;p:{q:{r:{s:{t:{switch(e-2|0){case 0:case 1:if(f>>>0<224){break p}m=223;if(x[u>>2]!=1){break s}break p;case 11:v[d+3|0]=64;e=y[Sb(n,d+3|0)|0];v[n|0]=e;if(!Kv(x[j+88>>2],1)){break p}v[g+4|0]=e;v[g+2|0]=1;v[g+5|0]=q;v[g+3|0]=c;e=c;break r;case 17:u:{switch(((f&240)>>>4|0)-8|0){case 0:v[g+3|0]=2;v[g+5|0]=f&15|224;break p;case 1:v[g+3|0]=3;v[g+5|0]=f&15|224;break p;default:break u}}if(Yi(x[j+84>>2],19)){break p}Ar(g);e=y[g+3|0];break r;case 13:c=x[j+84>>2];if(Yi(c,15)){break p}if(!Yi(c,19)){break p}v[g+3|0]=19;v[g+5|0]=f&15|144;break p;case 18:m=145;if((f|0)==1){break s}if((f&240)==128){if(Yi(x[j+84>>2],20)){break q}v[g+3|0]=19;break p}v[g+3|0]=0;break p;case 4:case 5:break t;default:break r}}m=f&240;if(!m){break p}}v[n|0]=m}if((e&255)!=20){break p}}e=y[g+5|0];if(y[g+2|0]|(e&240)!=128){break p}v[g+2|0]=2;v[g+5|0]=q;v[g+3|0]=c;v[g+4|0]=(((e&15)<<6|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?l&1?8454144:0:0)}x[a+480208>>2]=c;e=1;if(!(y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break a}if(!bd(b,y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24))){break a}JD(a+1298332|0,b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24),4);break a}g=N()|0;ub(i);break b}w[e+484412>>1]=64;f=y[d+81|0]|y[d+82|0]<<8|(y[d+83|0]<<16|y[d+84|0]<<24);x[k>>2]=f;g=y[d+93|0];if(g&2){h=e+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=f>>>1}x[e+484384>>2]=y[d+85|0]|y[d+86|0]<<8|(y[d+87|0]<<16|y[d+88|0]<<24);x[e+484388>>2]=(y[d+89|0]|y[d+90|0]<<8|(y[d+91|0]<<16|y[d+92|0]<<24))-1;if(g&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}v:{w:{if(!(g&4)){break w}f=y[d+96|0];if((f|0)==255){break w}v[d+4|0]=f;v[d+24|0]=64;A=e+484410|0,B=y[Sb(d+4|0,d+24|0)|0]<<2,w[A>>1]=B;break v}f=e+484414|0;w[f>>1]=z[f>>1]|32768}x:{if(g&8){g=e+484414|0;f=z[g>>1]|32;w[g>>1]=f;j=e+484408|0;e=y[d+97|0];if(e>>>0<=15){x[d+24>>2]=256;x[d+4>>2]=e<<4|8;h=x[qd(d+4|0,d+24|0)>>2]}else{h=128}w[j>>1]=h;w[g>>1]=f&65279|((e|0)==16)<<8;break x}w[e+484408>>1]=128}i=i+1|0;g=z[l>>1];continue}}g=N()|0;tb(d+36|0);break b}g=N()|0;Eb(d+4|0)}Q(g|0);p()}fb=d+256|0;return e|0}function a7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(ii(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1240;b=l+72|0;s=Ae(l+104|0,l+112|0,b);m=x[s>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);o=Fb(l+48|0);n=Fb(l+36|0);r=Fb(l+24|0);b=x[d>>2];x[31721]=0;ka(1250,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,o|0,n|0,l+20|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;k=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31721]=0;b=P(1224,a|0,l+524|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=U(1251,h|0,1,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if(b){x[31721]=0;O(1252,l+12|0,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;O(36,r|0,x[l+12>>2]);b=x[31721];x[31721]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31721]=0;b=P(1224,a|0,l+524|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=U(1251,h|0,1,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if(!b){break c}x[31721]=0;O(1252,l+12|0,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;O(36,r|0,x[l+12>>2]);b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Bb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if((b|0)!=x[Td(o,0)>>2]){break m}x[31721]=0;R(1227,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}v[g|0]=0;k=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:k;break c}n:{if(!Bb(x[n+4>>2],y[n+11|0])){break n}b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if((b|0)!=x[Td(n,0)>>2]){break n}x[31721]=0;R(1227,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}v[g|0]=1;k=Bb(x[n+4>>2],y[n+11|0])>>>0>1?n:k;break c}o:{b=Bb(x[o+4>>2],y[o+11|0]);if(!b){break o}if(!Bb(x[n+4>>2],y[n+11|0])){break o}x[f>>2]=x[f>>2]|4;a=0;break d}c=b;b=Bb(x[n+4>>2],y[n+11|0]);if(!(c|b)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|k|A))){k=0;break c}c=zb(l+12|0,xd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=ml(q);d=x[c>>2];if(!Ib(d,b)){break q}b=x[d>>2];x[31721]=0;b=U(1251,h|0,1,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){if(!b){break q}Pe(c);continue}break}break a}b=xd(q);b=vv(x[c>>2],b);if(Bb(x[r+4>>2],y[r+11|0])>>>0>=b>>>0){d=Fk(ml(r),0-b|0);t=ml(r);z=xd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Ib(d,t);if(!z){break r}if(!kc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Pe(b+12|0);Pe(b+8|0);d=x[d>>2];continue}break}fb=b+16|0;if(z^1){break p}}C=c,D=x[zb(l+8|0,xd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=ml(q);if(!Ib(x[l+8>>2],b)){break s}x[31721]=0;b=P(1224,a|0,l+524|0)|0;c=x[31721];x[31721]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[31721]=0;R(1227,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}Pe(l+8|0);continue}break}break a}if(!A){break c}b=ml(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[31721]=0;d=P(1224,a|0,l+524|0)|0;t=x[31721];x[31721]=0;if((t|0)==1){break v}if(d){break u}d=x[a>>2];x[31721]=0;t=R(1225,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[31721]=0;d=U(1251,h|0,64,t|0)|0;B=x[31721];x[31721]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31721]=0;S(1253,i|0,j|0,l+520|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=t;b=b+1|0;break w}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(t|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[31721]=0;S(1246,s|0,l+100|0,l+96|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31721]=0;R(1227,a|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31721]=0;S(1246,s|0,l+100|0,l+96|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!k){break x}b=k;k=1;while(1){if(Bb(x[b+4>>2],y[b+11|0])>>>0<=k>>>0){break x}x[31721]=0;c=P(1224,a|0,l+524|0)|0;d=x[31721];x[31721]=0;y:{if((d|0)==1){break y}z:{if(!c){c=x[a>>2];x[31721]=0;c=R(1225,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break y}if((c|0)==x[Td(b,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31721]=0;R(1227,a|0)|0;c=x[31721];x[31721]=0;k=k+1|0;if((c|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Rf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[31721]=0;b=P(1224,a|0,l+524|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[31721]=0;b=R(1225,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if((b|0)==x[l+88>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31721]=0;b=R(1227,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[31721]=0;c=P(1224,b|0,l+524|0)|0;d=x[31721];x[31721]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[31721]=0;c=R(1225,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break C}x[31721]=0;c=U(1251,h|0,64,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31721]=0;S(1253,i|0,j|0,l+520|0);c=x[31721];x[31721]=0;if((c|0)==1){break C}}c=x[b>>2];x[31721]=0;c=R(1225,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31721]=0;R(1227,b|0)|0;c=x[31721];x[31721]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Rb(r);Rb(n);Rb(o);Rb(q);tb(u);Jc(s);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Rb(r);Rb(n);Rb(o);Rb(q);tb(u);Jc(s);Q(a|0);p()}function ZS(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=0,V=E(0),W=0;k=fb-48|0;fb=k;l=b+223848|0;Uj(l,Tj(e,Ii(e,Mo(e),0))+1|0);le(k+40|0,x[l>>2],x[b+223852>>2]);fc(k+32|0,e,Tj(e,Ii(e,Mo(e),0)));F=x[k+32>>2];G=x[k+36>>2];l=0;o=fb-16|0;fb=o;H=a+906300|0;u=a+1074312|0;i=D(c,872)+b|0;I=i+1415|0;J=i+1304|0;K=i+1392|0;q=i+1368|0;s=i+1364|0;L=i+1336|0;M=i+1308|0;N=i+1300|0;O=i+1280|0;P=i+1402|0;g=i+1466|0;Q=E(y[g|0]);R=E(f>>>0);C=i+616|0;j=x[i+1272>>2];S=a+480188|0;p=1;m=255;while(1){if((n|0)!=(G|0)&A[k+44>>2]>l>>>0){h=y[vb(F,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=mm(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[sd(H,e)>>2];if(!e){break f}e=TA(e,45944,43e3);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!j){break b}break c}if(j){break c}e=0;break b;case 21:g:{if(!Ob(u,28)){e=0;if(!Ob(u,1)){break g}}e=w[K>>1]}h=D(x[q>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Xb((Fc(Aua(zua(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[q>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Xb((Fc(Aua(zua(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[o>>2]=x[M>>2]/2;x[o+12>>2]=127;e=x[qd(o,o+12|0)>>2];break d;case 24:x[o>>2]=x[N>>2]/2;x[o+12>>2]=127;e=x[qd(o,o+12|0)>>2];break d;case 0:e=0;if(!j){break d}h=z[j+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!j){break d}h=z[j+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[S>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[i+704|0]>>>7|0;break d;case 15:e=0;if(!j){break d}h=y[j+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[g|0]<0){break h}i:{if(l>>>0<3){break i}e=x[k+40>>2];if(y[vb(e,l-3|0)|0]!=240){break i}if(y[vb(e,l-2|0)|0]>239){break h}}r=sq(b,Q,R);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[g|0]=e;m=128;break d}m=(m&255)==255?f:m;e=f;break d;case 18:k:{if(!l){e=0;break k}h=x[k+40>>2];e=l;while(1){e=e-1|0;t=vb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(l-e>>>0<5){break a}t=x[k+40>>2];if(y[vb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(l|0)){h=y[vb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=Sc(e)?e-1|0:0}h=p^-1;p=1;l=(h&1)+l|0;T=vb(x[k+40>>2],l),U=e,v[T|0]=U;l=l+1|0;break a}e=z[C+786>>1];h=y[j+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=Nj(h)?h-1&15:0}}h=vb(x[k+40>>2],l);v[h|0]=(p&1?0:y[h|0]<<4)|e;p=p^1;l=(p&1)+l|0}n=n+1|0;continue}else{if(m<<24>>24>=0){v[g|0]=m}ac(o,x[k+40>>2],((p^-1)&1)+l|0);e=x[o+4>>2];x[k+40>>2]=x[o>>2];x[k+44>>2]=e;fb=o+16|0}break}o=x[k+44>>2];l=0;m:while(1){p=0;while(1){e=l;n:{o:{p:{q:{while(1){if(A[k+44>>2]<=e>>>0){break n}f=x[k+40>>2];i=vb(f,e);g=v[i|0];if((g|0)==-16){g=e;if(o-g>>>0>=4){l=4;if((y[vb(f,e+1|0)|0]&254)==240){break o}}r:{while(1){g=g+1|0;if(o>>>0<=g>>>0){break r}if(y[vb(f,g)|0]!=247){continue}break}l=(g-e|0)+1|0;if(l){break o}}T=vb(f,o),U=247,v[T|0]=U;o=o+1|0;l=o-e|0;break p}if((g|0)<0){break q}if(p&255){e=e-1|0;T=vb(f,e),U=p,v[T|0]=U;continue}break}l=l+1|0;continue m}T=k,U=bV(g&255),x[T+20>>2]=U;x[k+28>>2]=o-e;l=x[Gb(k+20|0,k+28|0)>>2]}if(!l){break n}f=x[k+40>>2];i=vb(f,e)}u=y[i|0];kr(k+20|0,f,x[k+44>>2],e,l);f=fc(k+12|0,x[k+20>>2],x[k+24>>2]);g=x[f+4>>2];x[k>>2]=x[f>>2];x[k+4>>2]=g;i=fb-32|0;fb=i;j=x[k+4>>2];s:{if(!j){break s}m=Bd(y[b+223884|0]);t:{f=x[k>>2];n=vb(f,0);g=y[n|0]-250|0;if(g>>>0>5|!(1<<g&37)){break t}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break t}q=(D(g,872)+b|0)+1453|0;v[q|0]=127;v[q+1|0]=0;g=g+1|0;continue}}u:{if((j|0)!=4|y[n|0]!=240){break u}g=y[vb(f,1)|0];if((g&254)!=240){break u}j=(D(c,872)+b|0)+616|0;n=vb(f,2);q=y[vb(f,3)|0];f=q<<24>>24;s=(g|0)!=241&(f|0)>=0;n=y[n|0];if(!(!s|n)){g=D(c,872)+b|0;n=g+1453|0;if(d){f=xh(sq(b,E(y[n|0]),E((f&255)>>>0)))}v[n|0]=f;v[g+1412|0]=0;f=wq(a,j,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break s}g=x[a+1298300>>2];if(m|yd(g)^1){break s}Cq(g,c,f>>>2&255,1);break s}h=n<<24>>24;if(s&(h|0)==1){g=D(c,872)+b|0;m=g+1454|0;if(d){f=xh(sq(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1411|0]=0;wq(a,j,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;wq(a,j,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=3)){g=(f|0)<0;f=mm(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break s}v[i+24|0]=f;g=a+906300|0;j=f&255;f=x[sd(g,j)>>2];if(!f){break s}r=E(E(127-q|0)/E(127));if(m){m=0;g=fb-16|0;fb=g;T=g,U=Vj(i+24|0),x[T+4>>2]=U;f=fb-16|0;fb=f;j=b+223860|0;h=RA(j,f+12|0,y[i+24|0]);n=x[h>>2];if(!n){m=fb-16|0;fb=m;n=dc(j);q=zh(f,Dc(24),Jg(m+8|0,n));n=x[q>>2];s=y[x[g+4>>2]];x[n+20>>2]=0;v[n+16|0]=s;T=dc(q),U=1,v[T+4|0]=U;fb=m+16|0;Xg(j,x[f+12>>2],h,x[f>>2]);n=ie(f);Zl(f);m=1}Wg(g+8|0,x[zb(f,n)>>2],m);fb=f+16|0;f=rd(x[g+8>>2]);fb=g+16|0;B[f+4>>2]=r;break s}if(!d){ru(x[f+20>>2],r);break s}g=sd(g,j);ru(x[f+20>>2],sq(b,B[g+144>>2],r));break s}if((g|0)!=241&(h|0)>=0){break s}h=mm(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break s}j=x[sd(a+906300|0,h&255)>>2];if(!j){break s}g=(g|0)!=241?n&127:n+128|0;r=E(E((f&255)>>>0)/E(127));if(m){T=nT(b+223872|0,ES(i+24|0,h,g)),V=r,B[T>>2]=V;break s}f=x[j>>2];if(!d){ib[x[f+44>>2]](j,g,r);break s}U=j,W=g,V=sq(b,E(ib[x[f+48>>2]](j,g)),r),T=x[x[j>>2]+44>>2],ib[T](U|0,W|0,E(V));break s}if(m){break s}m=z[a+480188>>1];v:{if(m>>>0>c>>>0){g=c+1|0;break v}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break s}}if(y[(D(c,872)+b|0)+707|0]&4|m>>>0<(g&65535)>>>0){break s}g=mm(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break s}g=x[sd(a+906300|0,g)>>2];if(!g){break s}m=y[n|0];if((m|0)==240){jf(i+16|0,x[k>>2],x[k+4>>2]);f=x[x[g>>2]+72>>2];j=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=j;ib[f|0](g,i)|0;break s}T=i,W=bV(m),x[T+24>>2]=W;x[i+12>>2]=j;j=i+24|0;m=x[Gb(j,i+12|0)>>2];x[i+24>>2]=0;yc(j,f,m);ib[x[x[g>>2]+68>>2]](g,x[i+24>>2])|0}fb=i+32|0;p=u>>>0<240?u:p;l=e+l|0;continue}break}break}fb=k+48|0}function h7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(ph(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1240;b=l+76|0;t=Ae(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);r=Fb(l- -64|0);q=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31721]=0;ka(1243,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,r|0,q|0,o|0,l+24|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];k=h;B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];c=m;e=0;d=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31721]=0;b=P(1209,a|0,l+524|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(Ff(x[k+8>>2],1,b)){x[31721]=0;O(1244,l+16|0,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;O(118,s|0,v[l+16|0]);b=x[31721];x[31721]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31721]=0;b=P(1209,a|0,l+524|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(b){break c}b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(!Ff(x[k+8>>2],1,b)){break c}x[31721]=0;O(1244,l+16|0,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;O(118,s|0,v[l+16|0]);b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Bb(x[q+4>>2],y[q+11|0])){break l}b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(y[bc(q,0)|0]!=(b&255)){break l}x[31721]=0;R(1212,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}v[g|0]=0;d=Bb(x[q+4>>2],y[q+11|0])>>>0>1?q:d;break c}m:{if(!Bb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(y[bc(o,0)|0]!=(b&255)){break m}x[31721]=0;R(1212,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}v[g|0]=1;d=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:d;break c}n:{b=Bb(x[q+4>>2],y[q+11|0]);if(!b){break n}if(!Bb(x[o+4>>2],y[o+11|0])){break n}x[f>>2]=x[f>>2]|4;a=0;break d}h=b;b=Bb(x[o+4>>2],y[o+11|0]);if(!(h|b)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|d|((e|0)==2&(B|0)!=0|A))){d=0;break c}h=zb(l+16|0,xd(r));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=zf(r);n=x[h>>2];if(!Ib(n,b)){break p}if(!Ff(x[k+8>>2],1,v[n|0])){break p}je(h);continue}break}b=xd(r);b=Bk(x[h>>2],b);if(Bb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){n=HC(zf(s),b);E=zf(s);z=xd(r);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=n;while(1){q:{z=Ib(n,E);if(!z){break q}if(!T$(y[n|0],y[x[b+8>>2]])){break q}n=je(b+12|0);je(b+8|0);n=x[n>>2];continue}break}fb=b+16|0;if(z^1){break o}}F=h,G=x[zb(l+12|0,xd(r))>>2],x[F>>2]=G}x[l+12>>2]=x[h>>2];r:{while(1){b=zf(r);if(!Ib(x[l+12>>2],b)){break r}x[31721]=0;b=P(1209,a|0,l+524|0)|0;h=x[31721];x[31721]=0;s:{if((h|0)==1){break s}if(b){break r}b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break s}if(y[x[l+12>>2]]!=(b&255)){break r}x[31721]=0;R(1212,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}je(l+12|0);continue}break}break a}if(!A){break c}b=zf(r);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}t:{while(1){u:{x[31721]=0;h=P(1209,a|0,l+524|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break u}if(h){break t}h=x[a>>2];x[31721]=0;n=R(1210,h|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}v:{if(Ff(x[k+8>>2],64,n)){h=x[j>>2];if((h|0)==x[l+520>>2]){x[31721]=0;S(1245,i|0,j|0,l+520|0);h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[j>>2]}x[j>>2]=h+1;v[h|0]=n;b=b+1|0;break v}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(n&255)!=(D|0)){break t}if(x[l+96>>2]==(c|0)){x[31721]=0;S(1246,t|0,l+100|0,l+96|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;c=m;b=0}x[31721]=0;R(1212,a|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31721]=0;S(1246,t|0,l+100|0,l+96|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31721]=0;b=P(1209,a|0,l+524|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}w:{if(!b){b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break w}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31721]=0;b=R(1212,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31721]=0;c=P(1209,b|0,l+524|0)|0;h=x[31721];x[31721]=0;x:{if((h|0)==1){break x}y:{if(!c){c=x[b>>2];x[31721]=0;c=R(1210,c|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break x}if(Ff(x[k+8>>2],64,c)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31721]=0;S(1245,i|0,j|0,l+520|0);c=x[31721];x[31721]=0;if((c|0)==1){break x}}c=x[b>>2];x[31721]=0;c=R(1210,c|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break x}h=x[j>>2];x[j>>2]=h+1;v[h|0]=c;x[31721]=0;R(1212,b|0)|0;c=x[31721];x[31721]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;z:{if(!d){break z}k=1;while(1){if(Bb(x[d+4>>2],y[d+11|0])>>>0<=k>>>0){break z}x[31721]=0;b=P(1209,a|0,l+524|0)|0;c=x[31721];x[31721]=0;A:{if((c|0)==1){break A}B:{if(!b){b=x[a>>2];x[31721]=0;b=R(1210,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break A}if(y[bc(d,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31721]=0;R(1212,a|0)|0;b=x[31721];x[31721]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Rf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}c=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(q);tb(r);tb(u);Jc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(q);tb(r);tb(u);Jc(t);Q(a|0);p()}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-272|0;fb=d;vc(b);e=fb-16|0;fb=e;f=d+126|0;QW(e+8|0,f);g=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){PW(f)}a:{b:{c:{d:{if(!e){break d}if(!RW(d+126|0)){break d}if(!c){i=1;break d}Ad(a,4194304);e=d+40|0;g=rc(e,17043);yb(a+1298344|0,g);tb(g);g=rc(e,10137);yb(a+1298356|0,g);tb(g);n=a+1298404|0,o=x[Ec(e,4)>>2],x[n>>2]=o;n=a,o=Hd(y[d+204|0]|y[d+205|0]<<8,y[d+206|0]|y[d+207|0]<<8,127),w[n+480188>>1]=o;g=y[d+195|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[d+193|0];x[a+480204>>2]=D(y[d+194|0],1e4);g=d+104|0;$e(g,d+130|0,59,3);Ac(e,g);yb(a+1298308|0,e);tb(e);e=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);e:{if(e>>>0<5){break e}if(!bd(b,e-4|0)){break e}if(!ek(b,14233)){break e}dk(Wb(x[a+484360>>2],y[a+484376|0]),b,y[d+198|0]|y[d+199|0]<<8,65535,65535)}f:{e=y[d+212|0]|y[d+213|0]<<8|(y[d+214|0]<<16|y[d+215|0]<<24);if(e>>>0<5){break f}if(!bd(b,e-4|0)){break f}if(!ek(b,13843)){break f}e=0;while(1){if((e|0)==32){break f}g=(e<<5)+a|0;Ue(g+480280|0);n=g+480284|0,o=((((Xd(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;e=e+1|0;continue}}e=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);g:{if(e>>>0<5){break g}if(!bd(b,e-4|0)){break g}if(!ek(b,14128)){break g}e=d+40|0;ce(e,b,(y[d+202|0]|y[d+203|0]<<8)<<6);k=c&2;h=a+480190|0;g=hc(d+104|0,e);ub(e);j=d+53|0;e=0;h:{while(1){if((e&65535)>>>0>=(y[d+202|0]|y[d+203|0]<<8)>>>0){break h}x[31721]=0;f=P(693,g|0,d+40|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}if(!f){break h}f=y[d+85|0]|y[d+86|0]<<8;w[d+38>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(ge(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[oe(h,d+38|0)>>1],w[n>>1]=o;x[31721]=0;O(694,d+40|0,i|0);f=x[31721];x[31721]=0;if((f|0)==1){break i}f=d+12|0;QZ(f,1,j);x[31721]=0;O(221,d+24|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break b}f=d+24|0;xc(((z[d+38>>1]<<5)+a|0)+946304|0,f);tb(f);if(!k){break j}x[31721]=0;P(152,b|0,y[d+77|0]|y[d+78|0]<<8|(y[d+79|0]<<16|y[d+80|0]<<24))|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}i=1;l=d+24|0;f=y[d+87|0];m=Wc(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}tg(m,i)}x[31721]=0;U(218,l|0,(D(z[d+38>>1],104)+a|0)+484380|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}ub(g)}i=1;if(!(c&1)){break d}m:{c=y[d+216|0]|y[d+217|0]<<8|(y[d+218|0]<<16|y[d+219|0]<<24);if(c>>>0<5){break m}if(!bd(b,c-4|0)){break m}if(!ek(b,13714)){break m}k=a+484344|0;Of(k,y[d+200|0]|y[d+201|0]<<8);f=0;while(1){if((y[d+200|0]|y[d+201|0]<<8)>>>0<=f>>>0){break m}if(!Er(b,d+24|0)){break m}n:{e=z[d+24>>1];if(e>>>0>3){c=d+104|0;ce(c,b,(e+15&131056)-4|0);g=hc(d+40|0,c);ub(c);x[31721]=0;c=U(199,k|0,f&65535,y[d+26|0])|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[31721]=0;e=U(153,c|0,x[d+48>>2],1)|0;c=x[31721];x[31721]=0;q:{if((c|0)!=1){c=y[d+26|0];if(!(e&c>>>0>(h&255)>>>0)){break p}x[31721]=0;c=R(200,g|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}e=c<<24>>24;if(e){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[d+104>>1]=e&31;w[d+12>>1]=z[a+480188>>1]-1;c=Vb(c,f);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Lc(d+104|0,d+12|0)>>1]);if((e|0)<0){x[31721]=0;O(201,d+104|0,g|0);j=x[31721];x[31721]=0;if((j|0)==1){break c}v[c|0]=y[d+104|0]+36;n=c,o=y[Hc(d+104|0)|0],v[n+1|0]=o}e=e&255;if(e&64){v[c+2|0]=1;x[31721]=0;j=R(200,g|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break c}v[d+104|0]=j;v[d+12|0]=64;n=c,o=y[Sb(d+104|0,d+12|0)|0],v[n+4|0]=o}if(!(e&32)){continue}x[31721]=0;O(201,d+104|0,g|0);e=x[31721];x[31721]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=y[Hc(d+104|0)|0];v[c+5|0]=e;switch(y[d+104|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[31721]=0;e=R(200,g|0)|0;j=x[31721];x[31721]=0;if((j|0)!=1){v[c+5|0]=e;x[31721]=0;P(186,g|0,1)|0;c=x[31721];x[31721]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}xe(Vb(x[k>>2],f),Vh(Ve(Le(d+104|0,14,0),c-1|0)))}ub(g)}f=f+1|0;continue}break}break c}c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);if(!c){break d}bd(b,c);JD(a+1298332|0,b,dh(b),4)}fb=d+272|0;return i|0}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-48|0;fb=g;d=x[b>>2];x[31721]=0;f=R(175,d|0)|0;d=x[31721];x[31721]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){h=Nb(g+36|0);x[31721]=0;e=(c|0)!=0;f=U(868,h|0,b|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}d=2;g:{h:{i:{j:{if(f){break j}x[31721]=0;f=U(869,h|0,b|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}d=3;if(f){break j}x[31721]=0;f=U(870,h|0,b|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}d=4;if(f){break j}f=0;x[31721]=0;i=U(871,h|0,b|0,e|0)|0;e=x[31721];x[31721]=0;d=1;if((e|0)==1){break e}if(!i){break i}}if(!c){d=1;f=0;break h}f=x[h>>2];if(!kc(f,x[h+4>>2])){Mw(b,f+12|0)}f=d}d=29904;k:{while(1){e=d;if((e|0)!=30480){i=x[e+8>>2];k=(i>>1)+a|0;d=x[e+4>>2];d=i&1?x[x[k>>2]+d>>2]:d;x[31721]=0;i=U(d|0,k|0,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}d=e+12|0;if(!i){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){d=(e|0)!=30480;f=0;break h}if(!(x[a+480184>>2]|!f)){x[a+480184>>2]=f}x[31721]=0;f=1;O(807,a+1298264|0,1);e=x[31721];x[31721]=0;d=1;if((e|0)==1){break g}}TR(h);if(f){break f}break a}break c}x[31721]=0;O(249,a|0,0);d=x[31721];x[31721]=0;if((d|0)==1){break d}x[31721]=0;O(807,a+1298264|0,1);d=x[31721];x[31721]=0;if((d|0)==1){break d}x[a+1074304>>2]=19988993;x[a+1298408>>2]=0}d=0;while(1){if((d|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){f=0;k=a+480180|0;d=0;l:{while(1){e=d&65535;if(e>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=f;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{e=x[((e<<2)+a|0)+900380>>2];if(e){i=x[k>>2];uc(e,65536);uc(e+4|0,64);uc(e+8|0,256);Qf(e+28|0,16384);Jf(e+30|0,128);Jf(e+31|0,17);if(y[e+16|0]>=4){v[e+16|0]=0}if(y[e+17|0]>=5){v[e+17|0]=0}if(y[e+18|0]>=3){v[e+18|0]=0}Jf(e+19|0,64);Jf(e+20|0,100);j=224;f=v[e+26|0];n:{if((f|0)>=-32){j=32;if((f|0)<33){break n}}v[e+26|0]=j}Jf(e+23|0,64);Jf(e+24|0,64);QB(e+48|0,64);QB(e+68|0,64);QB(e+88|0,(i|0)==4096?255:64);f=e+108|0;j=0;while(1){if((j|0)==128){if(!lp(y[e+14|0])){v[e+14|0]=5}if(y[e+34|0]>=251){v[e+34|0]=0}}else{o:{if(y[vb(f,j)|0]){if(y[vb(f,j)|0]<121){break o}}n=vb(f,j),o=j+1|0,v[n|0]=o}j=j+1|0;continue}break}f=d}d=d+1|0;continue}break}uc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[e>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[f>>2]=d}uc(e,65536);uc(f,65536);uc(a+480200|0,256);p:{f=a+480248|0;if(!kc(x[f>>2],x[a+480252>>2])){d=x[e>>2];x[31721]=0;O(872,f|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];cB(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(qn(x[a+480180>>2])){x[31721]=0;P(270,a+1074312|0,7)|0;d=x[31721];x[31721]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;pq(a);n=g,o=wb(x[a+484360>>2]),x[n+36>>2]=o;f=wb(x[a+484364>>2]);q:{while(1){r:{e=x[g+36>>2];if(!Ib(e,f)){if(x[a+480180>>2]){break r}d=0;break a}x[31721]=0;W(873,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break q}if(Yc(x[e>>2],x[e+4>>2])>>>0<=z[e+28>>1]){Ze(e,0)}cv(g+36|0);continue}break}ku(a+8|0,er(a));if(x[a+1074308>>2]){x[31721]=0;W(874,a|0);d=x[31721];x[31721]=0;if((d|0)==1){break p}}m=Nb(g+36|0);s:{t:{if((c&12)!=12){break t}k=a+906300|0;i=a+1298472|0;d=0;u:{v:{w:{x:{y:{z:{while(1){if((d|0)==250){break t}A:{l=sd(k,d);e=l+16|0;B:{if(!Pi(x[e>>2],x[l+20>>2])){break B}x[31721]=0;O(875,l|0,a|0);c=x[31721];x[31721]=0;C:{if((c|0)!=1){h=x[l>>2];if(!h){break C}f=x[l+148>>2];c=x[x[h>>2]+56>>2];x[31721]=0;O(c|0,h|0,f|0);c=x[31721];x[31721]=0;if((c|0)!=1){break B}}a=N()|0;break s}j=wb(x[m>>2]);f=wb(x[m+4>>2]);h=fb-16|0;fb=h;x[h+12>>2]=j;while(1){D:{if(!Ib(j,f)){break D}c=x[j>>2];if((y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))==(y[l+20|0]|y[l+21|0]<<8|(y[l+22|0]<<16|y[l+23|0]<<24))){c=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))==(y[l+16|0]|y[l+17|0]<<8|(y[l+18|0]<<16|y[l+19|0]<<24))}else{c=0}if(c){break D}j=x[Pe(h+12|0)>>2];continue}break}fb=h+16|0;if(Ib(j,wb(x[m+4>>2]))){break B}x[31721]=0;x[g+24>>2]=e;O(876,m|0,g+24|0);c=x[31721];x[31721]=0;if((c|0)==1){break A}x[31721]=0;f=P(1,g+12|0,18309)|0;c=x[31721];x[31721]=0;if((c|0)==1){break z}x[31721]=0;O(877,g|0,l|0);c=x[31721];x[31721]=0;if((c|0)==1){break y}x[31721]=0;S(2,g+24|0,f|0,g|0);c=x[31721];x[31721]=0;if((c|0)==1){break x}c=x[i>>2];x[31721]=0;S(389,c|0,2,g+24|0);c=x[31721];x[31721]=0;if((c|0)==1){break w}tb(g+24|0);tb(g);tb(f)}d=d+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(g+24|0)}tb(g)}tb(f);break s}c=y[a+1074368|0];x[31721]=0;O(878,a|0,c|0);a=x[31721];x[31721]=0;d=1;if((a|0)!=1){sc(m);break a}a=N()|0}sc(m);break b}a=N()|0;break b}a=N()|0;break b}i=D(f,104)+a|0;k=i+484380|0;E:{if(ge(x[k>>2],x[i+484400>>2])){Mj(k,a);break E}e=i+484414|0;f=z[e>>1];if(f&16384){break E}x[k>>2]=0;x[k+4>>2]=0;x[k+16>>2]=0;x[k+8>>2]=0;x[k+12>>2]=0;w[e>>1]=f&65505}f=i+484412|0;if(z[f>>1]>=65){w[f>>1]=64}F:{G:{if(!(y[i+484415|0]&2)){break G}if(!Ak(x[a+1298300>>2])){break G}x[31721]=0;W(879,a|0);f=x[31721];x[31721]=0;if((f|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}e=(d<<5)+a|0;Qf(e+480286|0,64);f=e+480284|0;if(z[f>>1]>=257){w[f>>1]=128}f=e+480288|0;if(y[f|0]>=251){v[f|0]=0}Ko((D(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=N()|0;break b}a=N()|0;TR(h)}ub(b);Q(a|0);p()}ub(b);fb=g+48|0;return d|0}function Bu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}h=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{i=x[b+656>>2];k:{if(!(!i|x[a+480180>>2]!=16777216)){k=x[i+44>>2]!=0;break k}if(!i){break j}}if((c|0)>128){break i}l=c-1|0;m=z[Zb(i+236|0,l)>>1];l:{if((m-1&65535)>>>0<=3998){h=(D(m,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Gj(x[b+656>>2])){break a}}m=y[vb(i+108|0,l)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;l=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){zo(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];d=a+480180|0;if(!(!(c&512)|x[d>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[d>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}l=0;if(!k){break g}if(d){l=y[b+797|0];if(l){break f}}x[b+708>>2]=0;l=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!h)){w[b+770>>1]=v[h+36|0];w[b+772>>1]=v[h+37|0];break d}if(h){break d}h=0;q=1;break c}l=D((x[x[i+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(l<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=l;x[b+852>>2]=0-l;l=1}q=!h;k=1;if(Pi(x[b+8>>2],x[b+12>>2])){break b}p:{k=a+1074312|0;if(!Ob(k,54)){break p}if(Gj(x[b+656>>2])){if(!Ob(k,117)){break p}}x[b+700>>2]=0;break a}k=(Ob(k,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[h+24>>2]}k=0}q:{if(qn(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Ee(n+12|0,12,131);break q}rX(n+12|0)}j=a+1074312|0;r:{if(Ob(j,34)){d=dm(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:k)){v[b+803|0]=0}p=uh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(j,48)){US(a,b,i,h)}s:{if(!Ob(j,115)|!i){break s}d=y[i+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}TS(b+692|0,c,d,y[i+27|0])}t:{if(k|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!i){break t}if(Ob(j,29)){v[b+798|0]=y[i+16|0]}if(!(y[i+60|0]&8)){Fj(b+724|0)}if(!(y[i+80|0]&8)){Fj(b+732|0)}if(!(y[i+100|0]&8)){Fj(b+740|0)}if(y[i+20|0]){c=((D(yu(yo(a)),y[i+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Ob(j,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[i+19|0]){break v}r=b,s=(D(yu(yo(a)),y[i+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(j,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[i+23|0];if(m){d=yu(yo(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[i+24|0];if(!m){break t}d=yu(yo(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(q){break a}w:{x:{if(!p){d=0;break x}if(!(k&x[b+700>>2]!=0)){x[b+700>>2]=p}y:{z:{if(!l){if(!k){if(Ob(j,69)){break z}if(Ob(j,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=p;v[b+851|0]=y[b+851|0]&239}if(!k){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=h;c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Ob(j,96)|y[b+789|0]){break B}o=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Gb(b+660|0,n+8|0)>>2];x[b>>2]=o;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[h+34>>1];o=c&1023;d=o|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[h+12>>2];c=x[h+16>>2];x[b+88>>2]=(o&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(o&2)){break D}x[b+80>>2]=x[h+4>>2];c=x[h+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Ob(j,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Ob(j,21);o=x[a+480180>>2];H:{I:{if(!(c|!(o&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((o|0)==16){break H}}if(o&67633152){break G}d=0}v[b+819|0]=d}if(Ob(j,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!k){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Xm(b);if(!Ob(j,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){h=y[b+789|0];break J}h=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(h&255)){break w}}if(!(h&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}d=c;K:{if(!(!d|!Ob(j,40)|(y[b+789|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break K}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;L:{if(d){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=c&-6324225|2097152;M:{if(Ob(j,23)){break M}if(Ob(j,22)){break M}if(Ob(j,52)){break M}if(Ob(j,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!yd(x[a+1298300>>2])|(g|0)==65535){break L}if(Ob(j,111)){zk(x[a+1298300>>2],g);break L}if(!Ob(j,110)){break L}BB(x[a+1298300>>2],g,0,1,0)}c=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=c&-1025;break P}if(!(c&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=ud(a,c);x[a>>2]=111960;f=eJ(a+8|0);x[31721]=0;e=P(73,a+152|0,b|0)|0;b=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31721]=0;b=ca(107)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=x[b>>2];c=0;x[31721]=0;b=P(1309,f|0,b+8|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}while(1){f:{d=x[b>>2];if(nc(d,x[a+12>>2])>>>0<=c>>>0){x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break f}break e}d=x[xb(d,c)>>2];if(d){el(d)}c=c+1|0;continue}break}x[31721]=0;b=U(1310,c|0,e|0,0)|0;d=x[31721];x[31721]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31721]=0;O(1311,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=U(1312,c|0,e|0,0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break t}x[31721]=0;O(1313,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,20)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=U(1314,c|0,e|0,0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break s}x[31721]=0;O(1315,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=U(1316,c|0,e|0,0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break r}x[31721]=0;O(1317,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=ud(b,0);x[b>>2]=113908;x[b>>2]=119520;x[31721]=0;O(1318,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1319,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break q}x[31721]=0;O(1320,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=ud(b,0);x[b>>2]=114056;x[b>>2]=119728;x[31721]=0;O(1321,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=ud(b,0);x[b>>2]=114288;x[b>>2]=119832;x[31721]=0;O(1322,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=ud(b,0);x[b>>2]=114172;x[b>>2]=119936;x[31721]=0;O(1323,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=ud(b,0);x[b>>2]=114404;x[b>>2]=120040;x[31721]=0;O(1324,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,24)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=U(1325,c|0,e|0,0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break p}x[31721]=0;O(1326,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,28)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=U(1327,c|0,e|0,0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break o}x[31721]=0;O(1328,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,72)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1329,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break n}x[31721]=0;O(1330,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,72)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1331,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}x[31721]=0;O(1332,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,76)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1333,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break l}x[31721]=0;O(1334,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,76)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1335,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break k}x[31721]=0;O(1336,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,544)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1337,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break j}x[31721]=0;O(1338,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,544)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1339,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break i}x[31721]=0;O(1340,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1341,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break h}x[31721]=0;O(1342,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;c=R(858,12)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=P(1343,c|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;O(1344,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=QI(b,0);x[b>>2]=119368;x[31721]=0;O(1345,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;b=R(858,8)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}b=PI(b,0);x[b>>2]=119444;x[31721]=0;O(1346,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}return a|0}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}a=N()|0;break c}b=T(0)|0}Y(b|0)|0;c=0;while(1){b=x[f>>2];if(nc(b,x[a+12>>2])>>>0<=c>>>0){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}tb(e);break c}b=x[xb(b,c)>>2];if(b){sm(b)}c=c+1|0;continue}}Wx(f);Q(a|0);p()}T(0)|0;Qb()}p()}function r9(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=fb-560|0;fb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=5296;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=5299;break a}u=e&1;C=u?5302:5297;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;Sf(a,32,c,g,e&-65537);Gf(a,C,u);d=f&32;Gf(a,b!=b?d?9978:13848:d?11132:14166,3);Sf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=lL(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=Bua(B,d>>>0>B>>>0?k+1|0:k,1e9,0);k=zua(d,hb,-1e9,0)+B|0;x[g>>2]=k;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q+D(k,-9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=D(w,h);k=l+4|0;j:{if((q|0)==(r|0)&(k|0)==(g|0)){break j}q=q-r|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>q>>>0?.5:(k|0)==(q|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}x[l>>2]=r;if(b+t==b){break j}d=h+r|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=eo((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;Sf(a,32,c,r,e);Gf(a,C,u);Sf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=eo(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}Gf(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){Gf(a,16776,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=eo(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}Gf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=eo(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}Gf(a,g,1);g=g+1|0;if(!(l|m)){break t}Gf(a,16776,1)}f=k-g|0;Gf(a,g,(f|0)>(m|0)?m:f);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Sf(a,48,m+18|0,18,0);Gf(a,w,z-w|0);break o}g=m}Sf(a,48,g+9|0,9,0)}Sf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=eo((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+93472|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}k=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=k+d|0;Sf(a,32,c,h,e);Gf(a,l,s);Sf(a,48,c,h,e^65536);Gf(a,f,i);Sf(a,48,d-i|0,0,0);Gf(a,m,g);Sf(a,32,c,h,e^8192);p=(c|0)<(h|0)?h:c}fb=n+560|0;return p|0}function Fsa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Sb(l,k)|0];v[j+8|0]=14;l=y[Sb(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[qd(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=qd(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[qd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=qD(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[qd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=Zg(qD(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Fc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=cr(a,f,g);if(!c){break c}a=qi(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;uc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;Jv(j+8|0);x[j+112>>2]=9;s=b,t=x[Gb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:xf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Sc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(z[e>>1]){break a}w[j+8>>1]=255;c=z[Lc(a+480190|0,j+8|0)>>1];w[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=hE(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=x[f+4>>2];x[c+492>>2]=x[f>>2];x[c+496>>2]=g;f=d+946312|0;g=x[f+4>>2];x[c+500>>2]=x[f>>2];x[c+504>>2]=g;f=d+946320|0;g=x[f+4>>2];x[c+508>>2]=x[f>>2];x[c+512>>2]=g;d=d+946328|0;f=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=f;gk(c,127,1);fk(c,0,1)}b=b+1|0;c=z[e>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=$l(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=cr(a,f,g);if(!i){break a}k=qi(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[vb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=zi(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=$l(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Iv(dK(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Sc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Zg(qD(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function zoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-224|0;fb=d;vc(b);a:{if(!mr(b,d+160|0)){break a}if(!sW(d+160|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(rW(d+160|0),hb))){break a}if(!c){e=1;break a}Ad(a,256);f=d+148|0;si(f,2,d+160|0);e=d+56|0;Ac(e,f);yb(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;j=gC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=j;v[d+56|0]=64;r=a,s=y[Sb(d+202|0,e)|0]<<2,x[r+480200>>2]=s;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{j=Nb(d+148|0);l=Nb(d+136|0);x[31721]=0;P(152,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31721];x[31721]=0;i:{if((e|0)==1){break i}x[31721]=0;U(216,b|0,j|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}x[31721]=0;P(152,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}x[31721]=0;U(216,b|0,l|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}x[31721]=0;P(152,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}e=a+484376|0;f=y[e|0];g=x[a+484360>>2];x[31721]=0;O(333,Wb(g,f)|0,y[d+212|0]|y[d+213|0]<<8);f=x[31721];x[31721]=0;if((f|0)==1){break i}e=Wb(x[a+484360>>2],y[e|0]);r=d,s=wb(x[e>>2]),x[r+56>>2]=s;e=wb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!uW(Wb(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;k=d+57|0;e=1;break j}x[31721]=0;g=R(200,b|0)|0;k=x[31721];x[31721]=0;k:{if((k|0)==1){break k}w[f>>1]=g;x[31721]=0;P(186,b|0,4)|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}Od(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){f=e&65535;if(f>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}h=Zb(x[l>>2],f-1|0);h=y[h|0]|y[h+1|0]<<8;x[31721]=0;h=P(152,b|0,h<<4)|0;i=x[31721];x[31721]=0;p:{if((i|0)!=1){if(h){break p}e=0;break b}b=N()|0;break c}x[31721]=0;P(702,b|0,d+56|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break o}x[31721]=0;h=(D(f,104)+a|0)+484380|0;S(703,d+56|0,h|0,0);i=x[31721];x[31721]=0;if((i|0)==1){break o}i=d+28|0;Mk(i,2,k);x[31721]=0;O(221,d+40|0,i|0);i=x[31721];x[31721]=0;if((i|0)==1){break n}i=((f<<5)+a|0)+946304|0;f=d+40|0;xc(i,f);tb(f);q:{r:{if(!g|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}f=GW(d+56|0);x[31721]=0;f=P(152,b|0,f|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break m}if(!f){break r}f=d+40|0;FW(f,y[d+86|0],y[d+87|0],1);x[31721]=0;U(218,f|0,h|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;i=0;e=x[j>>2];s:{if(kc(e,x[j+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31721]=0;f=P(152,b|0,f<<4)|0;g=x[31721];x[31721]=0;if((g|0)==1){break h}if(!f){break b}x[31721]=0;e=R(192,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break h}if((e|0)!=(y[d+188|0]|y[d+189|0]<<8)){break s}v[d+27|0]=0;i=1}n=c&1;if(n){x[31721]=0;O(226,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31721];x[31721]=0;if((c|0)==1){break h}}k=a+484344|0;o=a+480188|0;f=0;while(1){t:{if(!n|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31721]=0;c=U(199,k|0,f&65535,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}if(!c){break t}c=Zb(x[j>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31721]=0;c=P(152,b|0,c<<4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(i){x[31721]=0;c=R(192,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Vb(x[k>>2],f);_e(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31721]=0;e=R(200,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break f}h=e<<24>>24;if(!h){e=64;if(c>>>0>62){continue u}e=Vb(x[k>>2],f);g=x[e>>2];h=x[x[e+48>>2]+12>>2];e=c+1|0;_e(d+56|0,g,h,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=Ig(d+56|0);g=h&31;if(g>>>0<z[o>>1]){e=Vc(x[d+40>>2],g)}m=h&255;if(m&32){x[31721]=0;O(201,d+25|0,b|0);g=x[31721];x[31721]=0;v:{w:{x:{if((g|0)!=1){q=Hc(d+25|0);g=y[d+25|0];if(g>>>0>239){break x}g=EW((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[q|0]}if(m&64){x[31721]=0;g=R(200,b|0)|0;m=x[31721];x[31721]=0;if((m|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;r=e,s=y[Sb(d+25|0,d+24|0)|0],v[r+4|0]=s}if((h|0)>=0){continue}x[31721]=0;O(201,d+25|0,b|0);g=x[31721];x[31721]=0;if((g|0)==1){break d}r=e,s=y[Hc(d+25|0)|0],v[r+5|0]=s;tW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){xe(Vb(x[k>>2],f),sn(Ve(Le(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31721]=0;b=P(1,d+56|0,6088)|0;c=x[31721];x[31721]=0;z:{A:{B:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,d+40|0,5274)|0;c=x[31721];x[31721]=0;if((c|0)==1){break B}yb(a+1298356|0,b);tb(b);r=a+1298404|0,s=x[Ec(d+28|0,4)>>2],x[r>>2]=s;x[31721]=0;O(705,d+12|0,4405);b=x[31721];x[31721]=0;if((b|0)==1){break A}x[31721]=0;S(212,d+28|0,d+12|0,d+27|0);b=x[31721];x[31721]=0;if((b|0)==1){break z}b=a+1298368|0;a=d+28|0;yb(b,a);tb(a);Eb(d+12|0);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;Ue(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ld(l);ld(j);Q(b|0);p()}ld(l);ld(j)}fb=d+224|0;return e|0}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-176|0;fb=d;vc(c);a:{if(!$o(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break a}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break a}e=fb-32|0;fb=e;g=d+152|0;f=Nb(g);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];i=x[c>>2];x[31721]=0;h=U(153,i|0,h|0,8)|0;i=x[31721];x[31721]=0;if((i|0)==1){break d}if(!h){break e}x[31721]=0;O(831,e+4|0,c|0);h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;O(832,f|0,e+4|0);h=x[31721];x[31721]=0;if((h|0)==1){break f}Fd(e+4|0);continue}break}a=N()|0;break c}a=N()|0;Fd(e+4|0);break c}fb=e+32|0;break b}a=N()|0}fe(f);Q(a|0);p()}x[31721]=0;S(751,d+132|0,g|0,1129270605);c=x[31721];x[31721]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[31721]=0;c=P(752,d+132|0,d+114|0)|0;e=x[31721];x[31721]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!_b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Cb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Cb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[31721]=0;c=P(631,d+132|0,d+108|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[31721]=0;S(751,d+88|0,d+152|0,1397968452);e=x[31721];x[31721]=0;p:{q:{if((e|0)!=1){x[31721]=0;k=P(753,d+88|0,d+80|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break p}if(k){break q}break h}c=N()|0;break j}e=(Cb(z[d+120>>1])-1|0)/8|0;g=e<<3;f=g&31;g=Wc(d+76|0,(e>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>f|0:((1<<f)-1&1074268168)<<32-f|538447880>>>f)&255,(Cb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}tg(g,3);break r}tg(g,17);ed(g,16);break r}tg(g,16);ed(g,16);break r}tg(g,1)}c=x[d+80>>2];x[31721]=0;c=U(153,x[d+88>>2],x[d+96>>2],_b(c)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[31721]=0;P(186,d+88|0,_b(c)|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break l}}Eu(a,b);x[31721]=0;c=D(b,104)+a|0;h=c+484380|0;O(282,h|0,0);e=x[31721];x[31721]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=h,t=_b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);i=30-y[d+123|0]|0;e=0;while(1){c=f;if(i&255){f=c>>>1|0;i=i-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[31721]=0;U(218,g|0,h|0,d+88|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break D}x[31721]=0;S(751,d+56|0,d+152|0,1296126539);c=x[31721];x[31721]=0;if((c|0)==1){break C}x[31721]=0;c=R(175,x[d+56>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break B}if(!c){break u}x[31721]=0;S(751,d+16|0,d+152|0,1229869908);c=x[31721];x[31721]=0;if((c|0)==1){break A}x[31721]=0;c=P(754,d+16|0,d+36|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break z}ub(d+16|0);if(!c){break u}x[31721]=0;f=R(276,d+56|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break y}e=Nb(d+16|0);x[31721]=0;O(755,e|0,f|0);c=x[31721];x[31721]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[31721]=0;g=P(756,d+56|0,d+4|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break w}if(!g){break x}x[31721]=0;O(757,e|0,d+4|0);g=x[31721];x[31721]=0;if((g|0)==1){break w}x[31721]=0;g=y[d+10|0];P(186,d+56|0,!(g&1)+g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Cb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Cb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=wb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;i=c+484384|0;j=c+484396|0;l=c+484392|0;m=wb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,m)){break v}f=Cb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Cb(n)|0)){s=l,t=_b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((Cb(o)|0)==(f|0)){s=j,t=_b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((Cb(q)|0)==(f|0)){s=i,t=_b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Cb(r)|0)){s=g,t=_b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;zT(e);break m}Zk(h);zT(e)}x[31721]=0;S(751,d+16|0,d+152|0,1312902469);c=x[31721];x[31721]=0;if((c|0)==1){break n}x[31721]=0;c=R(175,x[d+16>>2])|0;e=x[31721];x[31721]=0;E:{if((e|0)==1){break E}F:{if(c){x[31721]=0;c=R(157,x[d+16>>2])|0;e=x[31721];x[31721]=0;if((e|0)==1){break E}x[31721]=0;S(320,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break F}break E}x[31721]=0;c=P(37,d+4|0,22250)|0;e=x[31721];x[31721]=0;if((e|0)==1){break E}xc(((b<<5)+a|0)+946304|0,c);tb(c)}OB(h,x[a+480180>>2]);Mj(h,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}fe(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);fe(d+152|0)}fb=d+176|0;return k|0}function Fo(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Sc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[Zb(g,j)>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(Nj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[vb(h+108|0,j)|0]>120){break b}j=z[Zb(g,j)>>1];n=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){n=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(Nj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(n|0);g=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;o=d^1;j=(g|0)!=(h|0);if((o|j|m)==1){w[b+774>>1]=0}i=!m;if(!(i|(j|!(d&p)))){break b}f:{if(i|o){break f}l=a+1074312|0;if(!(!Ob(l,32)|!(y[a+480208|0]&8))){n=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:n}q=x[a+480180>>2];g:{h:{if(!(q&1048580?j|!h:1)|(q|0)==268435456){break h}if((q|0)==1){if(Pi(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(l,79)){break g}if(!Pi(x[b+8>>2],x[b+12>>2])){break g}}k=1}if(!Ob(l,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}i:{if(!x[b+16>>2]|(i|(j|!z[a+480192>>1]))){break i}if(!Ob(a+1074312|0,87)){break i}k=Sc(y[b+788|0])^1|k}l=(g|0)!=(h|0);j:{if(Pi(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break j}if(h){if(Nj(y[h+31|0])){break j}}l=1}k:{l:{if(!(m|l)|!d){break l}if(!Ob(a+1074312|0,61)){break l}i=x[b+656>>2];g=x[b+104>>2];j=0;if(i|g){break k}}x[b+656>>2]=h;g=n;i=h;j=l}m:{n:{o:{if(!e){break o}p:{if(y[a+480180|0]&3){if(g){if(ge(x[g>>2],x[g+20>>2])){break p}}if(!Gj(i)){break o}}if(!g){break n}}if(w[g+34>>1]<0){break o}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&m)|!g){break m}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break m}if(!ge(x[g>>2],x[g+20>>2])){break m}x[b+704>>2]=x[g+24>>2];break m}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break m}h=0;x[b+688>>2]=0}if(k){break b}v[b+803|0]=0;q:{if(!i){break q}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break q}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}r:{if(!(x[a+480180>>2]&1048580?e:1)){break r}if(Ob(a+1074312|0,48)){break r}US(a,b,i,g)}s:{t:{u:{if(!f){break u}v:{w:{x:{y:{z:{A:{B:{C:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break B}if(!(!c|o)){e=(y[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}D:{c=x[a+480180>>2]&17301536;e=1;E:{if(!d|!c){break E}c=1;e=1;if(y[a+480208|0]&8){break E}e=1;if(!x[b+76>>2]){break E}if(!(y[b+89|0]&16)){break D}e=!x[b+696>>2]}if(j|(!i|!c)){break z}if(!e){break v}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break y}break A}if((j|!i)!=1){break v}break w}if(d){break B}if(!(y[b+89|0]&24)){e=0;break B}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break z}if(!e){break w}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break x}if(c&2048){break y}}if(!(y[i+60|0]&8)){Fj(b+724|0)}if(!(y[i+80|0]&8)){Fj(b+732|0)}if(y[i+100|0]&8){break x}Fj(b+740|0);break x}if(!e){break w}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break x}}Xm(b)}if(Ob(f,21)){break u}v[b+818|0]=0;x[b+756>>2]=0;break u}if(!i){break t}}if(v[i+60|0]&1){break u}if(Ob(f,32)){Fj(b+724|0);break u}Xm(b)}c=0;if(g){break s}if(!i){break a}c=1;if(Nj(y[i+31|0])){break s}break a}c=0;if(!g){break a}}F:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}G:{H:{if((e|0)!=4){break H}if(!Ob(a+1074312|0,40)|y[b+789|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;I:{J:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break J}break I}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break I}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break F}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];K:{if((y[i+100|0]&17)!=17){break K}if(Ob(e,36)|y[b+837|0]){break K}v[b+837|0]=127}e=y[i+21|0];if(Cd(e)){s=b,t=Rh(e),v[s+837|0]=t}e=y[i+22|0];if(!Cd(e)){break F}s=b,t=Rh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}L:{if(x[b+76>>2]|!d){break L}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break L}}x[b+8>>2]=0;x[b+12>>2]=0}M:{if(y[b+788|0]!=255){break M}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break M}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Gq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}N:{O:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break O}if(!(m|o)){d=x[a+480180>>2];if(d&5){break N}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(qn(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}P:{if(!(h&2)){h=x[b+76>>2];break P}h=x[b+76>>2];c=x[b+84>>2];if(h>>>0<=c>>>0){break P}x[b+76>>2]=c;h=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<h>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function esa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;d=fb-1344|0;fb=d;vc(b);h=fb-16|0;fb=h;f=d+768|0;uZ(h+8|0,f);j=x[h+12>>2];jc(h,x[b>>2],x[b+8>>2],x[h+8>>2],x[h+12>>2]);e=x[h+4>>2];if((e|0)==(j|0)){Ub(b,x[h+12>>2])}fb=h+16|0;e=(e|0)==(j|0);if(!e){tZ(f)}a:{if(!e){break a}if(!wZ(d+768|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(vZ(y[d+802|0]|y[d+803|0]<<8,y[d+804|0]|y[d+805|0]<<8),hb))){break a}if(!c){i=1;break a}k=qc(d+764|0);b:{while(1){if((i|0)!=32){n=(i<<5)+a|0;h=n+480280|0;Ue(h);j=(d+768|0)+(i<<4)|0;w[n+480284>>1]=((y[j+78|0]<<8&65280)>>>0)/255;e=d+496|0;Mk(e,1,j- -64|0);f=d+108|0;Ac(f,e);Tk(n+480289|0,f);tb(f);c:{d:{switch(y[j+79|0]){case 0:o=g+1|0;break c;case 1:x[h>>2]=1024;o=i+1|0;break c;case 2:break d;default:break b}}x[h>>2]=1024;e=d+108|0;Oc(e,k,i);Vo(e)}g=g+1|0;i=i+1|0;continue}break}Ad(a,33554432);w[a+480188>>1]=o&255;f=d+108|0;e=rc(f,6808);yb(a+1298344|0,e);tb(e);e=rc(f,11140);yb(a+1298356|0,e);tb(e);u=a+1298404|0,B=x[Ec(f,4)>>2],x[u>>2]=B;e:{if(y[d+847|0]){break e}i=1;g=1;while(1){if((i|0)==16){while(1){if((g|0)==16){break e}e=((g<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025;g=g+1|0;continue}}e=i<<4;i=i+1|0;if(y[(d+e|0)+847|0]==1){continue}break}}f=d+496|0;Te(f,1,d+768|0);e=d+108|0;Ac(e,f);yb(a+1298308|0,e);tb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+806|0]|y[d+807|0]<<8)<<4&16;x[a+480196>>2]=y[d+816|0];x[a+480204>>2]=D(y[d+817|0],1e4);x[a+480200>>2]=y[d+818|0]<<2;x[a+480228>>2]=y[d+819|0];e=y[d+804|0]|y[d+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;rw(b,f);Fr(Wb(x[a+484360>>2],y[a+484376|0]),f,y[d+800|0]|y[d+801|0]<<8,65535,255);s=c&1;if(s){Of(a+484344|0,y[d+802|0]|y[d+803|0]<<8)}q=a+484344|0;n=a+480188|0;f:{while(1){g:{if((y[d+802|0]|y[d+803|0]<<8)>>>0<=t>>>0){s=c&2;n=a+480192|0;f=1;c=0;h:while(1){if(z[n>>1]<=(c&65535)>>>0){i=32;break b}c=c+1|0;l=hE(a,c&65535,0);i=!l;h=fb-16|0;fb=h;g=d+108|0;ac(h+8|0,g,384);j=x[h+12>>2];jc(h,x[b>>2],x[b+8>>2],x[h+8>>2],x[h+12>>2]);e=x[h+4>>2];if((e|0)==(j|0)){Ub(b,x[h+12>>2])}fb=h+16|0;e=(e|0)==(j|0);if(!e){Tb(g,0,384)}if(!e|i){continue}i=f&65535;h=fb-32|0;fb=h;e=h+8|0;m=d+108|0;Te(e,1,m);g=h+20|0;Ac(g,e);xc(l+492|0,g);tb(g);i:{if(!(y[m+378|0]|y[m+379|0]<<8)){break i}g=l+236|0;j=0;while(1){x[h+20>>2]=120;x[h+8>>2]=116;if(A[Gb(h+20|0,h+8|0)>>2]<=j>>>0){break i}e=y[(j+m|0)+32|0];u=Zb(g,j+12|0),B=e+i|0,w[u>>1]=B;j=j+1|0;continue}}e=y[m+376|0]|y[m+377|0]<<8;v[l+33|0]=1;x[l>>2]=e;jD(m,l+48|0,0);jD(m,l+68|0,1);jD(m,l+88|0,2);e=y[l+100|0];if(e&1){v[l+100|0]=e|16}if(!(x[l>>2]|v[l+60|0]&1)){x[l>>2]=32767}fb=h+32|0;i=0;while(1){e=y[d+486|0]|y[d+487|0]<<8;if(e>>>0<=i>>>0){f=e+f|0;continue h}I_(b,d+44|0);j:{k:{if((y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24))!=808538953){break k}e=f+i|0;l=e&65535;if(l>>>0>3999){break k}w[a+480190>>1]=e;q=fb-32|0;fb=q;m=D(l,104)+a|0;k=m+484380|0;kd(k,0);e=q+8|0;hk(e,1,d+44|0);g=q+20|0;Ac(g,e);ye(k+43|0,g);tb(g);h=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);x[k>>2]=h;j=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[k+4>>2]=j;g=y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24);x[k+8>>2]=g;x[k+24>>2]=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);w[k+30>>1]=y[d+76|0]<<2;w[k+28>>1]=y[d+77|0];e=y[d+92|0];if(e&1){w[k+34>>1]=z[k+34>>1]|2;e=y[d+92|0]}if(e&2){w[k+34>>1]=z[k+34>>1]|4;e=y[d+92|0]}if(e&4){x[k+8>>2]=g>>>1;x[k+4>>2]=j>>>1;x[k>>2]=h>>>1;w[k+34>>1]=z[k+34>>1]|1;e=y[d+92|0]}if(e&8){w[k+34>>1]=z[k+34>>1]|32}fb=q+32|0;g=fb-16|0;fb=g;Ew(g+8|0,m+484423|0);e=d+24|0;qp(e,x[g+8>>2],x[g+12>>2]);fb=g+16|0;xc(((l<<5)+a|0)+946304|0,e);tb(e);e=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);if(!e){break k}g=d+4|0;ce(g,b,e);j=hc(d+24|0,g);ub(g);if(s){e=Wc(d+4|0,w[m+484414>>1]&1?16:8,1,0,0);x[31721]=0;U(218,e|0,k|0,j|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}}ub(j)}i=i+1|0;continue}break}break}a=N()|0;ub(j);break f}e=dh(b);l=dh(b);f=d+44|0;ce(f,b,e-4|0);r=hc(d+108|0,f);ub(f);l:{m:{if(!s){break m}x[31721]=0;f=U(199,q|0,t&65535,l|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}if(!f){break m}o=0;e=Ig(d+24|0);while(1){if(l>>>0<=o>>>0){break m}x[31721]=0;j=R(200,r|0)|0;f=x[31721];x[31721]=0;n:{if((f|0)!=1){if(j){break n}o=o+1|0;continue}break g}g=e;m=j&31;if(m>>>0<z[n>>1]){f=Vb(x[q>>2],t);g=jd(x[f>>2],x[x[f+48>>2]+12>>2],o,m)}if(j&32){x[31721]=0;O(201,d+44|0,r|0);f=x[31721];x[31721]=0;if((f|0)==1){break g}f=y[d+44|0];v[g|0]=f;u=g,B=y[Hc(d+44|0)|0],v[u+1|0]=B;o:{p:{if((f|0)==160){i=255;break p}if((f|0)==255){i=0;break p}i=0;f=(D(f>>>4|0,12)+(f&15)|0)+13|0;if(sZ(f)){break o}}f=i}v[g|0]=f}f=j&192;q:{if(!f){break q}if((f|0)==192){x[31721]=0;O(360,d+44|0,r|0);f=x[31721];x[31721]=0;if((f|0)!=1){f=d+44|0;i=Hc(f);h=Ye(f);j=cj(f);f=d+4|0;kD(f,y[d+44|0],y[i|0]);i=Hc(f);f=d+494|0;kD(f,y[h|0],y[j|0]);un(d+492|0,g,y[d+4|0],y[i|0],y[d+494|0],y[Hc(f)|0]);break q}break g}x[31721]=0;O(201,d+44|0,r|0);f=x[31721];x[31721]=0;r:{s:{if((f|0)!=1){f=d+4|0;kD(f,y[d+44|0],y[Hc(d+44|0)|0]);i=y[Hc(f)|0];f=y[d+4|0];if((f|0)!=13){break s}v[g+2|0]=1;f=g+4|0;break r}break g}v[g+3|0]=f;f=g+5|0}v[f|0]=i}Oc(d+44|0,k,m);if(!Hb(x[x[d+44>>2]>>2],x[d+48>>2])){continue}if(!J$(y[g+3|0],y[g+5|0])){continue}v[g+3|0]=0;continue}}ub(r);t=t+1|0;continue}}break}a=N()|0;ub(r)}Q(a|0);p()}i=i>>>0>31}fb=d+1344|0;return i|0}function Ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-1824|0;fb=e;vc(b);d=fb-16|0;fb=d;j=e+1224|0;DX(d+8|0,j);f=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);m=x[d+4>>2];if((m|0)==(f|0)){Ub(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(m|0);if(!d){CX(j)}a:{if(!d){break a}if(!EX(e+1224|0)){break a}if(!BC(b,16,0)){break a}d=e+1240|0;x[e+1216>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[e+1228|0]|y[e+1229|0]<<8|(y[e+1230|0]<<16|y[e+1231|0]<<24);x[e+1200>>2]=y[e+1224|0]|y[e+1225|0]<<8|(y[e+1226|0]<<16|y[e+1227|0]<<24);x[e+1204>>2]=d;d=e+1232|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+1208>>2]=f;x[e+1212>>2]=d;Ad(a,1);Lb(Lb(Zf(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;bd(b,20);l=a+480188|0;g=1;j=1;b:{while(1){c:{if((g|0)==16){d=e+1064|0;if(!xC(b,d)){tC(d)}d=a+484360|0;f=a+484376|0;Zv(Wb(x[d>>2],y[f|0]),e+1066|0,128);m=NX(b,Wb(x[d>>2],y[f|0]),y[e+1064|0],h,l,0,1);if(!(y[e+1065|0]|m>>>0>1)){g=0;if(!y[e+1064|0]){break a}}d=(m<<10)+h|0;x[e+1060>>2]=d;x[e+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],d-x[Gb(e+1060|0,e+24|0)>>2]|0)){break a}if(c){break c}break b}d=e+24|0;vC(b,d);i=d;f=D(g,104)+a|0;m=f+484380|0;d=((g<<5)+a|0)+946304|0;DC(i,m,d,1);k=x[m>>2];d:{if(!y[vb(d,0)|0]){break d}e:{if(hd(d,16778,3)){if(hd(d,16782,3)){break e}}if(y[vb(d,5)|0]==58){break d}}j=0}d=Cb(y[e+52|0]|y[e+53|0]<<8);if(d>>>0>=2){i=d<<1;d=Cb(y[e+50|0]|y[e+51|0]<<8);x[f+484388>>2]=i+d;x[f+484384>>2]=d;Zk(m)}f:{if(Cb(y[e+46|0]|y[e+47|0]<<8)>>>0<=4999){if(Cb(y[e+50|0]|y[e+51|0]<<8)>>>0<1e4){break f}}x[e+1064>>2]=5;t=e,u=x[We(e+1196|0,e+1064|0)>>2],x[t+1196>>2]=u}h=h+k|0;g=g+1|0;continue}break}g=y[e+1065|0];if(!g){v[e+1065|0]=120;g=120}g:{if(!hd(e+1200|0,14928,6)){v[e+1065|0]=120;x[a+480204>>2]=125e4;break g}x[a+480204>>2]=125e4;if((g|0)==120){break g}t=a,u=Xe(1773447.5/(+(240-g|0)*122)*1e4),x[t+480204>>2]=u;if(x[e+1196>>2]>=2){x[e+24>>2]=j&1?4:5;t=e,u=x[We(e+1196|0,e+24|0)>>2],x[t+1196>>2]=u;break g}x[e+24>>2]=j&1?1:2;t=e,u=x[We(e+1196|0,e+24|0)>>2],x[t+1196>>2]=u}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=e+1048|0;si(f,3,e+1200|0);d=e+24|0;Ac(d,f);yb(a+1298308|0,d);tb(d);Uh(a,0);f=j&1;r=x[b+8>>2];s=a+484376|0;while(1){h:{if((n&65535)>>>0<m>>>0){d=Wb(x[a+484360>>2],y[s|0]);d=Ib(uC(wb(x[d>>2]),wb(x[d+4>>2]),n),wb(x[d+4>>2]));BX(b,e+24|0);i:{if(d){p=zC(e+24|0,0)+p|0;if(p>>>0>512){break i}}i=0;d=x[e+1196>>2];h=0;j=0;j:while(1){if((j|0)==64){break h}g=0;while(1)if((g|0)==4){j=j+1|0;continue j}else{k=xb(Vd(e+24|0,j),g);o=y[vb(k,2)|0]&15;l=y[vb(k,3)|0];k:{if(!(!(h&255)|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24)))){h=h+1|0;if((h&255)>>>0<33){break k}d=6;x[e+1196>>2]=6;break k}h=0}l:{m:{n:{o:{switch(o-1|0){case 0:case 1:if((d|0)==1&l>>>0>=32){break m}k=(o|0)!=1;if(!(k|!l|l>>>0>2)){x[e+1048>>2]=2;d=x[We(e+1196|0,e+1048|0)>>2];break n}if(k|(l|0)!=55&(l|0)!=71){break l}if((d|0)<=2){break m}break l;case 10:d=6;break n;case 11:case 12:case 13:x[e+1048>>2]=2;d=x[We(e+1196|0,e+1048|0)>>2];x[e+1196>>2]=d;if((o|0)!=13){break l}i=((j|l)!=0)+i|0;h=1;break l;case 14:break o;default:break l}}x[e+1048>>2]=3;d=x[We(e+1196|0,e+1048|0)>>2]}x[e+1196>>2]=d;break l}x[e+1196>>2]=f;d=f}g=g+1|0;continue}}}g=0;break a}if(!(x[e+1196>>2]!=6|m+32>>>0>=q>>>0)){x[e+1196>>2]=5}bd(b,r);o=c&1;if(o){Of(a+484344|0,m)}n=a+484344|0;l=0;while(1)if((l|0)==(m|0)){g=22250;d=x[e+1196>>2];if(d>>>0<7){g=x[(d<<2)+25244>>2]}d=e+24|0;f=rc(d,8304);yb(a+1298344|0,f);tb(f);f=rc(d,10785);yb(a+1298356|0,f);tb(f);_h(a+1298368|0,g);t=a+1298404|0,u=x[Ec(d,28)>>2],x[t>>2]=u;g=1;if(!(c&2)){break a}while(1){if((g|0)==16){break b}c=D(g,104)+a|0;d=c+484384|0;Ub(b,x[d>>2]);f=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-f;c=c+484388|0;x[c>>2]=x[c>>2]-f;c=e+24|0;Wc(c,8,1,1,0);ag(c,d,b);g=g+1|0;continue}}else{BX(b,e+24|0);p:{if(!o){break p}if(!Kg(n,l&65535,64)){break p}j=0;x[e+20>>2]=0;q:while(1){if((j|0)==64){break p}d=Vb(x[n>>2],l);_e(e+1048|0,x[d>>2],x[x[d+48>>2]+12>>2],j);g=0;while(1)if((g|0)==4){j=j+1|0;continue q}else{d=Vc(x[e+1048>>2],g);f=xb(Vd(e+24|0,j),g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[e+8>>2]=f;x[e+12>>2]=f;f=e+18|0;Zo(f,e+8|0,d);k=(e+20|0)+g|0;h=y[e+18|0];f=Hc(f);i=y[f|0];r:{s:{if(!((h|0)!=14?i:0)){v[k|0]=0;if(h|i){break s}break r}i=y[k|0];if(!i){break s}p=i;q=i>>>4|0;i=i>>>0<16;v[d+4|0]=i?p:q;v[d+2|0]=i?4:3}t:{u:{v:{w:{x:{switch(h-12|0){case 1:h=x[e+1196>>2];if((h|0)!=6){v[e+18|0]=10;break v}v[f|0]=0;break w;case 0:v[f|0]=y[f|0]&127;break w;case 2:h=y[f|0];if(h>>>0<=1){i=14;if(x[e+1196>>2]>3){break u}}v[e+18|0]=10;v[k|0]=y[f|0];break w;case 3:break x;default:break w}}v[f|0]=y[f|0]&15}h=x[e+1196>>2]}if((h|0)<2){break t}h=y[f|0];i=y[e+18|0]}xf(d,i,h&255);break r}h=y[f|0];v[d+5|0]=h;y:{z:{A:{switch(y[e+18|0]){case 0:if(y[f|0]>2){break z}break;case 2:break y;case 1:break z;default:break A}}v[d+3|0]=0;break r}v[d+3|0]=1;break r}f=h&15;if(f){v[d+5|0]=f;v[d+3|0]=2;break r}if(h>>>0<16){break r}v[d+3|0]=3;v[d+5|0]=(h&240)>>>4}g=g+1|0;continue}}}l=l+1|0;continue}}if((i-1&255)>>>0<2){x[e+1196>>2]=6}n=n+1|0;q=(i&255)+q|0;continue}}g=1}fb=e+1824|0;return g|0}function jL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=fb-80|0;fb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){Gf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Jh(i)|y[b+2|0]!=36)){q=i-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[o+1|0];m:{if(!(!Jh(b)|y[o+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=iL(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Jh(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=iL(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+92943|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}hL(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5286;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=5286;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+93472|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5286|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=5286;break z}if(n&2048){q=1;z=5287;break z}q=n&1;z=q?5288:5286}k=eo(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:17077;m=l>>>0>=2147483647?2147483647:l;h=St(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;Sf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=gL(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}Sf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=gL(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}Gf(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}Sf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=ib[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){hL((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}Sf(a,32,h,l,n);Gf(a,z,q);Sf(a,48,h,l,n^65536);Sf(a,48,i,m,0);Gf(a,k,m);Sf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[31596]=o}p=-1}fb=j+80|0;return p}function Jra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=fb-192|0;fb=f;n=ek(b,13874);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;u=a+480228|0;B=a+480232|0;s=a+480200|0;m=a+480268|0;C=a+1298320|0;E=a+480248|0;F=Dv(a+1074312|0);G=a+480180|0;H=a+484376|0;I=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Mg(b);g=dh(b);if((e|0)==70791730){Dh(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],g)){break a}d=f+152|0;ce(d,b,g);h=hc(f+172|0,d);ub(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=B;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=u;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31721]=0;S(455,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31721]=0;S(455,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31721]=0;w[f+152>>1]=0;S(456,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)!=1){J=a,K=Hd(z[f+152>>1],z[a+480188>>1],127),w[J+480188>>1]=K;break j}e=N()|0;break b}x[31721]=0;S(457,h|0,g|0,l|0);d=x[31721];x[31721]=0;if((d|0)!=1){break j}break c}x[31721]=0;x[f+152>>2]=0;S(455,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+152>>2];break j}e=N()|0;break b}x[31721]=0;x[f+152>>2]=0;S(455,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)==1){break h}d=x[f+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31721]=0;S(455,h|0,g|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}break j}if(x[G>>2]==4){break j}x[31721]=0;S(456,h|0,g|0,f+152|0);d=x[31721];x[31721]=0;if((d|0)!=1){Ze(Wb(x[a+484360>>2],y[H|0]),z[f+152>>1]);break j}e=N()|0;break b}x[31721]=0;S(458,h|0,g|0,m|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}if(lp(y[m|0])){break j}v[m|0]=5;break j}d=Fb(f+152|0);e=x[h>>2];x[31721]=0;e=R(157,e|0)|0;g=x[31721];x[31721]=0;x:{if((g|0)==1){break x}x[31721]=0;S(459,h|0,d|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break x}x[31721]=0;S(261,f+140|0,0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break x}e=f+140|0;yb(C,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+152>>1]=(g>>>1|0)- -64;w[f+140>>1]=127;e=z[Lc(f+152|0,f+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31721]=0;O(201,f+152|0,h|0);e=x[31721];x[31721]=0;if((e|0)==1){break g}e=y[f+152|0];y:{if((e|0)==255){break y}j=y[Hc(f+152|0)|0];g=(d<<5)+a|0;t=g+480284|0;w[t>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[t>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[31721]=0;d=R(192,h|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}if(z[I>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;g=kZ(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[31721]=0;i=U(153,e|0,x[f+180>>2],4)|0;e=x[31721];x[31721]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31721]=0;e=R(154,h|0)|0;i=x[31721];x[31721]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[31721]=0;O(460,f+140|0,h|0);d=x[31721];x[31721]=0;A:{B:{C:{D:{if((d|0)!=1){x[31721]=0;S(461,f+152|0,x[f+140>>2],x[f+144>>2]);d=x[31721];x[31721]=0;if((d|0)==1){break D}x[31721]=0;d=P(106,f|0,f+152|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}tb(f+152|0);cc(f+140|0);e=x[h>>2];x[31721]=0;R(157,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break A}x[31721]=0;S(462,d|0,E|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break A}Bf(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(f+152|0)}cc(f+140|0);break b}e=N()|0;Bf(d);break b}e=0;g=Dv(F);E:while(1){d=x[h>>2];x[31721]=0;d=U(153,d|0,x[f+180>>2],1)|0;i=x[31721];x[31721]=0;if((i|0)==1){break d}if(!(d&e>>>0<121)){break j}x[31721]=0;i=R(200,h|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>120){break F}x[31721]=0;U(269,g|0,e|0,1)|0;j=x[31721];x[31721]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31721]=0;S(463,h|0,g|0,r|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];wp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}uc(s,256);uc(o,65536);uc(q,65536)}fb=f+192|0;return n|0}function tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;e=fb-272|0;fb=e;vc(b);a:{if(!g$(b,e+206|0)){break a}if(!qX(e+206|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(pX(e+206|0),hb))){break a}b:{if(!c){break b}Ad(a,16);f=e+44|0;si(f,2,e+210|0);g=e- -64|0;Ac(g,f);yb(a+1298308|0,g);tb(g);k=a+480190|0;w[k>>1]=y[e+236|0];w[a+480188>>1]=y[e+239|0];d=rc(g,8365);yb(a+1298344|0,d);tb(d);d=rc(g,10129);yb(a+1298356|0,d);tb(d);dg(f,4211);d=y[e+209|0];x[e+24>>2]=d>>>4;x[31721]=0;x[e+12>>2]=d&15;V(310,g|0,f|0,e+24|0,e+12|0);d=x[31721];x[31721]=0;c:{d:{if((d|0)!=1){d=e- -64|0;yb(a+1298368|0,d);tb(d);Eb(e+44|0);B=a+1298404|0,C=x[Ec(d,4)>>2],x[B>>2]=C;d=1;while(1){j=d&65535;if(j>>>0>z[k>>1]){d=0;k=a+480188|0;while(1)if(z[k>>1]<=d>>>0){d=e- -64|0;f=fb-16|0;fb=f;i=b;e:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){ah(b+d|0);b=b+1|0;continue}break}break e}JY(f+8|0,d);pd(f,i,x[f+8>>2],x[f+12>>2])}fb=f+16|0;tw(Wb(x[a+484360>>2],y[a+484376|0]),d,y[e+233|0]+1|0,255,254);d=y[e+238|0];b=e+24|0;ce(b,i,D(y[e+230|0]|y[e+231|0]<<8,192));m=hc(e+44|0,b);ub(b);f:{q=c&1;if(!q){break f}x[31721]=0;O(226,a+484344|0,y[e+232|0]+1|0);b=x[31721];x[31721]=0;if((b|0)!=1){break f}break d}r=d?d:64;s=a+484344|0;t=a+480188|0;b=0;while(1){g:{h:{i:{if(y[e+232|0]<n>>>0){if(!(b&u)){break h}B=e,C=wb(x[a+484344>>2]),x[B+12>>2]=C;j=wb(x[a+484348>>2]);break i}j:{if(q){x[31721]=0;f=U(199,s|0,n&65535,r|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}o=0;if(f){break j}}x[31721]=0;P(186,i|0,64)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break g}break d}while(1){k=o&65535;if(k>>>0>31){break g}x[31721]=0;f=R(192,i|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}k:{if((f-1&65535)>>>0>=(y[e+230|0]|y[e+231|0]<<8)>>>0|k>>>0>=z[t>>1]){break k}x[31721]=0;P(152,m|0,D(f,192)-192|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}f=0;d=Vb(x[s>>2],n);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,k);while(1){if((f|0)==(r|0)){break k}k=b;x[31721]=0;O(552,e+24|0,m|0);b=x[31721];x[31721]=0;l:{m:{n:{o:{p:{if((b|0)!=1){b=e+24|0;j=Hc(b);g=Ye(b);b=y[e+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[e+24|0]}v[d+1|0]=b<<4&48|y[j|0]>>>4;b=y[g|0];l=0;g=0;q:{r:{j=y[j|0]&15;switch(j-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}j=14;h=(b&240)<<24>>24;if((h|0)<=-17|!(435>>>((h+16&255)>>>4)&1)){break n}break o}b=(b&240?-16:15)&b;j=10;break n}break d}l=j;g=b}b=g;j=l;if(!((b|j)&255)){break m}}xf(d,j,b&255);b=1;s:{switch(y[d+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}u=1}b=k}f=f+1|0;d=D(z[t>>1],6)+d|0;continue}}o=o+1|0;continue}}while(1){t:{h=x[e+12>>2];if(Ib(h,j)){l=0;u:while(1){if(A[h+12>>2]<=l>>>0){break t}_e(e+24|0,x[h>>2],x[x[h+48>>2]+12>>2],l);B=e,C=wb(x[e+24>>2]),x[B+20>>2]=C;f=0;k=Yv(x[e+24>>2],x[e+28>>2]);g=0;while(1){b=x[e+20>>2];if(Ib(b,k)){d=1;v:{switch(y[b+3|0]-16|0){case 1:g=1;default:d=f;break;case 0:break v}}qg(e+20|0);f=d;continue}else{l=l+1|0;if(!(f&g&1)){continue u}break h}}}}B=e,C=wb(x[a+484344>>2]),x[B+20>>2]=C;k=wb(x[a+484348>>2]);w:while(1){g=x[e+20>>2];if(!Ib(g,k)){break h}f=0;x:while(1){if(A[g+12>>2]<=f>>>0){kn(e+20|0);continue w}_e(e+12|0,x[g>>2],x[x[g+48>>2]+12>>2],f);B=e,C=wb(x[e+12>>2]),x[B+8>>2]=C;d=Yv(x[e+12>>2],x[e+16>>2]);while(1){y:{b=x[e+8>>2];if(Ib(b,d)){b=y[b+3|0];if((b&254)!=16){break y}b=(b|0)==16;xe(g,Ve(Le(e+24|0,b?17:16,b?125:6),f))}f=f+1|0;continue x}qg(e+8|0);continue}}}}kn(e+12|0);continue}}z:{b=y[e+234|0]|y[e+235|0]<<8;if(!b){break z}x[31721]=0;aa(319,a+1298332|0,i|0,b|0,39,1);b=x[31721];x[31721]=0;if((b|0)!=1){break z}break d}A:{if(!(c&2)){break A}d=1;f=a+480190|0;while(1){b=d&65535;if(b>>>0>z[f>>1]){break A}c=D(b,104)+a|0;b=Wc(e+24|0,w[c+484414>>1]&1?16:8,1,0,1);x[31721]=0;U(218,b|0,c+484380|0,i|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){d=d+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(m);break b}n=n+1|0;continue}}else{f=(d<<5)+a|0;Ue(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+240|0]<<4|8)&248;d=d+1|0;continue}}else{i=e- -64|0;PE(b,i);g=fb-16|0;fb=g;h=(D(j,104)+a|0)+484380|0;kd(h,0);w[g+14>>1]=y[i+35|0]<<2;w[g+12>>1]=256;B=h,C=z[Lc(g+14|0,g+12|0)>>1],w[B+30>>1]=C;f=y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24);B:{if(f>>>0<3){break B}x[h>>2]=f;x[h+4>>2]=y[i+26|0]|y[i+27|0]<<8|(y[i+28|0]<<16|y[i+29|0]<<24);x[g+8>>2]=y[i+30|0]|y[i+31|0]<<8|(y[i+32|0]<<16|y[i+33|0]<<24);x[g+4>>2]=1;B=h,C=x[$c(g+8|0,g+4|0)>>2]-1|0,x[B+8>>2]=C;uc(h+8|0,f);l=x[h+8>>2];f=x[h+4>>2];C:{if(l>>>0<=f+4>>>0){x[h+4>>2]=0;x[h+8>>2]=0;l=0;f=0;break C}if(l>>>0<3){break C}w[h+34>>1]=z[h+34>>1]|2}v[h+37|0]=y[i+34|0];B=h,C=hw(0,v[i+34|0]<<4),x[B+24>>2]=C;if(!(v[i+36|0]&1)){break B}x[h+8>>2]=l>>>1;x[h+4>>2]=f>>>1;w[h+34>>1]=z[h+34>>1]|1;x[h>>2]=x[h>>2]>>>1}fb=g+16|0;f=e+24|0;Wk(f,2,i);g=e+44|0;Ac(g,f);xc(((j<<5)+a|0)+946304|0,g);d=d+1|0;tb(g);continue}}}d=N()|0;Eb(e+44|0);break c}d=N()|0;ub(m)}Q(d|0);p()}d=1}fb=e+272|0;return d|0}function Doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-352|0;fb=d;a:{b:{c:{if(!bd(b,60)){break c}if(!Bp(b,d+332|0)){break c}e=15;if(gv(d+332|0,15)){break b}}if(!bd(b,124)){break a}if(!Bp(b,d+332|0)){break a}e=31;if(!gv(d+332|0,31)){break a}}Ad(a,536870912);w[a+480190>>1]=e;vc(b);d:{while(1){if(z[a+480190>>1]>f>>>0){g=gp(b);x[(d+208|0)+(f<<2)>>2]=g;f=f+1|0;if(g>>>0<=131072){continue}break d}break}Ub(b,20);e=0;w[a+480192>>1]=0;w[a+480188>>1]=4;f=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;o=a,q=Xe(1776930/+(Cb(f)>>>0)*1e4),x[o+480204>>2]=q;x[a+480228>>2]=64;Uh(a,1);m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){vC(b,d+52|0);f=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=(D(l,104)+a|0)+484380|0;kd(i,1);x[i>>2]=f;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;o=i,q=y[Sb(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=q;f:{if(!f){break f}g=Cb(y[d+80|0]|y[d+81|0]<<8);k=Cb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(f>>>0<=k>>>0){k=f-1|0;x[i+4>>2]=k}if(f>>>0<g>>>0){x[i+8>>2]=f;g=f}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;f=0;while(1)if((f|0)==22){if(e>>>0>=128){break d}g=d+184|0;Wk(g,3,d+52|0);f=d+196|0;Ac(f,g);xc(((l<<5)+a|0)+946304|0,f);m=m+1|0;tb(f);continue e}else{g=(d+52|0)+f|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;e=e+1|0}f=f+1|0;continue}}break}m=1;g:{h:{i:{e=a+946336|0;f=Cc(d+52|0,14036);if(!AW(e,f)){x[31721]=0;g=P(37,d+196|0,14047)|0;i=x[31721];x[31721]=0;if((i|0)==1){break i}m=AW(e,g);tb(g)}tb(f);f=0;g=d+52|0;e=xC(b,g);if(!e){tC(g)}if(!e){break a}g=y[d+52|0];if(!CW(g)){break a}if(!c){break g}w[d+50>>1]=0;while(1)if((f|0)==(g|0)){f=a+484360|0;e=a+484376|0;h=Wb(x[f>>2],y[e|0]);i=y[d+53|0];Ze(h,g>>>0>i>>>0?i:0);tw(Wb(x[f>>2],y[e|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Ub(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){Of(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){j:{k:{l:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break l}f=1;while(1){e=z[a+480190>>1];c=f&65535;if(e>>>0<c>>>0){break k}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){ag(Wc(d+184|0,8,1,0,0),c,b)}f=f+1|0;continue}}m:{if(n){k=0;if(Kg(l,i&65535,64)){break m}}Ub(b,1024);break j}n:while(1){if((k|0)==64){break j}f=Vb(x[l>>2],i);_e(d+184|0,x[f>>2],x[x[f+48>>2]+12>>2],k);f=0;while(1)if((f|0)==4){k=k+1|0;continue n}else{g=Vc(x[d+184>>2],f);e=d+12|0;jm(e,b);o:{p:{q:{r:{if(y[vb(e,0)|0]!=255){break r}v[(d+44|0)+f|0]=0;v[(d+36|0)+f|0]=0;e=vb(d+12|0,1);h=y[e|0];if((h|0)==252&m){v[e|0]=254;break p}switch(h-252|0){case 1:break o;case 2:break p;case 0:break q;default:break r}}e=x[d+12>>2];x[d+28>>2]=e;x[d+8>>2]=e;e=d+33|0;Zo(e,d+8|0,g);h=Hc(e);e=y[g|0];s:{if(!e){break s}v[(d+36|0)+f|0]=0;v[(d+44|0)+f|0]=e;if(e>>>0>48){break s}v[d+27|0]=8;o=d,q=y[af(d+35|0,d+27|0)|0],v[o+35|0]=q}j=y[d+33|0];e=y[h|0];t:{if(j|e){v[g+5|0]=e;u:{v:{w:{switch(j-1|0){case 0:v[g+3|0]=1;break o;case 1:if(e>>>0>=16){v[g+3|0]=3;v[g+5|0]=(e&240)>>>4;break o}if(!e){break v}v[g+5|0]=e;v[g+3|0]=2;break o;case 2:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=0;v[g+3|0]=19;break o;case 3:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=1;v[g+3|0]=19;break o;case 4:h=y[g+1|0];if(!h){break v}v[d+27|0]=63;v[d+26|0]=e+(z[(D(h,104)+a|0)+484410>>1]>>>2|0);e=y[Sb(d+27|0,d+26|0)|0];v[g+5|0]=e;v[g+3|0]=13;if(!y[(d+36|0)+f|0]){break o}h=g+3|0;v[g+4|0]=e;v[g+2|0]=1;break u;case 5:h=g+3|0;j=y[g+1|0];if(!j){break u}v[g+3|0]=13;j=z[(D(j,104)+a|0)+484410>>1]>>>2|0;e=e>>>0<=j>>>0?j-e|0:0;v[g+5|0]=e;if(!y[(d+36|0)+f|0]){break o}v[g+4|0]=e;v[g+2|0]=1;break u;case 6:h=e&15;v[(d+36|0)+f|0]=h;j=y[(d+44|0)+f|0];e=j-((e&240)>>>4|0)|0;v[(d+40|0)+f|0]=e;o=g,q=zW(h,e&255,j),v[o+5|0]=q;v[g+3|0]=3;break o;case 7:h=e&15;v[(d+36|0)+f|0]=h;j=(e&240)>>>4|0;e=y[(d+44|0)+f|0];j=j+e|0;v[(d+40|0)+f|0]=j;o=g,q=zW(h,e,j&255),v[o+5|0]=q;v[g+3|0]=2;break o;case 8:break w;default:break v}}v[d+27|0]=8;o=d,q=y[af(d+35|0,d+27|0)|0],v[o+35|0]=q}h=g+3|0}v[h|0]=0;break t}if(y[g+3|0]){break o}}h=y[(d+36|0)+f|0];if(!h){break o}j=(d+40|0)+f|0;e=y[j|0];if(e){v[(d+44|0)+f|0]=e;v[g+5|0]=h;v[g|0]=e;v[j|0]=0}v[g+3|0]=4;break o}v[g+3|0]=14;v[d+35|0]=9;break o}v[g+3|0]=13}f=f+1|0;continue}}}e=z[a+480190>>1]}x:{y:{if((e&65535)==15){b=d+12|0;dg(b,4418);x[31721]=0;S(212,d+184|0,b|0,d+35|0);b=x[31721];x[31721]=0;if((b|0)!=1){break y}e=N()|0;Eb(d+12|0);break h}x[31721]=0;P(1,d+184|0,12390)|0;b=x[31721];x[31721]=0;if((b|0)==1){break x}}b=d+184|0;yb(a+1298344|0,b);tb(b);if((e&65535)==15){Eb(d+12|0)}_h(a+1298356|0,z[a+480190>>1]==15?5282:15105);o=a+1298404|0,q=x[Ec(d+184|0,28)>>2],x[o>>2]=q;break g}e=N()|0;break h}i=i+1|0;continue}}else{w[d+184>>1]=y[(d+f|0)+54|0]+1;o=d,q=z[oe(d+50|0,d+184|0)>>1],w[o+50>>1]=q;f=f+1|0;continue}}e=N()|0;tb(f)}Q(e|0);p()}f=1;break a}f=0}fb=d+352|0;return f|0}function NL(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=fb-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+87696>>2]);h=E(E(m-z)*B[g+87700>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+87704>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=yc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;At(y,d,o+244|0);f=d<<6;At(f+y|0,d,o+500|0);At(x,d,o+240|0);At(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=87792;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=xj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=xj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=xj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=xj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=xj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=xj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=xj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=xj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}yc(a,C+(b<<2)|0,3840)}}function Jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=fb-272|0;fb=f;vc(b);e=fb-16|0;fb=e;i=f+66|0;YZ(e+8|0,i);g=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){XZ(i)}a:{if(!e){break a}if(!_Z(f+66|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(ZZ(f+66|0),hb))){break a}b:{if(!c){break b}Ad(a,16777216);bg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;dr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);s=a+480188|0,t=Cb(y[f+266|0]|y[f+267|0]<<8),w[s>>1]=t;Uh(a,1);e=rc(d,8541);yb(a+1298368|0,e);tb(e);e=f+24|0;dg(e,3924);x[31721]=0;S(374,d|0,e|0,y[f+69|0]);d=x[31721];x[31721]=0;c:{if((d|0)!=1){d=f+44|0;yb(a+1298344|0,d);tb(d);e=f+24|0;Eb(e);g=rc(d,10789);yb(a+1298356|0,g);tb(g);s=a+1298404|0,t=x[Ec(d,26)>>2],x[s>>2]=t;Te(e,3,f+70|0);Ac(d,e);yb(a+1298308|0,d);tb(d);g=160;while(1){d:{d=g;if(!d){d=0;break d}g=d-1|0;if(y[(f+g|0)+102|0]==32){continue}}break}VZ(a+1298332|0,f+102|0,d,4);o=a+480190|0;d=Cb(y[f+262|0]|y[f+263|0]<<8);w[o>>1]=d;n=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=n&65535;if(e>>>0<d>>>0){g=a+484360|0;e=a+484376|0;Ze(Wb(x[g>>2],y[e|0]),Cb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;ce(d,b,512);n=hc(f+44|0,d);ub(d);d=y[e|0];g=x[g>>2];i=y[f+268|0]|y[f+269|0]<<8;x[31721]=0;S(279,Wb(g,d)|0,n|0,Cb(i)|0);d=x[31721];x[31721]=0;if((d|0)!=1){break i}d=N()|0;break h}i=D(d,104)+a|0;k=i+484380|0;kd(k,1);_o(k);f$(b,((d<<5)+a|0)+946304|0,y[f+69|0]==1?32:28);h=1;d=y[f+69|0];if(d>>>0>=3){Ub(b,14);d=rD(b);if((d|0)>=0){e=i+484414|0;w[e>>1]=z[e>>1]|32;s=i+484408|0,t=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),w[s>>1]=t}d=y[f+69|0]}if((d&255)>>>0>=2){h=Rk(b);s=i+484404|0,t=Rk(b),x[s>>2]=t}d=f+44|0;g=fb-16|0;fb=g;j:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[g>>2]=0;e=d;j=3;while(1){if(j){l=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[e|0]=l;v[e+1|0]=l>>>8;v[e+2|0]=l>>>16;v[e+3|0]=l>>>24;j=j-1|0;e=e+4|0;continue}break}break j}nr(g+8|0,d);pd(g,b,x[g+8>>2],x[g+12>>2])}fb=g+16|0;e=dc(d);d=Ab(d);l=_b(x[f+44>>2]);x[k>>2]=l;m=i+484384|0;j=_b(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));x[m>>2]=j;q=i+484388|0;r=_b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+j|0;x[q>>2]=r;e=i+484414|0;if(j){g=z[e>>1];break f}g=z[e>>1];if(_b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0>=3){break f}d=g&-3;break e}d=wb(x[Wb(x[a+484360>>2],y[e|0])>>2]);g=wb(x[Wb(x[a+484360>>2],y[e|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){i=x[Od(e+12|0)>>2];if(!Ib(i,g)){break k}d=al(z[d>>1],z[i>>1])?i:d;continue}}fb=e+16|0;d=z[d>>1];x[31721]=0;l=a+484344|0;q=d+1&65535;O(226,l|0,q|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];o=d>>>0<4?4:5;r=c&1;j=a+480188|0;e=0;while(1){if((e|0)==(q|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>z[c>>1]){break g}e=D(e,104)+a|0;g=Wc(f+8|0,w[e+484414>>1]&1?16:8,1,1,0);x[31721]=0;U(218,g|0,e+484380|0,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){d=d+1|0;continue}break}d=N()|0;break h}l:{if(!r){break l}d=y[f+264|0]|y[f+265|0]<<8;g=x[b+8>>2];i=z[j>>1];h=x[b>>2];x[31721]=0;d=U(153,h|0,g|0,D(i,D(Cb(d),o))|0)|0;g=x[31721];x[31721]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31721]=0;d=U(199,l|0,e&65535,Cb(d)|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break n}if(!d){break l}d=z[j>>1];v[f|0]=0;g=be(f+8|0,0,f);x[31721]=0;i=U(375,f+24|0,d|0,g|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}g=0;o:while(1){if(Cb(y[f+264|0]|y[f+265|0]<<8)>>>0<=g>>>0){ld(i);break l}d=Vb(x[l>>2],e);_e(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=0;while(1){if(z[j>>1]<=d>>>0){g=g+1|0;continue o}k=Vc(x[f+8>>2],d);v[f+4|0]=0;x[31721]=0;x[f>>2]=0;S(376,b|0,f|0,o|0);h=x[31721];x[31721]=0;p:{if((h|0)==1){break p}h=y[f|0];if((h-24&255)>>>0<=59){h=h+13|0;v[k|0]=h;s=Zb(x[i>>2],d),t=h,v[s|0]=t}m=y[f+1|0];q:{if(!m){h=Zb(x[i>>2],d);break q}v[k+1|0]=m;h=Zb(x[i>>2],d);v[h+1|0]=m}m=y[h+1|0];h=y[h|0];x[31721]=0;ya(377,a|0,k|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,m|0,f+20|0,f+16|0);h=x[31721];x[31721]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[k+2|0]=1;v[k+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;ld(i);break h}d=N()|0;break h}d=N()|0;break h}e=e+1|0;continue}}d=N()|0}ub(n);break c}ub(n);break b}d=g|2}w[e>>1]=d;if((h|0)==2){w[e>>1]=d|1;x[k>>2]=l>>>1;x[m>>2]=j>>>1;x[q>>2]=r>>>1}s=i+484410|0,t=Rk(b),w[s>>1]=t;d=rD(b);if(d){am(k,+(d|0)/96)}v[i+484417|0]=d<<4;n=n+1|0;d=z[o>>1];continue}}d=N()|0;Eb(f+24|0)}Q(d|0);p()}d=1}fb=f+272|0;return d|0}function $na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-112|0;fb=d;vc(c);a:{b:{c:{d:{if(!$o(c,d+100|0)|(y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24))!=1297239878){break d}e=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);if(!((e|0)==1482052408|(e|0)==1448293937)&(y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break d}e=fb-32|0;fb=e;j=Nb(d+88|0);e:{f:{g:{h:{i:{while(1){i=x[c+8>>2];g=x[c>>2];x[31721]=0;i=U(153,g|0,i|0,8)|0;g=x[31721];x[31721]=0;if((g|0)==1){break g}if(!i){break h}x[31721]=0;O(835,e+4|0,c|0);i=x[31721];x[31721]=0;if((i|0)!=1){x[31721]=0;O(836,j|0,e+4|0);i=x[31721];x[31721]=0;if((i|0)==1){break i}Fd(e+4|0);continue}break}a=N()|0;break f}a=N()|0;Fd(e+4|0);break f}fb=e+32|0;break e}a=N()|0}fe(j);Q(a|0);p()}x[31721]=0;i=R(171,d+68|0)|0;c=x[31721];x[31721]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((c|0)!=1){j=Wc(d- -64|0,8,1,1,0);if((y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break q}x[31721]=0;S(745,d+44|0,d+88|0,1296581714);c=x[31721];x[31721]=0;if((c|0)==1){break n}x[31721]=0;S(745,d+24|0,d+88|0,1296318804);c=x[31721];x[31721]=0;if((c|0)==1){break c}c=d+24|0;e=gd(i,c);ub(c);x[31721]=0;c=R(746,d+44|0)|0;h=x[31721];x[31721]=0;f=1;if((h|0)==1){break c}if(!c){break r}c=x[e>>2];x[31721]=0;c=R(175,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}if(!c){break r}x[31721]=0;k=R(284,d+44|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;e=R(276,d+44|0)|0;c=x[31721];x[31721]=0;t:{if((c|0)==1){break t}x[31721]=0;P(186,d+44|0,2)|0;c=x[31721];x[31721]=0;if((c|0)==1){break t}x[31721]=0;l=R(284,d+44|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break s}}break c}f=N()|0;break a}x[31721]=0;O(656,d+24|0,d+44|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}c=PZ(d+24|0);h=Cb(z[d+24>>1]);if(!h){break r}l=(l>>>0)/(h>>>0)|0;g=d+24|0;h=dc(g);g=Ye(g);h=Cb(y[h|0]|y[h+1|0]<<8);if((h|0)!=(Cb(y[g|0]|y[g+1|0]<<8)+1|0)){break r}if((h|0)==2){np(j,2)}u:{if((e|0)!=16){if((e|0)!=8){break r}v:{switch(Cb(y[c|0]|y[c+1|0]<<8)|0){case 0:tg(j,1);break u;case 2:tg(j,17);break u;case 3:break v;default:break r}}tg(j,16);break u}if(Cb(y[c|0]|y[c+1|0]<<8)){break r}ed(j,16)}f=0}ub(d+44|0);h=0;if(!f){break p}f=0;break j}x[31721]=0;S(745,d+44|0,d+88|0,1447576658);c=x[31721];x[31721]=0;w:{x:{y:{if((c|0)!=1){x[31721]=0;S(745,d+24|0,d+88|0,1128808782);c=x[31721];x[31721]=0;if((c|0)==1){break y}x[31721]=0;S(745,d+4|0,d+88|0,1112491097);c=x[31721];x[31721]=0;if((c|0)==1){break x}c=d+4|0;g=gd(i,c);ub(c);c=x[g>>2];x[31721]=0;e=R(175,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}c=0;z:{if(!e){break z}x[31721]=0;e=R(175,x[d+44>>2])|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}c=0;if(!e){break z}x[31721]=0;e=P(747,d+44|0,d+4|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}c=0;if(!e){break z}c=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);x[31721]=0;l=R(284,d+24|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break x}m=(c|0)!=1482052408;if(m){ed(j,16)}if((l|0)==6){np(j,3)}h=_b(x[d+4>>2]);e=x[d+8>>2];c=x[d+12>>2];k=_b(c);A:{B:{if(k>>>0<33){break B}n=_b(e);if(n>>>0<=k>>>0){break B}if(!((n>>>0)%(k>>>0)|0)){break A}}c=e}e=x[g>>2];x[31721]=0;g=x[d+20>>2];n=z[d+16>>1];k=R(157,e|0)|0;e=x[31721];x[31721]=0;o=1;if((e|0)==1){break x}e=m+((l|0)==6)|0;m=h>>>e|0;k=k>>>e|0;h=_b(g);l=Cb(n);c=_b(c)>>>e|0}ub(d+24|0);ub(d+44|0);if(o){break o}break j}f=N()|0;break b}f=N()|0;break w}f=N()|0;ub(d+24|0)}ub(d+44|0);break b}c=0}Eu(a,b);x[31721]=0;f=D(b,104)+a|0;e=f+484380|0;O(282,e|0,0);g=x[31721];x[31721]=0;if((g|0)==1){break m}x[e>>2]=k;c=c+m|0;x[f+484388>>2]=c;x[f+484384>>2]=m;if(!(c>>>0<=m+4>>>0|c>>>0>k>>>0)){c=(D(b,104)+a|0)+484414|0;w[c>>1]=z[c>>1]|2}c=D(b,104)+a|0;x[c+484404>>2]=l>>>0<2?22050:l;g=c+484410|0;c=h+128|0;f=c>>>8|0;w[g>>1]=(c&16776960)>>>0>65536?256:f&65535?f:256;OB(e,x[a+480180>>2]);x[31721]=0;S(745,d+44|0,d+88|0,1312902469);c=x[31721];x[31721]=0;if((c|0)==1){break l}x[31721]=0;c=R(175,x[d+44>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}C:{D:{if(c){x[31721]=0;c=R(157,x[d+44>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}x[31721]=0;S(334,d+44|0,((b<<5)+a|0)+946304|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break D}break k}x[31721]=0;c=P(37,d+24|0,22250)|0;f=x[31721];x[31721]=0;if((f|0)==1){break C}xc(((b<<5)+a|0)+946304|0,c);tb(c)}x[31721]=0;U(218,j|0,e|0,i|0)|0;b=x[31721];x[31721]=0;f=1;if((b|0)==1){break k}Mj(e,a);ub(d+44|0);break j}break k}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;ub(d+44|0);break b}ub(i);fe(d+88|0)}fb=d+112|0;return f|0}f=N()|0;ub(d+44|0)}ub(i)}fe(d+88|0);Q(f|0);p()}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;i=fb-160|0;fb=i;vc(b);a:{if(!wD(b,i+112|0)){break a}if(!qV(i+112|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(pV(y[i+159|0]),hb))){break a}Ad(a,128);g=i+100|0;Te(g,2,i+127|0);d=i+32|0;Ac(d,g);yb(a+1298308|0,d);tb(d);e=rc(d,8453);yb(a+1298344|0,e);tb(e);e=rc(d,6056);yb(a+1298356|0,e);tb(e);g=rc(g,18158);x[31721]=0;S(760,d|0,g|0,x[(y[i+126|0]<<2)+25212>>2]);d=x[31721];x[31721]=0;c:{if((d|0)!=1){d=i+32|0;yb(a+1298368|0,d);tb(d);tb(g);A=a+1298404|0,B=x[Ec(d,4)>>2],x[A>>2]=B;x[a+480208>>2]=12;RD(a+1298332|0,b,y[i+159|0]<<5,32,0);m=a+480190|0;e=Xd(b);w[m>>1]=e;g=1;while(1){j=g&65535;if(j>>>0>(e&65535)>>>0){dk(Wb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);g=0;d=Xd(b);if(d>>>0>=127){break a}f=a+480188|0;w[f>>1]=d+1;d=Xd(b);while(1)if(z[f>>1]<=g>>>0){o=a+484344|0;r=d+1|0;Of(o,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){s=a+480188|0;e:while(1){u=t&65535;g=z[s>>1];if(u>>>0>=g>>>0){d=No(i);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[31721]=0;O(762,d|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){a=N()|0;yf(d);Q(a|0);p()}x[31721]=0;O(761,o|0,d|0);e=x[31721];x[31721]=0;g=1;if((e|0)==1){break d}yf(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=g&65535;if(d>>>0>z[c>>1]){break b}d=D(d,104)+a|0;ag(Wc(i+32|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);g=g+1|0;continue}}k=0;f=Ig(i+32|0);f:while(1){g:{if((k|0)!=(r|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break g}}t=t+1|0;continue e}e=0;d=Vb(x[o>>2],k);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,u);while(1){h:{i:{if(e>>>0>63){break i}m=y[i+126|0];h=fb-16|0;fb=h;q=1;d=Xd(b);if((d|0)==252){q=Xd(b);d=Xd(b)}v[f|0]=(d-1&255)>>>0<60?d+36|0:0;d=h+12|0;jm(d,b);l=Hc(d);j=Ye(d);d=cj(d);v[f+1|0]=y[h+12|0];n=h+10|0;oV(n,y[l|0]&15,y[j|0],m);j=Hc(n);n=h+8|0;oV(n,y[l|0]>>>4|0,y[d|0],m);m=Hc(n);d=y[h+10|0];n=(d|0)!=10;l=y[h+8|0];j:{if(!(n|(l|0)!=10)){j=y[j|0];d=y[m|0];v[f+3|0]=10;j=j|d<<8;v[f+5|0]=j>>>6;if(j>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=d>>>6;break j}k:{l:{m:{n:{o:{if(!n){l=y[j|0];n=l<<2;A=j,B=ui(n),v[A|0]=B;if(l>>>0<64){break o}d=y[h+8|0];if(Th(d)>>>0>=Th(10)>>>0){break n}v[f+5|0]=n;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=l>>>6;break j}if((l|0)==10){d=y[m|0];l=d<<2;A=m,B=ui(l),v[A|0]=B;if(d>>>0<64){break o}if(Th(y[h+10|0])>>>0>=Th(10)>>>0){break o}v[f+5|0]=l;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=d>>>6;break j}if((d|0)!=(l|0)){break o}v[h+8|0]=0;break m}d=y[h+8|0]}if((d|0)==13){break l}if(d){break k}d=y[h+10|0]}if((d|0)==13){break k}}pg(h+10|0,h+8|0);pg(j,m)}fw(h+8|0,m,h+10|0,j);un(h+6|0,f,y[h+10|0],y[j|0],y[h+8|0],y[m|0])}fb=h+16|0;h=e+q|0;e=h>>>0>64?64-e|0:q;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[g+4|0]=d;v[g+5|0]=d>>>8;e=e-1|0;g=D(z[s>>1],6)+g|0;continue}}k=k+1|0;continue f}e=h>>>0>=64?64:h;continue}}}}e=e+1|0;g=0;if(Kg(o,f,64)){continue}break a}break}e=N()|0;yf(d);break c}else{e=(g<<5)+a|0;Ue(e+480280|0);h=e+480284|0;p:{if(y[i+126|0]>=51){e=(Xd(b)<<4|8)&248;break p}e=g&1?192:64}w[h>>1]=e;g=g+1|0;continue}}else{q:{if(y[i+126|0]>=52){d=i+32|0;if(!M_(b,d)){UD(d)}break q}f=i+32|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;h=x[b>>2];k=x[b+8>>2];e=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(h,k,e)){e=hf(b)}h=d+8|0;Wv(h,f);k=fc(d+16|0,x[d+8>>2],e);o=x[k>>2];jc(d,x[b>>2],x[b+8>>2],o,x[k+4>>2]);Wv(h,f);Tb(x[d+8>>2]+e|0,0,66-e|0);Ub(b,x[d+28>>2]);fb=d+32|0;d=y[i+94|0]|y[i+95|0]<<8;v[i+96|0]=d;v[i+97|0]=d>>>8;v[i+94|0]=171;v[i+95|0]=32}h=fb-32|0;fb=h;f=(D(j,104)+a|0)+484380|0;kd(f,0);_o(f);k=h+8|0;e=i+32|0;Mk(k,2,e+32|0);d=h+20|0;Ac(d,k);ye(f+43|0,d);tb(d);d=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);k=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);r:{if(d>>>0<=k>>>0){break r}x[f>>2]=d-k;x[f+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[h+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);A=f,B=x[Gb(h+20|0,f)>>2],x[A+16>>2]=B;w[f+30>>1]=y[e+60|0];x[f+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){am(f,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[f+34>>1]=z[f+34>>1]|8;d=y[e+61|0]}if(d&16){w[f+34>>1]=z[f+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break r}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}fb=h+32|0;f=i+20|0;Te(f,2,e);d=i+100|0;Ac(d,f);xc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[m>>1];continue}}}e=N()|0;tb(g)}Q(e|0);p()}g=1}fb=i+160|0;return g|0}function Sd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;A=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;Wf(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;Wf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=zua(v,e,c,0);e=hb;z=e;M=f;q=b;b=zua(f,0,b,0);i=b+s|0;f=hb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=zua(q,l,v,l);p=j+b|0;f=i;e=f+hb|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=zua(v,l,d,0);P=hb;b=zua(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=zua(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=zua(v,l,F,n);Q=hb;d=zua(O,m,M,l);H=d+A|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=zua(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=zua(B,m,L,l);z=b+J|0;K=f;f=f+hb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;q=b+g|0;e=c+z|0;v=b>>>0>q>>>0?e+1|0:e;f=v;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=zua(I,m,L,l);h=hb;e=zua(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=zua(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=zua(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=zua(B,m,F,m);l=hb;d=zua(I,m,O,m);h=d+e|0;f=hb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;Wf(k+48|0,p,r,b,c,f);Wf(k+32|0,d,e,h,i,f);Wm(k+16|0,p,r,b,c,g);Wm(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function xS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=fb-16|0;fb=h;a:{if(!Sc(d&255)){break a}m=a+1074376|0;j=(m+D(b,872)|0)+616|0;b:{g=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!g|e)){break b}if(Gj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!yd(c)){break c}Jj(c,b,0);break a}c=PA(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;tq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;Oo(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=g>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[Zb(g+236|0,k)>>1];f=a+1074312|0;Kb(h+8|0,f,104);e:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){Kb(h,f,34);if(Hb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[vb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Kb(h+8|0,f,43);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!Nj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!Gj(x[j+656>>2])){break f}c=0;if(!Sc(y[(D(b,872)+a|0)+1075789|0])){break f}d=mm(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=x[sd(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{f=(b|0)==(c|0);h:{if(!f&z[q>>1]>c>>>0){break h}e=D(c,872)+a|0;if(!f&z[e+1075778>>1]!=(p|0)){break h}n=e+1075648|0;f=x[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=(f|0)==(g|0)&y[e+1075789|0]==(d|0);if(!g){break n}if(i){break k}break h;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break h}if((f|0)==(g|0)){break i}Kb(h+8|0,k,104);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=y[g+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!y[g+34|0]){break i}}if(!y[e+1075789|0]|y[f+18|0]>2){break i}f=e+1075793|0;i=y[f|0];if(!i){break i}Vm(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;p:{q:{switch(y[x[n>>2]+18|0]){case 0:zo(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!yd(f)){break p}Jj(f,c&65535,1);break p;case 1:zo(a,f);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!yd(f)){break p}zk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break p}if(!yd(x[a+1298300>>2])){break p}Kb(h+8|0,k,105);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break p}zk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}d=y[(D(b,872)+a|0)+1075793|0];c=0;if(!d){break f}c=ib[x[x[e>>2]+104>>2]](e,d,b)|0}if(!(Pi(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!e|c^1){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Vm(a,b,255,0);w[(D(b,872)+a|0)+1075792>>1]=0}c=PA(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!yd(e)){break s}Jj(e,c,1)}l=tq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;t:{u:{switch(y[(i+D(b,872)|0)+798|0]){case 2:zo(a,l);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!yd(e)){break t}zk(e,b);Kb(h+8|0,k,105);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break t}CB(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!yd(e)){break t}Jj(e,b,1);break t;case 3:x[d>>2]=g|4096;if(!(e&512)){break t}if(!yd(x[a+1298300>>2])){break t}Kb(h+8|0,k,105);e=x[a+1298300>>2];if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){CB(e,b,c);break t}zk(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!yd(e)){break t}CB(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}fb=h+16|0}function lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-128|0;fb=g;vc(b);a:{b:{c:{d:{e:{if(!hX(b,14147)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[31721]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(249,a|0,32768);d=x[31721];x[31721]=0;if((d|0)==1){break b}x[31721]=0;d=P(1,g+84|0,8169)|0;i=x[31721];x[31721]=0;if((i|0)==1){break c}yb(a+1298344|0,d);tb(d);x[31721]=0;d=P(1,g+72|0,6060)|0;i=x[31721];x[31721]=0;if((i|0)==1){break d}yb(a+1298356|0,d);tb(d);o=a+1298404|0,q=x[Ec(g+44|0,28)>>2],x[o>>2]=q;m=a+484376|0;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[31721]=0;d=U(153,f|0,d|0,8)|0;f=x[31721];x[31721]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31721]=0;d=P(655,b|0,g- -64|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[31721]=0;S(188,g+24|0,b|0,_b(d)|0);d=x[31721];x[31721]=0;if((d|0)==1){break l}d=g+24|0;f=hc(g+44|0,d);ub(d);d=x[f>>2];x[31721]=0;d=R(175,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=_b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[31721]=0;d=R(157,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[31721]=0;O(656,g+24|0,f|0);e=x[31721];x[31721]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{h=Zb(g+24|0,d);e=z[a+480188>>1];v:{if(!Cb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;o=vb(h,e),q=1,v[o|0]=q;o=vb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;Ue(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Ue(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31721]=0;O(657,f|0,a|0);d=x[31721];x[31721]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[31721]=0;d=R(157,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31721]=0;d=R(276,f|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}o=a,q=Hd(d,1,255),x[o+480196>>2]=q;break f}d=x[f>>2];x[31721]=0;d=R(157,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31721]=0;n=R(276,f|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break f}break j}d=y[m|0];e=x[a+484360>>2];h=x[f>>2];x[31721]=0;h=R(157,h|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break j}x[31721]=0;aa(351,Wb(e,d)|0,f|0,h|0,255,254);d=x[31721];x[31721]=0;if((d|0)==1){break j}break f}d=k;if(Mf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Mf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[31721]=0;e=R(157,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[31721]=0;O(658,d|0,f|0);d=x[31721];x[31721]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=y[a+484376|0];d=x[a+484360>>2];x[31721]=0;O(333,Wb(d,b)|0,n&65535);b=x[31721];x[31721]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[31721]=0;O(226,a+484344|0,Mf(i,b)&65535);b=x[31721];x[31721]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Mf(e,x[k+4>>2])>>>0<=b>>>0){break w}x[31721]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(659,$g(e,b)|0,b|0,a|0,g+8|0);b=x[31721];x[31721]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Mf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;op(c);x:{if(x[c>>2]){e=x[$g(x[j>>2],b)>>2];x[31721]=0;e=R(157,e|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break h}uc(c,e);e=Wc(g+44|0,8,1,1,0);h=x[j>>2];x[31721]=0;U(218,e|0,c|0,$g(h,b)|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Pc(j);Pc(k);break e}ub(f);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Pc(j);Pc(k);Q(a|0);p()}function t0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;vc(b);a:{if(!Dr(b,11774)){break a}if(!jw(b,e+69|0)){break a}if(!uE(y[e+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(tE(e+69|0),hb))){break a}if(!Ub(b,y[e+78|0]|y[e+79|0]<<8)){break a}b:{if(!c){break b}Ad(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[e+71|0]&31)+1;f=a+480190|0;w[f>>1]=y[e+72|0];Uh(a,1);d=e+20|0;i=rc(d,8476);yb(a+1298344|0,i);tb(i);i=rc(d,7105);yb(a+1298356|0,i);tb(i);i=fb-16|0;fb=i;g=rc(i+4|0,4247);Zc(e,g);tb(g);fb=i+16|0;x[31721]=0;V(232,d|0,e|0,y[e+70|0],e+69|0);d=x[31721];x[31721]=0;c:{if((d|0)!=1){d=e+20|0;yb(a+1298368|0,d);tb(d);Eb(e);l=a+1298404|0,m=x[Ec(d,4)>>2],x[l>>2]=m;d=y[e+72|0];i=e+56|0;x[i>>2]=0;x[i+4>>2]=0;Ec(i+8|0,0);if(d){Kr(i,d);tF(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>z[f>>1]){x[31721]=0;P(233,b|0,a+1298308|0)|0;g=x[31721];x[31721]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){f=d&65535;if(f>>>0>z[g>>1]){d=0;g=a+480188|0;f:{while(1){if(z[g>>1]<=d>>>0){d=0;x[31721]=0;g=a+484344|0;O(226,g|0,y[e+73|0]|y[e+74|0]<<8);f=x[31721];x[31721]=0;if((f|0)==1){break e}break f}f=(d<<5)+a|0;Ue(f+480280|0);x[31721]=0;O(234,b|0,f+480289|0);f=x[31721];x[31721]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}g:{h:{i:{j:{while(1){if((y[e+73|0]|y[e+74|0]<<8)>>>0<=d>>>0){x[31721]=0;f=R(192,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break h}if(!f){break i}d=x[b+8>>2];g=x[b>>2];x[31721]=0;d=U(153,g|0,d|0,f|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break h}if(d){break j}break i}x[31721]=0;f=P(235,b|0,e+20|0)|0;h=x[31721];x[31721]=0;k:{if((h|0)==1){break k}x[31721]=0;h=U(199,g|0,d&65535,64)|0;j=x[31721];x[31721]=0;if((j|0)==1){break k}if((f&h)==1){f=x[g>>2];x[31721]=0;O(236,Vb(f,d)|0,e+20|0);f=x[31721];x[31721]=0;if((f|0)==1){break k}}d=d+1|0;continue}break}b=N()|0;break d}g=Nb(e+20|0);x[31721]=0;S(237,b|0,g|0,f|0);d=x[31721];x[31721]=0;l:{if((d|0)!=1){d=Fb(e);x[31721]=0;O(117,d|0,f|0);f=x[31721];x[31721]=0;m:{if((f|0)==1){break m}l=e,m=wb(x[g>>2]),x[l+40>>2]=m;h=wb(x[g+4>>2]);while(1){n:{f=x[e+40>>2];if(!Ib(f,h)){x[31721]=0;S(238,e+40|0,20,d|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}h=e+40|0;f=yb(d,h);tb(h);h=Jb(f);j=y[f+11|0];k=x[f+4>>2];x[31721]=0;aa(239,a+1298332|0,h|0,Xc(k,j)|0,76,0);h=x[31721];x[31721]=0;if((h|0)==1){break m}tb(f);cc(g);break i}o:{f=v[f|0];if((f|0)<0){j=x[zb(e+52|0,zf(d))>>2];x[31721]=0;V(240,d|0,j|0,f&127,32);f=x[31721];x[31721]=0;if((f|0)!=1){break o}break m}x[31721]=0;O(118,d|0,f|0);f=x[31721];x[31721]=0;if((f|0)!=1){break o}break m}je(e+40|0);continue}break}}b=N()|0;tb(d);break l}b=N()|0}cc(g);break d}d=y[a+484376|0];g=x[a+484360>>2];x[31721]=0;S(241,Wb(g,d)|0,b|0,y[e+75|0]|y[e+76|0]<<8);d=x[31721];x[31721]=0;if((d|0)==1){break h}f=c&1;h=a+484348|0;d=0;while(1){p:{q:{if((y[e+73|0]|y[e+74|0]<<8)>>>0>d>>>0){g=x[b+8>>2];j=x[b>>2];x[31721]=0;g=U(153,j|0,g|0,4)|0;j=x[31721];x[31721]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>z[g>>1]){break g}f=D(c,104)+a|0;h=z[f+484414>>1];Kb(e+20|0,x[i>>2],c-1|0);c=Wc(e,h&1?16:8,1,0,Hb(x[x[e+20>>2]>>2],x[e+24>>2])?6:0);x[31721]=0;U(218,c|0,f+484380|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}x[31721]=0;g=R(154,b|0)|0;j=x[31721];x[31721]=0;r:{s:{if((j|0)!=1){x[31721]=0;S(188,e|0,b|0,g|0);g=x[31721];x[31721]=0;if((g|0)==1){break s}g=hc(e+20|0,e);ub(e);if(!f){break r}j=x[a+484344>>2];if(!Ge(j,x[h>>2],d&65535)){break r}x[31721]=0;S(242,Vb(j,d)|0,0,g|0);j=x[31721];x[31721]=0;if((j|0)!=1){break r}b=N()|0;ub(g);break d}b=N()|0;break d}b=N()|0;break d}ub(g);d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}yf(i);break b}x[31721]=0;P(243,b|0,((f<<5)+a|0)+946304|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31721]=0;O(244,b|0,e+20|0);h=x[31721];x[31721]=0;t:{if((h|0)==1){break t}x[31721]=0;O(245,e+20|0,(D(g,104)+a|0)+484380|0);h=x[31721];x[31721]=0;if((h|0)==1){break t}h=y[e+36|0];Kb(e,x[i>>2],g-1|0);Ef(e,(h&3)!=0);d=d+1|0;continue}break}b=N()|0}yf(i);break c}b=N()|0;Eb(e)}Q(b|0);p()}d=1}fb=e+80|0;return d|0}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=fb-80|0;fb=d;g=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}Zd(d- -64|0,b);e=x[d+72>>2];f=x[d+76>>2];k=d+56|0;dl(k);b=zj(b,k,8);if((y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))!=1414681667|(y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24))!=776101705){Ei(b,e,f,0);break d}w[d+54>>1]=0;lg(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}e=d+46|0;dl(e);e=zj(b,e,8);if((y[d+46|0]|y[d+47|0]<<8|(y[d+48|0]<<16|y[d+49|0]<<24))!=1933333571|(y[d+50|0]|y[d+51|0]<<8|(y[d+52|0]<<16|y[d+53|0]<<24))!=1111389030){break d}w[d+44>>1]=0;lg(e,d+44|0);f=w[d+44>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Fb(d- -64|0);x[31721]=0;h=U(499,e|0,b|0,65535)|0;l=x[31721];x[31721]=0;if((l|0)==1){break b}if(!h){break i}x[31721]=0;S(500,d+32|0,c|0,b|0);h=x[31721];x[31721]=0;if((h|0)!=1){break j}break b}b=Fb(d- -64|0);x[31721]=0;h=P(502,e|0,b|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break c}if(!h){break h}x[31721]=0;S(500,d+32|0,c|0,b|0);h=x[31721];x[31721]=0;if((h|0)==1){break c}}h=d+32|0;yb(a+40|0,h);tb(h);tb(b);w[d+30>>1]=0;lg(e,d+30|0);w[d+28>>1]=0;lg(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((f|0)<=3){x[d+64>>2]=0;Jk(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=em(b);w[d+26>>1]=b;break k}lg(e,d+26|0);b=z[d+26>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Fb(d- -64|0);x[31721]=0;w[d+8>>1]=0;O(942,e|0,d+8|0);i=x[31721];x[31721]=0;if((i|0)==1){break g}n:{if(!n){x[31721]=0;i=U(499,e|0,f|0,65535)|0;j=x[31721];x[31721]=0;if((j|0)==1){break g}if(i){break n}break e}x[31721]=0;i=P(502,e|0,f|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break g}if(!i){break e}}x[31721]=0;S(500,d+32|0,c|0,f|0);i=x[31721];x[31721]=0;if((i|0)!=1){x[31721]=0;i=P(939,h|0,d+8|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break m}j=i;i=d+32|0;yb(j,i);tb(i);tb(f);b=b+1|0;continue}break}g=N()|0;break f}g=N()|0;tb(d+32|0);break f}b=d+32|0;dl(b);b=zj(e,b,8);if((y[d+32|0]|y[d+33|0]<<8|(y[d+34|0]<<16|y[d+35|0]<<24))!=1933333571|(y[d+36|0]|y[d+37|0]<<8|(y[d+38|0]<<16|y[d+39|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(KQ(b,c)){break o}break d}if(!JQ(b,c)){break d}}o=d,q=wb(x[a+4>>2]),x[o+64>>2]=q;c=wb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Sm(B[e>>2])){break d}Pe(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(KQ(b,c)){break p}break d}if(!JQ(b,c)){break d}}o=d,q=wb(x[a+16>>2]),x[o+64>>2]=q;c=wb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Sm(B[e>>2])){break d}Pe(d- -64|0);continue}break}o=a,q=nc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+24>>1]=0;lg(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;lg(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;kq(b,d+16|0);m=MQ(B[d+16>>2]);B[a+32>>2]=m;if(!Sm(m)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;cl(c+16|0,e);Km(c+24|0,b,x[c+16>>2],x[c+20>>2]);cl(c+8|0,e);fb=c+32|0;if(x[d+8>>2]!=1414681667|x[d+12>>2]!=776298313){break d}b=nc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=qh(b),x[o+64>>2]=q;x[d+4>>2]=0;o=a,q=x[ak(d- -64|0,d+4|0,42272)>>2],x[o+36>>2]=q;lq(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(UQ(nc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Nb(d- -64|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;o=d,q=(nc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+6>>1]=q;x[31721]=0;w[d+2>>1]=0;ha(937,a|0,e|0,g|0,d+4|0,d+2|0)|0;a=x[31721];x[31721]=0;g=1;if((a|0)==1){break r}sc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[31721]=0;O(943,e|0,xb(f,b-c|0)|0);c=x[31721];x[31721]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=N()|0;sc(e);break a}tb(b);break d}tb(b);break d}g=N()|0}tb(f);break a}tb(f)}fb=d+80|0;return g|0}g=N()|0;tb(b);break a}g=N()|0;tb(b)}Q(g|0);p()}function Gs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;f=e+448|0;fa(f|0,100,e+445|0,e+548|0,x[b>>2])|0;h=e+32|0;x[e+28>>2]=h;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=f;h=Di(h,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+32|0;h=f+(h<<2)|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31721]=0;a=U(1251,d|0,1,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if(a){x[31721]=0;O(36,g|0,32);a=x[31721];x[31721]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31721]=0;a=U(1251,d|0,1,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31721]=0;x[e+4>>2]=0;a=ea(1361,e+8|0,h|0,k|0,j|0,d|0,e+4|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31721]=0;O(36,g|0,37);c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;O(36,g|0,((a|0)<84?65:97)|0);a=x[31721];x[31721]=0;if((a|0)!=1){break q}break c}x[31721]=0;x[e+8>>2]=f;a=ea(1361,e+8|0,h|0,j|0,i|0,d|0,e+4|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31721]=0;O(36,g|0,37);f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;O(36,g|0,((a|0)<144?66:98)|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}if(m){break q}a=x[Td((D(c,12)+b|0)+172|0,0)>>2];x[31721]=0;a=U(1251,d|0,64,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if(!a){break q}n=(Jb(g)+(Bb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Bb(x[b+464>>2],y[b+471|0])|0)==(0-Bb(x[b+476>>2],y[b+483|0])|0)){break p}x[31721]=0;x[e+8>>2]=f;a=ea(1361,e+8|0,h|0,i|0,l|0,d|0,e+4|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;O(36,g|0,112);a=x[31721];x[31721]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31721]=0;a=U(1251,d|0,64,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if(a){x[31721]=0;a=ba(1362,e+28|0,h|0,e+4|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31721]=0;O(36,g|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31721]=0;a=P(1363,d|0,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;O(36,g|0,37);break u}a=x[f>>2];x[31721]=0;O(36,g|0,a|0)}a=x[31721];x[31721]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=89;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=106;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=121;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=83;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=77;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=100;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=72;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=109;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=73;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=117;break d}x[31721]=0;O(36,g|0,37);a=x[31721];x[31721]=0;c=119}if((a|0)==1){break c}x[31721]=0;O(36,g|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Rb(g);Q(a|0);p()}x[e+28>>2]=f;continue}}Zn(12661);p()}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!qk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Hm(d+192|0,b);x[31721]=0;e=P(465,d+180|0,14001)|0;f=x[31721];x[31721]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[31721]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;S(466,b|0,e|0,d+160|0);f=x[31721];x[31721]=0;if((f|0)==1){break A}Eb(e);v[d+179|0]=0;x[31721]=0;e=P(465,d+160|0,14723)|0;f=x[31721];x[31721]=0;if((f|0)==1){break z}x[31721]=0;S(467,b|0,d+179|0,e|0);f=x[31721];x[31721]=0;if((f|0)==1){break y}Eb(e);e=Ec(d+156|0,y[d+179|0]?0:c);x[31721]=0;c=P(465,d+144|0,15839)|0;f=x[31721];x[31721]=0;if((f|0)==1){break x}f=x[e>>2];x[31721]=0;V(931,b|0,a+40|0,c|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break w}Eb(c);w[d+142>>1]=65535;x[31721]=0;c=P(465,d+128|0,15523)|0;f=x[31721];x[31721]=0;if((f|0)==1){break v}x[31721]=0;U(495,b|0,d+142|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}Eb(c);w[d+126>>1]=0;x[31721]=0;c=P(465,d+112|0,15363)|0;f=x[31721];x[31721]=0;if((f|0)==1){break t}x[31721]=0;U(495,b|0,d+126|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break s}Eb(c);w[a>>1]=z[d+126>>1];x[31721]=0;c=P(465,d+100|0,15036)|0;f=x[31721];x[31721]=0;if((f|0)==1){break r}e=x[e>>2];x[31721]=0;V(932,b|0,a+52|0,c|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break q}Eb(c);x[31721]=0;c=P(465,d+88|0,14984)|0;e=x[31721];x[31721]=0;if((e|0)==1){break p}x[31721]=0;S(921,b|0,a+36|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break o}Eb(c);x[31721]=0;c=P(465,d+76|0,15525)|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}x[31721]=0;h=a+4|0;S(933,b|0,h|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break m}Eb(c);x[31721]=0;c=P(465,d- -64|0,15365)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}x[31721]=0;f=a+28|0;S(934,b|0,f|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break k}Eb(c);x[31721]=0;c=P(465,d+52|0,15220)|0;e=x[31721];x[31721]=0;if((e|0)==1){break j}x[31721]=0;S(934,b|0,a+30|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break i}Eb(c);x[31721]=0;c=P(465,d+40|0,15008)|0;e=x[31721];x[31721]=0;if((e|0)==1){break h}x[31721]=0;S(935,b|0,a+32|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break g}Eb(c);w[d+38>>1]=0;x[31721]=0;c=P(465,d+24|0,14963)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}x[31721]=0;U(495,b|0,d+38|0,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}Eb(c);i=MQ(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!Sm(i)){break d}k=d,l=wb(x[a+4>>2]),x[k+20>>2]=l;c=wb(x[a+8>>2]);while(1){g=x[d+20>>2];if(!Ib(g,c)){break e}if(!Sm(B[g>>2])){break d}Pe(d+20|0);continue}}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;Eb(c);break a}if(ol(y[b|0])){break d}c=z[f>>1];if((c-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=qh(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[ak(d+20|0,d+16|0,42272)>>2],x[k+36>>2]=l;if(nc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[d+38>>1];if((f|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31721]=0;w[d+16>>1]=c;w[d+18>>1]=(c+f|0)-1;a=ba(936,a|0,d+14|0,d+20|0,d+16|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31721]=0;w[d+16>>1]=c;w[d+18>>1]=(c+g|0)-1;a=ha(937,a|0,h|0,d+20|0,d+16|0,f|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31721]=0;W(938,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}}e=1}yh(b)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}yh(b);Q(a|0);p()}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-736|0;fb=d;vc(b);e=fb-16|0;fb=e;h=d+128|0;LW(e+8|0,h);f=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(f|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(f|0)==(j|0);if(!e){KW(h)}a:{if(!e){break a}if(!NW(d+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(MW(y[d+162|0]|y[d+163|0]<<8),hb))){break a}if(!c){n=1;break a}Ad(a,262144);f=d+92|0;Zi(f,2,d+128|0);e=d+12|0;Ac(e,f);yb(a+1298308|0,e);tb(e);h=rc(e,8317);yb(a+1298344|0,h);tb(h);e=rc(e,10125);yb(a+1298356|0,e);tb(e);e=fb-16|0;fb=e;g=f;f=rc(e+4|0,4193);Zc(g,f);tb(f);fb=e+16|0;v[d|0]=y[d+158|0];x[31721]=0;v[d+115|0]=y[d+157|0];O(695,d+116|0,d+115|0);e=x[31721];x[31721]=0;b:{c:{d:{if((e|0)!=1){x[31721]=0;V(253,d+12|0,d+92|0,d|0,d+116|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=d+12|0;yb(a+1298368|0,e);tb(e);tb(d+116|0);f=d+92|0;Eb(f);B=a+1298404|0,C=x[Ec(e,4)>>2],x[B>>2]=C;x[a+480208>>2]=12;h=a+480188|0;w[h>>1]=y[d+166|0]|y[d+167|0]<<8;w[d+12>>1]=y[d+162|0]|y[d+163|0]<<8;w[d+92>>1]=3999;B=a,C=z[Lc(e,f)>>1],w[B+480190>>1]=C;i_(Wb(x[a+484360>>2],y[a+484376|0]),d+224|0,y[d+160|0]|y[d+161|0]<<8);e=0;while(1)if(z[h>>1]<=e>>>0){e=d+12|0;ce(e,b,D(y[d+162|0]|y[d+163|0]<<8,80));j=c&2;h=hc(d+92|0,e);ub(e);l=d+60|0;e=0;e:{f:{while(1){if(z[a+480190>>1]<=e>>>0){n=1;if(c&1){break f}break b}x[31721]=0;O(696,h|0,d+12|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}Zi(d,2,l);x[31721]=0;O(221,d+116|0,d|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}e=e+1|0;f=d+116|0;xc(((e<<5)+a|0)+946304|0,f);tb(f);x[31721]=0;g=f;f=(D(e,104)+a|0)+484380|0;S(697,g|0,d+12|0,f|0);g=x[31721];x[31721]=0;g:{if((g|0)==1){break g}if(!j|!x[f>>2]){continue}x[31721]=0;g=P(152,b|0,y[d+30|0]|y[d+31|0]<<8|(y[d+32|0]<<16|y[d+33|0]<<24))|0;k=x[31721];x[31721]=0;if((k|0)==1){break g}if(!g){continue}x[31721]=0;U(218,d+116|0,f|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){continue}}break}break e}x[31721]=0;m=a+484344|0;O(226,m|0,y[d+164|0]|y[d+165|0]<<8);c=x[31721];x[31721]=0;if((c|0)==1){break e}o=d+16|0;t=d+14|0;q=d+15|0;u=d+17|0;A=d+13|0;r=a+480188|0;a=0;while(1){if((y[d+164|0]|y[d+165|0]<<8)>>>0<=a>>>0){break b}x[31721]=0;c=U(199,m|0,a&65535,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}h:{if(!c){break h}c=(a<<1)+d|0;c=y[c+480|0]|y[c+481|0]<<8;if(!c){break h}x[31721]=0;c=P(152,b|0,c<<4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}if(!c){break h}j=0;c=Vb(x[m>>2],a);l=jd(x[c>>2],x[x[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}c=x[b+8>>2];e=x[b>>2];x[31721]=0;c=U(153,e|0,c|0,1)|0;e=x[31721];x[31721]=0;i:{if((e|0)!=1){if(!c){break h}x[31721]=0;c=R(200,b|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break e}g=c<<24>>24;if(g){break i}j=j+1|0;l=D(z[r>>1],6)+l|0;continue}break e}w[o>>1]=0;x[d+12>>2]=0;e=g&31;c=D(e,6)+l|0;f=Ig(d+12|0);e=e>>>0<z[r>>1];k=e?c:f;i=g&255;j:{if(!(i&32)){break j}x[31721]=0;O(201,d+116|0,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}f=y[d+116|0];v[k|0]=f;B=e?c+1|0:A,C=y[Hc(d+116|0)|0],v[B|0]=C;k:{if(f){if((f|0)==254){break k}if(f>>>0<121){break j}}f=0}v[k|0]=f}l:{if(!(i&64)){break l}x[31721]=0;O(201,d+116|0,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}f=e?c+5|0:u;s=Hc(d+116|0);v[f|0]=y[s|0];i=y[d+116|0];m:{if(i>>>0<=15){xf(k,i,y[s|0]);break m}v[(e?c+3|0:q)|0]=i>>>0<=23?y[i+25351|0]:0}k=e?c+3|0:q;i=y[k|0];if((i|0)!=23){if((i|0)!=9){break l}v[k|0]=20;v[d|0]=y[f|0]>>>3;v[d+115|0]=1;B=f,C=y[af(d,d+115|0)|0]-1&15|128,v[B|0]=C;break l}v[d|0]=64;B=f,C=y[Sb(f,d)|0]<<1,v[B|0]=C}if((g|0)>=0){continue}v[(e?c+2|0:t)|0]=1;x[31721]=0;f=R(200,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}v[(e?c+4|0:o)|0]=f;continue}}a=a+1|0;continue}}b=N()|0;ub(h);break c}else{f=(e<<5)+a|0;Ue(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+192|0]<<4|4)&244;e=e+1|0;continue}}b=N()|0;tb(d+116|0);break d}b=N()|0}Eb(d+92|0)}Q(b|0);p()}ub(h)}fb=d+736|0;return n|0}function mL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+D(s,-24)|0;o=x[(e<<2)+90160>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+90176>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=l-24|0;g=0;h=(o|0)>0?o:0;n=(d|0)<=0;while(1){a:{if(n){f=0;break a}k=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(k-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;u=(l|0)<25;z=l-25|0;g=o;b:{while(1){f=C[(g<<3)+i>>3];c=0;h=g;k=(g|0)<=0;if(!k){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=nk(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{i:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>t;r=h;h=j-(c<<t)|0;x[r+476>>2]=h;n=c+n|0;j=h>>y;break i}if(q){break h}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!k){while(1){r=(i+480|0)+(c<<2)|0;v=x[r>>2];k=16777215;j:{k:{if(h){break k}k=16777216;if(v){break k}h=0;break j}x[r>>2]=k-v;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}k=(g<<2)+i|0;x[k+476>>2]=x[k+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-nk(1,q)}if(f==0){c=1;k=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;k=x[(i+480|0)+(h<<2)>>2]|k;if((h|0)>(o|0)){continue}break}if(!k){break n}l=q;while(1){l=l-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(s+g<<2)+90176>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=nk(f,24-l|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}l=q}x[(i+480|0)+(g<<2)>>2]=c}f=nk(1,l);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(o|0)?o:a;if((d|0)>=0){while(1){f=C[(c<<3)+92944>>3]*C[(c+h<<3)+i>>3]+f;l=(c|0)!=(d|0);c=c+1|0;if(l){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=m+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=m+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return n&7}function l7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;ad(h,x[d+28>>2]);x[31721]=0;i=R(1219,x[h>>2])|0;j=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Yb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Yb(h);Q(a|0);p()}LJ(a,f+24|0,h+44|0,c,e,i);break b}KJ(a,f+16|0,h+44|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=sk(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[27951];x[h+24>>2]=x[27950];x[h+28>>2]=g;g=x[27949];x[h+16>>2]=x[27948];x[h+20>>2]=g;g=x[27947];x[h+8>>2]=x[27946];x[h+12>>2]=g;g=x[27945];x[h>>2]=x[27944];x[h+4>>2]=g;k=h,l=sk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[27959];x[h+24>>2]=x[27958];x[h+28>>2]=g;g=x[27957];x[h+16>>2]=x[27956];x[h+20>>2]=g;g=x[27955];x[h+8>>2]=x[27954];x[h+12>>2]=g;g=x[27953];x[h>>2]=x[27952];x[h+4>>2]=g;k=h,l=sk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(ii(a,b+12|0)){break H}if(!uj(i,1,sl(x[a>>2]))){break H}ao(a);continue}break}if(ii(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Vs(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=yc(h,111840,44);k=g,l=sk(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[27976];g=x[27975];x[h+8>>2]=x[27974];x[h+12>>2]=g;g=x[27973];x[h>>2]=x[27972];x[h+4>>2]=g;k=h,l=sk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[27987];x[h+24>>2]=x[27986];x[h+28>>2]=g;g=x[27985];x[h+16>>2]=x[27984];x[h+20>>2]=g;g=x[27983];x[h+8>>2]=x[27982];x[h+12>>2]=g;g=x[27981];x[h>>2]=x[27980];x[h+4>>2]=g;k=h,l=sk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=sk(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}JJ(f+20|0,h+44|0,c,e,i);break b}a=mj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;L:{M:{if(ii(c,a+12|0)){break M}b=4;if((rk(i,sl(x[c>>2]))|0)!=37){break M}b=2;if(!ii(ao(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function O0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-864|0;fb=f;vc(b);e=fb-16|0;fb=e;i=f+92|0;fF(e+8|0,i);d=x[e+12>>2];jc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(d|0)){Ub(b,x[e+12>>2])}fb=e+16|0;e=(d|0)==(g|0);if(!e){eF(i)}a:{if(!e){break a}if(!hF(f+92|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],gF(y[f+607|0]))){break a}if(!c){j=1;break a}Ad(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[f+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;e=a+484360|0;d=a+484376|0;dk(Wb(x[e>>2],y[d|0]),b,y[f+607|0],65535,65535);e=Wb(x[e>>2],y[d|0]);o=f,q=wb(x[e>>2]),x[o+40>>2]=q;e=wb(x[e+4>>2]);while(1){d=x[f+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break a}Od(f+40|0);continue}break}bg(a);j=1;while(1){i=j&65535;if(i>>>0>z[a+480190>>1]){b:{j=1;c:{d:{e:{if(!(c&1)){break e}m=x[b+8>>2];i=a+484344|0;Of(i,128);c=0;f:{while(1){if((c|0)==128){break f}d=f+16|0;e=(c<<1)+f|0;dF(d,b,(y[e+608|0]|y[e+609|0]<<8)+m|0,4674);e=hc(f+40|0,d);ub(d);d=x[e>>2];x[31721]=0;d=R(175,d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break c}g:{if(!d){break g}x[31721]=0;d=U(199,i|0,c&65535,32)|0;g=x[31721];x[31721]=0;if((g|0)==1){break c}if(!d){break g}g=0;d=Vb(x[i>>2],c);_e(f+16|0,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){h:{d=x[e>>2];x[31721]=0;d=U(153,d|0,x[f+48>>2],1)|0;h=x[31721];x[31721]=0;i:{j:{k:{l:{m:{if((h|0)!=1){if(!d){break h}x[31721]=0;d=R(200,e|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}n:{switch(d-251|0){case 0:break j;case 1:break k;case 2:break l;case 3:break m;case 4:break n;default:break i}}x[31721]=0;d=R(200,e|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}if(!d){break h}g=d+g|0;if(g>>>0>=32){break h}d=Vb(x[i>>2],c);_e(f- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=d;continue}break b}x[31721]=0;O(201,f- -64|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[vb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[vb(f- -64|0,1)|0];if(h>>>0>63){break d}o=Vc(x[f+16>>2],d),q=h+1|0,v[o+1|0]=q;continue}x[31721]=0;O(201,f- -64|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[vb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[vb(f- -64|0,1)|0];if(h>>>0>63){break d}d=Vc(x[f+16>>2],d);v[d+4|0]=63-h;v[d+2|0]=1;continue}x[31721]=0;d=R(200,e|0)|0;h=x[31721];x[31721]=0;if((h|0)!=1){h=Vc(x[f+16>>2],0);v[h+5|0]=d;v[h+3|0]=12;continue}break b}d=Vc(x[f+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break d}x[31721]=0;h=R(200,e|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break b}if(h>>>0>=124){break d}o=Vc(x[f+16>>2],d),q=(D(h>>>4|0,12)+(h&15)|0)+13|0,v[o|0]=q;d=d&1;k=d|k;l=!d|l;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(k&l&1)){break e}c=z[a+480188>>1];b=0;while(1){if((b|0)==(c|0)){break e}w[((b<<5)+a|0)+480284>>1]=b<<8&256;b=b+1|0;continue}}_h(a+1298344|0,14744);_h(a+1298356|0,14753);_h(a+1298368|0,14744);o=a+1298404|0,q=x[Ec(f+40|0,4)>>2],x[o>>2]=q;break a}ub(e);j=0;break a}}}else{e=f+81|0;d=fb-16|0;fb=d;o:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Qh(e,11,d);break o}vw(d+8|0,e);pd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[f+48>>2]=0;x[f+40>>2]=0;x[f+44>>2]=0;g=vb(e,1);d=f+40|0;o=vb(d,0),q=y[g|0],v[o|0]=q;g=vb(e,6);o=vb(d,1),q=y[g|0],v[o|0]=q;g=vb(e,2);o=vb(d,2),q=y[g|0],v[o|0]=q;g=vb(e,7);o=vb(d,3),q=y[g|0],v[o|0]=q;g=vb(e,3);o=vb(d,4),q=y[g|0],v[o|0]=q;g=vb(e,8);o=vb(d,5),q=y[g|0],v[o|0]=q;g=vb(e,4);o=vb(d,6),q=y[g|0],v[o|0]=q;g=vb(e,9);o=vb(d,7),q=y[g|0],v[o|0]=q;g=vb(e,5);o=vb(d,8),q=y[g|0],v[o|0]=q;g=vb(e,10);o=vb(d,9),q=y[g|0],v[o|0]=q;e=vb(e,0);o=vb(d,10),q=y[e|0],v[o|0]=q;e=(D(i,104)+a|0)+484380|0;kd(e,2);x[f+8>>2]=x[f+48>>2];d=x[f+44>>2];x[f>>2]=x[f+40>>2];x[f+4>>2]=d;Yk(e,1,f);d=f- -64|0;cF(d,((i<<3)+f|0)+86|0);e=f+16|0;Ac(e,d);xc(((i<<5)+a|0)+946304|0,e);j=j+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}fb=f+864|0;return j|0}function wz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(!(d|g|h)){j=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}Db(j);x[k>>2]=0}x[31721]=0;X(87);j=x[31721];x[31721]=0;c:{d:{if((j|0)==1){m=Va(124984,47440,47496,48476,125172,125276,125224,125116,125104,125420,125388,125356,125344,125568,0)|0;e:{f:{n=gb;if((n|0)==($(124984)|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=277;if((k|0)==1){break f}break c}if(($(47440)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=358;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(47496)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=359;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(48476)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=357;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125172)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=300;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125276)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=299;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125224)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=298;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125116)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=297;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125104)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=296;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125420)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=289;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125388)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=288;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125356)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=287;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}if(($(125344)|0)==(n|0)){j=Y(m|0)|0;x[31721]=0;O(1106,k|0,j|0);k=x[31721];x[31721]=0;j=286;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break e}o=$(125568)|0;j=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31721]=0;O(1106,k|0,m|0);k=x[31721];x[31721]=0;j=267;if((k|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break e}break d}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break d}}T(0)|0;Qb()}p()}Q(a|0);p()}Z();k=j;m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=wg(g?g:22250),x[q+20>>2]=r}if(h){x[h>>2]=k}if(!i){break a}g=x[l+44>>2];q=i,r=wg(g?g:22250),x[q>>2]=r}g=x[l+44>>2];if(g){Db(g);x[l+44>>2]=0}g:{if(!(j&1)){break g}x[31721]=0;O(1104,l+32|0,a|0);g=x[31721];x[31721]=0;h:{i:{if((g|0)!=1){j:{if(f){g=x[f+24>>2];x[31721]=0;O(1105,g|0,l+32|0);g=x[31721];x[31721]=0;if((g|0)!=1){break j}break i}g=Jb(l+32|0);if(b){x[31721]=0;O(b|0,g|0,c|0);g=x[31721];x[31721]=0;if((g|0)==1){break i}break j}Vt(g,l)}tb(l+32|0);break g}g=T(0)|0;break h}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22250;x[l+4>>2]=254;x[l>>2]=9174;kP(18455,l);Ut(125920);Z()}fb=l+48|0}function Lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-192|0;fb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!$o(b,d+180|0)){break l}if(!yX(d+180|0)){break l}g=Zh(d+160|0);h=Fb(d+148|0);Rv(d+84|0);x[31721]=0;f=P(620,b|0,d+76|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=_b(_b(x[d+80>>2])-4|0),x[m+80>>2]=n;while(1){f=_b(_b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(c){break n}if((_b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31721]=0;S(188,d+56|0,b|0,_b(f)|0);f=x[31721];x[31721]=0;if((f|0)==1){break d}e=d+56|0;f=hc(d,e);ub(e);e=x[f>>2];x[31721]=0;j=R(175,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}o:{if(!j){break o}p:{e=_b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31721]=0;P(186,f|0,4)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;e=R(621,f|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}if(!e){break o}e=_b(x[d+80>>2]);if(e>>>0<7){break o}i=x[Ec(d+52|0,28)>>2];x[31721]=0;V(622,f|0,h|0,i|0,e-6|0);e=x[31721];x[31721]=0;if((e|0)==1){break b}break o}x[31721]=0;l=P(623,f|0,d+84|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break o}break b}Mw(g,f);break o}x[31721]=0;k=U(624,a|0,f|0,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}}ub(f);if(j){x[31721]=0;f=P(620,b|0,d+76|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break i}if(f){continue}}break}if(zd(x[h+4>>2],y[h+11|0])){x[31721]=0;b=P(1,d+56|0,14881)|0;c=x[31721];x[31721]=0;if((c|0)==1){break g}yb(h,b);tb(b)}q:{if(!(k&l&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31721]=0;b=Cb(b)&256;U(269,a+1074312|0,5,!b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break f}c=Cb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;m=a,n=z[Lc(d,d+40|0)>>1],x[m+480228>>2]=n}c=!b;b=Cb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;Te(b,2,d+84|0);x[31721]=0;O(221,d|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}yb(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!Qq(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!Qq(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!Qq(e,0,23)){break q}j=y[d+136|0]|y[d+137|0]<<8;if(!Qq(j,0,59)){break q}i=y[d+138|0]|y[d+139|0]<<8;if(!Qq(i,0,59)){break q}x[a+1298408>>2]=0;b=cp(d);m=b,n=Cb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[m>>2]=n;m=b,n=Cb(c),x[m+4>>2]=n;m=b,n=Cb(f),x[m+8>>2]=n;m=b,n=Cb(e),x[m+12>>2]=n;m=b,n=Cb(j),x[m+16>>2]=n;m=b,n=Cb(i),x[m+24>>2]=n;x[b+28>>2]=0;x[31721]=0;O(451,a+1298412|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31721]=0;b=R(175,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31721]=0;S(273,g|0,b|0,32);c=x[31721];x[31721]=0;if((c|0)==1){break c}if(fr(b,13798)){x[31721]=0;S(261,d+40|0,28,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}c=d+40|0;yb(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31721]=0;c=P(625,f|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}if(!c){x[31721]=0;c=R(205,g|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;aa(319,a+1298332|0,g|0,c|0,40,0);c=x[31721];x[31721]=0;if((c|0)==1){break c}}tb(b)}x[31721]=0;b=P(1,d+40|0,18146)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}x[31721]=0;S(493,d|0,b|0,h|0);c=x[31721];x[31721]=0;if((c|0)==1){break j}yb(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31721]=0;a=U(269,a+1074312|0,84,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break h}x[31721]=0;a=U(269,a|0,83,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break h}x[31721]=0;P(270,a|0,85)|0;a=x[31721];x[31721]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function dsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=fb-720|0;fb=j;a:{b:{if(d>>>0<=511){a=fb-16|0;fb=a;e=j+46|0;ac(a+8|0,e,554);d=x[a+12>>2];jc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){Ub(b,x[a+12>>2])}fb=a+16|0;a=(d|0)==(f|0);if(!a){Tb(e,0,554)}if(!a){break b}d=fb-32|0;fb=d;c:{a=j+46|0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;Mr(e,a+32|0);b=d+20|0;Ac(b,e);xc(c+492|0,b);tb(b);hk(e,1,a+4|0);Ac(b,e);xc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;ch(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=xb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}ch(f,b);e=x[f>>2]}b=af(k,g);a=Pd(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[af(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=Zb(k,b),q=g,w[o>>1]=q;o=vb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}k=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=hf(b)}g=d+8|0;e=j+46|0;rZ(g,e);h=fc(d+16|0,x[d+8>>2],f);i=x[h>>2];jc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);rZ(g,e);Tb(x[d+8>>2]+f|0,0,674-f|0);Ub(b,x[d+28>>2]);fb=d+32|0;g=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;Mr(f,e+32|0);a=d+20|0;Ac(a,f);xc(c+492|0,a);tb(a);hk(f,1,e+4|0);Ac(a,f);xc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;uc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Sb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Sb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];gk(c,a&127,a>>>7|0);a=y[e+59|0];fk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;Hw(e+304|0,c+48|0,0,f);Hw(e+386|0,c+68|0,32,f);Hw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=Zb(h,a),q=i,w[o>>1]=q;o=vb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=Zb(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}bd(b,d+k|0);if(!ek(b,14031)){break b}d=j+4|0;ce(d,b,Mg(b));a=hc(j+24|0,d);ub(d);b=x[a>>2];x[31721]=0;R(157,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;b=P(416,a|0,13813)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}if(b){x[31721]=0;b=R(200,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function jua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-3056|0;fb=e;vc(b);g=fb-16|0;fb=g;i=e+1102|0;S$(g+8|0,i);f=x[g+12>>2];j=b;jc(g,x[b>>2],x[b+8>>2],x[g+8>>2],x[g+12>>2]);b=x[g+4>>2];if((b|0)==(f|0)){Ub(j,x[g+12>>2])}fb=g+16|0;b=(b|0)==(f|0);if(!b){R$(i)}a:{if(!b){break a}if(!U$(e+1102|0)){break a}b:{if(!c){break b}if(!Mb(x[j>>2],x[j+8>>2],Bc(1024,0))){break a}Q$(j,e+576|0);Q$(j,e- -64|0);while(1){if((h|0)!=128){b=h<<2;g=x[b+(e+576|0)>>2];if(g>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}h=h+1|0;if(tm(x[j>>2],(b+g|0)+2978|0)){continue}break a}break}Ad(a,2);bg(a);b=e+40|0;d=rc(b,13879);yb(a+1298344|0,d);tb(d);d=rc(b,14740);yb(a+1298356|0,d);tb(d);d=rc(b,15541);yb(a+1298368|0,d);tb(d);o=a+1298404|0,q=x[Ec(b,4)>>2],x[o>>2]=q;b=y[e+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;Ze(Wb(x[a+484360>>2],y[a+484376|0]),y[e+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;h=0;while(1){if((h|0)==4){c:{while(1){d:{if((d|0)==32){h=0;break d}b=d+1|0;h=D(b,104)+a|0;f=h+484380|0;kd(f,2);i=e+20|0;P$(i,(D(d,13)+e|0)+1104|0);g=e+40|0;Ac(g,i);xc(((b<<5)+a|0)+946304|0,g);tb(g);d=(e+1102|0)+(d<<4)|0;g=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[f>>2]=g;f=g;g=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(f>>>0>=g>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[h+484414>>1]=2;x[h+484388>>2]=g;x[h+484384>>2]=d}x[h+484404>>2]=8287;d=b;continue}break}while(1){if((h|0)!=32){d=h+33|0;g=(D(d,104)+a|0)+484380|0;kd(g,2);f=e+20|0;P$(f,(D(h,13)+e|0)+2032|0);b=e+40|0;Ac(b,f);xc(((d<<5)+a|0)+946304|0,b);tb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(D(h,11)+e|0)+2448|0;f=vb(d,1);o=vb(b,0),q=y[f|0],v[o|0]=q;f=vb(d,6);o=vb(b,1),q=y[f|0],v[o|0]=q;f=vb(d,2);o=vb(b,2),q=y[f|0],v[o|0]=q;f=vb(d,7);o=vb(b,3),q=y[f|0],v[o|0]=q;f=vb(d,3);o=vb(b,4),q=y[f|0],v[o|0]=q;f=vb(d,8);o=vb(b,5),q=y[f|0],v[o|0]=q;f=vb(d,4);o=vb(b,6),q=y[f|0],v[o|0]=q;f=vb(d,9);o=vb(b,7),q=y[f|0],v[o|0]=q;f=vb(d,5);o=vb(b,8),q=y[f|0],v[o|0]=q;f=vb(d,10);o=vb(b,9),q=y[f|0],v[o|0]=q;d=vb(d,0);o=vb(b,10),q=y[d|0],v[o|0]=q;x[e+16>>2]=x[e+48>>2];b=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=b;Yk(g,1,e+8|0);h=h+1|0;continue}break}Fr(Wb(x[a+484360>>2],y[a+484376|0]),e+2800|0,256,255,65535);l=a+484344|0;Of(l,128);m=c&1;g=0;while(1){e:{f:{if((g|0)!=128){b=g<<2;bd(j,x[b+(e+576|0)>>2]+2978|0);d=e+20|0;ce(d,j,x[b+(e- -64|0)>>2]);b=hc(e+40|0,d);ub(d);if(!m){break e}x[31721]=0;d=U(199,l|0,g&65535,64)|0;h=x[31721];x[31721]=0;if((h|0)==1){break c}if(!d){break e}h=0;f=Vb(x[l>>2],g);while(1){if(h>>>0>63){break e}d=x[b>>2];x[31721]=0;d=U(153,d|0,x[e+48>>2],1)|0;i=x[31721];x[31721]=0;g:{if((i|0)!=1){if(!d){break e}x[31721]=0;d=R(200,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break c}if(d>>>0>12){break g}i=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,d);x[31721]=0;O(201,e+20|0,b|0);k=x[31721];x[31721]=0;if((k|0)==1){break c}k=y[e+20|0];d=d>>>0>3;v[i|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=Hc(e+20|0);v[i+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+20|0]>>>3&16);O$(i,y[k|0],d);continue}break c}i=d-32|0;if((i&255)>>>0<=12){i=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,i&65535);x[31721]=0;k=R(200,b|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break c}O$(i,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!h){break e}o=jd(x[f>>2],x[x[f+48>>2]+12>>2],h-1|0,0),q=14,v[o+3|0]=q;break e}x[31721]=0;d=R(200,b|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break c}h=d+h|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}ag(Wc(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}ub(b);d=0;break a}ub(b);g=g+1|0;continue}}}else{w[((h<<5)+a|0)+480284>>1]=h&1?192:64;h=h+1|0;continue}break}a=N()|0;ub(b);Q(a|0);p()}d=1}fb=e+3056|0;return d|0}function uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-320|0;fb=d;vc(b);a:{if(!$o(b,d+308|0)){break a}if(!K_(d+308|0)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Ub(b,4)}if(!yi(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}if(!c){m=1;break a}Y$(b,d+108|0,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Ad(a,8192);e=d+24|0;f=rc(e,6574);yb(a+1298344|0,f);tb(f);f=rc(e,10141);yb(a+1298356|0,f);tb(f);t=a+1298404|0,u=x[Ec(e,4)>>2],x[t>>2]=u;f=d+88|0;Zi(f,2,d+108|0);Ac(e,f);yb(a+1298308|0,e);tb(e);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;g=z[oe(e,f)>>1];w[a+480188>>1]=g;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Sb(e,f)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(g>>>0);x[d+88>>2]=128;e=x[Gb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;e=0;while(1){if((e|0)==16){h=a+484376|0;g=Wb(x[a+484360>>2],y[h|0]);m=d+172|0;f=fb-16|0;fb=f;x[f+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=f+12|0;uc(e,128);uc(e,65535);j=z[f+12>>1];sg(g,j);e=0;while(1){if((e|0)==(j|0)){fb=f+16|0}else{i=y[e+m|0];t=Gr(x[g>>2],x[g+4>>2],e),u=(i|0)==255?-1:(i|0)==254?-2:i,w[t>>1]=u;e=e+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){Ze(Wb(x[a+484360>>2],y[h|0]),e)}o=c&2;j=a+484344|0;m=1;q=c&1;r=d+60|0;i=a+480190|0;s=a+480188|0;while(1){if(!yi(b,d+300|0)){break a}e=d+24|0;ce(e,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));c=hc(d+88|0,e);ub(e);c:{d:{if(!(!q|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[31721]=0;k=n&65535;e=U(199,j|0,k|0,64)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}if(!e){break c}x[31721]=0;P(186,c|0,2)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}f=0;e:{while(1){e=x[c>>2];x[31721]=0;e=U(153,e|0,x[d+96>>2],1)|0;g=x[31721];x[31721]=0;f:{if((g|0)!=1){if(!(e&f>>>0<64)){break e}x[31721]=0;e=R(200,c|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}h=e<<24>>24;if(h){break f}f=f+1|0;continue}break d}e=d+24|0;g=h&15;if(g>>>0<z[s>>1]){e=Vb(x[j>>2],k);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],f,g)}g:{if((h|0)>=0){break g}x[31721]=0;g=R(200,c|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break d}if(!g){break g}v[e|0]=g>>>0<109?g+12|0:g}g=h&255;if(g&64){x[31721]=0;h=R(200,c|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break d}v[e+1|0]=h}if(g&32){v[e+2|0]=1;x[31721]=0;h=R(200,c|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break d}v[d+12|0]=h;v[d|0]=64;t=e,u=y[Sb(d+12|0,d)|0],v[t+4|0]=u}if(!(g&16)){continue}x[31721]=0;O(201,d+12|0,c|0);g=x[31721];x[31721]=0;if((g|0)!=1){xf(e,y[d+12|0],y[Hc(d+12|0)|0]);continue}break}break d}n=n+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}e=z[i>>1];if(!ri(e)){break c}e=e+1|0;w[i>>1]=e;x[31721]=0;O(327,c|0,d+24|0);f=x[31721];x[31721]=0;h:{if((f|0)==1){break h}x[31721]=0;h=(D(e&65535,104)+a|0)+484380|0;O(328,d+24|0,h|0);e=x[31721];x[31721]=0;if((e|0)==1){break h}Zi(d,2,r);x[31721]=0;O(221,d+12|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break h}e=d+12|0;xc(((z[i>>1]<<5)+a|0)+946304|0,e);tb(e);if(!o){break c}e=y[d+37|0]|y[d+38|0]<<8;f=2;k=d+12|0;g=Wc(k,8,1,0,1);i:{if(!(e&64)){f=0;if(!(e&2)){break i}}tg(g,f)}if(e&4){ed(g,16)}x[31721]=0;U(218,k|0,h|0,c|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}f=(e<<5)+a|0;Ue(f+480280|0);g=y[(d+e|0)+156|0];if(g>>>0<=128){w[f+480284>>1]=g<<1}e=e+1|0;continue}}fb=d+320|0;return m|0}function qsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=fb-32|0;fb=g;a:{b:{if(!c){break b}f=Wh(a,b);a=wb(x[d>>2]);x[g+28>>2]=a;d=wb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}vc(a);c:{if((Rk(a)|0)==(c|0)){Ub(a,20);d=Rk(a);k=mg(g+16|0);c=_l(g+12|0,0,b?32:64);x[31721]=0;O(406,f|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;l=1;d:{while(1){h=o;while(1){e=x[a+8>>2];i=x[a>>2];x[31721]=0;e=U(153,i|0,e|0,1)|0;i=x[31721];x[31721]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=x[f+4>>2];i=x[f>>2];m=x[a+8>>2];x[31721]=0;x[g+12>>2]=m;m=P(407,k|0,g+12|0)|0;r=x[31721];x[31721]=0;if((r|0)==1){break a}u=m,A=Pd(i,e),x[u>>2]=A;x[31721]=0;e=R(200,a|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[31721]=0;e=R(276,a|0)|0;i=x[31721];x[31721]=0;t:{if((i|0)==1){break t}x[31721]=0;x[g+12>>2]=e;e=P(407,k|0,g+12|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=Pd(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[31721]=0;e=R(276,a|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}w[g+12>>1]=e;w[g+10>>1]=1;e=z[oe(g+12|0,g+10|0)>>1];h=D(e,D(s<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}u=g,A=em((e+z[pi(x[f+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Fv(b,h);x[31721]=0;v[g+10|0]=e;S(408,f|0,g+12|0,g+10|0);e=x[31721];x[31721]=0;if((e|0)!=1){break u}break a}u=g,A=em(z[pi(x[f+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Fv(b,h);x[31721]=0;v[g+10|0]=e;S(408,f|0,g+12|0,g+10|0);e=x[31721];x[31721]=0;if((e|0)!=1){break e}break a}x[31721]=0;j=R(200,a|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31721]=0;e=R(276,a|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}e=c+e|0;x[g+12>>2]=e;if(!(!(j&255)|e>>>0<t>>>0)){j=j-1|0;if(!(j&255)){break f}x[31721]=0;P(152,a|0,e|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}x[31721]=0;e=P(409,k|0,g+12|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=Pd(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[31721]=0;h=R(276,a|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}e=Fv(b,h);u=pi(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[31721]=0;s=R(410,a|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break e}break a}x[31721]=0;e=R(200,a|0)|0;l=x[31721];x[31721]=0;if((l|0)!=1){v[g+12|0]=e;v[g+10|0]=1;l=y[af(g+12|0,g+10|0)|0];break e}break a}x[31721]=0;P(186,a|0,1)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}x[31721]=0;c=P(152,a|0,d|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(!c){break d}c=x[a+8>>2];h=x[a>>2];x[31721]=0;c=U(153,h|0,c|0,2)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}if(!c){break d}h=y[f+12|0];v:{if(!(!(h&4)&q)){c=x[f+4>>2];break v}c=x[f+4>>2];e=x[f>>2];v[f+12|0]=h|4;h=Pd(e,c)-1|0;v[f+15|0]=h;v[f+16|0]=h}u=g,A=em(z[pi(c)>>1]+1|0),w[u+12>>1]=A;c=Fv(b,o);x[31721]=0;v[g+10|0]=c;S(408,f|0,g+12|0,g+10|0);c=x[31721];x[31721]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;EZ(k);break b}a=x[Yf(g+28|0)>>2];continue}break}break a}fb=g+32|0;return}a=N()|0;EZ(k);Q(a|0);p()}function Bz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[zl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Ll(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;de(g);h=x[f+96>>2];de(f+236|0);i=yl(h,x[f+240>>2],b);de(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=oc(f+248|0,22250);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Nc(h,g,f+8|0)){e=$b(8);x[31721]=0;c=ci(f+236|0,c,d);a=x[31721];x[31721]=0;f:{g:{h:{if((a|0)!=1){x[31721]=0;S(1019,f+96|0,18241,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}mc(e,f+96|0);a=0;x[31721]=0;S(100,e|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(c);if(!a){break c}}ic(e);break c}if(!e){break e}e=$b(8);a=x[b+4>>2];b=x[b>>2];x[31721]=0;g=ci(f+212|0,b,a);a=x[31721];x[31721]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31721]=0;S(1019,f+224|0,18277,g|0);a=x[31721];x[31721]=0;if((a|0)==1){break q}x[31721]=0;O(1021,f+236|0,f+224|0);b=x[31721];x[31721]=0;a=1;if((b|0)==1){break p}x[31721]=0;c=ci(f+200|0,c,d);a=x[31721];x[31721]=0;if((a|0)==1){break o}x[31721]=0;S(1023,f+96|0,f+236|0,c|0);b=x[31721];x[31721]=0;a=1;if((b|0)==1){break n}mc(e,f+96|0);x[31721]=0;S(100,e|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(f+96|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(c)}tb(f+236|0)}tb(f+224|0)}tb(g);if(!a){break c}}ic(e);break c}b=oc(f+192|0,22250);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Nc(h,g,f+88|0)){e=$b(8);x[31721]=0;c=ci(f+236|0,c,d);a=x[31721];x[31721]=0;r:{s:{t:{if((a|0)!=1){x[31721]=0;S(1019,f+96|0,18241,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break t}mc(e,f+96|0);a=0;x[31721]=0;S(100,e|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(c);if(!a){break c}}ic(e);break c}b=oc(f+184|0,12421);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Nc(h,g,f+80|0)){b=oc(f+176|0,5601);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Nc(c,d,f+32|0)){x[a+52>>2]=0;break e}b=oc(f+168|0,11285);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Nc(c,d,f+24|0)){x[a+52>>2]=1;break e}b=oc(f+160|0,9206);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(Nc(c,d,f+16|0)){x[a+52>>2]=2;break e}e=$b(8);x[31721]=0;c=ci(f+236|0,c,d);a=x[31721];x[31721]=0;u:{v:{w:{if((a|0)!=1){x[31721]=0;S(1019,f+96|0,14601,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break w}mc(e,f+96|0);a=0;x[31721]=0;S(100,e|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break v}b=N()|0;break u}b=N()|0;a=1}tb(c);if(!a){break c}}ic(e);break c}b=oc(f+152|0,11522);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Nc(h,g,f+72|0)){break e}b=oc(f+144|0,15616);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{if(Nc(c,d,f- -64|0)){break x}b=oc(f+136|0,15627);e=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=e;b=1;if(Nc(c,d,f+56|0)){break x}b=oc(f+128|0,12695);e=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=e;b=2;if(Nc(c,d,f+48|0)){break x}b=oc(f+120|0,9270);e=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=e;b=3;if(Nc(c,d,f+40|0)){break x}a=$b(8);x[31721]=0;c=P(37,f+96|0,11558)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=KM(b),x[j+116>>2]=k;if(!oz(f+96|0,a+24648|0)){break e}uA(a,f+96|0)}fb=f+256|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Ub(c,4);while(1){if(Bv(x[c>>2],x[c+8>>2])){break b}m=fb-288|0;fb=m;f=kU(m+6|0);h=fb-368|0;fb=h;k=yc(f,kU(h+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;j=fc(g+8|0,g+28|0,4);i=x[j>>2];jc(g+20|0,x[c>>2],x[c+8>>2],i,x[j+4>>2]);j=x[g+24>>2]==4&x[g+28>>2]==1399285583;if(j){Ub(c,4)}fb=g+32|0;c:{d:{e:{f:{g:{if(j){lU(c,4);j=E$(h+60|0,c);x[31721]=0;g=P(794,j|0,k|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break g}h:{if(!g){break h}g=x[j+8>>2];i=x[j>>2];l=y[k+26|0];x[31721]=0;g=U(795,i|0,g|0,l|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break g}if(!g){break h}g=0;i:{while(1){if(y[k+26|0]<=f>>>0){i=x[j+8>>2];l=x[j>>2];f=0;x[31721]=0;n=i;i=g&65535;g=U(795,l|0,n|0,i|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break e}if(!g){break h}x[31721]=0;O(796,j|0,i|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}lU(j,mU(k));f=qc(h+56|0);g=h+80|0;zB(g);x[31721]=0;O(797,j|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){w[h+102>>1]=0;w[h+104>>1]=0;f=iU(f,h+80|0,h+107|0);g=y[k+26|0];x[31721]=0;O(796,j|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){break i}}f=N()|0;break d}x[31721]=0;i=R(798,j|0)|0;l=x[31721];x[31721]=0;if((l|0)!=1){v[(f+k|0)+27|0]=i;f=f+1|0;g=g+i|0;continue}break}f=N()|0;break d}n=f;f=k+27|0;g=iU(n,f,f+y[k+26|0]|0);x[31721]=0;S(799,h+36|0,j|0,i|0);f=x[31721];x[31721]=0;if((f|0)==1){break f}f=0;x[31721]=0;O(578,h+16|0,h+36|0);i=x[31721];x[31721]=0;if((i|0)==1){f=N()|0;ub(h+36|0);break d}n=h+16|0;PF(h+8|0,n);i=wb(x[h+8>>2]);o=Vk(x[h+8>>2],x[h+12>>2]);l=fb-16|0;fb=l;x[l+12>>2]=i;while(1){if(Ib(i,o)){gU(g,y[i|0]);i=x[je(l+12|0)>>2];continue}else{fb=l+16|0}break}Ic(n);ub(h+36|0);if(x[g>>2]!=(y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24))){break h}f=mU(k);x[31721]=0;O(796,c|0,f|0);g=x[31721];x[31721]=0;f=1;if((g|0)==1){break e}}ub(j)}fb=h+368|0;break c}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(j);Q(f|0);p()}fb=m+288|0;if(f){continue}break}}vc(c);ag(b,a,c);a=1;break a}v[d|0]=1;vc(c);f=Mg(c);d=e+136|0;ce(d,c,hf(c));g=hc(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31721]=0;O(578,d|0,g|0);b=x[31721];x[31721]=0;j:{k:{l:{m:{if((b|0)!=1){c=Se(e+136|0);d=x[e+136>>2];h=IC(c,qh(d),e+132|0,e+128|0);x[31721]=0;b=x[e+132>>2];P(186,g|0,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){if(!h){break j}Bh(a);k=b+c|0;b=d-b|0;d=x[e+128>>2];c=0;while(1){n:{if(d){if(!b|(d|0)!=1){break k}d=x[a>>2];if(d>>>0>c>>>0){break n}break k}d=x[a>>2];if(d>>>0<=c>>>0){break k}}if(!ge(d,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;j=aY(h,k,qh(b),e+124|0,e+116|0,e+120|0);x[31721]=0;P(186,g|0,j|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}xi(e+120|0,qh(x[a>>2]-c|0));d=x[e+120>>2];o:{if((d|0)<=0){break o}f=x[e+124>>2];m=z[a+34>>1];if((Yd(m)|0)!=(f|0)){break o}i=D(c,f);l=x[a+20>>2];if(m&1){x[e+112>>2]=d;x[e+100>>2]=d;x[e- -64>>2]=d;x[e+48>>2]=d;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=l+(i<<1);x[31721]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(579,e+56|0,e+40|0);f=x[31721];x[31721]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=d;x[e+76>>2]=d;x[e+32>>2]=d;x[e+16>>2]=d;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=i+l;x[31721]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(580,e+24|0,e+8|0);f=x[31721];x[31721]=0;if((f|0)==1){break m}}b=b-j|0;k=j+k|0;c=c+d|0;d=$X(h);continue}}break m}c=N()|0;break l}c=N()|0;Ic(e+136|0)}ub(g);Q(c|0);p()}_X(h)}Ic(e+136|0);ub(g);a=(h|0)!=0}fb=e+176|0;return a|0}function r7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;ad(h,x[d+28>>2]);x[31721]=0;i=R(28,x[h>>2])|0;j=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Yb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Yb(h);Q(a|0);p()}OJ(a,f+24|0,h+12|0,c,e,i);break b}NJ(a,f+16|0,h+12|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=tk(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=tk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=tk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(ph(a,b+12|0)){break H}c=tl(x[a>>2]);if(!Ff(x[i+8>>2],1,c)){break H}Cm(a);continue}break}if(ph(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Zs(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[111752]|y[111753]<<8|(y[111754]<<16|y[111755]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[111749]|y[111750]<<8|(y[111751]<<16|y[111752]<<24);x[h>>2]=y[111745]|y[111746]<<8|(y[111747]<<16|y[111748]<<24);x[h+4>>2]=g;k=h,l=tk(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[111760];x[h>>2]=y[111756]|y[111757]<<8|(y[111758]<<16|y[111759]<<24);k=h,l=tk(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=tk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=tk(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}MJ(f+20|0,h+12|0,c,e,i);break b}a=nj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;L:{M:{if(ph(c,a+12|0)){break M}b=4;if((ll(i,tl(x[c>>2]))|0)!=37){break M}b=2;if(!ph(Cm(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function ok(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);c=j(1)|0;e=j(0)|0;a:{b:{g=c;p=c&2147483647;c:{if(!(p|e)){break c}o(+a);c=j(1)|0;f=j(0)|0;if(!f&(c|0)==1072693248){break c}q=c&2147483647;t=f;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(f|0)!=0|p>>>0>2146435072)&(!e|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}f=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-f|0;f=e>>>m|0;r=0;if((e|0)!=f<<m){break i}r=2-(f&1)|0}m=r;if(e){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(e){break f}f=1043-f|0;e=p>>>f|0;if((p|0)!=e<<f){break g}m=2-(e&1)|0}if((p|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?Infinity:0}return(g|0)>0?Infinity:0}if(q>>>0<=1072693246){return(g|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;e=q>>>0<1048576;d=e?a:d;o(+a);c=j(1)|0;j(0)|0;m=e?c:q;f=m&1048575;c=f|1072693248;m=(m>>20)+(e?-1076:-1023)|0;e=0;n:{if(f>>>0<235663){break n}if(f>>>0<767610){e=1;break n}c=f|1071644672;m=m+1|0}f=((e<<18)+(c>>>1|0)|0)+537395200|0;e=e<<3;w=C[e+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[e+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,f|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[e+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,g|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);c=j(1)|0;g=j(0)|0;o:{if((c|0)>=1083179008){if(g|c-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((c&2147482624)>>>0<1083231232){break o}if(g|c+1064252416){break a}if(!(d<=a-b)){break o}break a}e=0;f=c&2147483647;if(f>>>0>=1071644673){g=c+(1048576>>>(f>>>20|0)-1022|0)|0;f=g>>>20&2047;e=(g&1048575|1048576)>>>1043-f|0;e=(c|0)<0?0-e|0:e;l(0,0);l(1,g&-1048576>>f-1023);b=b-+n();o(+(d+b));c=j(1)|0;j(0)|0}l(0,0);l(1,c|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(e<<20)+c|0;p:{if((c|0)<=1048575){a=nk(a,e);break p}l(0,g|0);l(1,c|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function HR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;a:{b:{c:{if(!Sc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[i+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];g=i+14|0;c=w[g>>1];if((e|0)<=(c|0)){if((c|0)<=(nc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=_z(c,g);if(!Vg(d,Kf(c))){break f}om(a,rd(d)+4|0);break d}c=Zz(c,e<<16>>16);w[b+62>>1]=c;e=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;f=_z(a,b+62|0);t:{if(Vg(f,Kf(a))){x[31721]=0;O(132,e|0,rd(f)+4|0);a=x[31721];x[31721]=0;if((a|0)==1){break t}a=w[d+30>>1];c=w[g>>1];x[31721]=0;m=b,n=Yz(c,a)+5|0,x[m+36>>2]=n;O(129,b+48|0,b+36|0);a=x[31721];x[31721]=0;u:{if((a|0)!=1){x[31721]=0;P(77,e|0,b+48|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break u}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31721]=0;c=U(545,b+36|0,1,c+65<<24>>24)|0;a=x[31721];x[31721]=0;if((a|0)==1){break s}x[31721]=0;S(605,b+48|0,0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}a=b+48|0;f=yb(e,a);tb(a);tb(c);x[31721]=0;P(130,f|0,14624)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(c);break g}x[31721]=0;f=c;a=c<<16>>16;c=(a|0)/16|0;x[b+32>>2]=f-(c<<4)<<16>>16;O(886,b+36|0,b+32|0);f=x[31721];x[31721]=0;if((f|0)==1){break o}x[31721]=0;x[b+16>>2]=(c<<16>>16)%16;O(886,b+20|0,b+16|0);c=x[31721];x[31721]=0;if((c|0)==1){break n}x[31721]=0;S(2,b+48|0,b+36|0,b+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break m}c=b+48|0;h=yb(e,c);tb(c);tb(b+20|0);tb(b+36|0);if((a|0)<256){break p}x[31721]=0;O(887,b+4|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break k}j=b+36|0;f=b+4|0;c=xd(f);k=zf(f);l=xd(f);a=fb-16|0;fb=a;x[a+8>>2]=l;x[a+12>>2]=c;while(1){if(Ib(c,k)){m=x[a+8>>2],n=yq(v[c|0]),v[m|0]=n;c=je(a+12|0);je(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;Zc(j,f);x[31721]=0;S(605,b+48|0,0,j|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}a=b+48|0;yb(h,a);tb(a);tb(b+36|0);tb(b+4|0)}a=w[d+30>>1];c=w[g>>1];x[31721]=0;m=b,n=Yz(c,a)+5|0,x[m+20>>2]=n;O(129,b+48|0,b+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break i}x[31721]=0;P(77,e|0,b+48|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break h}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}break a}f=fb-16|0;fb=f;e=f+4|0;d=fb-32|0;fb=d;c=of(d+20|0,1,0);v:{w:{x:{while(1){h=Jb(c);fs(d+12|0,h,Bb(x[c+4>>2],y[c+11|0])+h|0,w[g>>1]);if(!x[d+16>>2]){break x}h=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,h|0);h=x[31721];x[31721]=0;if((h|0)!=1){continue}break}break w}g=x[d+12>>2];h=Jb(c);x[31721]=0;O(47,c|0,g-h|0);g=x[31721];x[31721]=0;y:{if((g|0)!=1){x[31721]=0;O(48,e|0,c|0);g=x[31721];x[31721]=0;if((g|0)!=1){break y}break w}break w}tb(c);fb=d+32|0;break v}a=N()|0;tb(c);Q(a|0);p()}Nh(a,e);tb(e);fb=f+16|0}fb=b- -64|0;break b}d=x[b>>2];b=fb-32|0;fb=b;z:{if(El(c)){x[b+16>>2]=x[7624];d=x[7623];x[b+8>>2]=x[7622];x[b+12>>2]=d;d=x[7621];x[b>>2]=x[7620];x[b+4>>2]=d;rc(a,(b+(c<<2)|0)-1004|0);break z}if(Sc(c)){e=Fb(b);x[31721]=0;c=c-1|0;g=(c|0)/12|0;c=P(888,e|0,d+(D(g,-12)+c<<16>>16<<2)|0)|0;d=x[31721];x[31721]=0;A:{if((d|0)==1){break A}x[31721]=0;c=P(889,c|0,g+48&255)|0;d=x[31721];x[31721]=0;if((d|0)==1){break A}x[31721]=0;P(3,a|0,c|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break A}tb(c);break z}a=N()|0;break a}if(!c){rc(a,16770);break z}rc(a,14595)}fb=b+32|0}fb=i+16|0;return}tb(e);Q(a|0);p()}function rS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=a+1074376|0;h=D(b,872);f=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Oj(x[f+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;f=z[(d<<1)+31696>>1];x[b+1075696>>2]=f;d=b+1075692|0;if(!x[d>>2]){break a}l=d,m=uh(a,y[b+1075789|0],c,f),x[l>>2]=m;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Kb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Kb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Kb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=a+906300|0;j=b+1|0;k=d-1|0;while(1){if((c|0)==(h|0)){break a}f=D(c,872)+a|0;c:{if(z[f+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:zo(a,f+1074992|0);if(!(y[f+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!yd(d)){break d}zk(d,c&65535);break d;case 1:g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!yd(d)){break d}zk(d,c&65535);break d;default:break e}}x[f+1075688>>2]=0;g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!yd(d)){break d}Jj(d,c&65535,1)}d=x[f+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[sd(i,g-1|0)>>2];if(!g){break c}ib[x[x[g>>2]+96>>2]](g,d,y[f+1075789|0]|256,0,b)}c=c+1|0;continue}}SU(f,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}Ym(a,f,d,4);break a;case 8:b=f;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d|0){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(l=Sc(y[b+788|0]),m=1,n=y[b+88|0]&2,n?l:m)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Kb(e+8|0,a+1074312|0,35);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}if(!Sc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[f+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}eB(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Kb(e+8|0,a+1074312|0,30);OA(a,b,d,Hb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}fb=e+16|0}function Qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;vc(b);d=fb-16|0;fb=d;d_(d+8|0,f+102|0);g=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Ub(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(i|0)){break c}if(!f_(f+102|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(e_(y[f+318|0],y[f+319|0]),hb))){break c}if(!c){e=1;break c}Ad(a,2);bg(a);x[a+480188>>2]=524296;t=a,u=Xe(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;Te(d,2,f+133|0);e=f+88|0;Ac(e,d);yb(a+1298308|0,e);tb(e);e=0;d:{e:{while(1){if((e|0)==8){f:{d=Wb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];n=o+1|0;dk(d,b,n,65535,65535);d=Nb(f+88|0);x[31721]=0;S(237,b|0,d|0,n|0);e=x[31721];x[31721]=0;if((e|0)==1){break f}t=f,u=wb(x[d>>2]),x[t+72>>2]=u;e=wb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}je(f+72|0);continue}break}t=a,u=y[vb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];i=y[f+319|0];g=Nb(f+72|0);x[31721]=0;m=i+1|0;S(237,b|0,g|0,m|0);i=x[31721];x[31721]=0;g:{if((i|0)==1){break g}x[31721]=0;i=a+484344|0;O(226,i|0,m|0);h=x[31721];x[31721]=0;if((h|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(m|0)){break e}e=y[vb(x[g>>2],c)|0];x[31721]=0;e=U(199,i|0,e|0,r|0)|0;h=x[31721];x[31721]=0;h:{if((h|0)!=1){if(!e){break e}h=0;k=Vb(x[i>>2],y[vb(x[g>>2],c)|0]);i:while(1){s=h&65535;if(s>>>0>7){break h}h=h+1|0;e=0;while(1){if(A[k+12>>2]<=e>>>0){continue i}x[31721]=0;j=R(200,b|0)|0;l=x[31721];x[31721]=0;j:{k:{if((l|0)!=1){j=j<<24>>24;if((j|0)>=0){break k}e=(j&127)+e|0;break j}break b}l=jd(x[k>>2],x[x[k+48>>2]+12>>2],e,s);if((j|0)==1){v[l|0]=254;break j}if((j-1&255)>>>0>96){break j}v[l+1|0]=h;v[l|0]=j+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{i=f+88|0;d=(f+102|0)+D(e,19)|0;vD(i,d+63|0);g=f+72|0;Ac(g,i);Tk(((e<<5)+a|0)+480289|0,g);tb(g);e=e+1|0;h=D(e,104)+a|0;j=h+484380|0;kd(j,2);v[f+83|0]=0;g=y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+75|0]|y[d+76|0]<<8|(y[d+77|0]<<16|y[d+78|0]<<24);d=y[d+71|0]|y[d+72|0]<<8|(y[d+73|0]<<16|y[d+74|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;Yk(j,1,f+8|0);x[h+484404>>2]=8215;d=f+60|0;Ac(d,i);xc(((e<<5)+a|0)+946304|0,d);tb(d);continue}break}e=N()|0;break a}j=o+1|0;c=a+484376|0;e=0;while(1){l:{if((e|0)==(j|0)){x[31721]=0;b=P(1,f+60|0,8616)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break l}break b}b=Wb(x[a+484360>>2],y[c|0]);k=e&65535;m:{if(!_i(b,k)){x[31721]=0;h=P(370,i|0,r|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}if((h|0)==65535){break m}b=Wb(x[a+484360>>2],y[c|0]);t=Zb(x[b>>2],e),u=h,w[t>>1]=u}b=uD(wb(x[Vb(x[i>>2],z[Zb(x[b>>2],e)>>1])+4>>2]),1);h=y[b+5|0];l=y[vb(x[d>>2],(e+1>>>0)%(n>>>0)|0)|0];if((h|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}h=y[c|0];m=x[a+484360>>2];x[31721]=0;h=P(371,Wb(m,h)|0,k|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break b}if((h|0)==65535){break n}b=uD(wb(x[Vb(x[i>>2],h)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}yb(a+1298344|0,b);tb(b);x[31721]=0;b=P(1,f+48|0,6049)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}yb(a+1298356|0,b);tb(b);b=f+24|0;si(b,2,f+113|0);x[31721]=0;S(372,f+36|0,4,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=f+36|0;yb(a+1298368|0,b);tb(b);t=a+1298404|0,u=x[Ec(b,4)>>2],x[t>>2]=u;cc(g)}cc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;cc(g)}cc(d);Q(e|0);p()}function Tsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=fb-960|0;fb=e;vc(b);d=fb-16|0;fb=d;h=e+862|0;l_(d+8|0,h);f=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Ub(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(g|0);if(!d){k_(h)}a:{if(!d){break a}if(!n_(e+862|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(m_(y[e+909|0]|y[e+910|0]<<8),hb))){break a}if(!c){l=1;break a}Ad(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=e+88|0;f=rc(d,8224);yb(a+1298344|0,f);tb(f);f=rc(d,8912);yb(a+1298356|0,f);tb(f);s=a+1298404|0,t=x[Ec(d,4)>>2],x[s>>2]=t;f=e+12|0;j_(f,e+866|0);Ac(d,f);yb(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[e+958|0]|y[e+959|0]<<8;if(d){RD(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;h=e+88|0;ac(d+8|0,h,771);f=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Ub(b,x[d+12>>2])}fb=d+16|0;l=(f|0)==(g|0);if(!l){Tb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;i_(Wb(x[d>>2],y[f|0]),e+88|0,y[e+345|0]);Ze(Wb(x[d>>2],y[f|0]),y[e+346|0]);bd(b,y[e+909|0]|y[e+910|0]<<8);m=a+484344|0;o=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}I$(b,e+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!wD(b,e+12|0)){break a}d=d+1|0;w[a+480190>>1]=d;Te(e,1,e+12|0);h=e+68|0;Ac(h,e);xc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);c=(D(d,104)+a|0)+484380|0;kd(c,0);i=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[c>>2]=i;f=y[e+50|0]|y[e+51|0]<<8|(y[e+52|0]<<16|y[e+53|0]<<24);x[c+4>>2]=f;g=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+49|0]<<4;if(v[e+58|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+59|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}Wc(h,v[e+58|0]&1?16:8,1,0,0);ag(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+347|0]|y[d+348|0]<<8;if(g){f=e+68|0;ce(f,b,g);i=hc(e+12|0,f);ub(f);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!o){break e}x[31721]=0;d=U(199,m|0,h&65535,n|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}if(!d){break e}x[31721]=0;d=R(200,i|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}x[31721]=0;P(186,i|0,1)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}q=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){if((f|0)!=(n|0)){d=Vb(x[m>>2],h);_e(e+68|0,x[d>>2],x[x[d+48>>2]+12>>2],f);s=e,t=wb(x[e+68>>2]),x[s>>2]=t;r=Yv(x[e+68>>2],x[e+72>>2]);while(1){d=x[e>>2];if(!Ib(d,r)){f=f+1|0;continue f}x[31721]=0;O(360,e+60|0,i|0);g=x[31721];x[31721]=0;if((g|0)==1){break c}j=e+60|0;g=Ye(j);j=cj(j);k=y[e+60|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;s=d,t=y[Hc(e+60|0)|0]+1|0,v[s+1|0]=t}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;g:{h:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break g;case 2:v[d+5|0]=g<<2;break g;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=g<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(g<<2)+4;break g;case 10:v[d+5|0]=g|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+24720|0];qg(e);continue}}break}xe(Vb(x[m>>2],h),Vh(Ve(Le(e+68|0,14,0),q)))}ub(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Ue(h);g=h;h=(e+862|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=e+960|0;return l|0}function L0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-560|0;fb=e;vc(b);d=fb-16|0;fb=d;f=e+63|0;YE(d+8|0,f);g=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Ub(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(j|0);if(!d){XE(f)}a:{if(!d){break a}if(!_E(e+63|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(ZE(y[e+173|0],y[e+174|0]),hb))){break a}Ad(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=e+36|0;g=rc(d,14637);yb(a+1298344|0,g);tb(g);g=rc(d,14670);yb(a+1298356|0,g);tb(g);_h(a+1298368|0,(y[e+63|0]|y[e+64|0]<<8)==26217?14637:14665);o=a+1298404|0,p=x[Ec(d,4)>>2],x[o>>2]=p;f=y[e+173|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=fb-16|0;fb=f;d=e+36|0;ac(f+8|0,d,25);l=x[f+12>>2];jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){Ub(b,x[f+12>>2])}fb=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+49|0]|y[e+50|0]<<8|(y[e+51|0]<<16|y[e+52|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;kd(f,0);x[f+24>>2]=8363;l=e+36|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[f+8>>2]=d;c:{if(!(k|d>>>0<=i>>>0)){x[f+8>>2]=0;break c}if(d){w[f+34>>1]=2;Zk(f)}}f=e+12|0;hk(f,2,l);d=e+24|0;Ac(d,f);xc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+65|0;rg(g,3,h,36);d=e+36|0;Ac(d,g);yb(a+1298308|0,d);tb(d);g=0;WE(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;tw(Wb(x[d>>2],y[h|0]),e+176|0,128,255,254);d=Wb(x[d>>2],y[h|0]);h=y[e+175|0];if(z[Zb(x[d>>2],h)>>1]<y[e+174|0]){Ze(d,h)}while(1)if((g|0)==8){j=a+484344|0;Of(j,y[e+174|0]);n=c&1;f=0;while(1)if(y[e+174|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Wc(e+36|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}ag(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{d:{e:{if(n){if(Kg(j,f&65535,64)){break e}}Ub(b,1536);break d}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;f:while(1){if((l|0)==64){d=(e+63|0)+f|0;g=y[d+369|0];if(g>>>0<63){xe(Vb(x[j>>2],f),Vh(Ve(Le(e+36|0,14,0),g)))}xe(Vb(x[j>>2],f),Vh(Le(e+36|0,16,y[d+241|0])));break d}g=0;d=Vb(x[j>>2],f);h=jd(x[d>>2],x[x[d+48>>2]+12>>2],l,0);while(1){if((g|0)==8){l=l+1|0;continue f}d=e+36|0;Hr(d,b);i=Hc(d);k=Ye(d);i=y[i|0];d=y[e+36|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+36|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;g:{h:{if(!(d&15)&(d|0)!=48){break h}k=y[i|0];if((k|0)==255){break g}m=k<<24>>24;d=m&15;v[h+5|0]=d;i:{if((m|0)<0){break i}k=k>>>4|0;v[h+3|0]=y[k+24520|0];j:{switch(k-3|0){case 0:v[h+5|0]=d|32;break h;case 1:v[h+5|0]=d|m<<4;break g;case 2:break h;case 3:break j;default:break g}}k:{switch(d|0){case 0:v[h+5|0]=79;break g;case 1:break k;default:break i}}v[h+5|0]=244;break g}v[h+3|0]=0;break g}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Ue(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}fb=e+560|0;return h|0}function LA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;f=fb-16|0;fb=f;m=D(b,872)+a|0;n=m+1075800|0;i=y[n|0];k=a+1074312|0;Kb(f+8|0,k,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[n|0]=h;break i}e=y[n|0];if(e){g=e-1|0;v[n|0]=g;e=0;if(g&255){break c}}v[n|0]=h;e=1;break c}Kb(f+8|0,k,52);g=c&256;if(!(!g|!Hb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){i=sZ(y[e+1075780|0])?1:i}if(y[(D(b,872)+a|0)+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Sc(y[(D(b,872)+a|0)+1075780|0])){break c}break d}j=x[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h>>>0<=1?1:h)>>>0)|0:1);i=i+1|0;break c}if((j|0)==16){break g}if((j|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Sc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h>>>0<=1?1:h;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break k}e=0;i=j&1048580?0:i}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Kb(f+8|0,k,52);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=m+1074992|0;q=(D(b,872)+a|0)+1075068|0;l:{if(x[q>>2]){break l}Kb(f+8|0,k,38);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!Gj(x[h+656>>2])){break a}}Kb(f+8|0,k,106);if(C=0,E=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),F=x[(D(b,872)+a|0)+1075688>>2],F?C:E){break a}if(e){j=D(b,872)+a|0;r=j+1075680|0;g=x[r>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[j+1075080>>2];break m}Kb(f+8|0,k,52);n:{if(C=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),E=0,F=y[(D(b,872)+a|0)+1075782|0]==1,F?C:E){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+32112|0])|0)/16;break n}x[f+4>>2]=g+(v[e+32128|0]<<2)}Ee(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}l=D(b,872)+a|0;s=l+1075692|0;t=x[s>>2];g=y[l+1075794|0];j=0;if(e&512){Kb(f+8|0,k,108);j=Hb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[q>>2]|(g-1&255)>>>0>119))){xS(a,b,0,g,1)}o:{if(!(x[a+480180>>2]&1048580)){m=0;break o}m=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}m=1;Fo(a,h,e,0,0,1)}l=l+1075080|0;Kb(f+8|0,k,85);p:{if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=D(b,872)+a|0;o=y[e+1075781|0];if(!o){break p}e=e+1075764|0;p=z[e>>1];Fo(a,h,o,0,0,1);w[e>>1]=p}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];B=x[l>>2];x[p>>2]=0;Kb(f+8|0,k,23);e=1;q:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break q}e=0;if(x[a+480180>>2]!=2){break q}e=(j^1)&x[q>>2]!=0}Bu(a,h,g,e,m,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(B&4096)|x[a+480180>>2]!=4)){x[l>>2]=x[l>>2]|4096}j=o+1075780|0;x[r>>2]=x[f+4>>2];if(z[a+480192>>1]){v[j|0]=g;vS(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[j|0]|!t))){x[s>>2]=t}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;r:{if(d-11>>>0<4294967286){break r}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break r}s:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break s}j=(D(b,872)+a|0)+1075656|0;b=x[xb(g+68|0,d-2|0)>>2];x[j>>2]=b}Eo(a,h,b)}i=e?i:0}a=f+8|0;Kb(a,k,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Kb(a,k,23);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}i=(Hb(b,d)&c>>>8)+i|0}v[n|0]=i}fb=f+16|0}function Es(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Ff(x[d+8>>2],1,v[f|0])){x[31721]=0;O(118,g|0,32);a=x[31721];x[31721]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Ff(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31721]=0;x[e>>2]=0;a=ea(1364,e+4|0,h|0,k|0,j|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31721]=0;O(118,g|0,37);c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;O(118,g|0,((a|0)<84?65:97)|0);a=x[31721];x[31721]=0;if((a|0)!=1){break q}break c}x[31721]=0;x[e+4>>2]=f;a=ea(1364,e+4|0,h|0,j|0,i|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31721]=0;O(118,g|0,37);f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;O(118,g|0,((a|0)<144?66:98)|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}if(m){break q}if(!Ff(x[d+8>>2],64,v[bc((D(c,12)+b|0)+172|0,0)|0])){break q}n=nz(g),o=109,v[n|0]=o;break q}if((Bb(x[b+464>>2],y[b+471|0])|0)==(0-Bb(x[b+476>>2],y[b+483|0])|0)){break p}x[31721]=0;x[e+4>>2]=f;a=ea(1364,e+4|0,h|0,i|0,l|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;O(118,g|0,112);a=x[31721];x[31721]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Ff(x[d+8>>2],64,a)){x[31721]=0;a=ba(1365,e+8|0,h|0,e|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31721]=0;O(118,g|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;O(118,g|0,37);break u}x[31721]=0;O(118,g|0,a|0)}a=x[31721];x[31721]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=89;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=106;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=121;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=83;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=77;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=100;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=72;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=109;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=73;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=117;break d}x[31721]=0;O(118,g|0,37);a=x[31721];x[31721]=0;c=119}if((a|0)==1){break c}x[31721]=0;O(118,g|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function Go(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=xB(x[a+24>>2],y[a+32|0]);t=Lj(r);c=t;e=x[a>>2];d=Rd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=fb-32|0;fb=k;d=c-d|0;c=x[Ab(a)>>2];e=x[a+4>>2];b:{if(d>>>0<=(c-e|0)/12>>>0){e=fb-16|0;fb=e;c=fv(e+4|0,a,d);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){gc(c);fb=e+16|0}else{FT(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}c=Ab(a);c=vm(k+12|0,Ep(a,Rd(x[a>>2],e)+d|0),Rd(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;d=cW(g+4|0,c+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){FT(e);e=x[d>>2]+12|0;x[d>>2]=e;continue}break}ee(d);fb=g+16|0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);j=zb(e+8|0,x[a>>2]);i=zb(e+4|0,x[c+4>>2]);g=x[d>>2];m=x[j>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[i>>2];x[d+12>>2]=g;while(1){j=x[d+8>>2];if(Pg(g,m)){iC(lx(j),Pn(g));g=um(d+12|0);um(d+8|0);g=x[g>>2];continue}break}fb=d+16|0;x[c+4>>2]=j;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),zc(c));x[c>>2]=x[c+4>>2];fb=e+16|0;d=x[c+4>>2];while(1){e=x[c+8>>2];if((e|0)!=(d|0)){e=e-12|0;x[c+8>>2]=e;yf(e);continue}break}d=x[c>>2];if(d){hs(c);Db(d)}}fb=k+32|0;break a}if(c>>>0<d>>>0){MT(a,e+D(c,12)|0)}}if(b){c=a+12|0;zq(c,ae(c));A=Ab(c),B=0,x[A>>2]=B;h=c;c=dc(c);x[h>>2]=c;x[c>>2]=0;x[a+28>>2]=0}k=Nb(f+52|0);c=x[a+24>>2];c=Iu(x[c+484344>>2],x[c+484348>>2]);x[31721]=0;j=U(629,f+40|0,c|0,28572)|0;c=x[31721];x[31721]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((l|0)==(t|0)){ld(j);cc(k);fb=f- -64|0;return}c=x[a+24>>2];h=x[c+484344>>2];c=x[c+484348>>2];m=z[Zb(x[r>>2],l)>>1];d=RT(h,c,m);x[f+36>>2]=d;c=Dd(x[a>>2],l);d:{e:{f:{if(b){x[31721]=0;v[f+20|0]=0;S(808,c|0,d|0,f+20|0);d=x[31721];x[31721]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31721]=0;O(762,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!_i(r,l&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];s=x[Gb(f+20|0,f+36|0)>>2];o=Kf(g);c=z[Zb(x[j>>2],m)>>1];if((c|0)!=65535){d=PT(g,z[_m(f+20|0,c,s)>>1],x[f+24>>2]);g:{if(Vg(d,Kf(g))){c=PT(g,z[_m(f+20|0,z[Zb(x[j>>2],m)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Kf(g)}x[f+32>>2]=d;while(1){h:{if(!Vg(d,c)){break d}e=Nb(f+20|0);d=Mn(rd(d)+8|0);x[31721]=0;O(809,e|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=Ec(f+12|0,o);i=_m(f+4|0,l,x[rd(x[f+32>>2])+4>>2]);d=x[d>>2];x[31721]=0;d=ba(810,g|0,d|0,i|0,e|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break h}x[f+16>>2]=d;o=x[Yg(f+16|0)>>2];ze(e);d=x[Yg(f+32|0)>>2];continue}}break}d=N()|0;ze(e);break e}q=Vb(x[x[a+24>>2]+484344>>2],m);c=Nf(x[x[q+48>>2]+12>>2]);x[31721]=0;v[f+20|0]=0;S(783,k|0,c|0,f+20|0);c=x[31721];x[31721]=0;if((c|0)!=1){n=x[f+36>>2];i:while(1){j:{if((n|0)==(s|0)){if(s){break d}A=Zb(x[j>>2],m),B=l,w[A>>1]=B;break d}c=1;i=0;e=x[x[q+48>>2]+12>>2];n=n-1|0;d=jd(x[q>>2],e,n,0);while(1){if(c>>>0<16&Nf(e)>>>0>i>>>0){u=vb(x[k>>2],i);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:h=y[d+5|0];if((h&240)==176){break l}break k;case 0:break m;default:break k}}h=y[d+5|0];if((h&240)!=96){break k}}v[u|0]=h&15;h=y[vb(x[k>>2],i)|0];e=h?h:e}h=c;c=e&255;c=D(h,c?c+1|0:1);d=d+6|0;i=i+1|0;e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31721]=0;O(809,e|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break n}c=Ec(f,o);d=_m(f+4|0,l,n);c=x[c>>2];x[31721]=0;o=ba(810,g|0,c|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break j}ze(e);continue i}}break}}break}d=N()|0;ze(e);break e}d=N()|0}ld(j);break c}l=l+1|0;continue}}d=N()|0}cc(k);Q(d|0);p()}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=fb-48|0;fb=h;vc(b);n=Xd(b);a:{if((n-5&255)>>>0<253){break a}if(!Mb(x[b>>2],x[b+8>>2],4355)){break a}g=1;while(1){if((g&65535)>>>0<=256){d=h+32|0;QD(b,d);if(!eV(d,n)){break a}e=0;d=fb-32|0;fb=d;j=y[h+43|0];m=y[h+41|0]|y[h+42|0]<<8;v[d+14|0]=0;v[d+18|0]=j;w[d+16>>1]=m;w[d+12>>1]=0;while(1){if((e|0)!=3){j=y[vb(d+16|0,e)|0];q=vb(d+12|0,e),r=j,v[q|0]=r;e=e+1|0;continue}break}j=$f(d+12|0);m=y[h+40|0];o=y[h+38|0]|y[h+39|0]<<8;e=0;v[d+10|0]=0;v[d+26|0]=m;w[d+24>>1]=o;w[d+8>>1]=0;while(1){if((e|0)!=3){m=y[vb(d+24|0,e)|0];q=vb(d+8|0,e),r=m,v[q|0]=r;e=e+1|0;continue}break}e=$f(d+8|0);fb=d+32|0;f=e>>>0<j>>>0?g:f;g=g+1|0;continue}break}if(!(f&65535)){break a}b:{if(!c){break b}Ad(a,1);w[a+480190>>1]=f;x[a+480228>>2]=(n|0)==3?192:48;x[a+480208>>2]=x[a+480208>>2]&-25165825|16777216;bd(b,1);m=f+1|0;o=m&65535;g=1;while(1)if((g|0)==(o|0)){bd(b,4097);dk(Wb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);g=Xd(b);if(g>>>0>31){break a}w[a+480188>>1]=g+1;g=Xd(b);d=z[a+480188>>1];f=g+1|0;if(!Mb(x[b>>2],x[b+8>>2],D(D(d,f),384)+d|0)){break a}while(1)if(z[a+480188>>1]<=k>>>0){d=a+484344|0;Of(d,f);j=c&1;k=0;while(1){c:{if((f|0)!=(k|0)){d:{if(j){if(Kg(d,k&65535,64)){break d}}Ub(b,D(z[a+480188>>1],384));break c}o=Ig(h+32|0);g=Vb(x[d>>2],k);q=h,r=wb(x[g>>2]),x[q+16>>2]=r;i=wb(x[g+4>>2]);while(1){g=x[h+16>>2];if(!Ib(g,i)){break c}e=h+20|0;q_(e,b);e=y[vb(e,0)|0];if((e-1&255)>>>0<=76){v[g|0]=e+36}e=h+20|0;q=g,r=y[vb(e,1)|0],v[q+1|0]=r;e:{if(!dV(g,y[vb(e,2)|0],y[vb(e,5)|0],n)){break e}e=h+20|0;if(!dV(o,y[vb(e,3)|0],y[vb(e,4)|0],n)){break e}e=y[h+35|0];if(e){un(h+14|0,g,y[g+3|0],y[g+5|0],e,y[h+37|0])}qg(h+16|0);continue}break}k=0;break a}f:{if(!(c&2)){break f}c=m&65535;g=1;while(1){if((c|0)==(g|0)){break f}f=D(g,104)+a|0;ag(Wc(h+32|0,w[f+484414>>1]&1?16:8,1,0,0),f+484380|0,b);g=g+1|0;continue}}_h(a+1298344|0,14170);_h(a+1298356|0,11136);qf(a+1298368|0);q=a+1298404|0,r=x[Ec(h+32|0,4)>>2],x[q>>2]=r;break b}k=k+1|0;continue}}else{g=(k<<5)+a|0;Ue(g+480280|0);q=g+480284|0,r=D(Xd(b),17),w[q>>1]=r;k=k+1|0;continue}}else{e=h+32|0;QD(b,e);d=0;f=fb-16|0;fb=f;j=(D(g,104)+a|0)+484380|0;kd(j,1);i=y[e+11|0];l=y[e+9|0]|y[e+10|0]<<8;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=l;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[vb(f+8|0,d)|0];q=vb(f+4|0,d),r=i,v[q|0]=r;d=d+1|0;continue}break}i=$f(f+4|0);l=y[e+8|0];p=y[e+6|0]|y[e+7|0]<<8;d=0;v[f+2|0]=0;v[f+10|0]=l;w[f+8>>1]=p;w[f>>1]=0;while(1){if((d|0)!=3){l=y[vb(f+8|0,d)|0];q=vb(f,d),r=l,v[q|0]=r;d=d+1|0;continue}break}q=j,r=i-$f(f)|0,x[q>>2]=r;i=y[e+2|0];l=y[e|0]|y[e+1|0]<<8;d=0;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=l;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[vb(f+8|0,d)|0];q=vb(f+4|0,d),r=i,v[q|0]=r;d=d+1|0;continue}break}q=j,r=$f(f+4|0)+1|0,x[q+4>>2]=r;i=y[e+5|0];l=y[e+3|0]|y[e+4|0]<<8;d=0;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=l;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[vb(f+8|0,d)|0];q=vb(f+4|0,d),r=i,v[q|0]=r;d=d+1|0;continue}break}q=j,r=$f(f+4|0)+1|0,x[q+8>>2]=r;d=y[e+13|0];i=d>>>2|0;i=z[j+34>>1]&-7|i&2|i&4;w[j+34>>1]=i;if(d&4){w[j+34>>1]=i|1;x[j>>2]=x[j>>2]>>>1}w[j+30>>1]=y[e+12|0];if((n|0)!=2){x[j+24>>2]=y[e+14|0]|y[e+15|0]<<8}cV(j);fb=f+16|0;f=Cc(h+20|0,22250);xc(((g<<5)+a|0)+946304|0,f);tb(f);g=g+1|0;continue}}k=1}fb=h+48|0;return k|0}function Oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-96|0;fb=e;g=a+140|0;Yj(e+76|0,g,1296125513);x[31721]=0;f=R(175,x[e+76>>2])|0;h=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Fb(e+28|0);x[31721]=0;h=R(157,x[e+76>>2])|0;i=x[31721];x[31721]=0;if((i|0)==1){break p}x[31721]=0;S(819,e+76|0,f|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break p}h=z[a+174>>1];x[31721]=0;S(820,e- -64|0,h|0,f|0);h=x[31721];x[31721]=0;if((h|0)==1){break o}x[31721]=0;S(821,e+4|0,c|0,e- -64|0);c=x[31721];x[31721]=0;if((c|0)==1){break n}c=e+4|0;xc(d,c);tb(c);tb(e- -64|0);tb(f)}if(y[a+176|0]){x[31721]=0;O(822,e+28|0,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}c=e+28|0;ye(b+43|0,c);tb(c)}x[31721]=0;S(814,e+28|0,g|0,1413894985);c=x[31721];x[31721]=0;if((c|0)==1){break l}x[31721]=0;f=R(823,e+28|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}g=e+28|0;ub(g);c=a+40|0;vc(c);x[31721]=0;g=P(824,c|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break j}if(g){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31721]=0;g=P(825,c|0,e+4|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break i}if(!g){break q}mR(e+4|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[31721]=0;c=P(825,c|0,e+4|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break i}if(c){mR(e+4|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;Zk(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31721]=0;c=P(682,c|0,7)|0;f=x[31721];x[31721]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;vc(c);x[31721]=0;c=P(826,c|0,e+4|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31721]=0;c=R(175,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break j}if(!c){break f}x[31721]=0;h=a+120|0;c=R(154,h|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[e+64>>2]=c;uc(e- -64|0,9);f=b+68|0;g=x[e+64>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[31721]=0;O(827,h|0,e+4|0);i=x[31721];x[31721]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);j=xb(f,c),k=i,x[j>>2]=k;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Mz(f+(g<<2)|0,kZ(f),41124)}c=a+80|0;vc(c);x[31721]=0;f=P(828,c|0,e+4|0)|0;g=x[31721];x[31721]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;j=b,k=z[Lc(e- -64|0,e+2|0)>>1],w[j+28>>1]=k;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;j=b,k=z[Lc(e- -64|0,e+2|0)>>1],w[j+30>>1]=k;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;j=b,k=z[Lc(e- -64|0,e+2|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31721]=0;a=U(153,a|0,f|0,32)|0;f=x[31721];x[31721]=0;if((f|0)==1){break s}if(!a){break b}x[31721]=0;O(829,c|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break s}x[31721]=0;a=R(205,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break s}x[31721]=0;S(830,c|0,b+43|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function Boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-176|0;fb=e;vc(b);a:{if(!wD(b,e+128|0)){break a}if(!xW(e+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(wW(y[e+159|0],y[e+161|0]),hb))){break a}b:{if(!c){break b}Ad(a,256);g=e+16|0;si(g,2,e+128|0);d=e+48|0;Ac(d,g);yb(a+1298308|0,d);tb(d);f=rc(d,15326);yb(a+1298344|0,f);tb(f);d=rc(d,10120);yb(a+1298356|0,d);tb(d);dg(g,4271);x[31721]=0;O(252,e+116|0,e+159|0);d=x[31721];x[31721]=0;c:{d:{if((d|0)!=1){x[31721]=0;V(704,e+48|0,e+16|0,e+158|0,e+116|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=e+48|0;yb(a+1298368|0,d);tb(d);tb(e+116|0);Eb(e+16|0);o=a+1298404|0,q=x[Ec(d,4)>>2],x[o>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);f=y[e+160|0];d=y[e+159|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=gC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;f=0;if(d>>>0>=11){v[e+48|0]=64;o=a,q=y[Sb(e+162|0,e+48|0)|0]<<2,x[o+480200>>2]=q}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){lr(b,e+16|0);d=y[e+28|0];if(d?(d|0)!=46:0){break c}i=fb-32|0;fb=i;d=(D(f,104)+a|0)+484380|0;kd(d,0);j=i+8|0;k=e+16|0;g=k;Mk(j,2,g);h=i+20|0;Ac(h,j);ye(d+43|0,h);tb(h);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[i+20|0]=y[g+22|0];v[i+8|0]=64;o=d,q=y[Sb(h,j)|0]<<2,w[o+30>>1]=q;h=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=h;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(h>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|h>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Gb(d+8|0,d)>>2],x[o+8>>2]=q}fb=i+32|0;g=e+4|0;Mk(g,2,k);d=e+116|0;Ac(d,g);xc(((f<<5)+a|0)+946304|0,d);tb(d);w[((f<<1)+e|0)+46>>1]=y[e+30|0]|y[e+31|0]<<8;f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;dk(Wb(x[d>>2],y[g|0]),b,y[e+159|0]?128:64,65535,65535);f=0;if(!uW(Wb(x[d>>2],y[g|0]))){break a}m=c&1;if(m){Of(a+484344|0,y[e+161|0])}h=a+484344|0;while(1)if(y[e+161|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Wc(e+16|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+46>>1];if(d>>>0<4){break f}if(!bd(b,d<<4)){break f}ag(c,g,b)}f=f+1|0;continue}}else{f=0;g:{h:{if(m){if(Kg(h,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Xd(b)+2&255)>>>0<=252){Ub(b,3)}f=f+1|0;continue}}o=e,q=wb(x[Vb(x[h>>2],l)>>2]),x[o+116>>2]=q;w[e+2>>1]=65535;x[e+4>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=z[e+2>>1];if((d|0)==65535){break g}xe(Vb(x[h>>2],l),sn(Ve(Le(e+16|0,12,d&255),x[e+4>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Xd(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+116>>2]]=254;break j}d=e+16|0;Hr(d,b);j=y[vb(d,0)|0];k=y[vb(d,1)|0];n=y[vb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+116>>2];v[d|0]=g;break k}i=i+1|0;continue i}d=x[e+116>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;tW(d,k&15,i,y[e+159|0],e+2|0,e+4|0)}f=f+1|0;sC(e+116|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Ue(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=N()|0;tb(e+116|0);break d}f=N()|0}Eb(e+16|0);Q(f|0);p()}f=0;break a}f=1}fb=e+176|0;return f|0}function rta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-128|0;fb=f;vc(b);a:{if(!mr(b,f- -64|0)){break a}if(!E_(f- -64|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],D_(f- -64|0))){break a}if(!c){j=1;break a}Ad(a,1);x[a+480208>>2]=x[a+480208>>2]|16777216;w[a+480188>>1]=y[f+109|0];w[a+480190>>1]=y[f+110|0];n=a,o=Bc((((y[f+113|0]<<8|48)&65328)>>>0)/100|0,0),x[n+480200>>2]=o;e=f+52|0;si(e,3,f+69|0);d=f+16|0;Ac(d,e);yb(a+1298308|0,d);tb(d);si(e,3,f+89|0);sr(d,4,e);yb(a+1298320|0,d);tb(d);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=a+484360|0;e=a+484376|0;dk(Wb(x[d>>2],y[e|0]),b,y[f+111|0],65535,65535);w[f+50>>1]=0;d=Wb(x[d>>2],y[e|0]);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;d=wb(x[d+4>>2]);while(1){e=x[f+16>>2];if(Ib(e,d)){w[f+52>>1]=z[e>>1];n=f,o=z[oe(f+52|0,f+50|0)>>1],w[n+50>>1]=o;Od(f+16|0);continue}else{d=z[f+50>>1]+1|0;w[f+50>>1]=d;j=Mb(x[b>>2],x[b+8>>2],D(D(z[a+480188>>1],d&65535),264)+(z[a+480190>>1]<<5)|0);if(!j){break a}d=0;while(1){e=z[a+480188>>1];if(e>>>0<=d>>>0){Ub(b,D(e,z[f+50>>1]-1|0)<<3);d=1;while(1){i=d&65535;if(i>>>0>z[a+480190>>1]){k=a+484344|0;Of(k,z[f+50>>1]);l=c&1;g=0;while(1){b:{c:{if(z[f+50>>1]<=g>>>0){if(!(c&2)){break c}d=1;while(1){c=d&65535;if(c>>>0>A[a+480228>>2]){break c}c=D(c,104)+a|0;ag(Wc(f+16|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);d=d+1|0;continue}}d:{if(l){if(Kg(k,g&65535,64)){break d}}Ub(b,z[a+480188>>1]<<8);break b}d=Vb(x[k>>2],g);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;m=wb(x[d+4>>2]);while(1){d=x[f+16>>2];if(!Ib(d,m)){break b}e=f+52|0;jm(e,b);e:{if(!y[vb(e,1)|0]){break e}if(y[vb(f+52|0,1)|0]>168){break e}n=d,o=(y[vb(f+52|0,1)|0]>>>1|0)+36|0,v[n|0]=o}h=f+52|0;n=d,o=y[vb(h,0)|0],v[n+1|0]=o;e=y[vb(h,3)|0];v[d+5|0]=e;f:{if(y[vb(h,2)|0]==8){g:{switch(e>>>4|0){case 0:v[d+3|0]=19;v[d+5|0]=e|128;break f;case 1:v[d+3|0]=11;v[d+5|0]=e<<4;break f;case 2:v[d+3|0]=19;v[d+5|0]=e|160;break f;case 3:case 4:break g;default:break f}}v[d+3|0]=19;v[d+5|0]=e-32;break f}if(y[vb(f+52|0,2)|0]==19){v[d+3|0]=9;i=e<<1&254;h=i+128|0;h:{if(e>>>0<=64){break h}h=384-i|0;if(e<<24>>24>=0){break h}h=128-i|0;if(e>>>0<=191){break h}h=i-128|0}n=d,o=ui(h),v[n+5|0]=o;break f}if((y[vb(f+52|0,2)|0]&240)==32){v[d+2|0]=1;v[d+3|0]=10;n=d,o=(y[vb(f+52|0,2)|0]<<2&60)+4|0,v[n+4|0]=o;break f}i:{if(y[vb(f+52|0,2)|0]<16){break i}if(y[vb(f+52|0,2)|0]==17){break i}if(y[vb(f+52|0,2)|0]!=18){break f}}e=d;d=f+52|0;xf(e,y[vb(d,2)|0]&15,y[vb(d,3)|0])}qg(f+16|0);continue}}b=f+16|0;c=rc(b,9510);yb(a+1298344|0,c);tb(c);c=rc(b,10141);yb(a+1298356|0,c);tb(c);n=a+1298404|0,o=x[Ec(b,4)>>2],x[n>>2]=o;break a}g=g+1|0;continue}}else{e=f+16|0;lr(b,e);h=fb-16|0;fb=h;v[h+15|0]=64;g=(D(i,104)+a|0)+484380|0;n=g,o=y[Sb(e+26|0,h+15|0)|0]<<2,w[n+30>>1]=o;v[g+37|0]=y[e+25|0]<<4;x[g>>2]=y[e+23|0]|y[e+24|0]<<8;x[g+4>>2]=y[e+27|0]|y[e+28|0]<<8;x[g+8>>2]=(y[e+29|0]|y[e+30|0]<<8)+(y[e+27|0]|y[e+28|0]<<8);w[g+34>>1]=z[g+34>>1]&65532|((y[e+29|0]|y[e+30|0]<<8)>>>0>2)<<1|y[e+22|0]==16;fb=h+16|0;g=f+4|0;Wk(g,3,e);e=f+52|0;Ac(e,g);xc(((i<<5)+a|0)+946304|0,e);d=d+1|0;tb(e);continue}}}else{e=f+4|0;C_(e,b);g=f+52|0;cF(g,e);e=f+16|0;Ac(e,g);Tk(((d<<5)+a|0)+480289|0,e);d=d+1|0;tb(e);continue}}}}}else{e=(d<<5)+a|0;Ue(e+480280|0);n=e+480284|0,o=D(Xd(b)&15,17),w[n>>1]=o;d=d+1|0;continue}}fb=f+128|0;return j|0}function qka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=fb-32|0;fb=l;s=x[a+4>>2];k=Re(x[a+8>>2],b);t=x[k>>2];a:{if(t+1>>>0<2){break a}i=(D(b,872)+s|0)+616|0;if(!(Pi(x[i+8>>2],x[i+12>>2])|y[k+4|0])){break a}h=D(b,872)+s|0;if(!x[h+720>>2]){break a}g=x[h+704>>2]&2;u=x[(g?h+700|0:h+692|0)>>2];n=x[h+700>>2];f=x[h+696>>2];w=Ob(x[a>>2]+1074312|0,31);e=rf(x[h+624>>2],x[h+628>>2],c);o=y[h+704|0]&128;k=o?0-e|0:e;m=hb;m=o?0-(m+((e|0)!=0)|0)|0:m;e=0;o=g?e:0;e=f;r=g?e:0;n=n-e|0;B=n<<1;C=h+1316|0;p=h+1467|0;A=h+1362|0;F=(y[A|0]&17)!=1;b:{c:{while(1){if((q|0)!=(t|0)){d:{if(d>>>0>q>>>0){e=(y[A|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=q-d;v[p|0]=y[p|0]&254|(d|0)==(q|0);e=x[a>>2];j=x[a+4>>2];f=Vb(x[e+484344>>2],z[j+70>>1]);f=jd(x[f>>2],x[x[f+48>>2]+12>>2],x[j+48>>2],b);g=y[f+3|0];e:{f:{switch(y[f+2|0]-11|0){case 0:j=l+8|0;fB(j,e,g,y[f+4|0],0);j=Ye(j);xu(x[a>>2],x[a+4>>2],b,z[l+8>>1]);e=1;if(!y[j|0]){break e}break d;case 1:aB(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12));break e;case 2:break f;default:break e}}$A(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12))}e=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=y[f+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}_A(x[a>>2],i,e&15);break g;case 2:xu(x[a>>2],x[a+4>>2],b,y[f+5|0]);break g;case 4:xu(x[a>>2],x[a+4>>2],b,0);break g;case 0:f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}aB(g,x[a+4>>2],b,f,0);break g;case 1:break k;case 3:break d}}f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}$A(g,x[a+4>>2],b,f,0);break g}f=y[f+5|0];e=f&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}ZA(x[a>>2],i,e);break g}YA(x[a>>2],i,e);break g}XA(x[a>>2],i,e&15);break g}SS(x[a>>2],i,y[f+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}e=1}x[l+28>>2]=x[C>>2];if(w){wu(x[a>>2],i)}if(!F){RS(x[a>>2],i,l+28|0);e=1}if(!w){wu(x[a>>2],i)}x[l+24>>2]=0;QS(i,l+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!e){if(!y[Re(x[a+8>>2],b)+4|0]){break m}}if(y[p|0]&96){TU(i,E(1),0,x[a>>2]);k=y[p|0];v[p|0]=(k&64?-65:-33)&k}hB(l+8|0,x[a>>2],i,x[l+28>>2],0);k=x[l+12>>2];x[h+624>>2]=x[l+8>>2];x[h+628>>2]=k;H=Re(x[a+8>>2],b),I=0,v[H+4|0]=I;e=rf(x[h+624>>2],x[h+628>>2],c);f=y[h+704|0]&128;k=f?0-e|0:e;g=hb;m=f?0-(g+((e|0)!=0)|0)|0:g}Pb(i,k,m);f=x[i>>2];e=x[i+4>>2];if((f>>>0<G>>>0&(e|0)<=(u|0)|(e|0)<(u|0))&((e|0)>=(r|0)&f>>>0>=o>>>0|(e|0)>(r|0)|((m|0)>0|(m|0)>=0))){break l}j=x[h+704>>2];if(!(j&2)){break c}if(j&4){g=x[h+696>>2];if(f>>>0<o>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){H=i,I=eh(0,g<<1,f,e),x[H>>2]=I;e=hb;x[i+4>>2]=e;x[h+704>>2]=j^128;f=k;k=0-f|0;m=0-(((f|0)!=0)+m|0)|0}e=(e-g>>>0)%(B-Ob(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(e>>>0<n>>>0){f=e+x[h+696>>2]|0;break n}f=x[h+700>>2]+(n-e|0)|0}x[i+4>>2]=f;f=x[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}x[h+704>>2]=f^128;e=k;k=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break l}j=x[h+700>>2];if(j+n>>>0<=e>>>0){e=j+((e-j>>>0)%(n>>>0)|0)|0}while(1){g=e;e=e-n|0;if(g>>>0>=j>>>0){continue}break}x[i>>2]=f;x[i+4>>2]=g}q=q+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;VU(i);x[(D(b,872)+s|0)+1324>>2]=0}H=Re(x[a+8>>2],b),I=0,x[H>>2]=I}fb=l+32|0}function JG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-32|0;fb=f;d=x[b+28>>2];x[f+24>>2]=x[b+24>>2];x[f+28>>2]=d;d=x[b+20>>2];x[f+16>>2]=x[b+16>>2];x[f+20>>2]=d;d=x[b+12>>2];x[f+8>>2]=x[b+8>>2];x[f+12>>2]=d;d=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=d;d=fb-144|0;fb=d;j=Fb(d+132|0);k=Fb(d+120|0);x[31721]=0;b=P(1,d+108|0,c|0)|0;c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=yb(k,b);tb(b);if(!x[f>>2]){break b}x[31721]=0;O(76,d+96|0,f|0);b=x[31721];x[31721]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){x[31721]=0;e=P(77,j|0,d+96|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break q}tb(d+96|0);x[31721]=0;b=P(1,d+84|0,16804)|0;g=x[31721];x[31721]=0;if((g|0)==1){break p}x[31721]=0;O(78,d+72|0,f+4|0);g=x[31721];x[31721]=0;if((g|0)==1){break o}x[31721]=0;S(2,d+96|0,b|0,d+72|0);g=x[31721];x[31721]=0;if((g|0)==1){break n}x[31721]=0;e=P(77,e|0,d+96|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break m}tb(d+96|0);g=d+72|0;tb(g);tb(b);x[31721]=0;b=P(1,g|0,16804)|0;g=x[31721];x[31721]=0;if((g|0)==1){break j}x[31721]=0;O(78,d+60|0,f+8|0);g=x[31721];x[31721]=0;if((g|0)==1){break i}x[31721]=0;S(2,d+96|0,b|0,d+60|0);g=x[31721];x[31721]=0;if((g|0)==1){break h}x[31721]=0;i=P(77,e|0,d+96|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}tb(d+96|0);tb(d+60|0);tb(b);b=x[f+24>>2];g=x[f+28>>2];if(x[f+12>>2]|(x[f+16>>2]|!(b|g))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(b);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(b);break c}x[31721]=0;e=P(1,d+96|0,13717)|0;h=x[31721];x[31721]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((h|0)!=1){x[31721]=0;i=P(77,i|0,e|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break J}tb(e);x[31721]=0;O(79,d+36|0,f+12|0);e=x[31721];x[31721]=0;if((e|0)==1){break I}x[31721]=0;e=P(1,d+24|0,14624)|0;h=x[31721];x[31721]=0;if((h|0)==1){break H}x[31721]=0;S(2,d+48|0,d+36|0,e|0);h=x[31721];x[31721]=0;if((h|0)==1){break G}x[31721]=0;O(79,d+12|0,f+16|0);h=x[31721];x[31721]=0;if((h|0)==1){break F}x[31721]=0;S(2,d+60|0,d+48|0,d+12|0);h=x[31721];x[31721]=0;if((h|0)==1){break E}x[31721]=0;i=P(77,i|0,d+60|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break D}tb(d+60|0);tb(d+12|0);tb(d+48|0);tb(e);tb(d+36|0);if(b|g){break y}x[31721]=0;S(80,a|0,i|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31721]=0;b=P(1,d+48|0,14624)|0;e=x[31721];x[31721]=0;if((e|0)==1){break w}x[31721]=0;O(81,d+36|0,f+24|0);e=x[31721];x[31721]=0;if((e|0)==1){break v}x[31721]=0;S(2,d+60|0,b|0,d+36|0);e=x[31721];x[31721]=0;if((e|0)==1){break u}x[31721]=0;e=P(77,i|0,d+60|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break t}tb(d+60|0);tb(d+36|0);tb(b);x[31721]=0;P(77,e|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(k);tb(j);Q(a|0);p()}Zc(a,j)}tb(c);tb(j);fb=d+144|0;fb=f+32|0}function KP(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=fb-16|0;fb=j;b=a+4208|0;i=Ck(E(B[xb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[xb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=Ce(E(10),E(E(JP(a)+E(E(B[xb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Qm(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=Ce(E(10),E(E(E(E(B[xb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=jq(E(E(IP(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=lB(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[xb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[xb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Lz(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[xb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Qm(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=Ce(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){MP((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+45392>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=Mh(a,5);e=Mh(a,11);c=E(d*Mh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Mh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Mh(a,3);l=Mh(a,9);g=E(c*g);c=E(g*Mh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Mh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Mh(a,12);g=B[a+4496>>2];l=Mh(a,1);m=Mh(a,7);q=Mh(a,0);r=Mh(a,6);t=b,u=Ce(E(10),E(E(JP(a)+E(E(B[xb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Qm(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));fb=b+16|0;v[a+5046|0]=0;fb=j+16|0}function dS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){i=a+327720|0;c=fb-352|0;fb=c;fU(c+340|0,8);x[31721]=0;la(800,c+328|0,9);j=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((j|0)!=1){x[31721]=0;j=P(801,c+312|0,14)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}x[31721]=0;O(802,c+340|0,j|0);e=x[31721];x[31721]=0;if((e|0)==1){break k}x[31721]=0;O(802,c+328|0,j|0);e=x[31721];x[31721]=0;if((e|0)==1){break k}eU(c+240|0,4900);eU(c+168|0,32e3);YT(c+96|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31721]=0;e=P(803,c+72|0,c+340|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break j}Mu(c+84|0,c+240|0,e);ze(e);x[31721]=0;e=P(803,c+48|0,c+328|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break i}Mu(c+60|0,c+168|0,e);ze(e);x[31721]=0;e=P(803,c+24|0,c+84|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break h}Mu(c+36|0,c+96|0,e);ze(e);x[31721]=0;e=P(803,c|0,c+60|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break g}g=c+12|0;Mu(g,c+96|0,e);ze(e);e=c+84|0;Bq(e);l=c+36|0;Bq(l);m=c+60|0;Bq(m);Bq(g);q=c+328|0;Bq(q);Aq(x[c+84>>2],x[c+88>>2],Ho(i,0));Aq(x[c+36>>2],x[c+40>>2],Ho(i,1));Aq(x[c+60>>2],x[c+64>>2],Ho(i,2));Aq(x[c+12>>2],x[c+16>>2],Ho(i,3));Aq(x[c+328>>2],x[c+332>>2],Ho(i,4));ze(g);ze(l);ze(m);ze(e);dn(j);ze(q);ze(c+340|0);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;ze(c+36|0)}ze(c+60|0)}ze(c+84|0)}dn(j)}ze(c+328|0)}ze(c+340|0);Q(a|0);p()}lA(a+131112|0,9.6377,.97);lA(a+196648|0,8.5,.5);lA(a+262184|0,7,.425)}c=a+368680|0;if(!(u=0,v=pR(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];i=fb+-64|0;fb=i;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){d=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;h=J(C[i+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){j=~~h;break n}j=-2147483648}w[m>>1]=j;b=b+1|0;continue}}else{h=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=ff(d*.8975979010256552)*-.5+.5;break o;case 1:f=ff(d*.8975979010256552)*-.46+.54;break o;case 2:f=ff(d*1.7951958020513104)*.08+(ff(d*.8975979010256552)*-.5+.42);break o;case 3:f=ff(d*1.7951958020513104)*.05677+(ff(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=ff(d*1.7951958020513104)*.07922+(ff(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;h=Ti(d*h)/d}h=f*h;C[i+(b<<3)>>3]=h;o=o+h;b=b+1|0;continue}}break}fb=i- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function Ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-240|0;fb=e;v[e+239|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[zl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ll(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;de(f);g=x[e+80>>2];de(e+216|0);h=yl(g,x[e+220>>2],b);de(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=oc(e+228|0,22250);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Nc(g,f,e)){d=$b(8);x[31721]=0;O(1012,e+216|0,e+239|0);a=x[31721];x[31721]=0;if((a|0)==1){break g}x[31721]=0;S(1019,e+80|0,18241,e+216|0);a=x[31721];x[31721]=0;if((a|0)==1){break f}mc(d,e+80|0);a=0;x[31721]=0;S(100,d|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break e}if(!d){break h}d=$b(8);a=x[b+4>>2];b=x[b>>2];x[31721]=0;a=ci(e+192|0,b,a);b=x[31721];x[31721]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31721]=0;S(1019,e+204|0,18277,a|0);b=x[31721];x[31721]=0;if((b|0)==1){break p}x[31721]=0;O(1021,e+216|0,e+204|0);b=x[31721];x[31721]=0;c=1;if((b|0)==1){break o}x[31721]=0;O(1012,e+180|0,e+239|0);b=x[31721];x[31721]=0;if((b|0)==1){break n}x[31721]=0;S(1023,e+80|0,e+216|0,e+180|0);b=x[31721];x[31721]=0;if((b|0)==1){break m}mc(d,e+80|0);x[31721]=0;S(100,d|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=oc(e+172|0,22250);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Nc(g,f,e+72|0)){d=$b(8);x[31721]=0;O(1012,e+216|0,e+239|0);a=x[31721];x[31721]=0;q:{r:{if((a|0)!=1){x[31721]=0;S(1019,e+80|0,18241,e+216|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}mc(d,e+80|0);a=0;x[31721]=0;S(100,d|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break q}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(a){break d}break c}b=oc(e+164|0,7462);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Nc(g,f,e- -64|0)){b=oc(e+156|0,7444);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Nc(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=oc(e+148|0,6989);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Nc(g,f,e+48|0)){b=oc(e+140|0,6970);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Nc(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=oc(e+132|0,7073);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Nc(g,f,e+32|0)){v[a+62|0]=c;break h}b=oc(e+124|0,6064);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){v[a+63|0]=c;break h}b=oc(e+116|0,7511);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Nc(g,f,e+16|0)){v[a+64|0]=c;break h}b=oc(e+108|0,13509);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Nc(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=KM(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!oz(e+80|0,b+24648|0)){break h}uA(b,e+80|0)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(!a){break c}}ic(d)}Q(b|0)}p()}function vH(){var a=0,b=0,c=0,d=0;if(y[500368]){return x[125091]}b=ud(502008,1);x[b>>2]=111960;c=eJ(b+8|0);x[31721]=0;d=P(37,b+152|0,14271)|0;a=x[31721];x[31721]=0;a:{b:{c:{if((a|0)!=1){Hf(c);aJ(501680,1);x[31721]=0;W(1260,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}$I(501688,1);x[31721]=0;W(1261,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}_I(501696,1);x[31721]=0;W(1262,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ZI(501712,1);x[31721]=0;W(1263,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501720,1);x[125430]=113908;x[31721]=0;W(1264,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;X(1265);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;W(1266,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501744,1);x[125436]=114056;x[31721]=0;W(1267,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501752,1);x[125438]=114288;x[31721]=0;W(1268,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501760,1);x[125440]=114172;x[31721]=0;W(1269,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501768,1);x[125442]=114404;x[31721]=0;W(1270,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}YI(501776,1);x[31721]=0;W(1271,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}XI(501800,1);x[31721]=0;W(1272,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501832,1);x[125458]=115124;x[31721]=0;W(1273,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501840,1);x[125460]=115368;x[31721]=0;W(1274,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501848,1);x[125462]=115580;x[31721]=0;W(1275,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501856,1);x[125464]=115812;x[31721]=0;W(1276,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}WI(501864,1);x[31721]=0;W(1277,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}VI(501872,1);x[31721]=0;W(1278,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}UI(501880,1);x[31721]=0;W(1279,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}TI(501888,1);x[31721]=0;W(1280,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501896,1);x[125474]=118504;x[31721]=0;W(1281,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501904,1);x[125476]=118668;x[31721]=0;W(1282,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501912,1);x[125478]=118832;x[31721]=0;W(1283,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}ud(501920,1);x[125480]=118996;x[31721]=0;W(1284,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}SI(501928,1);x[31721]=0;W(1285,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}RI(501944,1);x[31721]=0;W(1286,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;X(1287);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;W(1288,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;X(1289);a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;W(1290,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}QI(501992,1);x[31721]=0;W(1291,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}PI(502e3,1);x[31721]=0;W(1292,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}Wx(c);Q(b|0);p()}x[125090]=502008;v[500368]=1;x[125091]=500360;return 500360}function Dz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[zl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ll(e+128|0,g,f,f-1|0);f=x[e+132>>2];x[b>>2]=x[e+128>>2];x[b+4>>2]=f}f=e+128|0;de(f);g=x[e+128>>2];de(e+116|0);h=yl(g,x[e+120>>2],b);de(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+132>>2]){a=oc(e+144|0,22250);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Nc(g,f,e+8|0)){d=$b(8);x[31721]=0;O(1016,e+116|0,e+152|0);a=x[31721];x[31721]=0;f:{g:{h:{if((a|0)!=1){x[31721]=0;S(1019,e+128|0,18241,e+116|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}mc(d,e+128|0);a=0;x[31721]=0;S(100,d|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}ic(d);break c}if(!d){break e}d=$b(8);a=x[b+4>>2];b=x[b>>2];x[31721]=0;f=ci(e+92|0,b,a);a=x[31721];x[31721]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31721]=0;S(1019,e+104|0,18277,f|0);a=x[31721];x[31721]=0;if((a|0)==1){break q}x[31721]=0;O(1021,e+116|0,e+104|0);b=x[31721];x[31721]=0;a=1;if((b|0)==1){break p}x[31721]=0;O(1016,e+80|0,e+152|0);a=x[31721];x[31721]=0;if((a|0)==1){break o}x[31721]=0;S(1023,e+128|0,e+116|0,e+80|0);b=x[31721];x[31721]=0;a=1;if((b|0)==1){break n}mc(d,e+128|0);x[31721]=0;S(100,d|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(e+128|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(f);if(!a){break c}}ic(d);break c}b=oc(e+72|0,22250);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Nc(g,f,e+40|0)){d=$b(8);x[31721]=0;O(1016,e+116|0,e+152|0);a=x[31721];x[31721]=0;r:{s:{t:{if((a|0)!=1){x[31721]=0;S(1019,e+128|0,18241,e+116|0);a=x[31721];x[31721]=0;if((a|0)==1){break t}mc(d,e+128|0);a=0;x[31721]=0;S(100,d|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}ic(d);break c}b=oc(e- -64|0,7759);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Nc(g,f,e+32|0)){if(!Bd(y[a+28|0])){break e}if(c<=0|c>4){a=$b(8);x[31721]=0;d=P(37,e+128|0,7854)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,d);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}a=x[a+24>>2];i=a,j=Xe(65536/c),x[i+480244>>2]=j;pq(a);break e}b=oc(e+56|0,7811);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){if(!Bd(y[a+28|0])){break e}if(c<=0|c>4){a=$b(8);x[31721]=0;d=P(37,e+128|0,7875)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,d);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}b=N()|0;ic(a);break c}a=x[a+24>>2];i=a,j=Xe(c*65536),x[i+480240>>2]=j;pq(a);break e}b=oc(e+48|0,7829);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Nc(g,f,e+16|0)){break e}i=x[a+24>>2],j=Wi(c*65536),x[i+480236>>2]=j}fb=e+160|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function TL(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(Bt(c)){h=x[b+484344>>2];if(Ge(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}c=Vb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Sc(d)){if(!El(d)){break k}}e=g+24|0;HR(e,b,d,y[c+1|0]);x[31721]=0;O(1067,g+36|0,e|0);b=x[31721];x[31721]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[31721]=0;P(37,g+36|0,16770)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}}b=9968;c=y[c|0];if(!Sc(c)){b=El(c)?10278:16770}x[31721]=0;b=P(37,g+12|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break h}c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){sv(g+36|0,b);break l}Cc(g+36|0,16775)}b=y[b|0];x[31721]=0;b=P(37,g+24|0,(b?10801:16775)|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Sg(y[c|0])){Cc(g+36|0,18424);break m}d=y[c+2|0];if(d){of(g+36|0,1,fR(x[x[b+8>>2]+88>>2],d));break m}Cc(g+36|0,18424)}b=18424;if(!Sg(y[c|0])){b=y[c+2|0]?5505:18424}x[31721]=0;b=P(37,g+24|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Sg(y[c|0])){i=g,j=Hj(y[c+2|0],y[c+4|0])&255,x[i+12>>2]=j;JC(g+36|0,g+12|0);break n}if(y[c+2|0]){sv(g+36|0,c+4|0);break n}Cc(g+36|0,16775)}b=5489;if(!Sg(y[c|0])){b=y[c+2|0]?5489:16775}x[31721]=0;b=P(37,g+24|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Sg(y[c|0])){i=g,j=(Hj(y[c+3|0],y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31721]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;S(1169,g+36|0,g+12|0,b+4|0);d=x[31721];x[31721]=0;p:{if((d|0)!=1){Ch(b+4|0);fb=b+32|0;break p}a=N()|0;Ch(b+4|0);Q(a|0);p()}break o}d=y[c+3|0];if(d){of(g+36|0,1,eR(x[x[b+8>>2]+84>>2],d));break o}Cc(g+36|0,16776)}b=12375;if(!Sg(y[c|0])){b=y[c+3|0]?12375:16776}x[31721]=0;b=P(37,g+24|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}q:{if(Sg(y[c|0])){i=g,j=Hj(y[c+3|0],y[c+5|0])&255,x[i+12>>2]=j;JC(g+36|0,g+12|0);break q}if(y[c+3|0]){sv(g+36|0,c+5|0);break q}Cc(g+36|0,16775)}b=11162;if(!Sg(y[c|0])){b=y[c+3|0]?11162:16775}x[31721]=0;b=P(37,g+24|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a)}fb=g+48|0}function nra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-192|0;fb=f;Zd(f+80|0,b);i=x[f+88>>2];l=x[f+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Jk(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(zn(14123)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;Rx(h+8|0,h+28|0);Km(h+20|0,b,x[h+8>>2],x[h+12>>2]);Im(e+24|0,x[h+28>>2]);fb=h+32|0;h=-1;g=x[e+24>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Fb(e+12|0);x[31721]=0;j=U(499,b|0,g|0,256)|0;k=x[31721];x[31721]=0;if((k|0)==1){break b}if(!j){break e}x[31721]=0;S(500,e|0,d|0,g|0);j=x[31721];x[31721]=0;if((j|0)!=1){break f}break b}g=Fb(e+12|0);x[31721]=0;j=P(502,b|0,g|0)|0;k=x[31721];x[31721]=0;if((k|0)==1){break b}if(!j){break d}x[31721]=0;S(500,e|0,d|0,g|0);j=x[31721];x[31721]=0;if((j|0)==1){break b}}yb(c,e);tb(e);tb(g);lg(b,e);g=0;x[e+12>>2]=0;Jk(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((g|0)==(j|0)){break g}g=g+1|0;if(HQ(a,b,d)){continue}break}break c}x[e+12>>2]=0;Jk(b,e+12|0);h=x[e+12>>2]==(zn(14161)|0)?1:-1;break c}tb(g);break c}tb(g)}fb=e+32|0;break a}a=N()|0;tb(g);Q(a|0);p()}h:{if(h){break h}fg(x[x[b>>2]-12>>2]+b|0,0);b=Hm(f+80|0,Ei(b,i,l,0));x[31721]=0;h=P(465,f+68|0,14267)|0;i=x[31721];x[31721]=0;i:{if((i|0)!=1){x[31721]=0;x[f+48>>2]=3;x[f+52>>2]=0;S(466,b|0,h|0,f+48|0);i=x[31721];x[31721]=0;if((i|0)!=1){Eb(h);v[f+67|0]=0;x[31721]=0;h=P(465,f+48|0,14723)|0;i=x[31721];x[31721]=0;if((i|0)!=1){x[31721]=0;S(467,b|0,f+67|0,h|0);i=x[31721];x[31721]=0;if((i|0)!=1){Eb(h);h=Ec(f+44|0,y[f+67|0]?0:d);x[31721]=0;d=R(480,b|0)|0;i=x[31721];x[31721]=0;if((i|0)!=1){x[31721]=0;i=R(481,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){x[f+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=ol(y[b|0]);yh(b);h=a?-1:1;break h}x[31721]=0;d=P(465,f+24|0,15839)|0;e=x[31721];x[31721]=0;if((e|0)==1){break l}e=x[b+44>>2];g=x[b+40>>2];x[31721]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31721]=0;V(483,b|0,f+40|0,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){break o}break j}x[31721]=0;d=P(465,f+12|0,15523)|0;e=x[31721];x[31721]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];g=x[b+40>>2];x[31721]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break q}Eb(d);if(!e){break p}x[31721]=0;S(484,b|0,f+40|0,f+38|0);d=x[31721];x[31721]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31721]=0;d=P(465,f|0,15363)|0;e=x[31721];x[31721]=0;if((e|0)==1){break n}e=x[b+44>>2];g=x[b+40>>2];x[31721]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31721]=0;V(485,b|0,f+40|0,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break j}}Wz(f+40|0);d=x[f+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}yh(b);Q(a|0);p()}fb=f+192|0;return h|0}function Bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;_C(d,b);Gn(g+4|0,d);x[31721]=0;S(479,e+216|0,x[g+4>>2],x[g+8>>2]);b=x[31721];x[31721]=0;a:{if((b|0)!=1){Ic(g+12|0);fb=g+32|0;break a}a=N()|0;Ic(g+12|0);Q(a|0);p()}x[31721]=0;S(461,e+104|0,x[e+216>>2],x[e+220>>2]);b=x[31721];x[31721]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[31721]=0;g=P(106,e+228|0,e+104|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break z}tb(e+104|0);cc(e+216|0);if(c>>>0<2189){break g}b=Hm(e+104|0,g);x[31721]=0;c=P(465,e+216|0,10124)|0;d=x[31721];x[31721]=0;if((d|0)==1){break x}x[31721]=0;x[e+88>>2]=19988993;x[e+92>>2]=0;S(466,b|0,c|0,e+88|0);d=x[31721];x[31721]=0;if((d|0)==1){break w}Eb(c);v[e+103|0]=0;x[31721]=0;c=P(465,e+88|0,11047)|0;d=x[31721];x[31721]=0;if((d|0)==1){break v}x[31721]=0;S(467,b|0,e+103|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break u}Eb(c);d=Ec(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31721]=0;c=P(465,e+72|0,15839)|0;h=x[31721];x[31721]=0;if((h|0)==1){break i}h=x[d>>2];x[31721]=0;V(468,b|0,f|0,c|0,h|0);f=x[31721];x[31721]=0;if((f|0)==1){break t}Eb(c);x[31721]=0;c=P(465,e+60|0,15523)|0;f=x[31721];x[31721]=0;if((f|0)==1){break s}d=x[d>>2];x[31721]=0;V(469,b|0,a|0,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break r}Eb(c);x[31721]=0;c=P(465,e+48|0,15363)|0;d=x[31721];x[31721]=0;if((d|0)==1){break q}x[31721]=0;d=a+484360|0;S(470,b|0,d|0,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break p}Eb(c);x[31721]=0;c=P(465,e+36|0,24998)|0;f=x[31721];x[31721]=0;if((f|0)==1){break o}x[31721]=0;S(471,b|0,a+484344|0,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31721]=0;c=P(465,e+24|0,25004)|0;h=x[31721];x[31721]=0;if((h|0)==1){break m}x[31721]=0;V(472,b|0,d|0,c|0,f|0);d=x[31721];x[31721]=0;if((d|0)==1){break l}Eb(c);if(ol(y[b|0])){x[31721]=0;c=P(1,e+12|0,16313)|0;d=x[31721];x[31721]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31721]=0;S(389,a|0,1,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}tb(c)}yh(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}cc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}yh(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31721]=0;d=ba(473,f|0,g|0,b|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31721]=0;c=P(1,e+216|0,16619)|0;d=x[31721];x[31721]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31721]=0;S(389,a|0,1,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31721]=0;V(474,g|0,a|0,d|0,c>>>0<2188|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}}tb(b)}Bf(g);fb=e+368|0;return}a=N()|0}tb(b)}Bf(g)}Q(a|0);p()}function Qg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-112|0;fb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;Wf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;Wf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}Wf(j- -64|0,d,e,b,c,128-f|0);Wm(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;Wf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}Wf(j+16|0,d,e,h,i,p+127|0);Wm(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=j+112|0}function Jta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-720|0;fb=d;vc(b);f=fb-16|0;fb=f;h=d+110|0;o$(f+8|0,h);g=x[f+12>>2];j=b;jc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Ub(j,x[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){n$(h)}a:{if(!b){break a}if(!p$(d+110|0)){break a}b:{if(!c){break b}Ad(a,67108864);bg(a);b=y[d+135|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=rc(d,8179);yb(a+1298344|0,b);tb(b);b=rc(d,10804);yb(a+1298356|0,b);tb(b);b=d+84|0;dg(b,4174);f=y[d+134|0];x[d+64>>2]=f>>>4;x[31721]=0;x[d+104>>2]=f&15;V(310,d|0,b|0,d- -64|0,d+104|0);b=x[31721];x[31721]=0;c:{d:{if((b|0)!=1){yb(a+1298368|0,d);tb(d);Eb(d+84|0);o=a+1298404|0,q=x[Ec(d,28)>>2],x[o>>2]=q;Zv(Wb(x[a+484360>>2],y[a+484376|0]),d+158|0,y[d+157|0]+1|0);while(1){e:{if((e|0)==31){cE(j,a+1298308|0,32);e=1;break e}b=e+1|0;g=D(b,104)+a|0;h=g+484380|0;kd(h,1);f=(d+110|0)+(e<<2)|0;o=h,q=_b(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[o>>2]=q;k=_b(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=_b(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}Zk(h);e=(d+110|0)+e|0;v[d|0]=y[e+548|0];v[d+84|0]=64;o=g+484410|0,q=y[Sb(d,d+84|0)|0]<<2,w[o>>1]=q;v[g+484417|0]=y[e+579|0]<<4;e=b;continue}break}while(1){if((e|0)!=32){l$(j,((e<<5)+a|0)+946304|0,30);e=e+1|0;continue}break}n=c&1;if(n){Of(a+484344|0,y[d+156|0]+1|0)}h=a+484344|0;k=a+480188|0;f=0;while(1){if(y[d+156|0]<f>>>0){e=1;if(!(c&2)){break a}b=Wc(d,8,1,1,0);while(1){if((e|0)==32){break b}ag(b,(D(e,104)+a|0)+484380|0,j);e=e+1|0;continue}}g=Zh(d+84|0);f:{g:{if(y[d+136|0]){x[31721]=0;b=R(276,j|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}x[31721]=0;S(188,d- -64|0,j|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break f}break g}b=z[k>>1];x[31721]=0;S(188,d- -64|0,j|0,b<<8);b=x[31721];x[31721]=0;if((b|0)==1){break d}}b=d- -64|0;e=hc(d,b);gd(g,e);ub(e);ub(b);h:{if(!n){break h}x[31721]=0;b=U(199,h|0,f&65535,64)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}if(!b){break h}b=0;if(y[d+136|0]){x[31721]=0;O(311,g|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break d}i:while(1){if((b|0)==64){break h}e=Vb(x[h>>2],f);_e(d- -64|0,x[e>>2],x[x[e+48>>2]+12>>2],b);o=d,q=wb(x[d+64>>2]),x[o+104>>2]=q;l=b+d|0;e=128;i=Yv(x[d+64>>2],x[d+68>>2]);while(1){m=x[d+104>>2];if(!Ib(m,i)){b=b+1|0;continue i}j:{if(!(y[l|0]&e)){break j}x[31721]=0;O(312,g|0,m|0);m=x[31721];x[31721]=0;if((m|0)!=1){break j}break d}e=e>>>1|0;qg(d+104|0);continue}}}k:while(1){e=0;l=b&65535;if(l>>>0>=z[k>>1]){break h}while(1){if((e|0)==64){b=b+1|0;continue k}i=Vb(x[h>>2],f);i=jd(x[i>>2],x[x[i+48>>2]+12>>2],e,l);x[31721]=0;O(312,g|0,i|0);i=x[31721];x[31721]=0;if((i|0)!=1){e=e+1|0;continue}break}break}break d}ub(g);f=f+1|0;continue}break}break d}e=N()|0;Eb(d+84|0);break c}e=N()|0;ub(g)}Q(e|0);p()}e=1}fb=d+720|0;return e|0}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31601]){break a}a=a+b|0;c:{d:{if(x[31602]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=126388,j=x[31597]&Cua(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[31599]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!g){break b}c=x[d+28>>2];e=(c<<2)+126692|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=126392,j=x[31598]&Cua(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=g;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[31603]==(f|0)){x[31603]=d;a=x[31600]+a|0;x[31600]=a;x[d+4>>2]=a|1;if(x[31602]!=(d|0)){break a}x[31599]=0;x[31602]=0;return}if(x[31602]==(f|0)){x[31602]=d;a=x[31599]+a|0;x[31599]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=126388,j=x[31597]&Cua(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}g=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!g){break g}c=x[f+28>>2];e=(c<<2)+126692|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=126392,j=x[31598]&Cua(-2,c),x[i>>2]=j;break g}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=g;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31602]!=(d|0)){break f}x[31599]=a;return}if(a>>>0<=255){b=(a&-8)+126428|0;c=x[31597];a=1<<(a>>>3);k:{if(!(c&a)){x[31597]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+126692|0;l:{m:{e=x[31598];h=1<<c;n:{if(!(e&h)){x[31598]=e|h;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;h=e+(b&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[31605]-1|0;x[31605]=a?a:-1}}function gy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-32|0;fb=d;i=a+32|0;Oc(d+8|0,i,11);a:{b:{c:{if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Ei(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=x[a+36>>2];if(qk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Lh(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];e=lj(f,x[c+4>>2]);d:{if(b>>>0>e>>>0){j=fb-32|0;fb=j;f=b-e|0;h=x[Ab(c)>>2];b=x[c+4>>2];e:{if(f>>>0<=(h-b|0)/24>>>0){e=fb-16|0;fb=e;c=gJ(e+4|0,c,f);b=x[c+4>>2];f=x[c+8>>2];while(1){if((b|0)==(f|0)){gc(c);fb=e+16|0}else{dJ(b);b=b+24|0;x[c+4>>2]=b;continue}break}break e}e=Ab(c);e=zJ(j+12|0,FJ(c,lj(x[c>>2],b)+f|0),lj(x[c>>2],x[c+4>>2]),e);h=fb-16|0;fb=h;b=h+4|0;x[b>>2]=x[e+8>>2];k=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=k+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){dJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}ee(b);fb=h+16|0;uJ(c,e);pJ(e)}fb=j+32|0;break d}if(b>>>0<e>>>0){lJ(c,f+D(b,24)|0)}}f=a+40|0;lo(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>g>>>0){c=x[a+36>>2];if(qk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Lh(a,2,1024);break a}b=z[a+24>>1];w[d>>1]=b;if((b|0)==65535){oy(c,d);b=z[d>>1]}c=Rc(x[a+40>>2],x[a+44>>2]);e=b&65535;f:{if(!e){b=0;break f}if(e>>>0>(c^-1)>>>0){break f}Uj(f,c+e|0);zj(x[a+36>>2],vb(x[a+40>>2],c),e)}e=sf(x[a+52>>2],g);x[e>>2]=c;w[e+20>>1]=b;Oc(d+8|0,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){nl(x[a+36>>2],d+8|0);c=x[d+8>>2];b=x[d+12>>2];if(!ky(c,b)){break c}e=sf(x[a+52>>2],g);x[e+8>>2]=c;x[e+12>>2]=b}c=x[a+8>>2];g:{if(c){b=sf(x[a+52>>2],g);x[b+16>>2]=c;break g}Oc(d+8|0,i,7);if(!Hb(x[x[d+8>>2]>>2],x[d+12>>2])){b=sf(x[a+52>>2],g);break g}nl(x[a+36>>2],d+8|0);c=x[d+8>>2];if(!ky(c,x[d+12>>2])){break b}b=sf(x[a+52>>2],g);x[b+16>>2]=c}h:{if(x[b+16>>2]==-1){break h}Oc(d+8|0,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break h}i:{if(!g){b=0;e=sf(x[a+52>>2],0);h=0;break i}e=x[a+52>>2];c=sf(e,g-1|0);j=x[c+16>>2];b=x[c+8>>2]+j|0;c=x[c+12>>2];e=sf(e,g);h=b>>>0<j>>>0?c+1|0:c}c=h;x[e+8>>2]=b;x[e+12>>2]=c}Oc(d+8|0,i,8);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){w[d+30>>1]=0;oy(x[a+36>>2],d+30|0);Oc(d+8|0,i,9);Lm(x[a+36>>2],z[d+30>>1]<<Hb(x[x[d+8>>2]>>2],x[d+12>>2]))}g=g+1|0;continue}break}Zd(d+8|0,x[a+36>>2]);c=x[d+20>>2];x[a+80>>2]=x[d+16>>2];x[a+84>>2]=c}g=d+8|0;Oc(g,i,4);Ef(g,1);f=x[a+80>>2];j=x[a+84>>2];c=x[a+96>>2];h=x[a+16>>2];e=c+h|0;k=x[a+100>>2];b=k+x[a+20>>2]|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=(c|0)==x[a+72>>2]&(k|0)==x[a+76>>2];c=e?f:h;x[a+88>>2]=c;b=e?j:b;x[a+92>>2]=b;Ei(x[a+36>>2],c,b,0);Oc(g,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}Oc(d,i,7);if(!(Hb(x[x[d>>2]>>2],x[d+4>>2])|x[a+8>>2])){break a}b=x[a+88>>2];g=x[a+16>>2];c=b-g|0;e=x[a+92>>2]-(x[a+20>>2]+(b>>>0<g>>>0)|0)|0;f=x[a+52>>2];j=x[a+104>>2];a=0;while(1){if((a|0)==(j|0)){break a}b=sf(f,a);g=b;h=x[b+8>>2];i=h+c|0;b=x[b+12>>2]+e|0;x[g+8>>2]=i;x[g+12>>2]=i>>>0<h>>>0?b+1|0:b;a=a+1|0;continue}}Lh(a,2,2048);break a}Lh(a,2,2048)}fb=d+32|0}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(zd(g,h)){break a}f=y[nz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;ix(f,b,0,Xc(g,h)-1|0);yb(b,f);tb(f)}g=e+100|0;de(g);f=x[e+100>>2];de(e+88|0);f=LM(f,x[e+92>>2],b);de(g);b:{c:{d:{e:{if((f|0)==x[e+104>>2]){if(ke(b,22250)){a=$b(8);x[31721]=0;S(1010,e+100|0,18241,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,e+100|0);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(e+100|0);break c}if(!d){break e}a=$b(8);x[31721]=0;S(1010,e+76|0,18277,b|0);b=x[31721];x[31721]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31721]=0;O(1021,e+88|0,e+76|0);b=x[31721];x[31721]=0;if((b|0)==1){break j}x[31721]=0;S(547,e+100|0,e+88|0,c|0);b=x[31721];x[31721]=0;d=1;if((b|0)==1){break i}mc(a,e+100|0);x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(e+100|0);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}ic(a);break c}k:{switch(x[f+4>>2]){case 0:ve(e+68|0,b);b=fb-176|0;fb=b;f=b+12|0;Pf(f,c);x[31721]=0;O(127,b+24|0,f|0);c=x[31721];x[31721]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31721]=0;c=P(106,b+36|0,b+24|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break p}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31721]=0;g=ca(107)|0;h=x[31721];x[31721]=0;if((h|0)==1){break n}x[31721]=0;S(108,b+8|0,c+f|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}Yb(b+8|0);x[31721]=0;f=P(128,c|0,b+24|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break n}c=qk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Bf(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Bf(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Ez(a,e,b,d);break e;case 1:ve(e+60|0,b);b=fb-176|0;fb=b;f=b+12|0;Pf(f,c);x[31721]=0;O(127,b+24|0,f|0);c=x[31721];x[31721]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31721]=0;c=P(106,b+36|0,b+24|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break u}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31721]=0;g=ca(107)|0;h=x[31721];x[31721]=0;if((h|0)==1){break s}x[31721]=0;S(108,b+8|0,c+f|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break s}Yb(b+8|0);x[31721]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1137,c|0,b+24|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break s}c=qk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Bf(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Bf(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Cz(a,e+8|0,b,c,d);break e;case 2:ve(e+52|0,b);i=LZ(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Dz(a,e+16|0,i,d);break e;case 3:break k;default:break e}}ve(e+44|0,b);ve(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Bz(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function ER(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){vA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;JR(a)}DR(a+24648|0);o=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+45968|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(o>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){h=j;j=k+600|0;x[c+4>>2]=h-j;x[c>>2]=d-j}i=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(i))<E(2147483648)){d=~~i;break a}d=-2147483648}x[c+16>>2]=d- -8192;i=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(i))<E(2147483648)){d=~~i;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;i=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;h=k-7500|0;n=k>>>0>=h>>>0?h:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){h=~~l;break d}h=-2147483648}d=n+(h+((d|0)<96?d-96|0:0)|0)|0;h=(d|0)<=128?128:d;p=h>>>0>=3800?3800:h;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;i=E(i*m);e:{if(E(F(i))<E(2147483648)){q=~~i;break e}q=-2147483648}d=h-3800|0;h=(q+n|0)+(d>>>0<=h>>>0?d:0)|0;x[c+32>>2]=h;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){i=E(h|0);l=E(Ce(E(.0010000000474974513),(h|0)<4721?E(1):E(E(4720)/i))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;i=E(B[g+12>>2]*i);s=c,t=Ce(E(.0010000000474974513),i<=E(4720)?E(1):E(E(4720)/i)),B[s+28>>2]=t}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+47258>>1];w[k+36>>1]=z[d+47252>>1];w[k+40>>1]=z[d+47256>>1];w[k+38>>1]=z[d+47254>>1];x[k+44>>2]=n+((D(x[d+47248>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=yP(zP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=xP(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=xP(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Ee(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=yP(+E(m*m),r),x[s+4>>2]=u;Ee(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;g=(f+12|0)+D(c,12)|0;j=x[g+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[g+36>>1];w[d+110>>1]=z[g+42>>1];w[d+112>>1]=z[g+40>>1];w[d+114>>1]=z[g+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;BP(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(yd(b)){rU(b,x[a+24620>>2])}}function hoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,D=0;h=fb-4128|0;fb=h;g=Cb(y[a+14|0]|y[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(z[j>>1]<=y[a+23|0]){break a}kd(d,32);w[d+34>>1]=1;f=h+12|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;UV(h+4120|0,x[h+12>>2],x[h+16>>2],Cb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4120>>2];i=y[xb(g,0)+3|0];x[h+12>>2]=1;i=x[$c(qi(b,i+1|0)+24|0,f)>>2];k=f;f=x[h+4124>>2];UV(k,g,f,c?f:1);C=h,D=wb(x[h+12>>2]),x[C+4108>>2]=D;q=1/+(i>>>0);f=fb-16|0;fb=f;i=x[zb(f+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=f+16|0;f=x[d>>2];k=x[h+4120>>2];j=z[j>>1];while(1){g=x[h+4108>>2];if(Ib(g,i)){l=y[g+3|0];b:{if(l>>>0>=j>>>0){break b}g=v[g+1|0];if((g|0)<0){break b}l=qi(b,l+1|0);n=x[l>>2];f=Xe(q*(zi(+(g-v[xb(k,0)+1|0]|0)/-12)*+(n>>>0)*+A[l+24>>2]))+f|0;x[d>>2]=f}Pe(h+4108|0);continue}else{c:{r=Bh(d);if(!r){break c}j=(e<<12>>>0)/1e4|0;f=x[h+4124>>2];e=fb-16|0;fb=e;i=h+4108|0;x[i>>2]=0;x[i+4>>2]=0;qc(i+8|0);Nd(e+8|0,x[zb(e+4|0,i)>>2]);d:{if(!f){break d}x[31721]=0;O(758,i|0,f|0);g=x[31721];x[31721]=0;if((g|0)!=1){x[31721]=0;GV(i,f);f=x[31721];x[31721]=0;if((f|0)!=1){break d}}a=N()|0;FV(e+8|0);Q(a|0);p()}f=e+8|0;Md(f);FV(f);fb=e+16|0;t=x[i>>2];l=x[h+4120>>2];u=x[h+4124>>2];B=b+480190|0;f=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=xb(l,f);e=TV(t,f);k=y[g+3|0];e:{if(k>>>0>=z[B>>1]){break e}o=v[g+1|0];if((o|0)<0){break e}n=0;g=y[g+2|0];if((g+14&255)>>>0<=5){n=v[g+25150|0]}k=qi(b,k+1|0);g=x[k+24>>2];s=q*(zi(+(n<<24>>24)/96+ +(o-v[xb(l,0)+1|0]|0)/12)*+(g>>>0));if(s<=0){break e}g=SV(s);x[e+8>>2]=g;n=hb;x[e+12>>2]=n;x[e+16>>2]=x[k+20>>2];o=x[k>>2];x[e+76>>2]=o;x[e+88>>2]=z[k+34>>1]&1023;f:{if(c){x[e+664>>2]=m;m=Xe(+(o>>>0)/bC(g,n))+m|0;g=j;break f}g=(j>>>0)/(Cb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){g:{a=x[d>>2];if(a>>>0>b>>>0){Tb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;c=x[Gb(h+8|0,h+4|0)>>2];C=h,D=wb(x[i>>2]),x[C+8>>2]=D;j=wb(x[i+4>>2]);while(1){a=x[h+8>>2];if(!Ib(a,j)){break g}h:{i:{if(!x[a+16>>2]){break i}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break i}f=x[a+88>>2];x[h+4>>2]=c-e;C=h,D=Xe((+A[a+76>>2]-bC(x[a>>2],x[a+4>>2]))/bC(x[a+8>>2],x[a+12>>2])),x[C>>2]=D;m=x[Gb(h+4|0,h)>>2];x[31721]=0;V(x[((f&1|(f&64?18:16))<<2)+25744>>2],a|0,g|0,(h+12|0)+(e<<3)|0,m|0);e=x[31721];x[31721]=0;if((e|0)==1){break h}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break i}x[a+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;RV(i);Q(a|0);p()}RV(i);break c}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;a=fb-16|0;fb=a;x[a+12>>2]=c;uc(a+12|0,512);m=x[a+12>>2];while(1){if(m){j=od(x[f>>2]+2048|0,12);j=(j|0)>=32767?32767:j;w[e>>1]=(j|0)<=-32768?-32768:j;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}break}}fb=h+4128|0;return f|0}function ov(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[31602]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=126388,j=x[31597]&Cua(-2,c>>>3|0),x[i>>2]=j;break b}g=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[31599]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!g){break b}d=x[a+28>>2];e=(d<<2)+126692|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=126392,j=x[31598]&Cua(-2,d),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=g;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[31603]==(f|0)){x[31603]=a;b=x[31600]+b|0;x[31600]=b;x[a+4>>2]=b|1;if(x[31602]!=(a|0)){break a}x[31599]=0;x[31602]=0;return}if(x[31602]==(f|0)){x[31602]=a;b=x[31599]+b|0;x[31599]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=126388,j=x[31597]&Cua(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}g=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!g){break h}d=x[f+28>>2];e=(d<<2)+126692|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=126392,j=x[31598]&Cua(-2,d),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=g;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31602]!=(a|0)){break g}x[31599]=b;return}if(b>>>0<=255){c=(b&-8)+126428|0;d=x[31597];b=1<<(b>>>3);l:{if(!(d&b)){x[31597]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+126692|0;m:{e=x[31598];h=1<<d;n:{if(!(e&h)){x[31598]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function fZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-128|0;fb=g;i=mg(g+116|0);a:{b:{c:{if(d){x[31721]=0;S(486,a|0,i|0,c|0);c=x[31721];x[31721]=0;if((c|0)!=1){break c}break b}x[31721]=0;S(487,a|0,i|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}}k=Nb(g+104|0);m=b+480192|0;n=b+1298472|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[m>>1]){x[31721]=0;w[g+102>>1]=0;O(488,a|0,g+102|0);d=x[31721];x[31721]=0;t:{u:{v:{w:{if((d|0)!=1){j=fb-16|0;fb=j;o=z[g+102>>1];d=ae(i);e=dc(i);f=fb-16|0;fb=f;while(1){if(d){l=Uo(z[d+16>>1],o);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[zb(f+12|0,e)>>2];fb=f+16|0;x:{if(Ib(d,ng(i))){if(!Uo(z[g+102>>1],z[rd(d)>>1])){break x}}d=ng(i)}d=zb(j+12|0,d);fb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Vg(d,Kf(i))){break u}x[31721]=0;d=P(3,g+88|0,rd(d)+4|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break t}x[31721]=0;e=P(1,g+76|0,16786)|0;f=x[31721];x[31721]=0;if((f|0)==1){break v}f=Wq(d,e);tb(e);if(f){break p}e=x[b+4>>2];x[31721]=0;e=P(489,e|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31721]=0;e=P(1,g- -64|0,13543)|0;f=x[31721];x[31721]=0;y:{z:{A:{if((f|0)!=1){B:{if(!Wq(d,e)){x[31721]=0;f=P(1,g+52|0,13703)|0;h=x[31721];x[31721]=0;if((h|0)==1){break A}h=Wq(d,f);tb(f);tb(e);if(h){break B}break s}tb(e)}x[31721]=0;e=R(490,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break z}x[g+36>>2]=e;e=x[b+4>>2];f=x[pe(g+48|0,g+36|0)>>2];x[31721]=0;e=P(491,e|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break y}Hg(g+36|0);if(e){break e}break s}c=N()|0;break g}c=N()|0;tb(e);break g}c=N()|0;break g}c=N()|0;Hg(g+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Qd(k);dZ(i);fb=g+128|0;return}e=wb(x[k>>2]);h=wb(x[k+4>>2]);f=fb-16|0;fb=f;x[f+12>>2]=e;while(1){C:{if(!Ib(e,h)){break C}if(Wq(e,d)){break C}e=x[Uq(f+12|0)>>2];continue}break}fb=f+16|0;if(Ib(e,wb(x[k+4>>2]))){break p}x[31721]=0;O(492,k|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){break q}}c=N()|0;break g}x[31721]=0;e=P(1,g+12|0,17503)|0;f=x[31721];x[31721]=0;if((f|0)==1){break o}x[31721]=0;S(493,g+24|0,e|0,d|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}x[31721]=0;f=P(1,g|0,16362)|0;h=x[31721];x[31721]=0;if((h|0)==1){break m}x[31721]=0;S(2,g+36|0,g+24|0,f|0);h=x[31721];x[31721]=0;if((h|0)==1){break l}h=x[n>>2];x[31721]=0;S(389,h|0,2,g+36|0);h=x[31721];x[31721]=0;if((h|0)==1){break k}tb(g+36|0);tb(f);tb(g+24|0);tb(e)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(g+36|0)}tb(f)}tb(g+24|0)}tb(e)}tb(d)}Qd(k);break a}tb(d)}c=c+1|0;continue}}c=N()|0}dZ(i);Q(c|0);p()}function _0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Gb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;lo(c,x[Gb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Eh(a,b,i);h=Eh(a,b,i+4|0);f=Eh(a,b,i+5|0);u=e,w=Eh(a,b,i+6|0)<<8|Eh(a,b,i+7|0),x[u+28>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=$b(8);x[31721]=0;a=R(191,i|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=Eh(a,b,i+t|0),v[u+24|0]=w;ko(c,e+24|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}xi(e+28|0,d);s=x[e+28>>2];o=Eh(a,b,i+10|0);v[e+24|0]=o;ko(c,e+24|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=Lg(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Lg(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Lg(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Lg(j,f,1,e+8|0)){break o}k=Lg(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=$b(8);x[31721]=0;b=R(191,a|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=$b(8);x[31721]=0;b=R(191,a|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break q}}b=N()|0;ic(a);Q(b|0);p()}da(b|0,24424,165);p()}da(b|0,24424,165);p()}m=y[h+24464|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=Eh(x[e+8>>2],x[e+12>>2],h);o=o-od((Eh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|Eh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+24|0]=o;ko(c,e+24|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Lg(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Lg(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Lg(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Lg(j,g+4|0,1,e+8|0)){g=g+8|0;f=Lg(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Lg(j,f,5,e+8|0);break u}g=f+2|0;f=Lg(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Lg(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Lg(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=Lg(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Rc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[vb(x[c>>2],g)|0];v[e+24|0]=o;ko(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=$b(8);x[31721]=0;a=R(191,i|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}da(a|0,24424,165);p()}q=q-(q>>3)|0;continue}}da(a|0,24424,165);p()}i=kc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;ic(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=n+t|0;continue}}fb=e+32|0;return i|0}function Hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-32|0;fb=j;a:{b:{if(Ru(a)>>>0<b>>>0){if((b|0)<0){break b}n=No(j+20|0);x[31721]=0;O(765,n|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}fn(j+12|0,x[a>>2]);Nq(j+4|0,x[a>>2],x[a+4>>2]);m=fb-48|0;fb=m;d=x[n+4>>2];c=fc(m+40|0,x[j+12>>2],x[j+16>>2]);e=fc(m+32|0,x[j+4>>2],x[j+8>>2]);b=fb-16|0;fb=b;c=fc(b+8|0,x[c>>2],x[c+4>>2]);e=fc(b,x[e>>2],x[e+4>>2]);c=SW(x[c>>2],x[c+4>>2],x[e>>2],x[e+4>>2]);fb=b+16|0;c=c+d|0;x[n+4>>2]=c;c:{d:{if(!d){b=c-1|0;break d}b=c-1|0;if((b^d-1)>>>0<32){break c}}x[x[n>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}e=fc(m+24|0,x[j+12>>2],x[j+16>>2]);c=fc(m+16|0,x[j+4>>2],x[j+8>>2]);b=m+8|0;pp(b,x[n>>2],d);d=x[e>>2];o=fb-48|0;fb=o;e=x[e+4>>2];e:{if((e|0)==x[b+4>>2]){e=fc(o+40|0,d,e);c=fc(o+32|0,x[c>>2],x[c+4>>2]);b=fc(o+24|0,x[b>>2],x[b+4>>2]);d=fb-16|0;fb=d;f=x[e>>2];g=x[e+4>>2];c=en(x[c>>2],x[c+4>>2],f,g);x[d+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(g){i=32-g|0;x[d+8>>2]=i;k=c;c=x[qd(d+8|0,d+12|0)>>2];x[d+12>>2]=k-c;h=x[b>>2];g=-1<<g&-1>>>i-c;x[h>>2]=x[h>>2]&(g^-1)|g&x[f>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);f=x[e>>2]+4|0;x[e>>2]=f;c=x[d+12>>2]}k=f;f=(c|0)/32|0;NC(k,f,x[b>>2]);g=c-(f<<5)|0;x[d+12>>2]=g;f=f<<2;c=f+x[b>>2]|0;x[b>>2]=c;if((g|0)<=0){break f}c=e;e=f+x[e>>2]|0;x[c>>2]=e;c=x[b>>2];f=-1>>>32-g|0;x[c>>2]=x[c>>2]&(f^-1)|f&x[e>>2];x[b+4>>2]=x[d+12>>2]}fc(m,c,x[b+4>>2]);fb=d+16|0;break e}g=fc(o+16|0,d,e);d=fc(o+8|0,x[c>>2],x[c+4>>2]);f=fc(o,x[b>>2],x[b+4>>2]);e=fb-16|0;fb=e;c=x[d>>2];k=x[d+4>>2];b=x[g>>2];d=x[g+4>>2];c=en(c,k,b,d);x[e+12>>2]=c;g:{if((c|0)<=0){d=x[f+4>>2];break g}h:{if(!d){d=x[f+4>>2];break h}l=32-d|0;x[e+8>>2]=l;i=e+8|0;h=x[qd(i,e+12|0)>>2];x[e+12>>2]=c-h;c=x[f+4>>2];q=x[b>>2];x[e+8>>2]=h;k=32-c|0;x[e+4>>2]=k;b=x[f>>2];r=x[b>>2];i=x[Gb(i,e+4|0)>>2];l=q&(-1<<d&-1>>>l-h);x[b>>2]=(-1<<c&-1>>>k-i^-1)&r|(c>>>0>d>>>0?l<<c-d:l>>>d-c|0);c=c+i|0;d=c&31;x[f+4>>2]=d;c=b+(c>>>3&536870908)|0;x[f>>2]=c;b=h-i|0;if((b|0)>0){x[c>>2]=x[c>>2]&(-1>>>32-b^-1)|l>>>i+x[g+4>>2];x[f+4>>2]=b;d=b}b=x[g>>2]+4|0;x[g>>2]=b;c=x[e+12>>2]}h=32-d|0;i=-1<<d;l=i^-1;while(1){if((c|0)>=32){c=x[f>>2];b=x[b>>2];x[c>>2]=l&x[c>>2]|b<<d;x[f>>2]=c+4;x[c+4>>2]=i&x[c+4>>2]|b>>>h;c=x[e+12>>2]-32|0;x[e+12>>2]=c;b=x[g>>2]+4|0;x[g>>2]=b;continue}break}if((c|0)<=0){break g}l=x[b>>2];x[e+8>>2]=h;g=x[f>>2];b=x[g>>2];k=b;b=x[qd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-c;x[g>>2]=k|h<<d;c=b+d|0;d=c&31;x[f+4>>2]=d;c=g+(c>>>3&536870908)|0;x[f>>2]=c;g=x[e+12>>2]-b|0;x[e+12>>2]=g;if((g|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-g^-1)|h>>>b;d=x[e+12>>2];x[f+4>>2]=d}fc(m,x[f>>2],d);fb=e+16|0}fb=o+48|0;fb=m+48|0;VB(a,n);yf(n)}fb=j+32|0;return}cd();p()}a=N()|0;yf(n);Q(a|0);p()}function f1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-144|0;fb=d;vc(b);Ap(a);a:{if(!Ow(b,d+108|0)){break a}if(!NF(d+108|0)){break a}j=x[b+8>>2];b:{if(!bd(b,y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24))){break b}while(1){c:{if((y[d+120|0]|y[d+121|0]<<8|(y[d+122|0]<<16|y[d+123|0]<<24))>>>0>h>>>0){if(Mb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=64){if((Ni(b)|0)<=0){break d}}while(1){l=Xd(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(yq(l<<24>>24)&255)==y[f+13165|0]}g=e;f=f+1|0;continue}break}Ub(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}bd(b,j);if(!f){break a}if(!Mb(x[b>>2],x[b+8>>2],LF(d+108|0))){break a}if(!c){k=1;break a}g=fb-16|0;fb=g;e=d+108|0;bd(b,y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24));i=d+96|0;f=Nb(i);c=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);x[31721]=0;O(179,f|0,c|0);c=x[31721];x[31721]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24))>>>0<=c>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[31721]=0;h=U(153,j|0,h|0,5)|0;j=x[31721];x[31721]=0;if((j|0)==1){break g}if(!h){break h}h=y[e+4|0]|y[e+5|0]<<8;x[31721]=0;S(180,g+4|0,b|0,h|0);h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;O(181,f|0,g+4|0);h=x[31721];x[31721]=0;if((h|0)==1){break i}c=c+1|0;tb(g+4|0);continue}break}c=N()|0;break f}c=N()|0;tb(g+4|0);break f}fb=g+16|0;break e}c=N()|0;break f}c=N()|0}Qd(f);Q(c|0);p()}x[31721]=0;V(173,d+84|0,b|0,e|0,i|0);c=x[31721];x[31721]=0;j:{if((c|0)!=1){x[31721]=0;P(152,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31721];x[31721]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31721]=0;c=U(153,e|0,c|0,8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break q}if(c){break p}}k=kc(x[a>>2],x[a+4>>2])^1;sc(d+84|0);Qd(d+96|0);break a}b=N()|0;break k}x[31721]=0;aa(174,d+60|0,b|0,d+108|0,d+84|0,d+96|0);c=x[31721];x[31721]=0;if((c|0)!=1){e=Cp(d+60|0);x[31721]=0;c=R(175,x[d+60>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break o}if(c){x[31721]=0;c=R(176,d+24|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+96>>2];if(Rd(f,x[d+100>>2])>>>0<=e>>>0){break r}x[31721]=0;O(177,d+12|0,Dd(f,e)|0);e=x[31721];x[31721]=0;if((e|0)==1){break m}e=d+12|0;yb(c,e);tb(e)}Mw(g,d+60|0);x[31721]=0;O(178,a|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break m}Tr(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break k}b=N()|0;break l}b=N()|0;break l}b=N()|0;Tr(c)}ub(d+60|0);break k}b=N()|0}sc(d+84|0);break j}b=N()|0}Qd(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function qG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){Zw(d+108|0,b);x[31721]=0;b=P(1,d+96|0,18377)|0;e=x[31721];x[31721]=0;if((e|0)==1){break E}x[31721]=0;S(2,d+120|0,d+108|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break D}x[31721]=0;c=P(3,d+72|0,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break C}x[31721]=0;e=P(1,d+60|0,20182)|0;f=x[31721];x[31721]=0;if((f|0)==1){break B}x[31721]=0;S(4,d+84|0,c|0,e|0);f=x[31721];x[31721]=0;if((f|0)==1){break A}x[31721]=0;S(2,d+132|0,d+120|0,d+84|0);f=x[31721];x[31721]=0;if((f|0)==1){break z}tb(d+84|0);tb(e);tb(c);c=d+120|0;tb(c);tb(b);tb(d+108|0);b=x[a>>2];x[31721]=0;O(5,c|0,(b?b:22250)|0);b=x[31721];x[31721]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31721]=0;O(5,d+108|0,(b?b:22250)|0);b=x[31721];x[31721]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31721]=0;x[d+48>>2]=a;O(6,d+84|0,d+48|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}x[31721]=0;P(7,499544,18256)|0;a=x[31721];x[31721]=0;if((a|0)==1){break q}x[31721]=0;O(8,d+48|0,d+120|0);a=x[31721];x[31721]=0;if((a|0)==1){break p}x[31721]=0;P(9,499544,d+48|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break o}x[31721]=0;P(7,499544,17463)|0;a=x[31721];x[31721]=0;if((a|0)==1){break o}x[31721]=0;O(8,d+36|0,d+84|0);a=x[31721];x[31721]=0;if((a|0)==1){break n}x[31721]=0;P(9,499544,d+36|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;P(7,499544,17461)|0;a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;P(7,499544,18377)|0;a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;O(8,d+24|0,d+132|0);a=x[31721];x[31721]=0;if((a|0)==1){break l}x[31721]=0;P(9,499544,d+24|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break k}x[31721]=0;P(7,499544,13569)|0;a=x[31721];x[31721]=0;if((a|0)==1){break k}x[31721]=0;O(8,d+12|0,d+108|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}x[31721]=0;P(9,499544,d+12|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break i}x[31721]=0;P(7,499544,13567)|0;a=x[31721];x[31721]=0;if((a|0)==1){break i}x[31721]=0;R(10,499544)|0;a=x[31721];x[31721]=0;if((a|0)==1){break i}tb(d+12|0);tb(d+24|0);tb(d+36|0);tb(d+48|0);tb(d+84|0);tb(d+108|0);tb(d+120|0);tb(d+132|0)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(e)}tb(c)}tb(d+120|0)}tb(b)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function HP(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;kB(xb(d,0),B[a+4272>>2]);b=E(E(B[xb(d,0)>>2]*E(15920))+E(80));s=Ce(E(10),E(E(E(B[xb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=YP(c);v=jq(c);w=b;f=E(E(c*E(E(E(B[xb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(f),j(2))&2147483647;a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Qy(b)&2047;j:{k:{if(Qy(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Qy(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=GF(0);break j}if(!(b<E(-103.97207641601562))){break k}c=pF(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function Cz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[zl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Ll(f+112|0,h,g,g-1|0);g=x[f+116>>2];x[b>>2]=x[f+112>>2];x[b+4>>2]=g}g=f+112|0;de(g);h=x[f+112>>2];de(f+100|0);i=yl(h,x[f+104>>2],b);de(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+116>>2]){a=oc(f+128|0,22250);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Nc(h,g,f+8|0)){a=$b(8);x[31721]=0;O(1014,f+100|0,f+136|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}x[31721]=0;S(1019,f+112|0,18241,f+100|0);b=x[31721];x[31721]=0;if((b|0)==1){break f}mc(a,f+112|0);e=0;x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break e}if(!e){break h}a=$b(8);c=x[b>>2];b=x[b+4>>2];x[31721]=0;c=ci(f+76|0,c,b);b=x[31721];x[31721]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31721]=0;S(1019,f+88|0,18277,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break p}x[31721]=0;O(1021,f+100|0,f+88|0);b=x[31721];x[31721]=0;e=1;if((b|0)==1){break o}x[31721]=0;O(1014,f- -64|0,f+136|0);b=x[31721];x[31721]=0;if((b|0)==1){break n}x[31721]=0;S(1023,f+112|0,f+100|0,f- -64|0);b=x[31721];x[31721]=0;if((b|0)==1){break m}mc(a,f+112|0);x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);e=0;break l}b=N()|0;break d}b=N()|0;e=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(c);if(e){break d}break c}b=oc(f+56|0,22250);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Nc(h,g,f+32|0)){a=$b(8);x[31721]=0;O(1014,f+100|0,f+136|0);b=x[31721];x[31721]=0;q:{r:{if((b|0)!=1){x[31721]=0;S(1019,f+112|0,18241,f+100|0);b=x[31721];x[31721]=0;if((b|0)==1){break r}mc(a,f+112|0);e=0;x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break q}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(e){break d}break c}b=oc(f+48|0,10974);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Nc(h,g,f+24|0)){zz(a,Fc(c,d));break h}b=oc(f+40|0,8627);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Nc(h,g,f+16|0)){break h}a=x[a+32>>2];b=Cu(c,d);b=b>>>0>=4?1:b;c=fb-16|0;fb=c;s:{if((vk(y[a+140|0])|0)==(b|0)){d=a+120|0;Lt(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[19875];x[a+8>>2]=x[19874];x[a+12>>2]=e;e=x[19873];x[a>>2]=x[19872];x[a+4>>2]=e;ib[x[cq(a,vk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break s}IM(a,b,JM(a))}fb=c+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(!e){break c}}ic(a)}Q(b|0)}p()}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;lo(f,32);v[e+15|0]=0;ko(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Lh(a,2,16777216);break a}Zd(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Hi(f,d+e|0);e=e+1|0;continue}break}if(hd(d,24328,3)){Lh(a,2,512);break a}v[d+335|0]=0;Hi(x[a+36>>2],d+335|0);Tb(d+72|0,0,256);e=y[d+335|0];if(e){zj(x[a+36>>2],d+72|0,e)}f=b;b=rl(d,d+72|0,e);e=xy(f,b);Eb(b);if(!e){Lh(a,2,4096)}if(ol(y[a|0])){break a}Hi(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(tj(b,6)){Oc(d,a+32|0,9);Ef(d,1)}x[d+64>>2]=0;eK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Hi(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Hi(x[a+36>>2],d+63|0);f=-2}Lm(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!tj(b,4)){break b}nl(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Lh(a,1,4)}if(tj(b,5)){Hi(x[a+36>>2],d+71|0);Lm(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!tj(c,0)){break c}Hi(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Lh(a,1,2)}x[a+8>>2]=0;f=1;if(tj(c,1)){eK(x[a+36>>2],a+8|0)}g=tj(b,2);e=a+32|0;Oc(d,e,6);Ef(d,g);g=tj(b,3);Oc(d,e,7);Ef(d,g);g=z[a+24>>1];Oc(d,e,5);Ef(d,(g|0)!=0);b=tj(b,7);Oc(d,e,8);Ef(d,b);Oc(d,e,5);d:{if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break d}Oc(d+40|0,e,6);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Oc(d+32|0,e,7);if(Hb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Oc(d+24|0,e,8);f=Hb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Oc(b,e,11);Ef(b,f);Oc(d,e,11);if(tj(c,2)){w[d+40>>1]=0;oy(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Oc(d,e,9);Lm(b,f<<Hb(x[x[d>>2]>>2],x[d+4>>2]))}if(tj(c,3)){Lm(x[a+36>>2],5)}nl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Lh(a,2,8192);break a}x[a+104>>2]=b;if(!b){Lh(a,1,1)}Oc(d,e,11);e:{if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break e}nl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(ky(b,c)){break e}Lh(a,2,2048);break a}Zd(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Lh(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Oc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Hb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Oc(d,e,11);if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Oc(d,e,10);Ef(d,1)}fb=d+336|0}function aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=Nf(x[x[b+48>>2]+12>>2]);d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;qc(g+8|0);Nd(e+8|0,x[zb(e+4|0,g)>>2]);c:{d:{if(d){x[31721]=0;O(464,g|0,d|0);f=x[31721];x[31721]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=qr(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){gc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;Ig(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Md(d);cm(d);fb=e+16|0;break c}a=N()|0;cm(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31721]=0;v[c+19|0]=0;P(924,a|0,c+19|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31721]=0;P(924,a|0,c+18|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=jd(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Vc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break u}e=Vc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Ok(g);break b}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break q}e=Vc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break n}e=Vc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break k}e=Vc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break h}e=Vc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31721]=0;P(924,a|0,c+17|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break e}e=Vc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31721]=0;P(924,a|0,c+7|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;P(925,a|0,y[c+7|0])|0;d=x[31721];x[31721]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Ok(g);Q(a|0);p()}function wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=mB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=kf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=kf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=kf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=kf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=kf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=kf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=kf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=kf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=kf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=kf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=kf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=kf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=kf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=kf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=kf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Bd(y[f+12|0])){if(!Bd(y[f+12|0])){a=$b(4);x[a>>2]=0;a=Ij(a);x[a>>2]=121420;da(a|0,121456,846);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{d=x[f+8>>2];if(!d){Pf(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31721]=0;O(96,a|0,vh(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){while(1){if(vh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[bc(b+20|0,c)|0];x[31721]=0;O(98,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}e=b+8|0;Pf(e,c);x[31721]=0;S(11,b+20|0,d|0,e|0);c=x[31721];x[31721]=0;n:{o:{if((c|0)!=1){x[31721]=0;O(12,a|0,b+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break o}Rb(b+20|0);tb(b+8|0);break l}c=N()|0;break n}c=N()|0;Rb(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}W$(a,22,c)}fb=f+16|0}function TH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=fb-48|0;fb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=mL(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}fb=h+48|0;return d}function Npa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-560|0;fb=f;a:{if(!bd(b,1464)){break a}if(!Yq(b,f+556|0)){break a}Ad(a,1);Lb(Lb(Zf(a+1074312|0,83),84,1),85,1);b:{if(me(f+556|0,25236)){d=f+32|0;e=rc(d,8430);yb(a+1298344|0,e);tb(e);e=rc(d,14820);yb(a+1298356|0,e);tb(e);e=rc(d,14885);yb(a+1298368|0,e);break b}if(!me(f+556|0,15569)){break a}d=f+32|0;e=rc(d,8604);yb(a+1298344|0,e);tb(e);e=rc(d,12340);yb(a+1298356|0,e);tb(e);e=rc(d,15486);yb(a+1298368|0,e)}tb(e);s=a+1298404|0,t=x[Ec(d,28)>>2],x[s>>2]=t;bd(b,0);lZ(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+554|0;ww(d,b);m=Hc(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){zX(e);break c}dE(d+8|0,e);pd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Uh(a,0);o=a+484376|0;sg(Wb(x[a+484360>>2],y[o|0]),y[f+554|0]);l=a+484344|0;Of(l,y[f+554|0]);while(1)if(y[f+554|0]<=i>>>0){if(!(c&2)){break a}bd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){ag(Wc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{s=Zb(x[Wb(x[a+484360>>2],y[o|0])>>2],i),t=i,w[s>>1]=t;d:{if(!Kg(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,t=wb(x[Vb(x[l>>2],i)>>2]),x[s+24>>2]=t;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;k=h;g=j&15;h=(g|0)!=(h|0)&(g|0)!=0;p=h?k:p;q=h?g:q}d=d+1|0;sC(f+24|0);continue}break}xe(Vb(x[l>>2],i),Ve(Le(f+8|0,16,y[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}bd(b,(y[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Vb(x[l>>2],i);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{k=f+8|0;k$(k,b,d);j=y[f+8|0];k=y[Hc(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){xf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{e=f+32|0;vC(b,e);g=DC(e,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function dP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-192|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[zl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Ll(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;de(f);e=x[d+168>>2];de(d+156|0);e=yl(e,x[d+160>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+184|0,22250);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Nc(e,a,d)){a=$b(8);x[31721]=0;c=P(37,d+168|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=$b(8);c=x[b+4>>2];b=x[b>>2];x[31721]=0;e=ci(d+156|0,b,c);b=x[31721];x[31721]=0;f:{g:{h:{if((b|0)!=1){x[31721]=0;S(1019,d+168|0,18277,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break h}mc(a,d+168|0);c=0;x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(d+168|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}ic(a);break c}if(x[e+4>>2]){a=$b(8);x[31721]=0;c=P(37,d+168|0,11584)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d+148|0,22250);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Nc(b,c,d+72|0)){a=$b(8);x[31721]=0;c=P(37,d+168|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}e=oc(d+140|0,7462);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Nc(b,c,d- -64|0)){e=oc(d+132|0,7444);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Nc(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=oc(d+124|0,6989);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Nc(b,c,d+48|0)){e=oc(d+116|0,6970);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Nc(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=oc(d+108|0,7073);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Nc(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=oc(d+100|0,6064);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=oc(d+92|0,7511);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=oc(d+84|0,13509);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Nc(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;ic(a)}Q(b|0)}p()}function cn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31721]=0;a=R(284,b|0)|0;c=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[31721]=0;c=U(153,d|0,c|0,a|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}if(c){break d}x[31721]=0;a=R(205,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;P(186,b|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31721]=0;S(188,e+24|0,b|0,a|0);b=x[31721];x[31721]=0;f:{g:{h:{if((b|0)!=1){b=e+24|0;c=hc(e+44|0,b);ub(b);if(a>>>0<10){break g}x[31721]=0;b=R(740,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}if(!b){break g}x[31721]=0;b=R(284,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}x[e+20>>2]=b;a=a-10|0;uc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31721]=0;d=x[e+20>>2];O(290,h|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[31721]=0;a=P(741,f|0,a|0)|0;f=x[31721];x[31721]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31721]=0;a=R(537,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31721]=0;a=R(200,c|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[31721]=0;g=U(153,i|0,g|0,a|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}if(!g){continue}le(e+24|0,x[h>>2],x[h+4>>2]);kr(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31721]=0;Sn(475,e,c,x[e+8>>2],x[e+12>>2]);f=x[31721];x[31721]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[31721]=0;a=R(200,c|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[31721]=0;i=P(742,c|0,e+16|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=dc(f);av(f,i,Ne(wb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[31721]=0;a=P(742,c|0,e+16|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}if(!a){continue}a=e+16|0;f=dc(a);av(a,f,Ne(wb(x[h>>2]),b));av(a,f,Ne(Ne(wb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[31721]=0;a=R(200,c|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}Nb(cc(h));break f}x[31721]=0;S(336,c|0,h|0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}}ub(c)}fb=e- -64|0;return}a=N()|0;ub(c)}cc(h);Q(a|0);p()}function qe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31721]=0;O(117,b|0,Xc(e,d)|0);d=x[31721];x[31721]=0;d:{if((d|0)!=1){e:{while(1){if(Xc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Td(c,a)>>2];x[31721]=0;O(118,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31721];x[31721]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31721]=0;O(117,b|0,Xc(e,d)|0);d=x[31721];x[31721]=0;f:{if((d|0)!=1){g:{while(1){if(Xc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Td(c,a)>>2];x[31721]=0;O(118,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31721];x[31721]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:bf(a,c,48912);return;case 4:bf(a,c,49936);return;case 5:bf(a,c,50960);return;case 6:bf(a,c,51984);return;case 7:bf(a,c,53008);return;case 8:bf(a,c,54032);return;case 9:bf(a,c,55056);return;case 10:bf(a,c,56080);return;case 11:bf(a,c,57104);return;case 12:bf(a,c,58128);return;case 13:bf(a,c,59152);return;case 14:bf(a,c,60176);return;case 15:bf(a,c,61200);return;case 16:bf(a,c,62224);return;case 17:bf(a,c,63248);return;case 18:bf(a,c,64272);return;case 19:bf(a,c,65296);return;case 20:bf(a,c,66320);return;case 21:bf(a,c,67344);return;case 22:bf(a,c,68368);return;case 23:bf(a,c,69392);return;case 24:px(a,c,70416);return;case 25:px(a,c,48912);return;case 26:px(a,c,67344);return;default:a=$b(8);x[31721]=0;b=P(16,a|0,11106)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}b=N()|0;ic(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(Xc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Td(c,g)>>2];if(b>>>0>=2097152){x[31721]=0;O(118,f|0,63);a=x[31721];x[31721]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31721]=0;O(118,f|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[31721]=0;O(118,f|0,(a|i)<<24>>24);h=x[31721];x[31721]=0;a=d;break l}x[31721]=0;a=a-1|0;O(118,f|0,v[a+(e+10|0)|0]|-128);h=x[31721];x[31721]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,125116,17);p()}a=N()|0;tb(b);Q(a|0);p()}function eka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=42016;x[a+4>>2]=0;x[a>>2]=30560;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Hq(a+24604|0);jS(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Tb(b+28|0,0,40);Tb(b+68|0,0,49824);Tb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;UE(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[31721]=0;i=P(854,a+484360|0,a|0)|0;b=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[31721]=0;b=R(713,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[31721]=0;R(855,a+901404|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){cS(d+D(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=Ou(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;Sr(a+1074312|0);x[31721]=0;X(856);b=x[31721];x[31721]=0;if((b|0)==1){break g}s=a,t=bS(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;UR(b,4);x[31721]=0;e=R(857,a+1074376|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break g}x[31721]=0;j=U(607,a+1298264|0,a|0,255)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}k=qc(a+1298300|0);l=qc(a+1298304|0);m=Fb(a+1298308|0);n=Fb(a+1298320|0);o=Fb(a+1298332|0);q=iS(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;qq(a+12|0);FA(a+8204|0);FA(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Tb(c,0,1024);aS(g);x[31721]=0;b=R(858,12)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;hS(r);IA(q);tb(o);tb(n);tb(m);HA(l);GA(k);zu(j)}WA(e)}fS(d)}LB(i)}ZR(f);sc(h);Q(b|0);p()}function zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Qf(d+62|0,32);j=Nb(a);x[31721]=0;o=z[d+62>>1];O(541,j|0,o|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){k=b+480190|0;q=b+480192|0;c:{d:{while(1){if((r&65535)>>>0>=o>>>0){break d}e=1;c=z[k>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=qi(b,f);if(!ge(x[g>>2],x[g+20>>2])){if(!Ib(uC(wb(x[j>>2]),wb(x[j+4>>2]),e),wb(x[j+4>>2]))){break i}c=z[k>>1]}e=e+1|0;continue}break}w[d+60>>1]=e;a=1;while(1){c=a&65535;if(c>>>0>z[q>>1]){a=e}else{j:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=gr(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}e=No(d+48|0);x[31721]=0;a=P(781,b|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}if(!a){break e}x[31721]=0;O(782,b|0,e|0);c=x[31721];x[31721]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[q>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=gr(c);while(1){if((c|0)==(f|0)){break k}g=z[c>>1];l:{if(g>>>0>=A[d+52>>2]){break l}Kb(d+40|0,x[e>>2],g);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}fn(d+24|0,x[e>>2]);hV(d+32|0,x[d+24>>2],x[d+28>>2],1);Nq(d+16|0,x[e>>2],x[d+52>>2]);m=fb-16|0;fb=m;g=d+40|0;c=fc(m,x[d+32>>2],x[d+36>>2]);a=en(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);f=fb-16|0;fb=f;x[f+12>>2]=a;h=x[c+4>>2];m:{if(h){i=32-h|0;x[f+8>>2]=i;n=x[Gb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=x[c>>2];l=l&(x[i>>2]^-1);if(l){fc(g,i,yua(l));break m}if((a|0)==(n|0)){hV(g,i,h,a);break m}a=a-n|0;x[f+12>>2]=a;x[c>>2]=i+4}while(1){if(a>>>0>=32){h=x[c>>2];i=x[h>>2];if((i|0)!=-1){fc(g,h,yua(i^-1));break m}else{x[c>>2]=h+4;a=a-32|0;x[f+12>>2]=a;continue}}break}if(!a){fc(g,x[c>>2],0);break m}c=x[c>>2];h=(x[c>>2]^-1)&-1>>>32-a;if(!h){fc(g,c,a);break m}fc(g,c,yua(h))}fb=f+16|0;fb=m+16|0;fn(d+8|0,x[e>>2]);a=en(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;yf(e);if((a&65535)>>>0>3999){break f}}x[31721]=0;O(260,j|0,d+60|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}if(z[k>>1]>=(a&65535)>>>0){break f}w[k>>1]=a}r=r+1|0;continue}break}yf(e)}fb=d- -64|0;return}c=N()|0;break a}c=N()|0;break a}c=N()|0;yf(e)}ld(j);Q(c|0);p()}function hpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){Kg(c+484344|0,b,64);break a}k=c+484344|0;l=Hd(Rk(a),1,1024);if(!Kg(k,b,l)){break a}n=z[c+480188>>1];o=c+480190|0;b:while(1){if((j|0)==(l|0)){break a}e=Vb(x[k>>2],b);_e(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],j);i=0;while(1)if((i|0)==(n|0)){j=j+1|0;continue b}else{e=Vc(x[g+8>>2],i);f=g+4|0;jm(f,a);p=Ye(f);f=cj(f);h=y[g+4|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;m=y[Hc(g+4|0)|0];h=m+1|0;v[e+1|0]=h;q=h;h=h&255;if((q|0)!=(h|0)|h>>>0>z[o>>1]){break c}h=qi(c,h);if(!(!y[vb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[xb(h,0)>>2]==1){if(y[vb(d,i)|0]){break d}}if(x[xb(h,0)>>2]){break c}if(y[vb(d,i)|0]){break c}}v[e+1|0]=m+101}e:{f:{switch(y[p|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;r=e,s=y[Sb(g,f)|0]|16,v[r+5|0]=s;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;r=e,s=y[Sb(g,f)|0]|16,v[r+5|0]=s;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;r=e,s=y[Sb(g,f)|0]|80,v[r+5|0]=s;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;r=e,s=y[Sb(g,f)|0]|80,v[r+5|0]=s;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:Oo(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){r=e,s=y[vb(d,i)|0]?22:11,v[r+3|0]=s;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[vb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;r=e,s=y[Sb(g,g+3|0)|0]|240,v[r+5|0]=s;break g;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;r=e,s=y[Sb(g,g+3|0)|0]<<4|15,v[r+5|0]=s;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=vb(d,i);f=Vc(x[g+8>>2],v[f|0]+i|0);zr(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}fb=g+16|0}function naa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[31721]=0;e=ca(1154)|0;f=x[31721];x[31721]=0;d:{e:{f:{if((f|0)!=1){x[d+72>>2]=e;x[31721]=0;c=R(1155,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break e}x[d+152>>2]=c;oo(e,c);a=Fe(d+132|0,a);x[31721]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1147,e|0,d+48|0,15)|0;c=x[31721];x[31721]=0;if((c|0)==1){break f}if(a){x[31721]=0;W(859,e|0);a=x[31721];x[31721]=0;g=1;if((a|0)==1){break f}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break d}c=T(0)|0}sh(d+72|0);break c}if(b>=.6){x[31721]=0;e=ca(1154)|0;f=x[31721];x[31721]=0;g:{h:{i:{if((f|0)!=1){x[d+72>>2]=e;x[31721]=0;c=R(1155,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break h}x[d+152>>2]=c;oo(e,c);a=Fe(d+112|0,a);x[31721]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1147,e|0,d+24|0,2)|0;c=x[31721];x[31721]=0;if((c|0)==1){break i}if(a){x[31721]=0;W(859,e|0);a=x[31721];x[31721]=0;g=.8;if((a|0)==1){break i}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break g}c=T(0)|0}sh(d+72|0);break c}g=.2;if(b>=.2){x[31721]=0;e=ca(1154)|0;f=x[31721];x[31721]=0;j:{k:{l:{if((f|0)!=1){x[d+72>>2]=e;x[31721]=0;c=R(1155,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}x[d+152>>2]=c;oo(e,c);a=Fe(d+92|0,a);x[31721]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1147,e|0,d|0,0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break l}g=0;if(a){x[31721]=0;W(859,e|0);a=x[31721];x[31721]=0;g=.6;if((a|0)==1){break l}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break j}c=T(0)|0}sh(d+72|0);break c}if(!(b>=.1)){break b}x[31721]=0;S(189,d+72|0,a|0,2048);c=x[31721];x[31721]=0;if((c|0)!=1){c=Se(d+72|0);a=x[a>>2];x[31721]=0;e=x[d+72>>2];a=R(157,a|0)|0;f=x[31721];x[31721]=0;m:{if((f|0)==1){break m}x[31721]=0;a=NH(1156,3,0,c,e,a,0);c=x[31721];x[31721]=0;if((c|0)==1){break m}g=C[(a<<3)+79512>>3];Ic(d+72|0);break b}c=T(0)|0;Ic(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;g=0;if((a|0)==1){break a}}Uc(d+156|0);fb=d+160|0;return+g}a=N()|0;Uc(d+156|0);Q(a|0);p()}function Mca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;n=fb-32|0;fb=n;j=of(n+20|0,1,0);a:{b:{while(1){e=Jb(j);i=e+Bb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=yN(g,d);d=hb}k=n+12|0;c:{d:{switch(c<<31|c-2>>>1){case 4:xN(k,e,i,g,d);break c;case 0:f=64-Ot(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15472|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{f=d;e=e-4|0;d=x[(g<<2&60)+78784>>2];v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;d=f>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-Ot(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14757|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{f=d;e=e-2|0;d=z[(g<<1&126)+78848>>1];v[e|0]=d;v[e+1|0]=d>>>8;d=f>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:l=61;h=67-Ot(g|1,d)>>>2|0;e:{if((h|0)>(i-e|0)){break e}i=e+h|0;e=i;while(1){if(!d&g>>>0>=257|d){f=d;e=e-2|0;d=z[(g<<1&510)+78976>>1];v[e|0]=d;v[e+1|0]=d>>>8;d=f>>>8|0;g=(f&255)<<24|g>>>8;continue}break}l=0;if(!h){break e}while(1){e=e-1|0;v[e|0]=y[(g&15)+11165|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}x[k+4>>2]=l;x[k>>2]=i;break c;default:break d}}f=g;h=d;o=D(c,c);q=D(o,c);r=D(o,o);l=0;f:{while(1){m=l|1;if(!h&c>>>0>f>>>0){break f}m=l|2;if(!h&f>>>0<o>>>0){break f}m=l|3;if(!h&f>>>0<q>>>0){break f}if(!h&f>>>0<r>>>0){m=l+4|0}else{l=l+4|0;f=Bua(f,h,r,0);h=hb;continue}break}}h=m;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=Bua(g,d,c,0);f=hb;s=e,t=y[(g-zua(h,f,c,0)|0)+4895|0],v[s|0]=t;o=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(o){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[n+16>>2]){break b}d=mi(Bb(x[j+4>>2],y[j+11|0]));x[31721]=0;O(46,j|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break a}c=x[n+12>>2];b=Jb(j);x[31721]=0;O(47,j|0,c-b|0);b=x[31721];x[31721]=0;g:{if((b|0)!=1){x[31721]=0;O(48,a|0,j|0);a=x[31721];x[31721]=0;if((a|0)!=1){break g}break a}break a}tb(j);fb=n+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function oS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-48|0;fb=i;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;g=fb-16|0;fb=g;e=x[d+4>>2];f=e;h=fb-16|0;fb=h;j=x[d>>2];e=x[zb(h+12|0,Aua(j,e,500654080,20))>>2];fb=h+16|0;h=fb-16|0;fb=h;k=lS(h+8|0,e);l=x[k>>2];fb=h+16|0;h=x[k+4>>2];if(j>>>0<l>>>0&(h|0)>=(f|0)|(f|0)<(h|0)){h=x[zb(g+12|0,1)>>2];f=fb-16|0;fb=f;e=x[zb(f+12|0,e-h|0)>>2];fb=f+16|0}fb=g+16|0;e=x[zb(d+12|0,e)>>2];fb=d+16|0;f=fb-16|0;fb=f;d=fb-16|0;fb=d;g=e+719468|0;k=(((e|0)>-719469?g:e+573372|0)|0)/146097|0;g=D(k,-146097)+g|0;h=((g>>>0)/36524|0)+g-(((g>>>0)/146096|0)+((g>>>0)/1460|0))|0;j=(h>>>0)/365|0;h=((g-((h>>>0)/1460|0)|0)+((h>>>0)/36500|0)|0)+D(j,-365)|0;l=D(h,5)+2|0;g=(l>>>0)/153|0;k=j+D(k,400)|0;j=g+(l>>>0<1530?3:-9)|0;k=uw(d+14|0,k+(j>>>0<3)|0);j=$p(d+13|0,j);g=$p(d+12|0,(h-((D(g,153)+2>>>0)/5|0)|0)+1|0);kS(f+12|0,z[k>>1],j,g);fb=d+16|0;d=x[f+12>>2];w[i+44>>1]=d;w[i+46>>1]=d>>>16;fb=f+16|0;d=fb-16|0;fb=d;e=lS(d,e);g=x[e>>2];c=ue(d+8|0,b-g|0,c-(x[e+4>>2]+(b>>>0<g>>>0)|0)|0);b=x[c>>2];fb=d+16|0;g=fb-16|0;fb=g;c=x[c+4>>2];d=JA(g+8|0,0);m=i,n=mS(b,c,x[d>>2],x[d+4>>2]),v[m+8|0]=n;d=fb-16|0;fb=d;e=ue(d+8|0,0,0);f=x[e>>2];fb=d+16|0;if(!(mS(b,c,f,x[e+4>>2])^1)){d=fb-16|0;fb=d;c=ue(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[zb(d+12|0,Aua(b,c,-694967296,0))>>2];fb=d+16|0;x[i+12>>2]=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;e=ue(f+8|0,zua(e,e>>31,-694967296,0),hb);h=x[e>>2];e=x[e+4>>2];fb=f+16|0;x[d>>2]=h;x[d+4>>2]=e;e=x[d>>2];b=ue(d+8|0,b-e|0,c-(x[d+4>>2]+(b>>>0<e>>>0)|0)|0);c=x[b>>2];e=x[b+4>>2];f=e;fb=d+16|0;b=fb-16|0;fb=b;d=x[zb(b+12|0,Aua(c,e,6e7,0))>>2];fb=b+16|0;x[i+16>>2]=d;b=fb-16|0;fb=b;e=fb-16|0;fb=e;d=ue(e+8|0,zua(d,d>>31,6e7,0),hb);h=x[d>>2];d=x[d+4>>2];fb=e+16|0;x[b>>2]=h;x[b+4>>2]=d;d=x[b>>2];d=ue(b+8|0,c-d|0,f-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0);c=x[d>>2];fb=b+16|0;d=x[d+4>>2];e=KA(c,d);x[i+24>>2]=e;f=hb;x[i+28>>2]=f;b=fb-16|0;fb=b;e=ou(b,e,f);f=x[e>>2];c=ue(b+8|0,c-f|0,d-(x[e+4>>2]+(c>>>0<f>>>0)|0)|0);d=x[c>>2];fb=b+16|0;m=i,n=QQ(d,x[c+4>>2]),x[m+32>>2]=n;x[i+36>>2]=hb;fb=g+16|0;a=nS(a);x[a>>2]=z[i+44>>1]<<16>>16;m=a,n=uf(y[i+46|0]),x[m+4>>2]=n;m=a,n=uf(y[i+47|0]),x[m+8>>2]=n;x[a+12>>2]=x[i+12>>2];x[a+16>>2]=x[i+16>>2];b=x[i+28>>2];x[a+24>>2]=x[i+24>>2];x[a+28>>2]=b;fb=i+48|0}function JZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(zd(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31721]=0;n=R(39,h|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}h=Jb(b);j=Bb(x[b+4>>2],y[b+11|0]);i=Lk(n);f=fb-16|0;fb=f;x[f+12>>2]=i;x[f+8>>2]=0;i=x[We(f+8|0,f+12|0)>>2];fb=f+16|0;x[31721]=0;O(40,k|0,D(j,i+1|0)|0);f=x[31721];x[31721]=0;if((f|0)==1){break c}o=(j<<2)+h|0;j=x[k>>2];m=j+Rc(j,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31721]=0;f=h+4|0;i=za(41,n|0,g+56|0,h|0,f|0,g+52|0,j|0,m|0,g+48|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break f}if((i|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{j=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31721]=0;i=za(41,n|0,g+56|0,h|0,o|0,g+52|0,j|0,m|0,g+48|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}l=1;if((i|0)==1){break k}}l=2;f=x[g+48>>2];if((i|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31721]=0;O(40,k|0,Rc(f,h)<<1);h=x[31721];x[31721]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];j=h+(f-j|0)|0;m=Rc(h,x[k+4>>2])+h|0;i=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(j|0)|(i|0)!=2){break p}x[31721]=0;v[g+47|0]=1;h=P(42,g+8|0,22252)|0;f=x[31721];x[31721]=0;r:{s:{t:{if((f|0)!=1){x[31721]=0;S(43,g+20|0,h|0,b|0);f=x[31721];x[31721]=0;if((f|0)==1){break t}x[31721]=0;aa(44,g+32|0,g+20|0,c|0,1,g+47|0);f=x[31721];x[31721]=0;if((f|0)==1){break s}tb(g+32|0);Rb(g+20|0);Rb(h);if(y[g+47|0]){break o}x[31721]=0;aa(44,a|0,b|0,c|0,2,0);a=x[31721];x[31721]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Rb(g+20|0)}Rb(h);break a;case 1:break q;default:break p}}v[e|0]=(i|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(j|0);Fb(a);break h}if((i|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}j=f}l=(i|0)==2;h=x[g+52>>2];i=o>>>0>h>>>0;if(l&i&f>>>0<m>>>0|i&(d|0)==2){continue}break}b=x[k>>2];x[31721]=0;U(45,a|0,b|0,f|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break e}}cc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}cc(k);Q(f|0);p()}function eV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;e=y[a+13|0];a:{if(e&227|(e&24)==16){break a}e=y[a+8|0];f=y[a+6|0]|y[a+7|0]<<8;v[c+22|0]=0;v[c+26|0]=e;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){e=y[vb(c+24|0,d)|0];h=vb(c+20|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=$f(c+20|0);f=y[a+11|0];g=y[a+9|0]|y[a+10|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[vb(c+24|0,d)|0];h=vb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}d=0;if($f(c+16|0)>>>0<e>>>0){break a}e=a+6|0;d=a+9|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+20>>1]=0;while(1){if((d|0)!=3){f=y[vb(c+24|0,d)|0];h=vb(c+20|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}f=$f(c+20|0);g=y[e+2|0];e=y[e|0]|y[e+1|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=g;w[c+24>>1]=e;w[c+16>>1]=0;while(1){if((d|0)!=3){e=y[vb(c+24|0,d)|0];h=vb(c+16|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=$f(c+16|0);b:{if(!((b|0)==2|(e|0)==(f|0))){d=0;if((y[a+14|0]|y[a+15|0]<<8)>>>0>=100){break b}break a}if((e|0)==(f|0)|(b|0)!=2){break b}d=0;if((y[a+14|0]|y[a+15|0]<<8)<<16>>16<0){break a}}b=y[a+13|0];e=f-e|0;if(e&1){d=0;if(b&4){break a}}c:{if(b&8){b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;w[c+24>>1]=f;v[c+26|0]=b;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[vb(c+24|0,d)|0];h=vb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(!$f(c+20|0)){break c}}b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=b;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[vb(c+24|0,d)|0];h=vb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if($f(c+20|0)){b=a+3|0;f=y[b+2|0];g=y[b|0]|y[b+1|0]<<8;d=0;v[c+18|0]=0;w[c+24>>1]=g;v[c+26|0]=f;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[vb(c+24|0,d)|0];h=vb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}if($f(c+16|0)>>>0>=e>>>0){break c}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;d=0;v[c+14|0]=0;w[c+24>>1]=a;v[c+26|0]=e;w[c+12>>1]=0;while(1){if((d|0)!=3){a=y[vb(c+24|0,d)|0];h=vb(c+12|0,d),i=a,v[h|0]=i;d=d+1|0;continue}break}a=$f(c+12|0);e=y[b+2|0];b=y[b|0]|y[b+1|0]<<8;d=0;v[c+10|0]=0;v[c+26|0]=e;w[c+24>>1]=b;w[c+8>>1]=0;while(1){if((d|0)!=3){b=y[vb(c+24|0,d)|0];h=vb(c+8|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}d=0;if($f(c+8|0)>>>0<=a>>>0){break a}}d=1;break a}d=0}fb=c+32|0;return d}function I0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-368|0;fb=e;vc(b);d=fb-16|0;fb=d;h=e+330|0;RE(d+8|0,h);f=x[d+12>>2];jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(f|0)){Ub(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(i|0);if(!d){QE(h)}a:{if(!d){break a}if(!TE(e+330|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(SE(y[e+365|0]),hb))){break a}b:{if(!c){break b}Ad(a,2097152);bg(a);Uh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);j=a+480190|0;w[j>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){Ze(Wb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;g=rc(d,6554);yb(a+1298344|0,g);tb(g);g=rc(d,11148);yb(a+1298356|0,g);tb(g);n=a+1298404|0,o=x[Ec(d,4)>>2],x[n>>2]=o;rw(b,d);Fr(Wb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>z[j>>1]){Ub(b,D(64-y[e+364|0]|0,37));h=a+484344|0;Of(h,y[e+365|0]);i=c&1;g=0;while(1)if(y[e+365|0]<=g>>>0){if(!(c&2)){break b}c=Wc(e+24|0,8,1,0,0);d=a+480190|0;g=1;while(1){f=g&65535;if(f>>>0>z[d>>1]){break b}ag(c,(D(f,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(i){if(Kg(h,g&65535,64)){break d}}Ub(b,2048);break c}d=Vb(x[h>>2],g);n=e,o=wb(x[d>>2]),x[n+24>>2]=o;j=wb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,j)){break c}f=e+12|0;jm(f,b);k=Hc(f);m=Ye(f);f=cj(f);l=y[e+12|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[k|0];xf(d,y[m|0],y[f|0]);qg(e+24|0);continue}}g=g+1|0;continue}}else{d=e+24|0;PE(b,d);h=fb-16|0;fb=h;f=(D(i,104)+a|0)+484380|0;kd(f,0);v[f+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=f,o=y[Sb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[f+36|0]=y[d+24|0];x[f>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[f+34>>1]=z[f+34>>1]|2;x[f+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[f+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;Wk(e,2,d);d=e+12|0;Ac(d,e);xc(((i<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);continue}}}g=1}fb=e+368|0;return g|0}function Laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-144|0;fb=d;h=AM(d+128|0);x[h>>2]=48684;Nb(h+4|0);oo(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=Fe(d+108|0,b);x[31721]=0;j=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=j;x[d+16>>2]=x[b+16>>2];j=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=j;b=g?13:15;b=f?b&14:b;b=U(1147,e|0,d|0,(i?b&3:b)|0)|0;e=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=$b(8);x[31721]=0;c=P(37,d+96|0,12010)|0;a=x[31721];x[31721]=0;if((a|0)!=1){mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;ic(b);break b}if(!y[a+63|0]){x[31721]=0;O(1148,a|0,a+36|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}}v[a+28|0]=1;oo(x[a+24>>2],x[a+4>>2]);x[31721]=0;O(1149,d+96|0,h|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}k=d,l=wb(x[d+96>>2]),x[k+92>>2]=l;e=a+68|0;i=wb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,i)){k=d,l=Xi(x[c>>2]),x[k+80>>2]=l;c=Kf(c);while(1){b=x[d+80>>2];if(!Vg(b,c)){break d}x[31721]=0;e=rd(b);b=P(73,d+20|0,e|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break h}x[31721]=0;V(1020,a|0,b|0,e+12|0,0);e=x[31721];x[31721]=0;if((e|0)==1){break g}tb(b);Yg(d+80|0);continue}}f=x[a+24>>2];g=x[b>>2];x[31721]=0;j=f;f=b+4|0;S(1150,j|0,g|0,f|0);g=x[31721];x[31721]=0;if((g|0)!=1){b=x[b>>2];x[31721]=0;O(1151,d+44|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break r}x[31721]=0;O(1067,d+56|0,d+44|0);b=x[31721];x[31721]=0;if((b|0)==1){break q}x[31721]=0;b=P(37,d+32|0,18377)|0;g=x[31721];x[31721]=0;if((g|0)==1){break p}x[31721]=0;S(1023,d+68|0,d+56|0,b|0);g=x[31721];x[31721]=0;if((g|0)==1){break o}x[31721]=0;S(547,d+80|0,d+68|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break n}x[31721]=0;O(181,e|0,d+80|0);f=x[31721];x[31721]=0;if((f|0)==1){break m}tb(d+80|0);tb(d+68|0);tb(b);tb(d+56|0);tb(d+44|0);Lq(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}kz(d+96|0);break b}a=N()|0;break b}kz(d+96|0);Jt(h);fb=d+144|0;return}a=N()|0}Jt(h);Q(a|0)}p()}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31721]=0;f=P(625,e|0,f|0)|0;e=x[31721];x[31721]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31721]=0;f=R(200,a|0)|0;e=x[31721];x[31721]=0;c:{if((e|0)==1){break c}x[31721]=0;j=d+484344|0;k=Hd(f+1|0,1,1024);f=U(199,j|0,b|0,k|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31721]=0;f=U(153,e|0,f|0,1)|0;e=x[31721];x[31721]=0;d:{if((e|0)!=1){if(!f){break b}x[31721]=0;i=R(200,a|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Vb(e,b);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Lc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31721]=0;g=R(200,a|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31721]=0;g=R(200,a|0)|0;f=x[31721];x[31721]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41136|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Hd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Zg(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:Ar(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31721]=0;O(201,h+10|0,a|0);f=x[31721];x[31721]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Hc(h+10|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31721]=0;g=R(200,a|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Gu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-16|0;fb=j;g=x[a+24>>2];h=xB(g,y[a+32|0]);i=x[h>>2];a:{if(Yc(i,x[h+4>>2])>>>0<=b>>>0){break a}if(RT(x[g+484344>>2],x[g+484348>>2],z[Zb(i,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Rd(h,x[a+4>>2])>>>0>b>>>0){if(A[Dd(h,b)+4>>2]>c>>>0){break b}}Go(a,0);if(Rd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}ac(j,x[d>>2],z[g+480188>>1]);h=j+8|0;l=x[j>>2];d=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;e=x[j+4>>2];while(1){if(!f&(e|0)==(k|0)){x[h>>2]=d;x[h+4>>2]=i}else{g=y[TV(l,k)+841|0];m=g^zua(d^k,f^i,435,256);g=!g;d=(q=d,r=zua(m,hb,435,256),s=g,s?q:r);i=g?i:hb;k=k+1|0;f=k?f:f+1|0;continue}break}g=0;d=_m(j,b,c);i=fb-16|0;fb=i;k=a+12|0;e=k;f=GT(z[d>>1],x[d+4>>2],ae(e),dc(e));c:{if(Ib(f,ng(e))){l=z[d>>1];m=x[d+4>>2];d=rd(f);if(!Nl(l,m,z[d>>1],x[d+4>>2])){break c}}f=ng(e)}d=x[zb(i+12|0,f)>>2];fb=i+16|0;if(Vg(d,Kf(k))){e=rd(d);g=kc(x[e+8>>2],x[e+12>>2])^1}i=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Kb(j,x[Dd(x[a>>2],b)>>2],c);f=1;n=Hb(x[x[j>>2]>>2],x[j+4>>2])^1;e=g|i;if(!(n|e)){break a}d:{e:{f:{g:{if(g){m=rd(d);e=wb(x[m+8>>2]);o=wb(x[m+12>>2]);d=x[h>>2];p=x[h+4>>2];l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){h:{if(!Ib(e,o)){break h}if(Vn(x[e>>2],x[e+4>>2],d,p)){break h}e=x[Ju(l+12|0)>>2];continue}break}fb=l+16|0;if(Ib(e,wb(x[m+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|n){break e}d=ET(k,_m(j,b,c));i:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=DT(e+4|0,d);BT(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;gc(d);fb=e+16|0;break i}f=fb-32|0;fb=f;e=Ab(d);e=Xr(f+12|0,Yr(d,fh(x[d>>2],x[d+4>>2])+1|0),fh(x[d>>2],x[d+4>>2]),e);BT(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;Id(d,e);Wr(e);fb=f+32|0}}d=ET(k,_m(j,b,c));j:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=DT(e+4|0,d);CT(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;gc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=Ab(d);e=Xr(f+12|0,Yr(d,fh(x[d>>2],x[d+4>>2])+1|0),fh(x[d>>2],x[d+4>>2]),e);CT(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;Id(d,e);Wr(e);fb=f+32|0}}Kb(j,x[Dd(x[a>>2],b)>>2],c);Ef(j,1);f=0}fb=j+16|0;return f|0}function wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Bg(k,g,r);t=hb;h=x[a+76>>2];cg(x[a>>2],x[a+4>>2],rf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){$d(j,i>>>3<<16>>16);_d(j,4);Pb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}$d(j,i>>>3<<16>>16);_d(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=zg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=zua(h,G,e,e>>31);m=hb;n=e;e=Xb(l,-16777216,16776704);e=zua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Xb(H,-16777216,16776704);m=zua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Qc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31721]=0;X(87);c=x[31721];x[31721]=0;a:{b:{if((c|0)==1){c=Ua(48476,124984,125568,0)|0;d=gb;c:{d:{e:{if(($(48476)|0)==(d|0)){c=Y(c|0)|0;x[31721]=0;b=P(993,a|0,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;b=P(993,b|0,18377)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;d=P(993,b|0,18353)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31721]=0;P(993,d|0,(b?b:22250)|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(124984)|0)==(d|0)){c=Y(c|0)|0;x[31721]=0;b=P(993,a|0,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break f}x[31721]=0;b=P(993,b|0,18377)|0;d=x[31721];x[31721]=0;if((d|0)==1){break f}x[31721]=0;d=P(993,b|0,18328)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31721]=0;P(993,d|0,(b?b:22250)|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125568)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31721]=0;b=P(993,a|0,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;b=P(993,b|0,18377)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;d=P(993,b|0,18344)|0;b=x[31721];x[31721]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31721]=0;P(993,d|0,(b?b:22250)|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break g}x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31721]=0;b=P(993,a|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}x[31721]=0;b=P(993,b|0,18377)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}x[31721]=0;P(993,b|0,13775)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)==1){break c}break a}b=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){break a}}T(0)|0;Qb()}p()}return}tb(a);Q(b|0);p()}function m0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=Ig(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){_e(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=Xd(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(Nf(x[x[a+48>>2]+12>>2])>>>0>e>>>0){g=Vc(x[f+32>>2],e)}d=1;if(!(k&64)){e=Xd(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=Xd(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=Xd(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=Xd(c);v[e|0]=d;if(h>>>0<=15){xf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[qd(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}Ar(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24576|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Sb(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[qd(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[qd(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}fw(i,e,m,l);d=y[f+27|0];p=Th(d);h=y[i|0];if(p>>>0<=Th(h)>>>0){break e}if(!y[g+2|0]){zr(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(wi(a+44|0)){f=x[a+44>>2];y=Gc(f,0);z=Gc(f,1);f=x[a+56>>2];A=Gc(f,0);C=Gc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[xb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[xb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[xb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[xb(f,3)>>2];g=x[xb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[xb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[xb(i,0)>>2];G=B[g+4>>2];j=xb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[xb(i,1)>>2];G=B[p+4>>2];S=xb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[xb(i,2)>>2])+E(P*B[xb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[xb(i,4)>>2])+E(O*B[xb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[xb(i,6)>>2])+E(N*B[xb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[xb(i,8)>>2])+E(M*B[xb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];Li(f,b,c,Gc(a,0),Gc(a,1),d)}break}}}function Hz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Tb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31721]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(981,e|0,67,5,c|0,b|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31721]=0;aa(981,a+4528|0,62,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31721]=0;aa(981,a+4552|0,53,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31721]=0;aa(981,a+4576|0,43,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31721]=0;aa(981,a+4600|0,32,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31721]=0;aa(981,a+4624|0,22,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31721]=0;aa(981,a+4648|0,75,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31721]=0;aa(981,a+4672|0,69,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31721]=0;aa(981,a+4696|0,60,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31721]=0;aa(981,a+4720|0,48,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31721]=0;aa(981,a+4744|0,36,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31721]=0;aa(981,a+4768|0,25,5,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;aa(981,a+4792|0,0,0,0,0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31721]=0;aa(981,a+4816|0,3,0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31721]=0;aa(981,a+4840|0,3,0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;aa(981,a+4864|0,407,1,c|0,0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;aa(981,a+4888|0,400,1,c|0,0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;aa(981,a+4912|0,10,0,c|0,-1);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;aa(981,a+4936|0,10,0,c|0,-1);c=x[31721];x[31721]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(124984)|0;if((gb|0)==($(124984)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=0,Q=E(0);a:{if(!x[a+4316>>2]){break a}if(!wi(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=x[a+44>>2];s=Gc(e,0);t=Gc(e,1);e=x[a+56>>2];u=Gc(e,0);v=Gc(e,1);L=ib[x[x[a>>2]+196>>2]](a)|0;w=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));I=E(ib[x[x[a>>2]+192>>2]](a));z=ib[x[x[a>>2]+216>>2]](a)|0;M=z&1;o=x[a+4324>>2];i=x[a+4320>>2];m=x[a+4328>>2];k=x[a+4312>>2];N=x[a+4276>>2];p=x[a+4264>>2];A=x[a+4256>>2];C=y[a+4260|0];r=a+4316|0;D=d;while(1){if(D){h=B[t>>2];l=B[s>>2];j=x[r>>2];e=ro(j,k+A|0);j=ro(j,k);b:{if(C){P=xb(H,m),Q=l,B[P>>2]=Q;P=xb(G,m),Q=h,B[P>>2]=Q;q=xb(p,e);P=xb(p,j),Q=E(E(B[q>>2]*w)+l),B[P>>2]=Q;g=E(E(B[xb(N,e)>>2]*w)+h);e=K;break b}g=E(E(B[xb(p,e)>>2]*w)+E(E(l+h)*E(.5)));e=J}P=xb(x[e>>2],j),Q=g,B[P>>2]=Q;c:{if(L){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(C){e=(m+2|0)%3|0;l=B[xb(H,e)>>2];h=B[xb(G,e)>>2]}e=x[r>>2];j=xb(p,ro(e,i+k|0));q=e;e=k+4096|0;O=B[xb(p,ro(q,e+i|0))>>2];n=B[j>>2];B[u>>2]=E(E(E(E(E(O-n)*E(E(i&4095)*E(.000244140625)))+n)-l)*I)+l;i=x[(C?4276:4264)+a>>2];j=x[r>>2];q=xb(i,ro(j,k+o|0));n=B[xb(i,ro(j,e+o|0))>>2];l=B[q>>2];B[v>>2]=E(E(E(E(E(n-l)*E(E(o&4095)*E(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;k=(((k|0)<=0?x[r>>2]<<12:0)+k|0)-4096|0;x[a+4312>>2]=k;h=M?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(z>>>0>1?e:0-e|0)+A|0;x[a+4324>>2]=o;i=z>>>0<4;t=t+4|0;s=s+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+A|0;x[a+4320>>2]=i;D=D-1|0;v=v+4|0;u=u+4|0;continue}else{e=a;a=x[a+56>>2];Li(e,b,c,Gc(a,0),Gc(a,1),d)}break}}}function yqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;a:{b:{if(!c){break b}n=e,o=Xd(a),v[n+8|0]=o;ko(b,e+8|0);k=c-1|0;c=0;while(1){f=1;if(!k){break a}c:{d:{d=c<<1&254;e:{if(!d){if(!wf(a,e+8|0)){break b}g=1;d=y[e+8|0]<<1|1;c=d&255;if(d>>>0<=255){break e}break c}if((c&65535)>>>0>127){break d}c=d}if(!wf(a,e+8|0)){break b}v_(b,e+8|0);k=k-1|0;continue}g=1;c=d}while(1){f:{g:{h:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!wf(a,e+8|0)){break h}c=y[e+8|0]<<1|1;d=c&255;c=c>>>0>255}g=Sq(g,1)+c|0;c=d<<1&254;if(c){break g}if(!wf(a,e+8|0)){break h}d=y[e+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break f}c=0;break f}if(d>>>0>127){continue}}break}i:{if((g|0)<=2){j=0;h=g-2|0;break i}if(!wf(a,e+8|0)){break b}d=Sq(g-3|0,8)|y[e+8|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!wf(a,e+8|0)){break b}c=y[e+8|0]<<1|1;d=c&255;f=c>>>0>255}l=Sq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!wf(a,e+8|0)){break b}d=y[e+8|0]<<1|1;c=d&255;d=d>>>0>255}g=1;h=k;d=Sq(f+l|0,1)+d|0;if(!d){while(1){j:{k:{l:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!wf(a,e+8|0)){break l}c=y[e+8|0]<<1|1;d=c&255;c=c>>>0>255}g=Sq(g,1)+c|0;c=d<<1&254;if(c){break k}if(!wf(a,e+8|0)){break l}d=y[e+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break j}c=0;break j}if(d>>>0>127){continue}}break}d=g+2|0}g=h;h=d+j|0;f=0;if(g>>>0<h>>>0|(h|0)<=0|(m|0)>=0){break a}d=x[b+4>>2];f=0;if((0-Rc(x[b>>2],d)|0)>(m|0)){break a}d=zb(e+12|0,wb(d));v[e+8|0]=0;g=e+8|0;j=fb-32|0;fb=j;f=x[d>>2];d=x[b>>2];i=Bk(f,wb(d))+d|0;d=x[Ab(b)>>2];l=x[b+4>>2];m:{if(h>>>0<=d-l>>>0){d=h;f=l-i|0;if(d>>>0>f>>>0){rp(b,h-f|0,g);d=f;if(!d){break m}}w_(b,i,l,h+i|0);Qh(i,d,(g>>>0>=i>>>0?A[b+4>>2]>g>>>0?h:0:0)+g|0);break m}d=Ab(b);d=hn(j+8|0,Wl(b,Rc(x[b>>2],l)+h|0),i-x[b>>2]|0,d);OY(d,h,g);i=jr(b,d,i);gn(d)}zb(j+28|0,i);fb=j+32|0;n=e,o=Ne(HC(wb(x[b+4>>2]),h),m),x[n+8>>2]=o;n=e,o=HC(wb(x[b+4>>2]),h),x[n+4>>2]=o;d=h;while(1){f=y[YX(e+8|0)|0];n=YX(e+4|0),o=f,v[n|0]=o;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}f=0}fb=e+16|0;return f|0}
function vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Bg(i,g,q);s=hb;h=x[a+76>>2];cg(x[a>>2],x[a+4>>2],rf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;$d(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);_d(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=zg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=zua(h,G,e,e>>31);l=hb;m=e;e=Xb(k,-16777216,16776704);e=zua(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Xb(H,-16777216,16776704);l=zua(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Qc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;$d(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);_d(j,4);Pb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function cP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-112|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[zl(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Ll(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;de(f);e=x[d+88>>2];de(d+76|0);e=yl(e,x[d+80>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+104|0,22250);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Nc(e,a,d)){a=$b(8);x[31721]=0;c=P(37,d+88|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}a=$b(8);c=x[b+4>>2];b=x[b>>2];x[31721]=0;e=ci(d+76|0,b,c);b=x[31721];x[31721]=0;f:{g:{h:{if((b|0)!=1){x[31721]=0;S(1019,d+88|0,18277,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break h}mc(a,d+88|0);c=0;x[31721]=0;S(100,a|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(d+88|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}ic(a);break c}if(x[e+4>>2]!=2){a=$b(8);x[31721]=0;c=P(37,d+88|0,11584)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d+68|0,22250);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Nc(b,c,d+32|0)){a=$b(8);x[31721]=0;c=P(37,d+88|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}e=oc(d+60|0,7759);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){g=1;if(!Bd(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=oc(d+52|0,7811);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){g=1;if(!Bd(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=oc(d+44|0,7829);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Nc(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;ic(a)}Q(b|0)}p()}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];w=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Bg(k,g,p);r=hb;h=x[a+76>>2];cg(x[a>>2],x[a+4>>2],rf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){$d(j,i>>>3<<16>>16);_d(j,4);Pb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}$d(j,i>>>3<<16>>16);_d(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=zg(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=zua(h,G,e,e>>31);m=hb;n=e;e=Xb(l,-16777216,16776704);e=zua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Xb(H,-16777216,16776704);m=zua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Qc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function iQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!$m(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}Sd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];IQ(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if(($m(b,c,k,p,f,g,h,m)|0)<=0){if($m(b,c,k,p,f,g,n,m)){h=b;i=c;break a}Sd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Sd(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Sd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){Sd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}Sd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Sd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=oD(c,+y[a+2|0]*1e4/240),v[f+12|0]=g;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[qd(d+88|0,d+76|0)>>2],v[f+111|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:aw(d+76|0,15633);x[31721]=0;O(562,d- -64|0,d+12|0);a=x[31721];x[31721]=0;f:{g:{h:{i:{if((a|0)!=1){x[31721]=0;O(562,d+52|0,d+111|0);a=x[31721];x[31721]=0;if((a|0)==1){break i}x[31721]=0;V(563,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}a=d+88|0;ve(d+100|0,a);pf(b,x[d+100>>2],x[d+104>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:aw(d+76|0,15574);x[31721]=0;O(562,d- -64|0,d+12|0);a=x[31721];x[31721]=0;j:{k:{l:{m:{if((a|0)!=1){x[31721]=0;O(562,d+52|0,d+111|0);a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;V(563,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31721];x[31721]=0;if((a|0)==1){break l}a=d+88|0;ve(d+44|0,a);pf(b,x[d+44>>2],x[d+48>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=oc(d+36|0,15660);pf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=Cc(a+4|0,4048);Zc(d+76|0,c);tb(c);fb=a+16|0;x[31721]=0;O(562,d- -64|0,d+111|0);a=x[31721];x[31721]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[31721]=0;O(562,d+52|0,d+35|0);a=x[31721];x[31721]=0;if((a|0)==1){break s}x[31721]=0;O(562,d+12|0,d+34|0);a=x[31721];x[31721]=0;if((a|0)==1){break r}x[31721]=0;aa(744,d+88|0,d+76|0,d- -64|0,d+52|0,d+12|0);a=x[31721];x[31721]=0;if((a|0)==1){break q}a=d+88|0;ve(d+24|0,a);pf(b,x[d+24>>2],x[d+28>>2]);tb(a);tb(d+12|0);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=zua(j,H,e,e>>31);i=hb;v=e;e=Xb(g,-16777216,16776704);e=zua(l,G,e,e>>31);g=v+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(y,-16777216,16776704);i=zua(z,F,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=zua(j,I,e,e>>31);i=hb;y=e;e=Xb(g,-16777216,16776704);e=zua(l,H,e,e>>31);g=y+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(z,-16777216,16776704);i=zua(A,G,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function xe(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(kc(e,x[a+4>>2])){break a}g=x[b+4>>2];if(g>>>0>=A[a+12>>2]){break a}c=z[b+8>>1];i=x[x[a+48>>2]+12>>2];f=Nf(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=jd(e,i,f,g);f=y[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=y[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=y[e+3|0]){break d}break b}if((k|0)==y[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=x[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[c+3|0]-9|0){case 4:if(!Kv(x[x[i+8>>2]+88>>2],1)){break j}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=y[c+5|0];if(e>>>0>128){break j}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break l}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=y[b+11|0];g=13;m:{switch(y[b+10|0]-1|0){case 1:g=9;e=ui(e<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=e;v[b+10|0]=g;f=f&254;break h}v[h+15|0]=0;v[h+14|0]=0;g=b;c=!d;d=y[b+10|0];n:{if(!(c|(d|0)!=9)){e=y[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+12|0;zr(e,d,y[b+11|0],1);d=h+4|0;DD(d,h+15|0,h+14|0);CD(d,e);d=y[h+15|0];if(!d){f=y[b+12|0];break g}f=y[b+12|0];c=y[h+14|0]}v[g+11|0]=c;v[b+10|0]=d;f=f&254}v[b+12|0]=f}d=1;if(f&1){break f}v[b+12|0]=f^4;if(xe(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=xe(a,b);break a}d=1}fb=h+16|0;return d}function $T(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Vd(d,h<<1);oR(c+160|0,C[e>>3],C[e+8>>3]);d=Vd(d,h);oR(c+144|0,C[d>>3],C[d+8>>3]);Oi(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Vd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Vd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Vd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Vd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Cl(g,f,o,n);j=c- -64|0;Bj(j,f,o,n);l=c+96|0;Cl(c+48|0,l,u,t);f=c+16|0;Bj(f,l,u,t);Oi(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Cl(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Cl(c,j,C[c+32>>3],C[c+40>>3]);Oi(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Vd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Bj(c,g,C[c+48>>3],C[c+56>>3]);Oi(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Vd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Bj(c,j,C[c+32>>3],C[c+40>>3]);Oi(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Vd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Vd(h,d+i|0);m=Vd(h,d);n=C[a>>3];o=C[a+8>>3];Bj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;iA(Vd(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];v=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Bg(i,g,o);q=hb;h=x[a+76>>2];cg(x[a>>2],x[a+4>>2],rf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;$d(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);_d(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=zg(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=zua(h,G,e,e>>31);l=hb;m=e;e=Xb(k,-16777216,16776704);e=zua(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Xb(H,-16777216,16776704);l=zua(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Qc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;$d(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);_d(j,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Ara(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);d=fb-96|0;fb=d;c=fb-16|0;fb=c;e=b+16|0;JY(c+8|0,e);f=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((f|0)!=(g|0)){Tb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d+56|0;ce(c,a,Mg(a));f=hc(d+76|0,c);ub(c);x[31721]=0;c=R(205,f|0)|0;e=x[31721];x[31721]=0;a:{b:{if((e|0)==1){break b}x[31721]=0;O(290,b+4|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}le(d+48|0,x[b+4>>2],x[b+8>>2]);x[31721]=0;Sn(475,d+56|0,f,x[d+48>>2],x[d+52>>2]);c=x[31721];x[31721]=0;if((c|0)!=1){x[31721]=0;c=R(154,a|0)|0;e=x[31721];x[31721]=0;c:{if((e|0)==1){break c}x[31721]=0;S(188,d+28|0,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}a=d+28|0;c=hc(d+56|0,a);ub(a);a=x[c>>2];x[31721]=0;a=R(175,a|0)|0;e=x[31721];x[31721]=0;d:{if((e|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[c+8>>2];e=x[c>>2];x[31721]=0;a=U(153,e|0,a|0,5)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}if(!a){break g}x[31721]=0;P(476,c|0,d+24|0)|0;a=x[31721];x[31721]=0;h:{if((a|0)!=1){a=4;e=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}x[31721]=0;a=R(154,c|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31721]=0;S(188,d+4|0,c|0,a|0);a=x[31721];x[31721]=0;i:{j:{if((a|0)!=1){a=d+4|0;e=hc(d+28|0,a);ub(a);if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1414682436){break j}x[31721]=0;h=E(xa(477,e|0));a=x[31721];x[31721]=0;if((a|0)==1){break e}i=b,j=Ld(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1196380752){break i}x[31721]=0;a=R(154,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}x[b+148>>2]=a}ub(e);continue}}ub(c);ub(f);fb=d+96|0;return}a=N()|0;break d}a=N()|0;ub(e);break d}a=N()|0}ub(c);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function z7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Ey(x[g>>2]);o=jy(x[g>>2]);oh(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31721]=0;g=P(1236,k|0,g<<24>>24)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31721]=0;g=P(1236,k|0,48)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[31721]=0;g=P(1236,k|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!xK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!Jh(h)){break d}g=g+1|0;continue}}e:{if(zd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31721]=0;V(1230,k|0,i|0,g|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}zm(i,g);x[31721]=0;r=R(1228,o|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Ws((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[bc(j+4|0,l)|0]<=0){break f}if(v[bc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31721]=0;q=P(1236,k|0,q|0)|0;n=x[31721];x[31721]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[31721]=0;i=R(1231,o|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31721]=0;i=P(1236,k|0,i<<24>>24)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31721]=0;V(1230,k|0,g|0,c|0,h|0);i=x[31721];x[31721]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function gK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=x[d>>2];if(!h){break k}if(!a){g=c;break j}x[d>>2]=0;g=c;break i}l:{if(!x[x[124227]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=v[e|0];if(g){x[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return gf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=y[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=x[e>>2];if((d|d-16843009)&-2139062144){break p}x[a>>2]=d&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=y[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}x[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=x[(f<<2)+111504>>2];d=1;continue}d=y[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=y[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=y[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;x[a>>2]=d;g=g-1|0;a=a+4|0;break q}x[31596]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=y[e|0];if(!(e&3|d-1>>>0>126)){d=x[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=x[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=x[(h<<2)+111504>>2];d=1;continue}d=y[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=y[e|0]}if(d&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-g|0}x[31596]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function Li(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!kQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Gc(l,0);l=Gc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=kQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function J7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=kw(x[g>>2]);o=ry(x[g>>2]);oh(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31721]=0;g=P(29,k|0,g<<24>>24)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31721]=0;g=P(29,k|0,48)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[31721]=0;g=P(29,k|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!xK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!Jh(h)){break d}g=g+1|0;continue}}e:{if(zd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31721]=0;V(1217,k|0,i|0,g|0,h|0);h=x[31721];x[31721]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}zm(i,g);x[31721]=0;r=R(1215,o|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){zm((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[bc(j+4|0,m)|0]<=0){break f}if(v[bc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[31721]=0;q=P(29,k|0,q|0)|0;n=x[31721];x[31721]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[31721]=0;i=R(1218,o|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[31721]=0;V(1217,k|0,g|0,c|0,i|0);i=x[31721];x[31721]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31721]=0;i=P(29,k|0,i<<24>>24)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function tfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=Mq(1,32);d:{e:{if(!k){a=Pm($b(4));x[31721]=0;S(100,a|0,124984,34);a=x[31721];x[31721]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:985;x[k>>2]=f;c=mg(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31721]=0;e=P(37,j+56|0,e|0)|0;m=x[31721];x[31721]=0;j:{if((m|0)!=1){x[31721]=0;m=P(996,c|0,e|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break j}x[31721]=0;O(275,m|0,l|0);l=x[31721];x[31721]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31721]=0;e=P(37,j+44|0,e|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break g}Tt(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31721]=0;a=R(858,104)|0;m=x[31721];x[31721]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31721]=0;b=P(997,f|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}x[j+20>>2]=b;b=x[pe(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31721]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(1027,a|0,j|0,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break k}i=T(0)|0;Uc(j+20|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Uc(j+20|0);x[k+24>>2]=b+8;Ml(c);break d}i=T(0)|0}Ml(c);Y(i|0)|0;x[31721]=0;V(991,11340,k|0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31721]=0;V(991,11340,0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Qb()}p()}function ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=zua(j,F,e,e>>31);i=hb;t=e;e=Xb(g,-16777216,16776704);e=zua(l,E,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(u,-16777216,16776704);i=zua(v,C,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function rv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ed(b)}if(b>>>0>=4294967232){x[31596]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[31717]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;ov(d,c);break b}if(x[31603]==(g|0)){d=d+x[31600]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[31600]=d;x[31603]=c;break b}if(x[31602]==(g|0)){d=d+x[31599]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31602]=h;x[31599]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=126388,o=x[31597]&Cua(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+126692|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=126392,o=x[31598]&Cua(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;ov(c,l)}c=e}if(c){return c+8|0}c=Ed(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;yc(c,a,b>>>0>e>>>0?e:b);Db(a);return c}function i1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-112|0;fb=d;vc(b);Ap(a);a:{if(!yi(b,d+104|0)){break a}if(!RF(d+104|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}ex(a);n=d,o=dx(),x[n+84>>2]=o;c=d+84|0;cx(hj(x[a+4>>2])+32|0,c);as(c);k=x[hj(x[a+4>>2])+32>>2];c=gh(x[b>>2]);if(c&1){break a}e=c-4|0;bd(b,e);g=fb-16|0;fb=g;c=g+13|0;Qw(c,b);h=y[vb(c,0)|0];i=y[vb(c,1)|0];c=y[vb(c,2)|0];fb=g+16|0;h=c|(i<<8|h<<16);if(!h){break a}x[31721]=0;O(40,k|0,h|0);c=x[31721];x[31721]=0;c:{if((c|0)==1){b=T(124984)|0;if((gb|0)!=($(124984)|0)){break c}Y(b|0)|0;Z();break a}bd(b,4);c=d+84|0;QF(c,b,e);Gn(d- -64|0,c);jf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];i=x[k>>2];e=fb-32|0;fb=e;b=x[d+76>>2];n=e,o=y[vb(b,0)|0],v[n+28|0]=o;n=e,o=y[vb(b,1)|0],v[n+29|0]=o;n=e,o=y[vb(b,2)|0],v[n+30|0]=o;n=e,o=y[vb(b,3)|0],v[n+31|0]=o;g=Sr(e+12|0);c=b+c|0;x[g+12>>2]=c-4;x[g+8>>2]=b;mk(g,y[c-1|0]);c=h;d:while(1){e:{f:{g:{if(!c){break g}if(mk(g,1)){break f}b=1;while(1){f=mk(g,2);b=f+b|0;if((f|0)==3){continue}break}x[e+8>>2]=b;uc(e+8|0,c);b=0;f=x[e+8>>2];while(1)if((b|0)==(f|0)){if(!c){break g}break f}else{c=c-1|0;n=i+c|0,o=mk(g,8),v[n|0]=o;b=b+1|0;continue}}fb=e+32|0;break e}f=mk(g,2);b=f+2|0;x[e+8>>2]=b;h:{if((f|0)==3){i:{if(!mk(g,1)){b=5;f=7;break i}f=y[vb(e+28|0,3)|0]}f=mk(g,f);while(1){j=mk(g,3);b=j+b|0;if((j|0)==7){continue}break}x[e+8>>2]=b;break h}f=mk(g,y[vb(e+28|0,f)|0])}uc(e+8|0,c);b=0;m=x[e+8>>2];while(1){if((b|0)==(m|0)){continue d}j=0;l=c+f|0;if(h>>>0>l>>>0){j=y[i+l|0]}c=c-1|0;v[i+c|0]=j;b=b+1|0;continue}}break}le(d+24|0,x[k>>2],x[k+4>>2]);jf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Jd(d+16|0);x[31721]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=eg(163,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31721];x[31721]=0;if((c|0)!=1){gd(hj(x[a+4>>2])+12|0,b);ub(b);Ic(d+84|0);break b}b=N()|0;Ic(d+84|0)}Q(b|0);p()}f=1}fb=d+112|0;return f|0}function xu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=D(c,872)+b|0;f=e+704|0;x[f>>2]=x[f>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}h=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[h+1427|0]=d;v[h+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{g=e+616|0;i=x[g+656>>2];if(Oj(i)){a=z[(D(c,872)+b|0)+1384>>1];if(!a){break c}e=0;d=x[b+16>>2];e=d?x[(D(c,872)+b|0)+1472>>2]:e;k=0-a|0;j=a;g=D(c,872)+b|0;h=g+1324|0;a=x[h>>2];l=(+(d>>>0)+1)*+(((a|0)<0?k:j)|0)/+A[b+40>>2];d:{if(F(l)<2147483648){d=~~l;break d}d=-2147483648}g=g+1472|0;x[g>>2]=d;if(y[f+2|0]&16){d=D(x[x[i+44>>2]+36>>2]+1|0,d);x[g>>2]=d}d=d-e|0;f=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^f)-f>>>0){if(!a){break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[h>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;return 0}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[h>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break c}h=a+1074312|0;e:{if(!(!Ob(h,118)|!(y[f+1|0]&2))){d=0;if(Sc(y[(D(c,872)+b|0)+1404|0])){break e}}f=1;i=D(c,872)+b|0;e=i+1467|0;f:{if(!(v[e|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Ob(h,6)){break f}d=x[a+480180>>2]}f=0;if((d|0)!=8){break f}f=(y[a+480208|0]&2)>>>1|0}j=x[a+480180>>2];d=z[i+1384>>1];if(!((j|0)!=268435456|d>>>0<240)){f=v[e|0]&1;d=d-240|0}d=d<<((j|0)==64?1:2);i=D(c,872)+b|0;b=i+1316|0;g:{if(!x[b>>2]){break g}c=i+1324|0;if(!(x[c>>2]!=0&f)){break g}j=Ej(a)?d:0-d|0;k=x[b>>2];m=x[c>>2];if(!(!(y[e|0]&16)&(k|0)>=(m|0))){yk(a,g,b,j,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((k|0)<=(m|0)){break g}yk(a,g,b,0-j|0,1);g=x[b>>2];c=x[c>>2];h:{if((g|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}if(!Ob(h,112)){break g}v[e|0]=y[e|0]|16}c=x[b>>2];b=i+1324|0;i:{if((c|0)!=x[b>>2]){break i}if(!Ob(h,25)&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=f?d:0}return d}return 0}function jP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=Mq(1,28);if(!k){a=Pm($b(4));x[31721]=0;S(100,a|0,124984,34);a=x[31721];x[31721]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:985;x[k>>2]=f;c=mg(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31721]=0;e=P(37,j+56|0,e|0)|0;m=x[31721];x[31721]=0;k:{if((m|0)!=1){x[31721]=0;m=P(996,c|0,e|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break k}x[31721]=0;O(275,m|0,l|0);l=x[31721];x[31721]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31721]=0;e=P(37,j+44|0,e|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break h}Tt(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31721]=0;a=R(858,80)|0;m=x[31721];x[31721]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31721]=0;b=P(997,f|0,d|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=x[pe(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31721]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(998,a|0,j|0,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break l}i=T(0)|0;Uc(j+20|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=b;Uc(j+20|0);Ml(c);i=k;break d}i=T(0)|0}Ml(c);Y(i|0)|0;x[31721]=0;V(991,15171,k|0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(iq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31721]=0;V(991,15171,0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Qb()}p()}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=zua(j,G,e,e>>31);i=hb;t=e;e=Xb(g,-16777216,16776704);e=zua(l,F,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(u,-16777216,16776704);i=zua(y,E,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;c=Cf(a,c);Zd(i,x[a+36>>2]);a:{if(!c){Oc(i,a+32|0,5);e=0;if(Hb(x[x[i>>2]>>2],x[i+4>>2])){break a}}e=fb-240|0;fb=e;h=Hm(e+128|0,x[a+36>>2]);x[31721]=0;g=P(465,e+116|0,26152)|0;f=x[31721];x[31721]=0;b:{c:{d:{e:{if((f|0)!=1){x[31721]=0;x[e+96>>2]=19988993;x[e+100>>2]=0;S(466,h|0,g|0,e+96|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}Eb(g);if(!ol(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[e+115|0]=0;x[31721]=0;g=P(465,e+96|0,5505)|0;f=x[31721];x[31721]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){x[31721]=0;S(467,h|0,e+115|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break p}Eb(g);g=Fb(e+84|0);x[31721]=0;f=P(465,e+72|0,10094)|0;j=x[31721];x[31721]=0;if((j|0)==1){break o}x[31721]=0;S(791,h|0,g|0,f|0);j=x[31721];x[31721]=0;if((j|0)==1){break n}Eb(f);x[31721]=0;S(261,e+60|0,(y[e+115|0]?0:d)|0,g|0);d=x[31721];x[31721]=0;if((d|0)==1){break m}d=e+60|0;hp(b,d);tb(d);w[e+58>>1]=0;x[31721]=0;d=P(465,e+44|0,10783)|0;f=x[31721];x[31721]=0;if((f|0)==1){break g}x[31721]=0;U(495,h|0,e+58|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break l}Eb(d);Qf(e+58|0,4e3);x[31721]=0;d=P(465,e+32|0,13541)|0;f=x[31721];x[31721]=0;if((f|0)==1){break k}j=z[e+58>>1];f=x[zb(e+28|0,j)>>2];x[31721]=0;V(792,h|0,b|0,d|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break j}Eb(d);w[e+26>>1]=65535;x[31721]=0;d=P(465,e+12|0,8964)|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}x[31721]=0;k=U(495,h|0,e+26|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break h}f=z[e+26>>1];Eb(d);if(f>>>0<j>>>0&k){Ze(b,f)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(f);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}yh(h);Q(a|0);p()}yh(h);fb=e+240|0;e=c}cf(a,e);fb=i+16|0}function lta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=LD(d+40|0,b);r=or(i);e=Nb(a);x[31721]=0;a=R(205,b|0)|0;c=x[31721];x[31721]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Gb(d+12|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Gb(d+1100|0,d+24|0)>>2];x[31721]=0;O(331,e|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;h=R(343,d+24|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;f=P(344,d+12|0,8192)|0;a=x[31721];x[31721]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=xb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31721]=0;o=P(161,i|0,s|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Rc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=xb(a,c);l=l-1|0;q=l&65535;t=vb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[xb(a,c)>>1];if(c>>>0<8192){continue}break}a=zb(d+8|0,wb(x[e+4>>2]));c=Ne(wb(x[f>>2]),q);l=wb(x[f+4>>2]);a=x[a>>2];x[31721]=0;V(332,e|0,a|0,c|0,l|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[31721]=0;O(345,e|0,vb(a,q)|0);a=x[31721];x[31721]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Rc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[vb(x[f>>2],q)|0];c=xb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=or(i);x[31721]=0;P(152,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}cc(f);sc(h);ub(i);fb=d+1104|0;return}c=N()|0;cc(f);break b}c=N()|0}sc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}cc(e);ub(i);Q(c|0);p()}function bU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Vd(i,e+l|0);d=Vd(i,e);o=C[h>>3];p=C[h+8>>3];Bj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;iA(Vd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Vd(d,j<<1);d=Vd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Oi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Vd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Vd(f,t);Oi(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Vd(f,u);Oi(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Vd(f,v);Oi(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Cl(k,f,m,n);q=c- -64|0;Bj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Cl(c+48|0,g,m,n);f=c+16|0;Ol(f,-0,-1);Bj(c,g,m,n);Oi(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Cl(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Bj(f,k,C[c+48>>3],C[c+56>>3]);d=Vd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Cl(f,q,C[c+32>>3],C[c+40>>3]);d=Vd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Bj(f,q,C[c+32>>3],C[c+40>>3]);d=Vd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function bP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[zl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Ll(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;de(f);e=x[d+72>>2];de(d+60|0);e=yl(e,x[d+64>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+88|0,22250);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Nc(e,a,d)){a=$b(8);x[31721]=0;c=P(37,d+72|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}c=$b(8);a=x[b+4>>2];b=x[b>>2];x[31721]=0;e=ci(d+60|0,b,a);a=x[31721];x[31721]=0;f:{g:{h:{if((a|0)!=1){x[31721]=0;S(1019,d+72|0,18277,e|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}mc(c,d+72|0);a=0;x[31721]=0;S(100,c|0,48476,1008);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=N()|0;tb(d+72|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e);if(!a){break c}}ic(c);break c}if(x[e+4>>2]!=1){a=$b(8);x[31721]=0;c=P(37,d+72|0,11584)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d+52|0,22250);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Nc(b,c,d+24|0)){a=$b(8);x[31721]=0;c=P(37,d+72|0,10482)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}e=oc(d+44|0,10974);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Nc(b,c,d+16|0)){e=x[a+8>>2];f=e>>31;break e}e=oc(d+36|0,8627);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Nc(b,c,d+8|0)){break e}e=vk(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;ic(a)}Q(b|0)}p()}function yO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=$b(8);x[31721]=0;c=P(37,c+4|0,5123)|0;d=x[31721];x[31721]=0;if((d|0)==1){break k}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79528>>2];break h}d=N()|0;ic(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[We(n,c)>>2];l:{if((a|0)==x[Hq(n)+32>>2]){a=-1;if(x[Hq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=$b(8);x[31721]=0;d=P(37,d+4|0,10385)|0;a=x[31721];x[31721]=0;m:{if((a|0)!=1){mc(c,d);x[31721]=0;S(100,c|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;ic(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function aP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[zl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ll(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;de(f);g=x[e+72>>2];de(e+60|0);h=yl(g,x[e+64>>2],c);de(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=oc(e+88|0,22250);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Nc(g,f,e)){a=$b(8);x[31721]=0;b=P(37,e+72|0,10482)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(d){a=$b(8);b=x[c+4>>2];c=x[c>>2];x[31721]=0;b=ci(e+60|0,c,b);c=x[31721];x[31721]=0;f:{g:{h:{if((c|0)!=1){x[31721]=0;S(1019,e+72|0,18277,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break h}mc(a,e+72|0);d=0;x[31721]=0;S(100,a|0,48476,1008);c=x[31721];x[31721]=0;if((c|0)!=1){break b}c=N()|0;tb(e+72|0);break g}c=N()|0;break f}c=N()|0;d=1}tb(b);if(!d){break c}}ic(a);break c}Fb(a);break e}c=oc(e+52|0,22250);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Nc(g,f,e+24|0)){a=$b(8);x[31721]=0;b=P(37,e+72|0,10482)|0;c=x[31721];x[31721]=0;if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;ic(a);break c}c=oc(e+44|0,12421);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Nc(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Cc(a,5601);break e;case 1:Cc(a,11285);break e;case 2:Cc(a,9206);break e;default:break i}}Fb(a);break e}c=oc(e+36|0,11522);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Nc(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Cc(a,15616);break e;case 1:Cc(a,15627);break e;case 2:Cc(a,12695);break e;case 3:Cc(a,9270);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}c=N()|0;ic(a)}Q(c|0)}p()}function Jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(zd(g,h)){break a}e=y[nz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;ix(e,c,0,Xc(g,h)-1|0);yb(c,e);tb(e)}e=d+84|0;de(e);g=x[d+84>>2];de(d+72|0);g=LM(g,x[d+76>>2],c);de(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(ke(c,22250)){a=$b(8);x[31721]=0;b=P(37,d+84|0,10482)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=$b(8);x[31721]=0;S(1010,d+84|0,18277,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,d+84|0);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}c=N()|0;tb(d+84|0);break c}c=N()|0;ic(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ve(d- -64|0,c);x[31721]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1011,b|0,d+8|0,f|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){x[31721]=0;v[d+72|0]=b;O(1012,a|0,d+72|0);a=x[31721];x[31721]=0;if((a|0)!=1){break g}}break i;case 1:ve(d+56|0,c);x[31721]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=OH(b,d+16|0,f);c=hb;f=x[31721];x[31721]=0;if((f|0)!=1){x[31721]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1014,a|0,d+72|0);a=x[31721];x[31721]=0;if((a|0)!=1){break g}}break i;case 2:ve(d+48|0,c);x[31721]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1015,b|0,d+24|0,f|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;C[d+72>>3]=i;O(1016,a|0,d+72|0);a=x[31721];x[31721]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ve(d+40|0,c);x[31721]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1017,a|0,b|0,d+32|0,f|0);a=x[31721];x[31721]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}Zc(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;ic(a)}Q(c|0)}p()}function T6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+944|0;x[a+940>>2]=j;j=wy(j,100,11182,a+16|0);x[a+48>>2]=1207;k=a+48|0;o=Ae(a+520|0,0,k);x[a+48>>2]=1207;k=Ae(a+512|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;f=a+944|0;break d}j=Kd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=oj(a+940|0,j,11182,a);if((j|0)!=-1){f=x[a+940>>2];Oe(o,f);Oe(k,Ed(j<<2));h=x[k>>2];if(!Ak(h)){break d}}x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break a}j=N()|0;break c}ad(a+508|0,x[d+28>>2]);x[31721]=0;r=R(1219,x[a+508>>2])|0;g=x[31721];x[31721]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31721]=0;V(1230,r|0,f|0,f+j|0,h|0);g=x[31721];x[31721]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31721]=0;ka(1258,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31721];x[31721]=0;if((c|0)==1){break i}x[a+36>>2]=1207;c=Ae(a+40|0,0,a+36|0);m=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Ed(l<<2));m=x[c>>2];if(m){break h}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31721]=0;ma(1259,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;b=ea(1239,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break b}}}j=N()|0;Jc(c)}Rb(g);Rb(f);tb(i)}Yb(a+508|0)}Jc(k);Jc(o);Q(j|0);p()}Jc(c);Rb(g);Rb(f);tb(i);Yb(a+508|0);Jc(k);Jc(o);fb=a+1056|0;return b|0}p()}function Rqa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=x[a>>2];c=yv(e,x[a+4>>2]);if(c>>>0<=63){l=fb-32|0;fb=l;g=64-c|0;e=x[Ab(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=(e-b|0)/33>>>0){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(g,33);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){gc(c);fb=e+16|0}else{vY(a);a=a+33|0;x[c+4>>2]=a;continue}break}break a}h=Ab(a);c=l+12|0;e=a;f=yv(x[a>>2],b)+g|0;b=fb-16|0;fb=b;x[b+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=yY(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[$c(b+8|0,b+12|0)>>2]}fb=b+16|0;break b}cd();p()}f=yv(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Fg(c+12|0,h);c:{if(!a){b=0;a=0;break c}if(a>>>0>=130150525){Xj();p()}b=Dc(D(a,33));x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+8>>2];a=x[d+12>>2]}x[c>>2]=b;f=b+D(f,33)|0;x[c+8>>2]=f;x[c+4>>2]=f;n=zc(c),o=b+D(a,33)|0,x[n>>2]=o;fb=d+16|0;d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+D(g,33);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){vY(a);a=x[b>>2]+33|0;x[b>>2]=a;continue}break}ee(b);fb=d+16|0;b=fb-16|0;fb=b;h=zb(b+12|0,x[e+4>>2]);i=zb(b+8|0,x[e>>2]);j=zb(b+4|0,x[c+4>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;g=fb-16|0;fb=g;f=fb-16|0;fb=f;j=x[j>>2];k=x[h>>2];h=x[i>>2];i=k-h|0;k=j+D((i|0)/-33|0,33)|0;m=$h(k,h,i);i=D((i|0)/33|0,33);x[f+12>>2]=m+i;Ud(g+8|0,h+i|0,f+12|0);fb=f+16|0;Ud(a+8|0,h,zb(g+4|0,j+D((k-j|0)/33|0,33)|0));fb=g+16|0;g=x[a+8>>2];x[a+4>>2]=x[a+12>>2];Ud(d+8|0,g,a+4|0);fb=a+16|0;fb=d+16|0;x[c+4>>2]=x[d+12>>2];wc(e,c+4|0);wc(e+4|0,c+8|0);wc(Ab(e),zc(c));x[c>>2]=x[c+4>>2];fb=b+16|0;e=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(e|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){zc(c);Db(a)}}fb=l+32|0;return}if((c|0)!=64){xY(a,e+2112|0)}}function Lla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],r)+D(w[i+4>>1],s)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=zua(m,F,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=zua(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(s,-16777216,16776704);k=zua(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Qc(k,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function X6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+336|0;x[a+332>>2]=j;j=wy(j,100,11182,a+16|0);x[a+48>>2]=1207;k=a+48|0;o=Ae(a+216|0,0,k);x[a+48>>2]=1207;k=Ae(a+208|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;f=a+336|0;break d}j=Kd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=oj(a+332|0,j,11182,a);if((j|0)!=-1){f=x[a+332>>2];Oe(o,f);Oe(k,Ed(j));h=x[k>>2];if(!Ak(h)){break d}}x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break a}j=N()|0;break c}ad(a+204|0,x[d+28>>2]);x[31721]=0;r=R(28,x[a+204>>2])|0;g=x[31721];x[31721]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31721]=0;V(1217,r|0,f|0,f+j|0,h|0);g=x[31721];x[31721]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31721]=0;ka(1256,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31721];x[31721]=0;if((c|0)==1){break i}x[a+36>>2]=1207;c=Ae(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Ed(l));m=x[c>>2];if(m){break h}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31721]=0;ma(1257,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31721];x[31721]=0;if((h|0)!=1){x[31721]=0;b=ea(23,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break b}}}j=N()|0;Jc(c)}tb(g);tb(f);tb(i)}Yb(a+204|0)}Jc(k);Jc(o);Q(j|0);p()}Jc(c);tb(g);tb(f);tb(i);Yb(a+204|0);Jc(k);Jc(o);fb=a+448|0;return b|0}p()}function Mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],s)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=zua(m,G,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=zua(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(s,-16777216,16776704);k=zua(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Qc(k,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function rfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=Mq(1,32);d:{e:{if(!j){a=Pm($b(4));x[31721]=0;S(100,a|0,124984,34);a=x[31721];x[31721]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:985;x[j>>2]=f;c=mg(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31721]=0;e=P(37,k+24|0,e|0)|0;m=x[31721];x[31721]=0;j:{if((m|0)!=1){x[31721]=0;m=P(996,c|0,e|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break j}x[31721]=0;O(275,m|0,l|0);l=x[31721];x[31721]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31721]=0;e=P(37,k+12|0,e|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break g}Tt(c,e)}tb(e);i=i+8|0;continue}}x[31721]=0;e=R(858,104)|0;i=x[31721];x[31721]=0;k:{l:{m:{if((i|0)!=1){x[31721]=0;d=P(997,f|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=x[pe(k+8|0,k+4|0)>>2];x[31721]=0;a=ha(1028,e|0,a|0,b|0,d|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break k}i=T(0)|0;Uc(k+4|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Uc(k+4|0);x[j+24>>2]=a+8;Ml(c);break d}i=T(0)|0}Ml(c);Y(i|0)|0;x[31721]=0;V(991,4973,j|0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31721]=0;V(991,4973,0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Qb()}p()}function tX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Sb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:xf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}eD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}fb=f+16|0;return g}function TW(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;g=x[b>>2];i=x[b+4>>2];a:{if((i|0)==(f|0)){b=fc(l+8|0,e,f);j=fb-16|0;fb=j;e=en(c,d,g,f);x[j+12>>2]=e;b:{if((e|0)<=0){e=x[b>>2];break b}c:{if(!f){f=x[b>>2];break c}h=32-f|0;x[j+8>>2]=h;c=x[qd(j+8|0,j+12|0)>>2];x[j+12>>2]=e-c;d=x[b>>2];e=-1<<f&-1>>>h-c;x[d>>2]=x[d>>2]&(e^-1)|e&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;x[b>>2]=f;g=g+4|0;e=x[j+12>>2]}c=(e|0)/32|0;NC(g,c,f);d=e-(c<<5)|0;x[j+12>>2]=d;c=c<<2;e=c+x[b>>2]|0;x[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;x[e>>2]=x[e>>2]&(d^-1)|d&x[c+g>>2];x[b+4>>2]=x[j+12>>2]}fc(a,e,x[b+4>>2]);fb=j+16|0;break a}j=a;h=fc(l,e,f);f=fb-16|0;fb=f;e=en(c,d,g,i);x[f+12>>2]=e;d:{if((e|0)<=0){a=x[h+4>>2];break d}e:{if(!i){a=x[h+4>>2];break e}k=32-i|0;x[f+8>>2]=k;c=f+8|0;b=x[qd(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[h+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[h>>2];n=x[d>>2];c=x[Gb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;x[h+4>>2]=a;d=d+(k>>>3&536870908)|0;x[h>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+i;x[h+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=x[h>>2];e=x[g>>2];x[b>>2]=i&x[b>>2]|e<<a;x[h>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=x[g>>2];x[f+8>>2]=c;g=x[h>>2];b=x[g>>2];k=b;b=x[qd(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;x[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;x[h+4>>2]=a;c=g+(c>>>3&536870908)|0;x[h>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|e>>>b;a=x[f+12>>2];x[h+4>>2]=a}fc(j,x[h>>2],a);fb=f+16|0}fb=l+16|0}function BR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){h=a+480180|0;e=x[h>>2];i=1;c:{d:{e:{f=x[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Kb(g+8|0,a+1074312|0,21);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}e=D(b,872)+a|0;f=e+1075811|0;v[f|0]=y[f|0]+(y[e+1075815|0]<<2)}f=D(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=tA(a,y[k|0],y[l|0]);f:{if(Oj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[f+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=f+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}f=x[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Kb(g+8|0,k,21);f=x[a+480208>>2];g:{if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Kb(g+8|0,k,80);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;yk(a,j,c,d,0);e=x[j+656>>2];c=rq(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Kb(g+8|0,a+1074312|0,21);if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=rq(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}fb=g+16|0}function hP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=Mq(1,28);if(!j){a=Pm($b(4));x[31721]=0;S(100,a|0,124984,34);a=x[31721];x[31721]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:985;x[j>>2]=f;c=mg(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31721]=0;e=P(37,k+24|0,e|0)|0;m=x[31721];x[31721]=0;k:{if((m|0)!=1){x[31721]=0;m=P(996,c|0,e|0)|0;n=x[31721];x[31721]=0;if((n|0)==1){break k}x[31721]=0;O(275,m|0,l|0);l=x[31721];x[31721]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31721]=0;e=P(37,k+12|0,e|0)|0;l=x[31721];x[31721]=0;if((l|0)==1){break h}Tt(c,e)}tb(e);i=i+8|0;continue}}x[31721]=0;e=R(858,80)|0;i=x[31721];x[31721]=0;l:{m:{n:{if((i|0)!=1){x[31721]=0;d=P(997,f|0,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=x[pe(k+8|0,k+4|0)>>2];x[31721]=0;a=ha(1002,e|0,a|0,b|0,d|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break l}i=T(0)|0;Uc(k+4|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Uc(k+4|0);Ml(c);i=j;break d}i=T(0)|0}Ml(c);Y(i|0)|0;x[31721]=0;V(991,15070,j|0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(iq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31721]=0;V(991,15070,0,g|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Qb()}p()}function Oi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Si(p)){break a}if(!Si(m)){break a}h=vf(b);f=vf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Si(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Si(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=vf(d);f=vf(e);b:{if(h|f){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Si(c),w?u:v);break b}if(k){break b}c:{if(vf(s)){break c}if(vf(t)){break c}if(vf(r)){break c}if(!vf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Si(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Si(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Si(e),w?u:v)}m=(b*e+d*c)*Infinity;p=(b*d-e*c)*Infinity}Ol(a,p,m)}function L6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=fb-16|0;fb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=fb-16|0;fb=s;u=Ih(s+12|0,x[a+8>>2]);m=j-c|0;k=0;o=0;n=fb-1040|0;fb=n;i=x[e>>2];x[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=gK(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=x[n+12>>2];break g}t=(n+16|0)!=(p|0)?q:0;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=x[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=it(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){x[e>>2]=o}fb=n+1040|0;Hh(u);fb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=Xx(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!Xx(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=r+16|0;return a|0}f=x[h>>2];continue}}function vS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;e=a+1074376|0;d=D(b,872);a:{if(x[(e+d|0)+704>>2]&134218752){break a}g=x[(a+d|0)+1075648>>2];if(!Gj(g)|y[g+15|0]&2){break a}e=mm(a,e,b,2,1)-1|0;if((e&255)>>>0>249){break a}h=x[sd(a+906300|0,e)>>2];if(!h){break a}d=D(b,872)+a|0;j=d+1075780|0;e=y[j|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;d=y[Sb(d+1075784|0,c+8|0)|0];break b}f=y[d+1075783|0];if((f|0)!=46){d=255;if((f|0)!=13){break b}v[c+8|0]=64;d=y[Sb((D(b,872)+a|0)+1075785|0,c+8|0)|0];break b}d=y[(D(b,872)+a|0)+1075785|0]+3>>>2|0}i=a+1074312|0;Kb(c+8|0,i,2);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(Sc(e)){e=y[vb(g+108|0,e-1|0)|0]}Vm(a,b,e&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((d|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,d,b);break a}k=x[g+4>>2];c:{if(!e){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Kb(c+8|0,i,28);m=c,n=f+(Hb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;Ee(c+4|0,0,256);f=e;if(Sc(e)){f=y[vb(g+108|0,e-1|0)|0]}Kb(c+8|0,i,117);if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Il(y[j+2|0],y[j+3|0])){break c}}Vm(a,b,f&255,z[c+4>>1])}a=y[g+35|0];Kb(c+8|0,i,101);a=(a|0)==1;f=(d|0)!=255;if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){e=Sc(e)}if(((e?a:f)|0)!=1){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((d|0)!=255){ru(a,E(E(E(d<<1)/E(-127))+E(1)));break a}ru(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((d|0)!=255){v[c+8|0]=127;v[c+4|0]=d<<1;n=h,o=7,p=y[Sb(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Gb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function yg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=h;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];j=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;i=z[a+28>>1];if((i|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=i}g=((c+j|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+26752>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+26752>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+26752>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+26752>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+26752>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+26752>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+26240>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Pla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],p)+D(w[i+4>>1],q)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=zua(m,C,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=zua(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(q,-16777216,16776704);k=zua(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Qc(k,e,24);x[b+4>>2]=e-(o&z);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function Zs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=Ys(c,d);x[i+4>>2]=1207;n=Xs(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break a}break b}Oe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31721]=0;h=P(1209,a|0,i+124|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}if((h|!k)==1){x[31721]=0;b=P(1209,a|0,i+124|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31721]=0;o=R(1210,b|0)|0;b=x[31721];x[31721]=0;g:{if((b|0)!=1){if(g){break g}x[31721]=0;o=P(1211,e|0,o|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31721]=0;R(1212,a|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=v[bc(b,q)|0];j:{if(g){break j}x[31721]=0;r=P(1211,e|0,r<<24>>24)|0;t=x[31721];x[31721]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(r&255)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=zd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Jc(n);fb=i+128|0;return d|0}}a=N()|0;Jc(n);Q(a|0)}p()}function Vs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=Ys(c,d);x[i+4>>2]=1207;n=Xs(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break a}break b}Oe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31721]=0;h=P(1224,a|0,i+124|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}if((h|!k)==1){x[31721]=0;b=P(1224,a|0,i+124|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31721]=0;o=R(1225,b|0)|0;b=x[31721];x[31721]=0;g:{if((b|0)!=1){if(g){break g}x[31721]=0;o=P(1226,e|0,o|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31721]=0;R(1227,a|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Td(b,q)>>2];j:{if(g){break j}x[31721]=0;r=P(1226,e|0,r|0)|0;t=x[31721];x[31721]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=zd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Jc(n);fb=i+128|0;return d|0}}a=N()|0;Jc(n);Q(a|0)}p()}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=fb-32|0;fb=g;f=dU(g+20|0,1<<x[b+12>>2]);e=x[f>>2];while(1){c=x[a>>2];if(fh(c,x[a+4>>2])>>>0>d>>>0){c=Re(c,d);cU(Vd(e,d),C[c>>3]);d=d+1|0;continue}break}bU(b,f);w=g,y=wb(x[f>>2]),x[w>>2]=y;u=wb(x[f+4>>2]);while(1){d=x[g>>2];if(Ib(d,u)){m=C[d+8>>3];k=fb-32|0;fb=k;o(+C[d>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;e=e&2147483647;q=c&2147483647;c=(e|0)==(q|0)&r>>>0<s>>>0|e>>>0<q>>>0;h=c?r:s;c=c?e:q;v=c;l(0,h|0);l(1,c|0);p=+n();t=c>>>20|0;i=p;a:{if((t|0)==2047){break a}c=(e|0)==(q|0)&r>>>0>s>>>0|e>>>0>q>>>0;l(0,(c?r:s)|0);c=c?e:q;l(1,c|0);m=+n();b:{if(!(h|v)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(t>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}rL(k+24|0,k+16|0,m);rL(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;fb=k+32|0;cU(d,Yp(p));Lq(g);continue}break}$T(b,f);_T(f);h=x[f>>2];e=Ek(h,x[f+4>>2])>>>1|0;c=e>>>0<=1?1:e;d=1;while(1){if((c|0)!=(d|0)){yB(Vd(h,d),2);yB(Vd(h,d+e|0),0);d=d+1|0;continue}break}bU(b,f);w=g,y=wb(x[f>>2]),x[w+16>>2]=y;e=wb(x[f+4>>2]);while(1){h=x[g+16>>2];if(Ib(h,e)){ZT(g,C[h>>3],C[h+8>>3]);c=x[g+12>>2];x[h+8>>2]=x[g+8>>2];x[h+12>>2]=c;c=x[g+4>>2];x[h>>2]=x[g>>2];x[h+4>>2]=c;Lq(g+16|0);continue}break}$T(b,f);_T(f);e=x[a>>2];c=fh(e,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){dn(f);fb=g+32|0}else{a=Vd(b,d);w=Re(e,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function Cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;Of(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Mg(a);Ub(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Xd(a)+1|0;break c}c=dh(a)}d=dh(a);bd(a,e+f|0);e=h+8|0;ce(e,a,d);f=hc(h+28|0,e);ub(e);x[31721]=0;c=U(199,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Vb(x[k>>2],j);m=h,n=wb(x[c>>2]),x[m+8>>2]=n;l=wb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31721]=0;d=R(200,f|0)|0;e=x[31721];x[31721]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31721]=0;d=R(200,f|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31721]=0;e=R(200,f|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31721]=0;e=R(200,f|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}}if(d&8){x[31721]=0;i=R(200,f|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}}if(d&16){x[31721]=0;d=R(200,f|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){xf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25486|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}qg(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function Qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],p)+D(v[i+2|0],q)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=zua(m,E,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=zua(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(q,-16777216,16776704);k=zua(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Qc(k,e,24);x[b+4>>2]=e-(o&A);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function c4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Bb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Td(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Td(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Td(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Td(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Td(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Td(d,a)>>2]==121){break b}if(x[Td(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Td(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Td(d,a)>>2]==121){break b}if(x[Td(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Td(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Td(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+38134>>1];i=w[b+38132>>1];e=w[b+38130>>1];g=w[b+38128>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=zua(s,B,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=zua(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(p,-16777216,16776704);i=zua(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Hm(c+80|0,a);x[31721]=0;d=P(465,c+68|0,42255)|0;a=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31721]=0;x[c+56>>2]=19988993;x[c+60>>2]=0;S(466,e|0,d|0,c+56|0);a=x[31721];x[31721]=0;if((a|0)==1){break n}Eb(d);if(ol(y[e|0])){break e}x[31721]=0;d=P(465,c+56|0,13434)|0;a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;V(497,e|0,b|0,d|0,920);a=x[31721];x[31721]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31721]=0;d=P(465,c+36|0,16755)|0;a=x[31721];x[31721]=0;if((a|0)==1){break k}x[31721]=0;S(921,e|0,c+52|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}Eb(d);x[31721]=0;d=P(465,c+24|0,16745)|0;a=x[31721];x[31721]=0;if((a|0)==1){break i}x[31721]=0;S(921,e|0,c+48|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31721]=0;f=P(465,c|0,14133)|0;a=x[31721];x[31721]=0;if((a|0)==1){break d}x[31721]=0;S(922,e|0,d|0,f|0);a=x[31721];x[31721]=0;if((a|0)==1){break g}Eb(f);if(kc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31721]=0;O(872,d|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31721]=0;O(923,b|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}sc(d)}yh(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}sc(d)}yh(e);Q(a|0);p()}function J3(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Bb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[bc(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=v[bc(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=v[bc(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[bc(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[bc(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[bc(d,a)|0]==121){break b}if(y[bc(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[bc(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[bc(d,a)|0]==121){break b}if(y[bc(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[bc(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[bc(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function ora(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;i=Cf(a,c);Zd(g,x[a+36>>2]);j=a;a:{if(!i){Oc(g,a+32|0,5);c=0;if(Hb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Hm(e+80|0,x[a+36>>2]);x[31721]=0;a=P(465,e+68|0,26159)|0;c=x[31721];x[31721]=0;b:{c:{d:{e:{if((c|0)!=1){x[31721]=0;x[e+8>>2]=19988993;x[e+12>>2]=0;S(466,f|0,a|0,e+8|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}Eb(a);if(!ol(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31721]=0;a=P(465,e+52|0,10094)|0;c=x[31721];x[31721]=0;f:{g:{h:{i:{if((c|0)!=1){x[31721]=0;S(507,f|0,e+67|0,a|0);c=x[31721];x[31721]=0;if((c|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}Jf(e+67|0,50);x[31721]=0;a=P(465,e+40|0,13288)|0;c=x[31721];x[31721]=0;if((c|0)==1){break f}x[31721]=0;S(507,f|0,e+66|0,a|0);c=x[31721];x[31721]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Kj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=MB(e+8|0,x[b+12>>2]);x[31721]=0;S(508,b|0,h|0,a|0);c=x[31721];x[31721]=0;if((c|0)==1){break h}Ql(a);a=x[b>>2]}k=z[Sj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];n=b,o=Kj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}Ze(Sj(x[b>>2],a),k);l=x[b>>2];x[31721]=0;O(509,e+8|0,c|0);m=x[31721];x[31721]=0;if((m|0)!=1){x[31721]=0;V(510,f|0,Sj(l,a)|0,e+8|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}c=c+1|0;Eb(e+8|0);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Ql(a);break c}c=N()|0;Eb(a);break c}c=N()|0}yh(f);Q(c|0);p()}yh(f);fb=e+192|0;c=i}cf(j,c);fb=g+16|0}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[Ab(a)>>2]){f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[31721]=0;O(686,a|0,b|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;gc(c);fb=f+16|0;break a}a=N()|0;gc(c);Q(a|0);p()}return}h=fb-32|0;fb=h;i=Ab(a);f=h+12|0;g=jv(x[a>>2],x[a+4>>2])+1|0;d=fb-16|0;fb=d;x[d+12>>2]=g;e=fb-16|0;fb=e;x[e+12>>2]=76695844;x[e+8>>2]=2147483647;c=x[Gb(e+12|0,e+8|0)>>2];fb=e+16|0;b:{if(c>>>0>=g>>>0){e=XW(a);if(e>>>0<c>>>1>>>0){x[d+8>>2]=e<<1;c=x[$c(d+8|0,d+12|0)>>2]}fb=d+16|0;break b}cd();p()}g=jv(x[a>>2],x[a+4>>2]);e=fb-16|0;fb=e;Fg(f+12|0,i);c:{if(!c){d=0;c=0;break c}if(c>>>0>=76695845){Xj();p()}d=Dc(D(c,56));x[e+12>>2]=c;x[e+8>>2]=d;d=x[e+12>>2];c=x[e+8>>2]}x[f>>2]=c;g=c+D(g,56)|0;x[f+8>>2]=g;x[f+4>>2]=g;j=zc(f),k=c+D(d,56)|0,x[j>>2]=k;fb=e+16|0;c=x[f+8>>2];x[31721]=0;O(686,c|0,b|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[f+8>>2]=x[f+8>>2]+56;e=fb-16|0;fb=e;b=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);g=zb(e+4|0,x[f+4>>2]);d=x[b>>2];i=x[c>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[g>>2];x[c+12>>2]=d;while(1){g=x[c+8>>2];if(Pg(d,i)){b=fb-16|0;fb=b;x[b+12>>2]=g;x[b+12>>2]=x[b+12>>2]-56;fb=b+16|0;g=x[b+12>>2];b=YW(d);d=Ul(g,b);Ul(d+12|0,b+12|0);iC(d+24|0,b+24|0);w[d+52>>1]=z[b+52>>1];g=x[b+48>>2];x[d+44>>2]=x[b+44>>2];x[d+48>>2]=g;g=x[b+40>>2];x[d+36>>2]=x[b+36>>2];x[d+40>>2]=g;b=VW(c+12|0);VW(c+8|0);d=x[b>>2];continue}break}fb=c+16|0;x[f+4>>2]=g;wc(a,f+4|0);wc(a+4|0,f+8|0);wc(Ab(a),zc(f));x[f>>2]=x[f+4>>2];fb=e+16|0;WW(f);fb=h+32|0;break d}a=N()|0;WW(f);Q(a|0);p()}}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+38134>>1];i=w[b+38132>>1];e=w[b+38130>>1];g=w[b+38128>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=zua(s,C,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=zua(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(p,-16777216,16776704);i=zua(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function zr(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;be(a,1,Sb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;be(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;be(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;be(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42192|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Sb(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;be(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}be(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;be(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;be(a,3,e+14|0);break a}d=c&240;if(!d){be(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;be(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;be(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2&60|2;be(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;be(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;be(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;be(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;be(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;be(a,1,e+14|0);break a}v[e+14|0]=0;be(a,0,e+14|0)}fb=e+16|0}function PU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Ph(d);d=x[d+8>>2];if(!g){continue}break}break c}d=BZ(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Ph(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Ph(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;pn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){pn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Ph(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ar(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Ph(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;$q(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;ar(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;$q(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Ph(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;ar(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;$q(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function b7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1240;h=Ae(a+200|0,a+208|0,a+16|0);ad(a+192|0,x[e+28>>2]);x[31721]=0;i=R(1219,x[a+192>>2])|0;b=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[31721]=0;b=na(1249,a+620|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(!b){break e}b=y[14633]|y[14634]<<8|(y[14635]<<16|y[14636]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14630]|y[14631]<<8|(y[14632]<<16|y[14633]<<24);x[a+176>>2]=y[14626]|y[14627]<<8|(y[14628]<<16|y[14629]<<24);x[a+180>>2]=b;x[31721]=0;V(1230,i|0,a+176|0,a+186|0,a+128|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}x[a+4>>2]=1207;d=Ae(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Oe(d,Ed((c>>2)+2|0));e=x[d>>2];if(e){break f}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((qK(a+16|0,a)|0)!=1){x[31721]=0;W(1242,8e3);b=x[31721];x[31721]=0;if((b|0)!=1){break a}break c}Jc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(iy(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31721]=0;b=P(1224,a+620|0,a+616|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Yb(a+192|0);Jc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Jc(d)}Yb(a+192|0);Jc(h);Q(c|0);p()}p()}function oQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=fb-16|0;fb=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;Mz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=nc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[$c(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(Zt(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;l=i>>>0<=1?1:i;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(l|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(Zt(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(Zt(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(Zt(o^(x[p>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[xb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[p>>2]=j;h=h+1|0;continue}}fb=m+16|0}function i7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1240;h=Ae(a+152|0,a+160|0,a+16|0);ad(a+144|0,x[e+28>>2]);x[31721]=0;i=R(28,x[a+144>>2])|0;b=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[31721]=0;b=na(1241,a+268|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(!b){break e}b=y[14633]|y[14634]<<8|(y[14635]<<16|y[14636]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14630]|y[14631]<<8|(y[14632]<<16|y[14633]<<24);x[a+128>>2]=y[14626]|y[14627]<<8|(y[14628]<<16|y[14629]<<24);x[a+132>>2]=b;x[31721]=0;V(1217,i|0,a+128|0,a+138|0,a+118|0);b=x[31721];x[31721]=0;if((b|0)==1){break g}x[a+4>>2]=1207;d=Ae(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Oe(d,Ed(c+2|0));e=x[d>>2];if(e){break f}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((qK(a+16|0,a)|0)!=1){x[31721]=0;W(1242,8e3);b=x[31721];x[31721]=0;if((b|0)!=1){break a}break c}Jc(d)}else{b=a+118|0;i=OZ(b);j=e,k=y[((Ii(b,i,y[c|0])-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31721]=0;b=P(1209,a+268|0,a+264|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Yb(a+144|0);Jc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Jc(d)}Yb(a+144|0);Jc(h);Q(c|0);p()}p()}function R6(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=jJ(Fk(xd(n),1),ml(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=kt(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(zd(x[n+4>>2],y[n+11|0])){break a}h=x[Td(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(zd(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=jJ(xd(m),ml(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!uj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=kt(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=kt(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(zd(x[l+4>>2],y[l+11|0])){s=-1}else{s=v[bc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[bc(l,t)|0]==127){break f}s=v[bc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}Ws(A,h)}u=u+1|0;continue}break}}function ne(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31721]=0;O(54,b|0,Xc(e,d)|0);d=x[31721];x[31721]=0;d:{if((d|0)!=1){e:{while(1){if(Xc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[bc(c,a)|0];x[31721]=0;O(36,b|0,((d|0)<0?65533:d&255)|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31721]=0;O(54,b|0,Xc(e,d)|0);d=x[31721];x[31721]=0;f:{if((d|0)!=1){while(1){if(Xc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[bc(c,a)|0];x[31721]=0;O(36,b|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:ef(a,c,48912);return;case 4:ef(a,c,49936);return;case 5:ef(a,c,50960);return;case 6:ef(a,c,51984);return;case 7:ef(a,c,53008);return;case 8:ef(a,c,54032);return;case 9:ef(a,c,55056);return;case 10:ef(a,c,56080);return;case 11:ef(a,c,57104);return;case 12:ef(a,c,58128);return;case 13:ef(a,c,59152);return;case 14:ef(a,c,60176);return;case 15:ef(a,c,61200);return;case 16:ef(a,c,62224);return;case 17:ef(a,c,63248);return;case 18:ef(a,c,64272);return;case 19:ef(a,c,65296);return;case 20:ef(a,c,66320);return;case 21:ef(a,c,67344);return;case 22:ef(a,c,68368);return;case 23:ef(a,c,69392);return;case 24:SA(a,c,70416);return;case 25:SA(a,c,48912);return;case 26:SA(a,c,67344);return;default:a=$b(8);x[31721]=0;b=P(16,a|0,11106)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}b=N()|0;ic(a);Q(b|0);p();case 0:break c}}NZ(a,c);return}da(b|0,125116,17);p()}a=N()|0;Rb(b);Q(a|0);p()}function wq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Ee(h+12|0,0,127);Ee(h+8|0,0,127);j=a+1074312|0;i=Ob(j,1);k=x[h+12>>2];a:{if(i){i=x[h+8>>2];break a}w[b+780>>1]=0;v[b+837|0]=k;i=x[h+8>>2];w[b+782>>1]=0;v[b+838|0]=i}l=D(d+256|0,k);m=(l|0)/256|0;b:{if(!(!Ob(j,36)|i|(l|0)<65024)){m=-1;if(!(y[b+851|0]&2)){break b}x[b+88>>2]=x[b+88>>2]&-32769;break b}x[b+88>>2]=x[b+88>>2]|32768;e=Ce(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,k)>>>0);c:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break c}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(Ce(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;rT(d,E(120),E(2e4));kB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));d:{if(!(!Ob(j,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break d}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;kB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);e:{if(y[b+845|0]==1){n=b,p=Jl(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Jl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Jl(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break e}d=Jl(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Jl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Jl(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break e}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break b}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return m}function Tja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(yd(x[a+24>>2])){break f}i=Xc(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;g=f+8|0;x[g>>2]=-1;x[g+4>>2]=-1;x[31721]=0;h=LH(67);d=x[31721];x[31721]=0;b=hb;if((d|0)==1){T(0)|0;Qb();p()}e=fb-16|0;fb=e;d=ue(e+8|0,zua(h,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=cA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=VQ(g,f,Ab(f));x[31721]=0;h=LH(68);d=x[31721];x[31721]=0;b=hb;if((d|0)==1){T(0)|0;Qb();p()}g=a+24|0;j=f,k=cA(QQ(h,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=VQ(e,f,Ab(f));d=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31721]=0;x[c+8>>2]=b;O(61,e|0,c+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;x[c+8>>2]=d;O(61,e|0,c+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}h=a+4|0;b=a;a=0;g:{while(1){if(Xc(x[b+8>>2],y[b+15|0])>>>0<=a>>>0){b=wb(x[e>>2]);a=wb(x[e+4>>2]);x[31721]=0;d=U(62,c+8|0,b|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break g}a=N()|0;break b}d=y[bc(h,a)|0];x[31721]=0;x[c+8>>2]=d;O(61,e|0,c+8|0);d=x[31721];x[31721]=0;if((d|0)!=1){a=a+1|0;continue}break}a=N()|0;break b}x[31721]=0;b=R(63,d|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;fA(g,a);Cj(a);Um(d);sc(e);break f}a=N()|0;Um(d);break b}hb=d;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31721]=0;S(66,b|0,c+8|0,c+16|0);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;sc(b);Q(a|0);p()}x[31721]=0;d=R(63,b|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;fA(g,a);Cj(a);Um(b)}fb=c+32|0;return}a=N()|0;Um(b);break a}a=N()|0;break b}a=N()|0}sc(e)}Q(a|0);p()}function ju(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=$b(8);x[31721]=0;b=P(52,a|0,22250)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break g}b=N()|0;ic(a);break a}if(!x[b>>2]){a=$b(8);x[31721]=0;b=R(861,a|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break f}b=N()|0;ic(a);break a}d=x[b>>2];j=x[b+4>>2];b=fb-16|0;fb=b;jf(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;iG(g,h,x[b+12>>2]);x[g+12>>2]=0;fb=b+16|0;i:{j:{if(a&2){b=Fn(f+88|0,g);x[31721]=0;b=R(862,b|0)|0;e=x[31721];x[31721]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Fn(f+68|0,g);x[31721]=0;e=R(863,d|0)|0;h=x[31721];x[31721]=0;d=1;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}d=Fn(f+48|0,g);x[31721]=0;h=P(864,d|0,c|0)|0;i=x[31721];x[31721]=0;d=1;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}d=Fn(f+28|0,g);x[31721]=0;i=P(865,d|0,c|0)|0;m=x[31721];x[31721]=0;d=1;if((m|0)==1){break c}if((i|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(i|0)==-1?-1:l?b:(h|0)==-1?-1:b}k:{if(!(a&1)){break k}b=29904;while(1){if((b|0)==30480){break k}a=x[b>>2];if(a){d=Fn(f+8|0,g);x[31721]=0;a=P(a|0,d|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}fb=f+128|0;return d}b=N()|0;break a}da(b|0,125276,17);p()}da(b|0,125172,17);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function e4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-576|0;fb=c;Tb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;while(1){a:{if((d|0)==7){d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Di(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;fa(e|0,100,14273,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Di(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0<=1){break a}g=D(d,12)+a|0;e=c+32|0;ym(g+172|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13333,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Di(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;ym(g+316|0,f,f+(e<<2)|0);d=d+1|0;continue}break}d=c+32|0;ym(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;d=Di(d,c+20|0,100,c+24|0,x[a>>2]);if((d|0)!=-1){e=c+32|0;ym(a+472|0,e,e+(d<<2)|0);d=c+8|0;Gs(d,a,99,b);lh(a+484|0,d);Rb(d);Gs(d,a,114,b);lh(a+496|0,d);Rb(d);Gs(d,a,120,b);lh(a+508|0,d);Rb(c+8|0);Gs(d,a,88,b);lh(a+520|0,d);Rb(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;fa(e|0,100,14286,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Di(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0>1){g=D(d,12)+a|0;e=c+32|0;ym(g+4|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13540,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Di(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;ym(g+88|0,f,f+(e<<2)|0);d=d+1|0;continue}}break}Zn(12661);p()}function hH(a,b,c){var d=0,e=0,f=0,g=0;d=fb-432|0;fb=d;a:{f=Ds(d+428|0,b);e=x[f>>2];b:{if(!yd(e)){x[31721]=0;b=P(37,d+416|0,b|0)|0;a=x[31721];x[31721]=0;c:{d:{e:{if((a|0)!=1){x[31721]=0;S(1019,d+16|0,17686,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}x[31721]=0;W(1347,d+16|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}Rp(e);if(!Op(a+8|0,22250,x[f>>2])){x[a+8>>2]=2147483647}if(!Op(a+12|0,22250,x[f>>2])){x[a+12>>2]=2147483647}x[31721]=0;O(275,a+16|0,22250);b=x[31721];x[31721]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22250;b=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((b|0)==-1){x[31721]=0;W(1242,12661);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31721]=0;e=d+16|0;b=U(1354,a+28|0,e|0,e+(b<<2)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22250;x[d+8>>2]=0;x[d+12>>2]=0;h:{e=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){x[31721]=0;g=d+16|0;U(1354,a+40|0,g|0,g+(e<<2)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}x[d+4>>2]=22250;x[d+8>>2]=0;x[d+12>>2]=0;e=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){break h}}x[31721]=0;W(1242,12661);a=x[31721];x[31721]=0;if((a|0)!=1){break a}break f}x[31721]=0;g=d+16|0;U(1354,a+52|0,g|0,g+(e<<2)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}x[31721]=0;b=P(1355,d+416|0,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}ei(a+68|0,c);ei(a+72|0,c);Rb(b);il(f);fb=d+432|0;return}a=N()|0}il(f);Q(a|0);p()}p()}function SP(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=fb-16|0;fb=c;e=a+4208|0;b=Jz(B[xb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=jq(E(B[Qm(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[xb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=Ce(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Jz(B[xb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Qm(c+12|0,c+8|0)>>2];m=c,n=E(Jz(B[xb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Qm(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=fb-16|0;fb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=fo(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=fo(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=fo(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=fo(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=fo(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Oy(b,f+8|0);b=fo(C[f+8>>3],d&1)}fb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=jq(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44048>>2];fb=c+16|0}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=zua(q,B,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=zua(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=zua(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=jg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=zua(q,C,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=zua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(F,-16777216,16776704);i=zua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Cg(a,n,u);fb=f+48|0}function V6(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=kJ(Ne(xd(n),1),zf(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=hm(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(zd(x[n+4>>2],y[n+11|0])){break a}p=y[bc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(zd(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=kJ(xd(m),zf(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Ff(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=hm(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=hm(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}if(zd(x[l+4>>2],y[l+11|0])){q=-1}else{q=v[bc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[bc(l,t)|0]==127){break e}q=v[bc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}zm(A,x[c>>2])}u=u+1|0;continue}break}}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=zua(q,B,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=zua(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=zua(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Vj(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=ae(a);a:{if(c){g=dc(h);while(1){a=c;c=a+14|0;if(Wu(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!Wu(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=dc(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=dc(h);j=zh(e,Dc(48),Jg(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=dc(j),l=1,v[k+4|0]=l;fb=i+16|0;Xg(h,x[e+12>>2],g,x[e>>2]);b=ie(e);Zl(e);d=1}Wg(f+8|0,x[zb(e,b)>>2],d);fb=e+16|0;a=Yo(x[f+8>>2]);fb=f+16|0;return a+32|0}function d1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Ni(b)^-1;a:{if(nc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){hu(a);break a}Ni(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Ub(b,4)}j=f,k=Ni(b),x[j+44>>2]=k;Ub(b,4);h=Ni(b);i=Ni(b);if(!((h|0)>0&(i|0)>36)){hu(a);break a}if(fr(Dd(x[e>>2],x[xb(x[d>>2],g)>>2]),13165)){hu(a);break a}e=f+4|0;dF(e,b,i,h);d=hc(f+24|0,e);ub(e);b=x[d>>2];x[31721]=0;b=R(175,b|0)|0;e=x[31721];x[31721]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31721]=0;R(185,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31721]=0;P(186,d|0,8)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31721]=0;P(186,d|0,16)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}}x[31721]=0;R(187,d|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31721]=0;R(187,d|0)|0;c=x[31721];x[31721]=0;b=8;break g}h:{if(b>>>0>=100){x[31721]=0;P(186,d|0,4)|0;b=x[31721];x[31721]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31721]=0;R(187,d|0)|0;c=x[31721];x[31721]=0;b=4}if((c|0)==1){break b}x[31721]=0;P(186,d|0,b|0)|0;break e}x[31721]=0;R(187,d|0)|0}b=x[31721];x[31721]=0;if((b|0)==1){break b}x[31721]=0;b=R(187,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;S(188,f+4|0,d|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}b=a;a=f+4|0;j=hc(b,a),k=x[f+44>>2],x[j+20>>2]=k;ub(a)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+38134>>1];i=w[b+38132>>1];e=w[b+38130>>1];g=w[b+38128>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=zua(q,z,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=zua(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(n,-16777216,16776704);i=zua(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Bg(m,b,o);r=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];cg(h,e,rf(m,p,d),hb);n=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);_d(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=zg(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=zua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(s,-16777216,16776704);j=zua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=zua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,p);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{$d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);_d(i,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=jg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=zua(q,C,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=zua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(F,-16777216,16776704);i=zua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Cg(a,n,u);fb=f+48|0}function wh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Io(f,g);break b}Io(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];tU(x[a>>2],d);tU(x[a+4>>2],d);w[a+22>>1]=h;EB(a);vU(a);v[a+21|0]=f;EB(a);vU(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;EB(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27344|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Jo(a);w[a+14>>1]=z[((e&15)<<1)+27376>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22235|0];uU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Jo(a);w[a+26>>1]=e&15;Jo(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Jo(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){l=b;if(d){b=Xb(l,-16777216,16776704);m=zua(r,A,b,b>>31);n=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=zua(b,b>>31,s,B);m=b+m|0;o=hb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Xb(e,-16777216,16776704);e=zua(q,z,b,b>>31);n=e+m|0;b=hb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(g+8|0,i,h);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=l;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+38134>>1];i=w[b+38132>>1];e=w[b+38130>>1];g=w[b+38128>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=zua(q,A,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=zua(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(n,-16777216,16776704);i=zua(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function yk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(y[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;x[i+12>>2]=(f^d)-f;uc(i+12|0,1020);h=x[i+12>>2];f=c;i:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35424:35488)>>2];break i}h=x[(h&-4)+(Ob(a+1074312|0,7)?35552:36576)>>2];break i}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35488:35424)>>2];break i}h=x[(h&-4)+(Ob(a+1074312|0,7)?36576:35552)>>2]}j=zua(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Fc(Aua(j,h,65536,0),hb);x[k>>2]=f;if((f|0)!=(g|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!(f^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}if(Ob(a+1074312|0,7)){break g}g=x[c>>2]}f=g-d|0;break d}f=x[c>>2];if((d|0)<0){g=zua(f,0,14317456,0);h=hb;f=zua(f,0,0-d|0,0);d=hb;f=f+14317456|0;d=f>>>0<14317456?d+1|0:d;f=FS(Bua(g,h,f,d),hb);break d}d=zua(f,f>>31,d,0);g=hb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=FS(Bua(zua(f,0,14317456,0),hb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function yz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;yc(a,d+24604|0,40);x[e+8>>2]=b;wA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=$b(8);x[31721]=0;b=P(37,d+4|0,10830)|0;a=x[31721];x[31721]=0;i:{if((a|0)!=1){mc(c,b);x[31721]=0;S(100,c|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;ic(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!oz(e+8|0,a+24648|0)){break d}uA(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];yc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){Mt(f,x[Hq(b+8|0)+32>>2]);Io(f,x[Hq(b+8|0)+36>>2]);break j}if((c|0)<=0){Mt(f,0);Io(f,0);break j}a=D(c,1e3);Mt(f,a);Io(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}wA(d,e+8|0);break d;default:d=$b(8);x[31721]=0;c=P(37,e+8|0,10385)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(d,c);x[31721]=0;S(100,d|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=Ce(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;ic(d)}Q(b|0)}p()}function dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){l=e;if(d){e=Xb(l,-16777216,16776704);f=zua(p,A,e,e>>31);e=hb;b=Xb(b,-16777216,16776704);b=zua(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];m=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=zua(b,b>>31,q,B);m=m+f|0;b=hb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Pb(g+8|0,i,h);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=l;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function rna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Lj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;qc(f+8|0);Nd(c+8|0,x[zb(c+4|0,f)>>2]);a:{b:{if(d){x[31721]=0;O(644,f|0,d|0);h=x[31721];x[31721]=0;if((h|0)==1){break b}xE(f,d)}h=c+8|0;Md(h);Wj(h);fb=c+16|0;break a}a=N()|0;Wj(c+8|0);Q(a|0);p()}c=x[a>>2];h=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(g&65535)){break c}b=wb(c);d=wb(x[a+4>>2]);c=fb-16|0;fb=c;b=uC(b,d,z[e+30>>1]);x[c+12>>2]=b;if(Ib(b,d)){x[c+8>>2]=b;while(1){b=x[Od(c+8|0)>>2];if(Ib(b,d)){b=z[b>>1];if((b|0)==z[e+30>>1]){continue}w[x[c+12>>2]>>1]=b;Od(c+12|0);continue}break}b=x[c+12>>2]}fb=c+16|0;b=zb(e+12|0,b);c=x[zb(e+8|0,wb(x[a+4>>2]))>>2];d=fb-16|0;fb=d;g=x[b>>2];b=x[a>>2];b=(ep(g,wb(b))<<1)+b|0;if(Ib(g,c)){yn(a,Nv(b+(ep(c,g)<<1)|0,x[a+4>>2],b))}zb(d+12|0,b);fb=d+16|0;k=e,l=wb(x[a>>2]),x[k+4>>2]=l;d=wb(x[a+4>>2]);while(1){b=x[e+4>>2];if(Ib(b,d)){d:{c=x[a+24>>2];g=x[c+484344>>2];b=z[b>>1];if(!Ge(g,x[c+484348>>2],b)){break d}b=Vb(g,b);k=e,l=wb(x[b>>2]),x[k>>2]=l;g=wb(x[b+4>>2]);h=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,g)){break d}e:{if(y[b+3|0]!=12){break e}j=Yc(c,h);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[Zb(c,i)|0],v[k+5|0]=l}qg(e);continue}}Od(e+4|0);continue}else{b=x[f>>2];d=Yc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[Zb(b,c)>>1],w[k+28>>1]=l}break}}}else{k=Zb(h,b),l=b-g|0,w[k>>1]=l;g=(z[Zb(c,b)>>1]==254)+g|0;b=b+1|0;continue}break}ld(f);fb=e+32|0}function yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Bg(m,b,o);r=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];cg(h,e,rf(m,p,d),hb);n=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(i,v[h+x[g+12>>2]|0]<<6);_d(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=zg(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=zua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(s,-16777216,16776704);j=zua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=zua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,p);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{$d(i,v[h+x[g+12>>2]|0]<<6);_d(i,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function i0(){var a=0,b=0,c=0;if(!y[500064]){a=fb-16|0;fb=a;wt(499712);x[124940]=-1;x[124938]=499768;x[124936]=126072;x[124928]=94620;v[499764]=0;b=a+12|0;ad(b,x[124929]);c=x[x[124928]+8>>2];x[31721]=0;O(c|0,499712,b|0);b=x[31721];x[31721]=0;a:{if((b|0)!=1){Yb(a+12|0);fb=a+16|0;break a}b=N()|0;Yb(a+12|0);co(499712);Q(b|0);p()}yt(499040);x[124760]=94752;x[124758]=94732;x[124759]=0;ho(499040,499712);GK(499776,126216,499824);zy(499208,499776);GK(499832,125920,499880);zy(499376,499832);zy(499544,x[x[x[124844]-12>>2]+499400>>2]);FK(x[x[124758]-12>>2]+499032|0);CK(x[x[124844]-12>>2]+499376|0);FK(x[x[124844]-12>>2]+499376|0);a=fb-16|0;fb=a;SK(499888);x[124984]=-1;x[124982]=499944;x[124980]=126072;x[124972]=95012;v[499940]=0;b=a+12|0;ad(b,x[124973]);c=x[x[124972]+8>>2];x[31721]=0;O(c|0,499888,b|0);b=x[31721];x[31721]=0;b:{if((b|0)!=1){Yb(a+12|0);fb=a+16|0;break b}b=N()|0;Yb(a+12|0);nt(499888);Q(b|0);p()}BK(499128);x[124782]=95144;x[124780]=95124;x[124781]=0;ho(499128,499888);EK(499952,126216,5e5);yy(499292,499952);EK(500008,125920,500056);yy(499460,500008);yy(499628,x[x[x[124865]-12>>2]+499484>>2]);DK(x[x[124780]-12>>2]+499120|0);CK(x[x[124865]-12>>2]+499460|0);DK(x[x[124865]-12>>2]+499460|0);v[500064]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Ed((x[a+12>>2]<<2)+4|0);x[125018]=b;if(!b){break c}b=Ed(x[a+8>>2]);if(b){c=x[125018];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125018]=0}fb=a+16|0;x[124209]=42;x[124227]=500164}function Nka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[31721]=0;b=U(153,h|0,b|0,l|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[31721]=0;S(188,f+8|0,c|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}b=f+8|0;h=hc(f+28|0,b);ub(b);x[31721]=0;O(578,b|0,h|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}z=Se(f+8|0);q=x[f+8>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Ic(f+8|0);ub(h);n=(q-l<<1)+n|0;continue h}x[31721]=0;g=R(571,h|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){x[31721]=0;b=R(200,h|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break f}x[f>>2]=b;Ee(f,0,89);x[31721]=0;P(186,h|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28616|0];B=g;g=w[(r<<1)+28624>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?g:0-g|0);Ee(f,0,88);Ee(f+4|0,-32768,32767);g=x[f+4>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Ic(f+8|0);break d}b=N()|0}ub(h);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function Fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-96|0;fb=c;Yj(c+76|0,b,1413829443);x[31721]=0;b=R(175,x[c+76>>2])|0;d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31721]=0;S(814,c+56|0,a+140|0,1413894985);a=x[31721];x[31721]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31721]=0;a=P(897,c+56|0,13691)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31721]=0;a=R(205,c+56|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break m}x[31721]=0;S(273,c+56|0,b|0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break m}x[31721]=0;d=P(73,c+20|0,b|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break l}x[31721]=0;W(898,c+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break k}x[31721]=0;S(899,c+32|0,d|0,c+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break j}a=c+32|0;e=yb(b,a);tb(a);tb(c+8|0);tb(d);x[31721]=0;S(261,a|0,2,e|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}x[31721]=0;a=R(777,c+32|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}tb(c+32|0);tb(e);b=a-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31721]=0;a=U(153,x[c+76>>2],x[c+84>>2],2)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31721]=0;b=R(192,c+76|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function uO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;g=Nb(a);a:{b:{c:{d=b+36|0;a=x[d>>2];f=x[b+40>>2];d:{if(Ib(a,f)){qc(c+28|0);break d}x[31721]=0;O(1080,c+16|0,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}x[31721]=0;a=R(1064,c+16|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[c+28>>2]=a;lf(c+16|0);f=x[b+40>>2];a=x[b+36>>2]}if(!Ib(a,f)){d=x[c+28>>2];a=x[d>>2]}f=x[d+4>>2];x[31721]=0;O(179,g|0,lj(a,f)|0);a=x[31721];x[31721]=0;e:{if((a|0)!=1){i=c,j=wb(x[d>>2]),x[i+12>>2]=j;f=wb(x[d+4>>2]);f:{g:{h:{i:{j:{while(1){a=x[c+12>>2];if(!Ib(a,f)){xl(c+28|0);fb=c+32|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[31721]=0;d=Sj(e,d);O(1081,c|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break f}x[31721]=0;O(1067,c+16|0,c|0);e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;O(181,g|0,c+16|0);e=x[31721];x[31721]=0;if((e|0)==1){break j}tb(c+16|0);tb(c);e=Pn(x[g+4>>2]);k:{if(!zd(x[e+4>>2],y[e+11|0])){break k}a=x[a+12>>2];if(!_i(d,a&255)){break k}e=x[b+24>>2];h=x[e+1298404>>2];a=z[Zb(x[d>>2],a)>>1];d=x[e+484344>>2];x[31721]=0;O(1074,c|0,Vb(d,a)|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}x[31721]=0;S(1082,c+16|0,h|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break g}a=c+16|0;yb(Pn(x[g+4>>2]),a);tb(a);tb(c)}Wz(c+12|0);continue}break}a=N()|0;break i}a=N()|0;tb(c+16|0)}tb(c);break e}a=N()|0;break e}a=N()|0;tb(c);break e}a=N()|0;break e}a=N()|0}xl(c+28|0);break a}a=N()|0;lf(c+16|0);break a}a=N()|0}Qd(g);Q(a|0);p()}function S7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;hy(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31721]=0;b=P(1224,a+380|0,a+376|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+204>>2]=b+c}x[31721]=0;b=R(1225,x[a+380>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(fy(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31721]=0;R(1227,a+380|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}SJ(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Rf(a+220|0,a+32|0,x[a+28>>2],e);x[31721]=0;b=P(1224,a+380|0,a+376|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function $7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;my(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[31721]=0;b=P(1209,a+268|0,a+264|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+192>>2]=b+c}x[31721]=0;b=R(1210,x[a+268>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(ly(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31721]=0;R(1212,a+268|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}SJ(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Rf(a+208|0,a+32|0,x[a+28>>2],e);x[31721]=0;b=P(1209,a+268|0,a+264|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function R7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);ad(a+16|0,x[d+28>>2]);x[31721]=0;b=R(1219,x[a+16>>2])|0;c=x[31721];x[31721]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31721]=0;V(1230,b|0,111712,111738,a+208|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}Yb(a+16|0);c=Fb(a+184|0);b=Kc(c);x[31721]=0;O(47,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=bc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[31721]=0;d=P(1224,a+316|0,a+312|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}if(d){break c}g=x[a+180>>2];d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31721]=0;O(47,c|0,d<<1);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=Kc(c);x[31721]=0;O(47,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=bc(c,0);x[a+180>>2]=d+b}x[31721]=0;d=R(1225,x[a+316>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}if(Wn(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break c}x[31721]=0;R(1227,a+316|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;Yb(a+16|0);break a}x[31721]=0;O(47,c|0,x[a+180>>2]-b|0);b=x[31721];x[31721]=0;f:{if((b|0)==1){break f}b=Jb(c);d=Kd();x[a>>2]=f;if((RJ(b,d,a)|0)!=1){x[e>>2]=4}x[31721]=0;b=P(1224,a+316|0,a+312|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}}b=N()|0;tb(c)}tb(h);Q(b|0);p()}function _7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);ad(a+16|0,x[d+28>>2]);x[31721]=0;b=R(28,x[a+16>>2])|0;c=x[31721];x[31721]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31721]=0;V(1217,b|0,111712,111738,a+208|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}Yb(a+16|0);c=Fb(a+184|0);b=Kc(c);x[31721]=0;O(47,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=bc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[31721]=0;d=P(1209,a+252|0,a+248|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}if(d){break c}g=x[a+180>>2];d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31721]=0;O(47,c|0,d<<1);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=Kc(c);x[31721]=0;O(47,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}b=bc(c,0);x[a+180>>2]=d+b}x[31721]=0;d=R(1210,x[a+252>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break e}if(Xn(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break c}x[31721]=0;R(1212,a+252|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;Yb(a+16|0);break a}x[31721]=0;O(47,c|0,x[a+180>>2]-b|0);b=x[31721];x[31721]=0;f:{if((b|0)==1){break f}b=Jb(c);d=Kd();x[a>>2]=f;if((RJ(b,d,a)|0)!=1){x[e>>2]=4}x[31721]=0;b=P(1209,a+252|0,a+248|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}}b=N()|0;tb(c)}tb(h);Q(b|0);p()}function AB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[vb(g,b)|0];if((d|0)==255){break c}if(v[vb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[Zb(f,d)>>1]!=65535){if(z[Zb(f,d)>>1]!=(b|0)){break c}}j=Zb(f,d),k=b,w[j>>1]=k;j=vb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[Zb(f,d)>>1]!=65535){if(!(y[vb(i,d)|0]&32)){h=v[vb(g,z[Zb(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=Zb(f,d),k=b,w[j>>1]=k;j=vb(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=vb(g,z[Zb(f,e)>>1]),k=255,v[j|0]=k;j=Zb(f,e),k=b,w[j>>1]=k;j=vb(g,b),k=d,v[j|0]=k}d=Pl(a,b)}g=d&255;if((g|0)==255){break a}if(Ak(x[a>>2])){break a}e=Dd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=oU(g);h=f+3|0;d=0;while(1){if((d|0)==2){wh(x[a>>2],x[a+4>>2],b,Nu(g)|192,y[vb(c,10)|0])}else{e=d?h:f;wh(x[a>>2],x[a+4>>2],b,e|32,y[vb(c,d)|0]);wh(x[a>>2],x[a+4>>2],b,e|64,y[vb(c,d+2|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|96,y[vb(c,d+4|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|128,y[vb(c,d+6|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|224,y[vb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function jU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:pB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15472|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;e=x[(d<<2&60)+78784>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14757|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;e=z[(d<<1&126)+78848>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11165|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;e=z[(d<<1&510)+78976>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4895|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function y7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-416|0;fb=i;x[i+408>>2]=37;x[i+412>>2]=0;l=Ts(i+408|1,13905,x[c+4>>2]);x[i+364>>2]=i+368;a=Kd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=mh(i+368|0,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=mh(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1207;k=Ae(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Kd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=oj(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=oj(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Oe(k,a)}f=a+j|0;g=pj(a,f,x[c+4>>2]);x[i+116>>2]=1207;e=Ae(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<3);if(!j){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(e,j);b=a}a=i+108|0;ad(a,x[c+28>>2]);x[31721]=0;ga(1238,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31721];x[31721]=0;i:{if((a|0)!=1){Yb(i+108|0);x[31721]=0;a=ea(1239,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}Jc(e);Jc(k);fb=i+416|0;break b}a=N()|0;Yb(i+108|0);break g}a=N()|0}Jc(e);break c}p()}a=N()|0}Jc(k);Q(a|0);p()}return a|0}function I7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-256|0;fb=i;x[i+248>>2]=37;x[i+252>>2]=0;l=Ts(i+248|1,13905,x[c+4>>2]);x[i+204>>2]=i+208;a=Kd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=mh(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=mh(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1207;k=Ae(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Kd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=oj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=oj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Oe(k,a)}f=a+j|0;g=pj(a,f,x[c+4>>2]);x[i+116>>2]=1207;e=Ae(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<1);if(!j){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(e,j);b=a}a=i+108|0;ad(a,x[c+28>>2]);x[31721]=0;ga(1233,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31721];x[31721]=0;i:{if((a|0)!=1){Yb(i+108|0);x[31721]=0;a=ea(23,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}Jc(e);Jc(k);fb=i+256|0;break b}a=N()|0;Yb(i+108|0);break g}a=N()|0}Jc(e);break c}p()}a=N()|0}Jc(k);Q(a|0);p()}return a|0}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=zua(o,z,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=zua(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=zua(m,v,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=jg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=zua(o,A,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=zua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(C,-16777216,16776704);i=zua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(q&v);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Cg(a,l,s);fb=f+48|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=zua(o,z,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=zua(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=zua(m,w,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function F2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;eu(d+48|0);a:{b:{c:{if(vp(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=$b(8);x[31721]=0;c=P(37,d+36|0,10453)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}g=aM(c);if(g){b=_L(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!$L(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[zj(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(vp(e)){a=$b(8);x[31721]=0;c=P(37,d+36|0,10453)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(AF(e)){break f}if(!qk(e)){break f}a=$b(8);x[31721]=0;c=P(37,d+36|0,10453)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=fc(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=ju(a,d+8|0,g?d+24|0:0);if(a+1>>>0>=3){a=$b(8);x[31721]=0;c=P(37,d+36|0,8057)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;ic(a);break c}fb=d+2096|0;break a}b=N()|0;ic(a)}Q(b|0)}p()}return a|0}function BA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=Sr(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function Bla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Bg(k,b,m);p=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];cg(h,e,rf(k,n,d),hb);l=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);_d(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=zg(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=zua(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=zua(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=zua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{$d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);_d(i,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function CO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;f=Nb(a);a=0;c=x[b+24>>2];g=Lj(Wb(x[c+484360>>2],y[c+484376|0]));x[31721]=0;O(179,f|0,g|0);c=x[31721];x[31721]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[Zb(x[Wb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(vn(d,h,c)){x[31721]=0;O(1074,e+40|0,Vb(d,c)|0);c=x[31721];x[31721]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[31721]=0;S(1061,e+52|0,c|0,e+40|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(181,f|0,e+52|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}tb(e+52|0);tb(e+40|0);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31721]=0;c=P(37,e+28|0,9240)|0;d=x[31721];x[31721]=0;g:{if((d|0)!=1){x[31721]=0;O(181,f|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31721]=0;c=P(37,e+16|0,9202)|0;d=x[31721];x[31721]=0;h:{if((d|0)!=1){x[31721]=0;O(181,f|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31721]=0;c=P(37,e+4|0,14595)|0;d=x[31721];x[31721]=0;i:{if((d|0)!=1){x[31721]=0;O(181,f|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Qd(f);Q(a|0);p()}function x0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;vc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Hr(d,c);i=Hc(d);h=Ye(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=jd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+24560|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+8|0]=64;e=y[Sb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[ak(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}fb=f+16|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=jg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=zua(o,A,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=zua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(C,-16777216,16776704);i=zua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Qc(i,e,24);x[g+4>>2]=e-(q&w);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Cg(a,l,s);fb=f+48|0}function Xta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=fb-32|0;fb=k;e=b;b=x[a>>2];b=(ep(e,wb(b))<<1)+b|0;h=x[a+4>>2];a:{b:{if(h>>>0<A[Ab(a)>>2]){if((b|0)!=(h|0)){break b}d=fb-16|0;fb=d;a=vi(d+4|0,a,1);ej(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;gc(a);fb=d+16|0;break a}d=Ab(a);d=ik(k+8|0,jk(a,Yc(x[a>>2],h)+1|0),b-x[a>>2]>>1,d);x[31721]=0;O(297,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[d+4>>2];e=zb(h+12|0,b);f=zb(h+8|0,x[a>>2]);i=zb(h+4|0,x[d+4>>2]);g=x[e>>2];j=x[f>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[i>>2];x[e+12>>2]=g;while(1){i=x[e+8>>2];if(Pg(g,j)){f=fb-16|0;fb=f;x[f+12>>2]=i;w$(f+12|0,-1);fb=f+16|0;i=x[f+12>>2];g=x$(g);ej(i,y[g|0]|y[g+1|0]<<8);g=$v(e+12|0);$v(e+8|0);g=x[g>>2];continue}break}fb=e+16|0;x[d+4>>2]=i;e=x[a+4>>2];f=x[d+8>>2];while(1){if((b|0)!=(e|0)){ej(f,y[b|0]|y[b+1|0]<<8);f=f+2|0;b=b+2|0;continue}break}x[d+8>>2]=f;wc(a,d+4|0);wc(a+4|0,d+8|0);wc(Ab(a),zc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;b=c;fj(d);break a}a=N()|0;fj(d);Q(a|0);p()}i=fb-16|0;fb=i;f=x[a+4>>2];e=(f-(b+2|0)|0)+b|0;j=vi(i+4|0,a,h-e>>1);g=x[j+4>>2];d=e;while(1){if(d>>>0>=h>>>0){gc(j);while(1){if((b|0)!=(e|0)){e=e-2|0;f=v$(f-2|0,e);continue}break}fb=i+16|0}else{ej(g,y[d|0]|y[d+1|0]<<8);g=g+2|0;x[j+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}zb(k+28|0,b);fb=k+32|0}function gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){j=b;if(d){b=Xb(j,-16777216,16776704);k=zua(p,y,b,b>>31);l=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=zua(b,b>>31,q,z);k=b+k|0;m=hb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Xb(e,-16777216,16776704);e=zua(o,v,b,b>>31);l=e+k|0;b=hb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(g+8|0,i,h);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=j;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=j;fb=g+16|0}function U7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;hy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31721]=0;b=P(1224,a+364|0,a+360|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+188>>2]=b+c}x[31721]=0;b=R(1225,x[a+364>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(fy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31721]=0;R(1227,a+364|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=VJ(c,x[a+188>>2],e),B[j>>2]=k;Rf(a+204|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+364|0,a+360|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function b8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;my(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31721]=0;b=P(1209,a+252|0,a+248|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+176>>2]=b+c}x[31721]=0;b=R(1210,x[a+252>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(ly(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31721]=0;R(1212,a+252|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=VJ(c,x[a+176>>2],e),B[j>>2]=k;Rf(a+192|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+252|0,a+248|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function T7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;hy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31721]=0;b=P(1224,a+364|0,a+360|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+188>>2]=b+c}x[31721]=0;b=R(1225,x[a+364>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(fy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31721]=0;R(1227,a+364|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=TJ(c,x[a+188>>2],e),C[j>>3]=k;Rf(a+204|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+364|0,a+360|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function a8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;my(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Kc(d);x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){c=bc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31721]=0;b=P(1209,a+252|0,a+248|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31721]=0;O(47,d|0,b<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+176>>2]=b+c}x[31721]=0;b=R(1210,x[a+252>>2])|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}if(ly(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31721]=0;R(1212,a+252|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=TJ(c,x[a+176>>2],e),C[j>>3]=k;Rf(a+192|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+252|0,a+248|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){j=e;if(d){e=Xb(j,-16777216,16776704);f=zua(m,y,e,e>>31);e=hb;b=Xb(b,-16777216,16776704);b=zua(l,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];k=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=zua(b,b>>31,n,z);k=k+f|0;b=hb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Pb(g+8|0,i,h);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=j;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=j;fb=g+16|0}function Q6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;ad(a+476|0,x[d+28>>2]);x[31721]=0;n=R(1219,x[a+476>>2])|0;g=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=x[Td(f,0)>>2];x[31721]=0;h=P(1236,n|0,45)|0;j=x[31721];x[31721]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31721]=0;ka(1258,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}x[a+4>>2]=1207;c=Ae(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Oe(c,Ed(i<<2));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31721]=0;ma(1259,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;b=ea(1239,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}Jc(c);Rb(h);Rb(g);tb(j);Yb(a+476|0);fb=a+480|0;return b|0}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Jc(c)}Rb(h);Rb(g);tb(j)}Yb(a+476|0);Q(f|0);p()}function M6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=Ih(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=My(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}yc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;Hh(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=Yx(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=Yx(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function qqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=vb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=Zb(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=Zb(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}GC(a+484|0,b+48|0,0,c);GC(a+590|0,b+68|0,0,c);GC(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Sb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Lc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Lc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];gk(b,c&127,c>>>7|0);a=y[a+825|0];fk(b,a&127,a>>>7|0);fb=e+16|0}function Cla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Bg(k,b,m);p=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];cg(h,e,rf(k,n,d),hb);l=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(i,v[h+x[g+12>>2]|0]<<6);_d(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=zg(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=zua(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=zua(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=zua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{$d(i,v[h+x[g+12>>2]|0]<<6);_d(i,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function X7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Wp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31721]=0;g=P(1224,a+332|0,a+328|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+180>>2]=g+c}x[31721]=0;g=R(1225,x[a+332>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31721]=0;R(1227,a+332|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=_J(c,x[a+180>>2],e,b),x[k>>2]=l;x[f+4>>2]=hb;Rf(a+196|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+332|0,a+328|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function V7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Wp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31721]=0;g=P(1224,a+332|0,a+328|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+180>>2]=g+c}x[31721]=0;g=R(1225,x[a+332>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31721]=0;R(1227,a+332|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=WJ(c,x[a+180>>2],e,b),x[k>>2]=l;x[f+4>>2]=hb;Rf(a+196|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+332|0,a+328|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function U6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;ad(a+172|0,x[d+28>>2]);x[31721]=0;n=R(28,x[a+172>>2])|0;g=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=y[bc(f,0)|0];x[31721]=0;h=P(29,n|0,45)|0;j=x[31721];x[31721]=0;if((j|0)==1){break e}o=(g|0)==(h&255)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31721]=0;ka(1256,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}x[a+4>>2]=1207;c=Ae(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Oe(c,Ed(i));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31721]=0;ma(1257,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}Jc(c);tb(h);tb(g);tb(j);Yb(a+172|0);fb=a+176|0;return b|0}x[31721]=0;X(1208);b=x[31721];x[31721]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Jc(c)}tb(h);tb(g);tb(j)}Yb(a+172|0);Q(f|0);p()}function Y7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Wp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31721]=0;g=P(1224,a+332|0,a+328|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+180>>2]=g+c}x[31721]=0;g=R(1225,x[a+332>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31721]=0;R(1227,a+332|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=bK(c,x[a+180>>2],e,b),x[k>>2]=l;Rf(a+196|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+332|0,a+328|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function W7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Wp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31721]=0;g=P(1224,a+332|0,a+328|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+180>>2]=g+c}x[31721]=0;g=R(1225,x[a+332>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31721]=0;R(1227,a+332|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=ZJ(c,x[a+180>>2],e,b),w[k>>1]=l;Rf(a+196|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+332|0,a+328|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function Qta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31721]=0;k=vh(g,a);O(113,i|0,k|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[bc(b,a)|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31721]=0;O(305,i|0,Dd(c,g)|0);h=x[31721];x[31721]=0;g=e;if((h|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[31721]=0;O(305,i|0,Dd(c,j)|0);e=x[31721];x[31721]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[31721]=0;O(114,i|0,e|0);e=x[31721];x[31721]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=$b(8);x[31721]=0;a=R(99,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){x[31721]=0;S(100,a|0,40228,17);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;ic(b);break b}a=N()|0}tb(i);Q(a|0)}p()}function PJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Wp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31721]=0;g=P(1224,a+332|0,a+328|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+180>>2]=g+c}x[31721]=0;g=R(1225,x[a+332>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31721]=0;R(1227,a+332|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=XJ(c,x[a+180>>2],e,b),x[k>>2]=l;Rf(a+196|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1224,a+332|0,a+328|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function qS(a){var b=0,c=0,d=0,e=0,f=0,g=0;f=fb-48|0;fb=f;c=uw(f+30|0,x[a>>2]);b=$p(f+29|0,x[a+4>>2]);hY(f+32|0,z[c>>1],b);c=$p(f+28|0,x[a+8>>2]);b=z[f+32>>1];e=fb-16|0;fb=e;v[e+15|0]=y[f+34|0];kS(f+36|0,b,e+15|0,c);fb=e+16|0;d=fb-16|0;fb=d;g=fb-16|0;fb=g;c=z[f+36>>1]<<16>>16;e=y[f+38|0];b=uf(2)>>>0>=uf(e)>>>0;e=uf(e);c=c-b|0;b=(((c|0)<0?c-399|0:c)|0)/400|0;c=D(b,-400)+c|0;b=x[zb(g+12|0,((((uf(y[f+39|0])+D(b,146097)|0)+((D(e+(e>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(c>>>2)|0)+D(c,365)|0)-((c>>>0)/100|0)|0)-719469|0)>>2];fb=g+16|0;b=x[zb(d+12|0,b)>>2];fb=d+16|0;c=zb(f+24|0,x[a+12>>2]);g=fb-16|0;fb=g;d=fb-16|0;fb=d;e=fb-16|0;fb=e;b=x[zb(e+12|0,D(b,24))>>2];fb=e+16|0;x[d+8>>2]=b;b=x[zb(d+12|0,x[c>>2]+x[d+8>>2]|0)>>2];fb=d+16|0;b=x[zb(g+12|0,b)>>2];fb=g+16|0;c=zb(f+20|0,x[a+16>>2]);g=fb-16|0;fb=g;d=fb-16|0;fb=d;e=fb-16|0;fb=e;b=x[zb(e+12|0,D(b,60))>>2];fb=e+16|0;x[d+8>>2]=b;b=x[zb(d+12|0,x[c>>2]+x[d+8>>2]|0)>>2];fb=d+16|0;b=x[zb(g+12|0,b)>>2];fb=g+16|0;g=ue(f+8|0,x[a+24>>2],x[a+28>>2]);e=fb-16|0;fb=e;d=fb-16|0;fb=d;c=fb-16|0;fb=c;a=ue(c+8|0,zua(b,b>>31,60,0),hb);b=x[a>>2];a=x[a+4>>2];fb=c+16|0;x[d>>2]=b;x[d+4>>2]=a;c=x[d>>2];b=c+x[g>>2]|0;a=x[g+4>>2]+x[d+4>>2]|0;b=ue(d+8|0,b,b>>>0<c>>>0?a+1|0:a);a=x[b>>2];fb=d+16|0;b=ue(e+8|0,a,x[b+4>>2]);a=x[b>>2];fb=e+16|0;b=ou(f+40|0,a,x[b+4>>2]);a=x[b>>2];fb=f+48|0;hb=x[b+4>>2];return a}function goa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=fb-16|0;fb=i;kd(d,32);g=i+8|0;PV(g,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);g=dc(g);PV(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{g=x[g>>2];if(g-838861>>>0<4294128436){break a}f=x[dc(i)>>2];x[d>>2]=D(g,320);w[d+34>>1]=1;if(!Bh(d)){break a}l=g<<2;e=+(l>>>0);p=+(f>>>0)/e;q=+(g>>>0)/e;r=1/+A[d>>2];s=+A[i>>2];t=+A[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){a=1;break a}m=+(g>>>0);n=0;o=0;a=x[b+20>>2];if(ge(x[b>>2],a)){e=m*q+t;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=z[b+34>>1];j=Yd(k);h=D(f,j);e=e-+(f>>>0);d:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break d}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=x[c+20>>2];if(ge(x[c>>2],a)){e=m*p+s;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=z[c+34>>1];j=Yd(k);h=D(f,j);e=e-+(f>>>0);f:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break f}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}n=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=r*+(a>>>0);u=x[d+20>>2]+(a<<1)|0,v=aC(o*(1-e)+n*e),w[u>>1]=v;a=a+l|0;f=f+1|0;continue}}}fb=i+16|0;return a|0}function e8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Xp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+215|0];while(1){d:{x[31721]=0;g=P(1209,a+220|0,a+216|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+184>>2]=g+c}x[31721]=0;g=R(1210,x[a+220>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Xn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111712)){break c}x[31721]=0;R(1212,a+220|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=_J(c,x[a+184>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Rf(a+200|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+220|0,a+216|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Xp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+215|0];while(1){d:{x[31721]=0;g=P(1209,a+220|0,a+216|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+184>>2]=g+c}x[31721]=0;g=R(1210,x[a+220>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Xn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111712)){break c}x[31721]=0;R(1212,a+220|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=WJ(c,x[a+184>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Rf(a+200|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+220|0,a+216|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;kd(b,2);f=e+24|0;Mk(f,2,a+1|0);d=e+36|0;Ac(d,f);ye(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Gb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Gb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;kh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);kh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);kh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;Yk(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Sb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function DI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function eN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=x[a+32>>2];f=hq(g);if(!f){f=fq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=$b(8);x[31721]=0;c=P(37,h+4|0,6e3)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=$b(8);x[31721]=0;c=P(37,h+4|0,11318)|0;a=x[31721];x[31721]=0;if((a|0)!=1){mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;ic(b);break b}f=PA(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Ko(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;Xm(i);Fo(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Bu(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Wi(Iv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Wi(Iv(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=sB(i,c),w[l+480212>>1]=m;fb=h+16|0;return j|0}a=N()|0;ic(b)}Q(a|0)}p()}function b4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31721]=0;k=vh(g,a);O(96,h|0,k|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[bc(b,a)|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31721]=0;O(97,h|0,Dd(c,g)|0);j=x[31721];x[31721]=0;g=e;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[31721]=0;O(97,h|0,Dd(c,i)|0);e=x[31721];x[31721]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[31721]=0;O(98,h|0,e|0);e=x[31721];x[31721]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=$b(8);x[31721]=0;a=R(99,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){x[31721]=0;S(100,a|0,40228,17);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;ic(b);break b}a=N()|0}tb(h);Q(a|0)}p()}function f8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Xp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+215|0];while(1){d:{x[31721]=0;g=P(1209,a+220|0,a+216|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+184>>2]=g+c}x[31721]=0;g=R(1210,x[a+220>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Xn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111712)){break c}x[31721]=0;R(1212,a+220|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=bK(c,x[a+184>>2],e,b),x[j>>2]=k;Rf(a+200|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+220|0,a+216|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function d8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Xp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+215|0];while(1){d:{x[31721]=0;g=P(1209,a+220|0,a+216|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+184>>2]=g+c}x[31721]=0;g=R(1210,x[a+220>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Xn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111712)){break c}x[31721]=0;R(1212,a+220|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=ZJ(c,x[a+184>>2],e,b),w[j>>1]=k;Rf(a+200|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+220|0,a+216|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function YJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Xp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){c=bc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+215|0];while(1){d:{x[31721]=0;g=P(1209,a+220|0,a+216|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31721]=0;O(47,d|0,g<<1);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=Kc(d);x[31721]=0;O(47,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=bc(d,0);x[a+184>>2]=g+c}x[31721]=0;g=R(1210,x[a+220>>2])|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}if(Xn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111712)){break c}x[31721]=0;R(1212,a+220|0)|0;g=x[31721];x[31721]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=XJ(c,x[a+184>>2],e,b),x[j>>2]=k;Rf(a+200|0,a+16|0,x[a+12>>2],e);x[31721]=0;b=P(1209,a+220|0,a+216|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function AI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){rc(a,9750);break j}d=b>>>24|0;if(!(b&65535)){e=fb-16|0;fb=e;f=rc(e+4|0,4399);Zc(c+68|0,f);tb(f);fb=e+16|0;x[31721]=0;x[c+24>>2]=d;O(90,c+56|0,c+24|0);d=x[31721];x[31721]=0;k:{l:{m:{n:{if((d|0)!=1){x[31721]=0;x[c+8>>2]=b>>>16&255;O(91,c+44|0,c+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break n}x[31721]=0;V(92,a|0,c+68|0,c+56|0,c+44|0);a=x[31721];x[31721]=0;if((a|0)==1){break m}tb(c+44|0);tb(c+56|0);Eb(c+68|0);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}e=fb-16|0;fb=e;f=rc(e+4|0,4123);Zc(c+68|0,f);tb(f);fb=e+16|0;x[31721]=0;x[c+40>>2]=d;O(90,c+56|0,c+40|0);d=x[31721];x[31721]=0;if((d|0)==1){break i}x[31721]=0;x[c+36>>2]=b>>>16&255;O(91,c+44|0,c+36|0);d=x[31721];x[31721]=0;if((d|0)==1){break h}x[31721]=0;x[c+20>>2]=b>>>8&255;O(91,c+24|0,c+20|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;x[c+4>>2]=b&255;O(91,c+8|0,c+4|0);b=x[31721];x[31721]=0;if((b|0)==1){break f}x[31721]=0;ja(93,a|0,c+68|0,c+56|0,c+44|0,c+24|0,c+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}tb(c+8|0);tb(c+24|0);tb(c+44|0);tb(c+56|0);Eb(c+68|0)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function rU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Ak(c)){i=fb-16|0;fb=i;e=Dc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Jo((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+27264>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;xU(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;xU(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}wU(e,b)}else{wd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[tf(i+12|0,e)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;fA(a,b);Cj(b);break a}wU(c,b)}qU(a);fb=h+16|0}function HL(a){var b=0,c=0,d=0,e=0;He(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){He(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}He(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){He(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}He(x[a+80>>2],d)}He(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;He(x[a+80>>2],x[b+8>>2]);He(x[a+80>>2],x[b+28>>2]);He(x[a+80>>2],x[b+32>>2]);He(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];He(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}He(x[a+80>>2],d)}He(x[a+80>>2],x[a+260>>2]);He(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){He(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}He(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;He(x[a+80>>2],x[d+800>>2]);He(x[a+80>>2],x[d+928>>2]);He(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;He(x[a+80>>2],x[b+1068>>2]);He(x[a+80>>2],x[b+1076>>2]);He(x[a+80>>2],x[b+1084>>2]);He(x[a+80>>2],x[b+1092>>2]);He(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function E7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Ey(x[g>>2]);g=jy(x[g>>2]);oh(k+4|0,g);a:{b:{if(zd(x[k+8>>2],y[k+15|0])){x[31721]=0;V(1230,l|0,a|0,c|0,d|0);g=x[31721];x[31721]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31721]=0;j=P(1236,l|0,h<<24>>24)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31721]=0;h=P(1236,l|0,48)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31721]=0;h=P(1236,l|0,h|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}zm(j,c);i=0;x[31721]=0;o=R(1228,g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Ws((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[bc(k+4|0,h)|0]){break e}if(v[bc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31721]=0;n=P(1236,l|0,n|0)|0;m=x[31721];x[31721]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function EP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[127048]){if(!y[126920]){b=fb-16|0;fb=b;Fb(126896);x[31727]=0;v[126912]=0;x[31729]=0;x[31721]=0;a=ca(57)|0;c=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;yA(126908,ie(a));Cj(a);v[126912]=0;break f}a=ta(124984,125568)|0;c=gb;if(($(124984)|0)==(c|0)){Y(a|0)|0;x[31721]=0;X(58);b=x[31721];x[31721]=0;if((b|0)==1){break d}p()}if(($(125568)|0)!=(c|0)){break c}Y(a|0)|0;x[31721]=0;v[126912]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;break c}if(y[126912]){break e}}x[31721]=0;W(59,126892);a=x[31721];x[31721]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}}Cj(126916);Cj(126908);tb(126896);Q(a|0);p()}T(0)|0;Qb();p()}v[126920]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=iP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=$O(eP(f+12|0,32));break g}d=G(a);d=eP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=$O(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=xb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=rP(l,b,wP(b));nP(j,b);Um(b);fb=c- -64|0;yc(126928,yc(e,j,120),116);v[127048]=1}fb=e+240|0}function Ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-16|0;fb=f;s=x[a+16>>2];t=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];e=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Bg(l,b,m);p=hb;i=x[a+76>>2];b=x[a>>2];e=x[a+4>>2];cg(b,e,rf(l,n,d),hb);i=hb>>>0>i>>>0?d:0}h=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[f>>2]=b;x[f+4>>2]=e;while(1){if(d){d=d-1|0;x[f+8>>2]=b;x[f+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;r=(((e&2147483647)<<1|b>>>31)&-2)+s|0;e=m;b:{c:while(1){d:{if((e|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);e=x[a+116>>2];if(!e){break b}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break d}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){$d(h,g>>>3<<16>>16);_d(h,4);Pb(f+8|0,o,p);e=e-1|0;continue c}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}$d(h,g>>>3<<16>>16);_d(h,e);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=zg(h,t);e=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=e+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(f,l,n);c=c+8|0;b=x[f>>2];e=x[f+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=f+16|0}function Qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-48|0;fb=d;l=b+484344|0;m=b+480280|0;n=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){Yq(c,d+43|0);e=Mg(c);d:{f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);e:{if((f|0)==1229999433|(f|0)==1397771593){break e}f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);if((f|0)==1297110104|(f|0)==1297110099){break e}if(Mb(x[c>>2],x[c+8>>2],e)){break d}}v[d+47|0]=j;Dh(c,8);break c}ce(d,c,e);f=hc(d+20|0,d);ub(d);e=m;f:{if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))==1481001027){while(1){if((e|0)==(l|0)){h=1;break a}x[31721]=0;h=R(154,f|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break f}v[e+8|0]=h;e=e+32|0;continue}}if(y[d+43|0]!=70){break b}g=y[d+44|0];k=(g|0)==88;g:{if(!k){if((g-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break g}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}h=1;e=((i&255)+(k?-528:D(g,100)-5328|0)|0)+D(e&255,10)&65535;if(e>>>0>249){break a}e=sd(n,e);x[31721]=0;O(454,f|0,e|0);e=x[31721];x[31721]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}cD(a,h,d+47|0);fb=d+48|0;return}if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))!=1430540109){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function csa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=fb-16|0;fb=e;f=rc(e+4|0,4451);Zc(d+48|0,f);tb(f);fb=e+16|0;x[31721]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=zua(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=Aua(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+32>>2]=g+f;O(76,d+36|0,d+32|0);g=x[31721];x[31721]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[31721]=0;x[d+16>>2]=(e+D(f,-12)|0)+1;O(79,d+20|0,d+16|0);e=x[31721];x[31721]=0;if((e|0)==1){break j}x[31721]=0;x[d>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;O(79,d+4|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break i}x[31721]=0;aa(417,a|0,d+48|0,d+36|0,d+20|0,d+4|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}tb(d+4|0);tb(d+20|0);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}dg(d+48|0,4431);x[31721]=0;O(418,d+36|0,d+62|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;S(142,a|0,d+48|0,d+36|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}}tb(d+36|0);Eb(d+48|0);fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function O7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=kw(x[g>>2]);g=ry(x[g>>2]);oh(k+4|0,g);a:{b:{if(zd(x[k+8>>2],y[k+15|0])){x[31721]=0;V(1217,l|0,a|0,c|0,d|0);g=x[31721];x[31721]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31721]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31721]=0;h=P(29,l|0,48)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31721]=0;h=P(29,l|0,h|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}zm(j,c);i=0;x[31721]=0;o=R(1215,g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){zm((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[bc(k+4|0,h)|0]){break e}if(v[bc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31721]=0;n=P(29,l|0,n|0)|0;m=x[31721];x[31721]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function hB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Oj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32352>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(qn(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}uc(f+12|0,16777215);if(j&17408){g=Bc(Bua(zua(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Ej(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(Bua(zua(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(Bua(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Xe(zi(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=zua(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Fc(Aua(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}uc(h+12|0,2147483647);c=x[h+12>>2];b=jg(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function O3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=Ys(c,d);x[k+4>>2]=1207;n=Xs(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}Oe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(!h){break b}x[f>>2]=x[f>>2]|2;break b}g=x[g>>2];x[31721]=0;s=P(1226,e|0,g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Bb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Td(g,o)>>2];x[31721]=0;q=P(1226,e|0,q|0)|0;t=x[31721];x[31721]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Bb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=zd(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Jc(n);fb=k+128|0;return d|0}a=N()|0;Jc(n);Q(a|0);p()}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=Ys(c,d);x[k+4>>2]=1207;n=Xs(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}Oe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(!h){break b}x[f>>2]=x[f>>2]|2;break b}g=v[g|0];x[31721]=0;s=P(1211,e|0,g|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Bb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[bc(g,o)|0];x[31721]=0;q=P(1211,e|0,q|0)|0;t=x[31721];x[31721]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Bb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=zd(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Jc(n);fb=k+128|0;return d|0}a=N()|0;Jc(n);Q(a|0);p()}function sA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=AR(b,c);a:{if(!x[b+656>>2]|!(v[h+6|0]&1)){break a}e=x[h>>2];i=a+1074312|0;f=Ob(i,31);d=xw(x[b+656>>2],c);if(kc(x[d>>2],x[d+4>>2])){break a}f=e+(f^1)|0;g=Ob(i,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}j=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[xb(x[d>>2],j)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(j|0)!=y[d+16|0]))){g=Ob(i,70)}if(g|(f|0)!=(k|0)){break d}f=z[xb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[xb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[xb(a,y[d+15|0])>>1];if(!Ob(i,93)|(c|0)!=1|y[b+89|0]&8){break b}v[h+6|0]=y[h+6|0]&254;break b}j=1;e=z[pi(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[h+4>>1]==65535){break f}if(Ob(i,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[xb(g,y[d+13|0])>>1];g=z[xb(g,y[d+14|0])>>1]+1|0;break e}e=z[pi(x[d+4>>2])>>1];j=f>>>0>e>>>0;g=e;break e}g=x[d>>2];e=z[xb(g,y[d+15|0])>>1];g=z[xb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(!j|c){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[pi(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=h,m=Ob(i,31)+f|0,x[l>>2]=m}}function GO(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Cc(e+4|0,11600);x[31721]=0;b=d+12|0;P(37,b|0,11005)|0;c=x[31721];x[31721]=0;a:{if((c|0)==1){break a}x[31721]=0;b=d+24|0;P(37,b|0,11430)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+36|0;P(37,b|0,10997)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+48|0;P(37,b|0,8243)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+60|0;P(37,b|0,10982)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+72|0;P(37,b|0,8309)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+84|0;P(37,b|0,5620)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+96|0;P(37,b|0,12004)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+108|0;P(37,b|0,11373)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+120|0;P(37,b|0,12273)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+132|0;P(37,b|0,5472)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;b=d+144|0;P(37,b|0,7335)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;U(1071,a|0,d|0,13)|0;a=x[31721];x[31721]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function ZV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=x[a>>2];c=Oh(e,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;g=b-c|0;c=x[Ab(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=c-b>>8>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];e=x[b+8>>2];while(1){if((a|0)==(e|0)){gc(b);fb=c+16|0}else{BV(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Ab(a);c=h+12|0;e=a;f=Oh(x[a>>2],b)+g|0;b=fb-16|0;fb=b;x[b+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=XB(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[$c(b+8|0,b+12|0)>>2]}fb=b+16|0;break b}cd();p()}f=Oh(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Fg(c+12|0,i);c:{if(!a){b=0;a=0;break c}if(a>>>0>=16777216){Xj();p()}b=Dc(a<<8);x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+12>>2];a=x[d+8>>2]}x[c>>2]=a;f=a+(f<<8)|0;x[c+8>>2]=f;x[c+4>>2]=f;j=zc(c),k=a+(b<<8)|0,x[j>>2]=k;fb=d+16|0;d=fb-16|0;fb=d;a=d+4|0;x[a>>2]=x[c+8>>2];b=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=b+(g<<8);b=x[a>>2];while(1){if(x[a+4>>2]!=(b|0)){BV(b);b=x[a>>2]+256|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0;Id(e,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-256|0;x[c+8>>2]=b;continue}break}a=x[c>>2];if(a){zc(c);Db(a)}}fb=h+32|0;return}if(b>>>0<c>>>0){CV(a,e+(b<<8)|0)}}function PX(a,b){var c=0;a:{b:{c:{if(me(a,16750)){break c}if(me(a,17517)){break c}if(me(a,13681)){break c}if(me(a,13761)){break c}if(!me(a,14238)){break b}}w[b+10>>1]=4;x[b>>2]=12036;break a}d:{e:{if(me(a,17512)){break e}if(me(a,13686)){break e}if(!me(a,16740)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8391;w[b+10>>1]=4;break a}f:{if(!me(a,14276)){if(!me(a,14281)){break f}}w[b+10>>1]=8;x[b>>2]=8169;break a}g:{if(!me(a,15370)){if(!me(a,15375)){break g}}x[b>>2]=17104;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!me(a,25226)){if(!me(a,25231)){break h}}x[b+4>>2]=1;x[b>>2]=16910;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(hd(a,15530,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8509;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(hd(a,13699,3)){if(hd(a,13818,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8268;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!hd(a+1|0,13839,3)){v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=v[a|0]-48;break a}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(hd(a,13572,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8418;break i}if(me(a,13911)){v[b+16|0]=1;w[b+10>>1]=4;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-32|0;fb=d;l=a+480190|0;c=z[l>>1];v[d+20|0]=0;QT(b,c+1|0,d+20|0);j=a+480192|0;if(z[j>>1]){h=Nb(d+20|0);q=d,r=wb(x[a+484344>>2]),x[q+16>>2]=r;o=wb(x[a+484348>>2]);m=a+480188|0;while(1){i=x[d+16>>2];if(Ib(i,o)){a:{if(!Ib(x[i>>2],x[i+4>>2])){break a}c=z[m>>1];x[31721]=0;v[d+4|0]=0;S(783,h|0,c|0,d+4|0);c=x[31721];x[31721]=0;if((c|0)!=1){q=d,r=wb(x[i>>2]),x[q+12>>2]=r;k=0;b:while(1){f=0;if(A[i+12>>2]<=k>>>0){break a}while(1)if(z[m>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[d+12>>2];if(!Sc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[j>>1];break e}g=z[j>>1];c=y[vb(x[h>>2],f)|0];if(c){break e}c=1;break d}q=vb(x[h>>2],f),r=c,v[q|0]=r;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[Zb(e+236|0,y[x[d+12>>2]]-1|0)>>1];if(e>>>0>z[l>>1]){break f}n=d+4|0;Kb(n,x[b>>2],e);Ef(n,1)}c=c+1|0;continue}}f=f+1|0;sC(d+12|0);continue}}}a=N()|0;cc(h);Q(a|0);p()}kn(d+16|0);continue}else{c=z[a+480190>>1];while(1){if(c){Kb(d+4|0,x[b>>2],c);if(!Hb(x[x[d+4>>2]>>2],x[d+8>>2])){e=f;f=D(c,104)+a|0;f=e+ge(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{cc(h)}break}}break}}fb=d+32|0;return f&65535}function FI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=Cf(a,c);Zd(e,x[a+36>>2]);i=a;a:{if(!h){Oc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Hm(d+48|0,x[a+36>>2]);x[31721]=0;a=P(465,d+36|0,42260)|0;c=x[31721];x[31721]=0;b:{c:{d:{e:{if((c|0)!=1){x[31721]=0;x[d+16>>2]=19988993;x[d+20>>2]=0;S(466,f|0,a|0,d+16|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}Eb(a);if(!ol(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}k=d,l=aj(x[b>>2],x[b+4>>2]),w[k+34>>1]=l;w[d+32>>1]=65535;x[31721]=0;a=P(465,d+16|0,10105)|0;c=x[31721];x[31721]=0;f:{if((c|0)!=1){x[31721]=0;c=U(495,f|0,d+32|0,a|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Qf(d+34|0,4e3);a=z[d+34>>1];g:{if(aj(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31721]=0;O(226,b|0,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=x[b>>2];x[31721]=0;O(496,d+4|0,c|0);j=x[31721];x[31721]=0;if((j|0)!=1){x[31721]=0;V(497,f|0,Vb(g,c)|0,d+4|0,498);g=x[31721];x[31721]=0;if((g|0)==1){break h}c=c+1|0;Eb(d+4|0);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}yh(f);Q(c|0);p()}yh(f);fb=d+160|0;c=h}cf(i,c);fb=e+16|0}function Nla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(n,y,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=zua(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function Ce(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=SH(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(SH(e)){h=E(a*a);if((e|0)<0){h=(RH(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=mx(E(E(1)/h));break a}if((e|0)<0){c=RH(d);if(!c){a=UH(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125608>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125616>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=GF(i);break a}if(!(f<=-150)){break f}a=pF(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function wL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=re(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=re(a,k),x[p>>2]=q;i=re(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(ff(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Ti(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(ff(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Ti(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(ff(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Ti(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=re(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Ti((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Ti(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=re(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Gm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Em(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}ec(a,3);return 0}function uh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!qn(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31664>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Ej(a)){a=((e&255)>>>0)/12|0;b=zua(x[(D(a,-12)+e<<6&960)+35552>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;uc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31664>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;uc(f+12|0,-1>>>a|0);e=Bc(Bua(zua(z[((D(a,-12)+e&255)<<1)+31664>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Ee(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32160>>1])+D(z[(x[f+4>>2]<<1)+32144>>1],16-b|0)<<1>>>c|0;break a}if(!(b-25>>>0<84&(c&255)>>>0<=15)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(D(a,-12)+e&255)<<1)+31264>>1]<<5>>>a|0;break a}e=z[(b<<1)+31038>>1]<<2}fb=f+16|0;return e}function Y0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=Zh(a);Tb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Yd(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31721]=0;a=U(153,f|0,a|0,2)|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}if(!a){break j}x[31721]=0;a=R(192,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break h}if(!a){break e}x[31721]=0;S(188,g+8|0,b|0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break g}h=g+8|0;a=$r(g+28|0,h);f=gd(e,a);yc(f+20|0,a+20|0,1040);ub(a);ub(h);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Dn(z[h+34>>1])>>>0>=2){x[31721]=0;O(193,f|0,a+(d<<1)|0);a=x[31721];x[31721]=0;if((a|0)!=1){break e}break f}x[31721]=0;O(194,f|0,a+d|0);a=x[31721];x[31721]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(28832)|0;if((gb|0)!=($(28832)|0)){break b}Y(a|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function Uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;k=fb-32|0;fb=k;h=k+28|0;f=k+24|0;g=fb-16|0;fb=g;a:{b:{if(!kc(b,x[zb(g+12|0,ng(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=rd(b);m=z[j>>1];j=x[j+4>>2];if(!Nl(e,i,m,j)){break b}}x[g+12>>2]=b;e=zb(g+8|0,wb(x[a>>2]));c:{f=x[g+12>>2];if(!kc(f,x[e>>2])){f=x[wB(g+12|0)>>2];e=rd(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!Nl(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=vB(a,h,e,i);break a}if(Nl(m,j,e,i)){d:{f=uB(b);if(!kc(f,x[zb(g+12|0,ng(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=rd(f);if(!Nl(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=vB(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}fb=g+16|0;f=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;g=dc(a);h=k+12|0;e=zh(h,Dc(36),Jg(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;Ul(g+8|0,d);o=dc(e),p=1,v[o+4|0]=p;fb=b+16|0;Xg(a,x[k+28>>2],f,x[k+12>>2]);b=ie(h);JT(h);n=1}a=l+4|0;Wg(a,x[zb(k+12|0,b)>>2],n);fb=k+32|0;if(!y[dc(a)|0]){a=rd(x[l+4>>2])+8|0;IT(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Ab(d);o=Ab(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[zb(l+12|0,x[l+4>>2])>>2];fb=l+16|0;return a|0}function nM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Tf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=D(h,k);s=D(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=xb(x[b>>2],d);i=De(Dg(C[(d+r<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+on(i)|0;t=e;e=It(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d+s<<1)+o|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=dd(e),w[u>>1]=v;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function tM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Tf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=h+m|0;s=D(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=xb(x[b>>2],d);i=De(Dg(C[(d+s<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+on(i)|0;k=e;e=It(n)+e&-4096;x[j>>2]=k-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=r<<1;k=(d<<2)+o|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}t=j+x[k>>2]|0,u=dd(e),w[t>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!ge(x[a>>2],x[a+20>>2])){break a}Zk(a);b:{switch(Dn(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=Yd(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;OU(h+28|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;OU(h+8|0,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=Yd(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;NU(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;NU(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function Ola(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(n,z,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=zua(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function fO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb+-64|0;fb=e;a:{b:{c:{d:{f=a+36|0;d=x[f>>2];c=x[a+40>>2];e:{if(Ib(d,c)){qc(e+60|0);break e}c=e+24|0;po(c,a);x[31721]=0;c=R(1064,c|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break d}x[e+60>>2]=c;lf(e+24|0);c=x[a+40>>2];d=x[a+36>>2]}c=(k=f,l=x[e+60>>2],m=Ib(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=Ct(d);g=x[c>>2];i=lj(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=sf(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=sf(x[c>>2],f);break b}d=N()|0;lf(e+24|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[31721]=0;O(1098,d|0,f|0);f=x[31721];x[31721]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=GR(IX(e+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31721]=0;g=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=g;g=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=g;V(1099,e+48|0,f|0,(d?7:1)|0,e|0);c=x[31721];x[31721]=0;if((c|0)==1){break f}c=HB(x[e+52>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Ui(e+48|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;xl(e+60|0);fb=e- -64|0;return+b}}d=N()|0;xl(e+60|0)}Q(d|0);p()}function WP(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=Ce(E(10),E(E(E(B[xb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[xb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[xb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(Ce(E(10),E(E(E(B[xb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(mx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=UH(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Qm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[xb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[xb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function tK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=vd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=vd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=vd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=zua(e,d,10,0);d=b+c|0;c=hb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=vd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=vd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function Ad(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=er(a);dr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){Zf(a+1074312|0,120)}ku(a+8|0,c);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;CA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;mu(b);f=Uk(x[b>>2],x[b+4>>2]);c=eA(d+12|0,b);x[31721]=0;S(860,b|0,f|0,c|0);b=x[31721];x[31721]=0;a:{if((b|0)!=1){Fl(c);fb=d- -64|0;break a}a=N()|0;Fl(c);Q(a|0);p()}EU(a+484360|0);qf(a+1298308|0);qf(a+1298320|0);qf(a+1298332|0);b=e+12|0;Tb(b,0,68);b=iS(b);c=yb(a+1298344|0,b);yb(c+12|0,b+12|0);yb(c+24|0,b+24|0);yb(c+36|0,b+36|0);yb(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;IA(b);Vv(a+1298412|0);Hf(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Db(wv(d))}x[c>>2]=0;b=b+1|0;continue}}function T0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){kd(b,32);op(b);c=d+8|0;hk(c,1,a+4|0);e=d+20|0;Ac(e,c);ye(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Qf(b+30|0,256);w[b+32>>1]=y[a+17|0];Qf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Qf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);Zk(b);v[b+38|0]=y[(y[a+79|0]&7)+38112|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Ila(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Bg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];cg(b,g,rf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){i=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;d=d-1|0;p=(((i&2147483647)<<1|b>>>31)&-2)+q|0;i=l;b:{c:while(1){d:{if((i|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break b}b=x[e+8>>2];i=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;j=0;b=0;break d}b=x[e+8>>2];g=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;b=0;j=0;while(1)if((b|0)==2){$d(f,j>>>3<<16>>16);_d(f,4);Pb(e+8|0,n,o);i=i-1|0;continue c}else{j=(v[(b+g|0)+p|0]<<8)+j|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){j=(v[(b+i|0)+p|0]<<8)+j|0;b=b+1|0;continue}break}$d(f,j>>>3<<16>>16);_d(f,g);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=zg(f,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(e,k,m);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Bg(l,b,m);p=hb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];cg(b,f,rf(l,n,d),hb);i=hb>>>0>i>>>0?d:0}g=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;$d(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);_d(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=zg(g,r);f=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=f+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e,l,n);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;$d(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);_d(g,4);Pb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function A7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;x[f+360>>2]=37;x[f+364>>2]=0;h=Ts(f+360|1,22250,x[c+4>>2]);x[f+316>>2]=f+320;a=Kd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=mh(f+320|0,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;g=mh(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1207;i=Ae(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Kd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=oj(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=oj(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Oe(i,a)}j=a+g|0;l=pj(a,j,x[c+4>>2]);x[f+68>>2]=1207;h=Ae(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<3);if(!g){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(h,g);b=a}a=f+60|0;ad(a,x[c+28>>2]);x[31721]=0;ga(1238,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31721];x[31721]=0;i:{if((a|0)!=1){Yb(f+60|0);x[31721]=0;a=ea(1239,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}Jc(h);Jc(i);fb=f+368|0;break b}a=N()|0;Yb(f+60|0);break g}a=N()|0}Jc(h);break c}p()}a=N()|0}Jc(i);Q(a|0);p()}return a|0}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;d=x[b+1298304>>2];if(!yd(d)){e=fb-16|0;fb=e;c=Dc(12);x[31721]=0;d=R(959,c|0)|0;f=x[31721];x[31721]=0;a:{if((f|0)!=1){c=x[tf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(c);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;e=i+12|0;$R(c,ie(e));HA(e);d=x[c>>2]}f=fb-32|0;fb=f;c=f+8|0;QR(c,a);x[31721]=0;O(960,f+20|0,c|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){tb(f+8|0);m=f,n=wb(x[d>>2]),x[m+4>>2]=n;l=wb(x[d+4>>2]);c=0;d=0;while(1){d:{h=x[f+4>>2];if(!Ib(h,l)){e:{if(!d){break e}c=x[d+4>>2];if(!c){break e}x[31721]=0;b=U(c|0,d|0,b|0,a|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(b){c=x[d>>2];x[b+4>>2]=c;if(c){x[c+8>>2]=b}x[d>>2]=b}x[a>>2]=b}tb(f+20|0);fb=f+32|0;break b}j=0;e=x[h>>2];if(x[e+32>>2]==x[a+16>>2]){j=x[e+36>>2]==x[a+20>>2]}x[31721]=0;O(961,f+8|0,e+8|0);e=x[31721];x[31721]=0;if((e|0)!=1){g=fb-16|0;fb=g;k=f+8|0;ve(g+8|0,k);ve(g,f+20|0);e=tR(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);fb=g+16|0;tb(k);f:{if(!(!j|(e|0)!=0)){d=x[h>>2];c=3;break f}if((c|0)<2&j){d=x[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?x[h>>2]:d;c=e?1:c}Pe(f+4|0);continue}}break}d=N()|0;tb(f+20|0);break c}d=N()|0;tb(f+8|0)}Q(d|0);p()}fb=i+16|0}
function K7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Ts(f+200|1,22250,x[c+4>>2]);x[f+156>>2]=f+160;a=Kd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=mh(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=mh(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1207;i=Ae(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Kd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=oj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=oj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Oe(i,a)}j=a+g|0;l=pj(a,j,x[c+4>>2]);x[f+68>>2]=1207;h=Ae(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<1);if(!g){x[31721]=0;X(1208);a=x[31721];x[31721]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(h,g);b=a}a=f+60|0;ad(a,x[c+28>>2]);x[31721]=0;ga(1233,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31721];x[31721]=0;i:{if((a|0)!=1){Yb(f+60|0);x[31721]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break i}Jc(h);Jc(i);fb=f+208|0;break b}a=N()|0;Yb(f+60|0);break g}a=N()|0}Jc(h);break c}p()}a=N()|0}Jc(i);Q(a|0);p()}return a|0}function V2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(jh(a,x[b+8>>2],e)){Fx(b,c,d);return}a:{if(jh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Cx(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;Bs(x[h>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Bs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Bs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Bs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Kf(a);while(1){if(Vg(b,c)){b=x[zb(l+8|0,q)>>2];k=rd(x[l+12>>2]);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;i=fb-32|0;fb=i;g=i+28|0;d=i+24|0;e=fb-16|0;fb=e;a:{b:{if(!kc(b,x[zb(e+12|0,ng(a))>>2])){f=y[k|0];j=x[k+4>>2];h=rd(b);n=y[h|0];h=x[h+4>>2];if(!vo(f,j,n,h)){break b}}x[e+12>>2]=b;f=zb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!kc(d,x[f>>2])){d=x[wB(e+12|0)>>2];f=rd(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!vo(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=QA(a,g,f,j);break a}if(vo(n,h,f,j)){d:{d=uB(b);if(!kc(d,x[zb(e+12|0,ng(a))>>2])){f=y[k|0];j=x[k+4>>2];h=rd(d);if(!vo(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=QA(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=dc(a);g=i+12|0;e=zh(g,Dc(28),Jg(b+8|0,e));dC(x[e>>2]+16|0,k);r=dc(e),s=1,v[r+4|0]=s;fb=b+16|0;Xg(a,x[i+28>>2],d,x[i+12>>2]);b=ie(g);Zl(g);p=1}Wg(m+8|0,x[zb(i+12|0,b)>>2],p);fb=i+32|0;fb=m+16|0;zb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[Yg(l+12|0)>>2];continue}else{fb=l+16|0}break}}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;c=wb(x[a>>2]);x[g+44>>2]=c;k=wb(x[a+4>>2]);while(1){if(Ib(c,k)){i=g+24|0;a=wb(x[c>>2]);l=wb(x[c+4>>2]);c=UW(g+4|0,b);v[c+16|0]=y[b+16|0];x[c+12>>2]=x[b+12>>2];h=fb-16|0;fb=h;x[h+12>>2]=a;while(1){if(Ib(a,l)){f=fb-16|0;fb=f;if(!(y[a+5|0]|y[a+3|0]!=4)){d=f+8|0;Kb(d,x[c>>2],z[c+14>>1]);Ef(d,0);v[a+3|0]=0}d=y[a+2|0];if(!(y[a+4|0]|(d|0)!=11)){e=f+8|0;Kb(e,x[c>>2],z[c+14>>1]);Ef(e,0);v[a+2|0]=0;d=0}a:{b:{if(!y[a|0]){Kb(f+8|0,x[c>>2],z[c+14>>1]);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break b}d=y[a+2|0]}e=y[a+3|0];j=f+8|0;Kb(j,x[c>>2],z[c+14>>1]);Ef(j,(e|0)==4|(d|0)==11);d=y[a+3|0];break a}d=y[a+3|0];e=y[a+2|0];if(!(d|(e|0)==11)){v[a+5|0]=0;d=4;v[a+3|0]=4;break a}if(e|(d|0)==4){break a}v[a+4|0]=0;v[a+2|0]=11}c:{d:{e:{if(!(!y[c+16|0]|d)){v[a+3|0]=17;e=0;d=125;break e}e=0;f:{switch(d-16|0){case 1:break d;case 0:break f;default:break c}}if(y[a+5|0]){break c}e=1;d=6}v[a+5|0]=d}v[c+16|0]=e}a=z[c+14>>1]+1|0;w[c+14>>1]=z[c+12>>1]>(a&65535)>>>0?a:0;fb=f+16|0;a=x[qg(h+12|0)>>2];continue}break}a=iC(i,c);v[a+16|0]=y[c+16|0];x[a+12>>2]=x[c+12>>2];fb=h+16|0;yf(i);yf(c);c=x[kn(g+44|0)>>2];continue}else{fb=g+48|0}break}}function Ria(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=nc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((j|0)<(g|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=xb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=UQ(i),w[m+30>>1]=n;B[a+32>>2]=F(l);wk(a+4|0,(h-g|0)+1|0);c=wb(x[b>>2]);h=wb(x[b+4>>2]);f=Fk(wb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;Xl(b+24|0,c,h);Gk(b+16|0,x[b+24>>2],x[b+28>>2],f);c=$z(c,x[b+16>>2]);m=b,n=TQ(f,x[b+20>>2]),x[m+12>>2]=n;Ud(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=xb(c,b+g|0);m=xb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=xb(b,f-h|0);m=xb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{lq(a)}break}}break}f=1}return f|0}function jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Tf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(A[c+8>>2]<e>>>0){break c}h=x[c+28>>2];if(x[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=D(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(on(De(Dg(C[(d+o<<3)+m>>3])*134217728))+od(Ht(k),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=n<<1;r=(d<<2)+l|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}s=x[r>>2]+q|0,u=dd(j),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Tf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(A[c+8>>2]<e>>>0){break c}i=x[c+28>>2];if(x[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=D(b,g);q=D(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(on(De(Dg(C[(d+o<<3)+n>>3])*134217728))+od(Ht(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d+q<<1)+m|0;j=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=dd(k),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function HI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function nqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);op(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Xe(zi(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Sb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38112|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Sb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=x[a>>2];d=Uk(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{f=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(f>>>0<=(b-e|0)/52>>>0){dA(a,f,c);break c}h=Ab(a);d=_Q(a,Uk(x[a>>2],e)+f|0);j=Uk(x[a>>2],x[a+4>>2]);g=fb-16|0;fb=g;b=i+12|0;Fg(b+12|0,h);d:{if(!d){e=0;d=0;break d}ZQ(g+8|0,d);e=x[g+12>>2];d=x[g+8>>2]}x[b>>2]=d;h=d+D(j,52)|0;x[b+8>>2]=h;x[b+4>>2]=h;k=zc(b),l=d+D(e,52)|0,x[k>>2]=l;fb=g+16|0;x[31721]=0;S(930,b|0,f|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}g=fb-16|0;fb=g;c=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);f=zb(g+4|0,x[b+4>>2]);e=x[c>>2];h=x[d>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[f>>2];x[c+12>>2]=e;while(1){f=x[c+8>>2];if(Pg(e,h)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]-52;fb=d+16|0;j=x[d+12>>2];d=e-52|0;e=Ul(j,d);x[e+20>>2]=x[d+20>>2];f=x[d+16>>2];x[e+12>>2]=x[d+12>>2];x[e+16>>2]=f;bW(e+24|0,d+24|0);Zc(e+36|0,d+36|0);x[e+48>>2]=x[d+48>>2];d=XQ(c+12|0);XQ(c+8|0);e=x[d>>2];continue}break}fb=c+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=g+16|0;YQ(b)}fb=i+32|0;break a}a=N()|0;YQ(b);Q(a|0);p()}return}if(b>>>0<d>>>0){$Q(a,e+D(b,52)|0)}}function aM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;lz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];fg(x[x[a>>2]-12>>2]+a|0,0);Zd(b+80|0,x[d+4>>2]);a:{b:{c=x[d+4>>2];if(!qk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=di(b- -64|0,-1,-1);if(!Vn(x[b+88>>2],x[b+92>>2],x[a+8>>2],x[a+12>>2])){break b}}fg(c+x[x[c>>2]-12>>2]|0,0);break a}Ei(c,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(qk(x[a+16>>2])){fg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;Rm(c,b);a=x[d+4>>2];fg(x[x[a>>2]-12>>2]+a|0,0);break a}Ei(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(qk(x[a+16>>2])){fg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;Rm(c,b+16|0);a=x[d+4>>2];fg(x[x[a>>2]-12>>2]+a|0,0);break a}Zd(b- -64|0,c);c=x[d+4>>2];c:{if(!qk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2])){a=di(b+48|0,-1,-1);f=1;if(!Vn(x[b+72>>2],x[b+76>>2],x[a+8>>2],x[a+12>>2])){break c}}fg(x[x[c>>2]-12>>2]+c|0,0);c=x[d+4>>2];f=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;Rm(c,b+32|0);a=x[d+4>>2];fg(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=e+16|0;return f|0}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(wi(a+44|0)){n=x[a+44>>2];j=Gc(n,0);k=Gc(n,1);n=x[a+56>>2];t=Gc(n,0);n=Gc(n,1);u=B[xb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Gb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Gb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Li(a,b,c,t,n,d)}break}}fb=i+16|0}function NR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Wb(x[a+484360>>2],y[a+484376|0]);f=Yc(x[c>>2],x[c+4>>2]);a:{while(1){e=b&65535;if(e>>>0>=f>>>0){break a}if(!_i(c,e)){b=b+1|0;continue}break}f=a+1074312|0;e=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(e|0)){MR(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Go(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;cB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Ko((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Kb(d+8|0,f,23);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=d+16|0}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2160|0;fb=b;eu(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=$b(8);x[31721]=0;b=P(37,b+100|0,10453)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=jM(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=cM(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=fc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=ju(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=$b(8);x[31721]=0;b=P(37,b+100|0,8057)|0;c=x[31721];x[31721]=0;if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;ic(a);break b}fb=b+2160|0;return a|0}c=N()|0;ic(a)}Q(c|0)}p()}function hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){VC(d);break a}kh(c+8|0,d);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!ZU(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25720>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25496|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25504>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25696>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25732|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Tb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Gb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=hf(b)}h=c+8|0;Pr(h,e);i=fc(c+16|0,x[c+8>>2],f);jc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);Pr(h,e);Tb(x[c+8>>2]+f|0,0,36-f|0);Ub(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}fb=g+48|0;return a|0}function e3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;x[d+12>>2]=0;h=a>>>0<=1?1:a;b=h;if(b>>>0<=4294967216){a:{if(b>>>0>=4294967216){x[31596]=48;a=0;break a}e=b>>>0<11?16:b+11&-8;c=Ed(e+28|0);a=0;if(!c){break a}b=c-8|0;b:{if(!(c&15)){a=b;break b}g=c-4|0;i=x[g>>2];a=(c+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;f=(i&-8)-c|0;if(!(i&3)){b=x[b>>2];x[a+4>>2]=f;x[a>>2]=b+c;break b}x[a+4>>2]=f|x[a+4>>2]&1|2;f=a+f|0;x[f+4>>2]=x[f+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;f=b+c|0;x[f+4>>2]=x[f+4>>2]|1;ov(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=e+16>>>0){break c}x[a+4>>2]=e|b&1|2;b=a+e|0;e=c-e|0;x[b+4>>2]=e|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;ov(b,e)}a=a+8|0}if(a){x[d+12>>2]=a}}fb=d+16|0;a=x[d+12>>2];if(!a){d:{b=0;a=x[125546];if(!a){x[125546]=502192;w[251097]=128;j=502192,k=Hx(502704),w[j>>1]=k;a=x[125546]}d=(h+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502704){a=0}else{e=z[a+2>>1];if(e>>>0>d>>>0){b=e-d|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=d;w[a>>1]=0;a=a+4|0;break d}if((d|0)!=(e|0)){break e}d=z[a>>1];f:{if(!b){j=502184,k=Ix(d),x[j>>2]=k;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=Ix(z[a>>1]);continue}}}return a|0}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-32|0;fb=j;e=b;b=x[a>>2];h=D(gu(e,wb(b)),6)+b|0;a:{if(!c){break a}b=x[Ab(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-h|0)/6|0;if(e>>>0<c>>>0){aD(a,c-e|0,d);b=e;if((h|0)==(i|0)){break a}}l=fb-16|0;fb=l;f=x[a+4>>2];g=D((f-(D(c,6)+h|0)|0)/6|0,6)+h|0;m=qr(l+4|0,a,(i-g|0)/6|0);k=x[m+4>>2];e=g;while(1){if(e>>>0>=i>>>0){gc(m);e=h;if((g|0)!=(e|0)){g=g-e|0;$h(D((g|0)/-6|0,6)+f|0,e,g)}fb=l+16|0}else{Cv(k,e);k=k+6|0;x[m+4>>2]=k;e=e+6|0;continue}break}c=D(d>>>0>=e>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Ab(a);f=UY(j+8|0,XC(a,Kk(x[a>>2],i)+c|0),(h-x[a>>2]|0)/6|0,b);TY(f,c,d);g=fb-16|0;fb=g;b=x[f+4>>2];e=zb(g+12|0,h);d=zb(g+8|0,x[a>>2]);c=zb(g+4|0,x[f+4>>2]);n=f,o=QY(x[e>>2],x[d>>2],x[c>>2]),x[n+4>>2]=o;n=f,o=dR(h,x[a+4>>2],x[f+8>>2]),x[n+8>>2]=o;wc(a,f+4|0);wc(a+4|0,f+8|0);wc(Ab(a),zc(f));x[f>>2]=x[f+4>>2];fb=g+16|0;h=b;SY(f)}zb(j+28|0,h);fb=j+32|0}function iD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;a:{if(b&4){break a}e=y[a+14|0];b:{if(e>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|e>>>0<=y[a+13|0]){break a}d=x[a>>2];c=x[a+4>>2];if(Pd(d,c)>>>0<=e>>>0){break a}d=z[Mc(d,c,e)>>1];c=Mc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);e=y[a+14|0];if(z[c>>1]<(d-1|0)){e=z[Mc(x[a>>2],x[a+4>>2],e)>>1]-1&65535;d=Fq(a,e,64,64);c=zb(g+12|0,Fk(wb(x[a>>2]),y[a+14|0]));h=_l(g+8|0,e,d&255);i=fb-32|0;fb=i;d=x[c>>2];c=x[a>>2];f=(vv(d,wb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[Ab(a)>>2]){if((c|0)!=(f|0)){break d}zY(a,h);break c}d=Ab(a);d=ig(i+8|0,Uf(a,nc(x[a>>2],c)+1|0),f-x[a>>2]>>2,d);x[31721]=0;O(784,d|0,h|0);c=x[31721];x[31721]=0;if((c|0)!=1){f=jr(a,d,f);hg(d);break c}a=N()|0;hg(d);Q(a|0);p()}k=fb-16|0;fb=k;m=x[a+4>>2];d=(m-(f+4|0)|0)+f|0;l=th(k+4|0,a,c-d>>2);j=x[l+4>>2];e=d;while(1){if(c>>>0<=e>>>0){gc(l);ir(f,d,m);fb=k+16|0}else{Wo(j,z[e>>1]|z[e+2>>1]<<16);j=j+4|0;x[l+4>>2]=j;e=e+4|0;continue}break}v[f+2|0]=y[h+2|0];w[f>>1]=z[h>>1]}zb(i+28|0,f);fb=i+32|0;break a}v[a+14|0]=e-1}if((b|0)!=16777216){v[a+17|0]=255}fb=g+16|0}function Sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(l,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=zua(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function tsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;kd(b,32);_o(b);f=b,g=we((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((we((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=we((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(Bua(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=_b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=_b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=_b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+_b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Cb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{if(_b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break b}c=z[b+34>>1];if(_b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}w[b+34>>1]=c;f=b,g=c&65531|Cb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Cb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=we((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){am(b,+(c|0)/96);c=we((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){Oz(a);a:{if(!y[a+4240|0]){break a}e=zA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;$t(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Nz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Ti(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];sT(h+8|0,1);g=Aj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|$l(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Li(g,b,c,Gc(a,0),Gc(a,1),d);fb=h+16|0}function CY(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;be(a,0,d+14|0);break a}e=y[b+25024|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Sb(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Sb(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}be(a,e,d+15|0)}fb=d+16|0}function Hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){j=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];l=b;j=x[a+8>>2];m=Bg(j,b,k);n=hb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];cg(b,f,rf(j,l,d),hb);i=hb>>>0>i>>>0?d:0}g=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){f=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=k;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;$d(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);_d(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=zg(g,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,l);c=c+8|0;continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;$d(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);_d(g,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(l,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=zua(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);k=zua(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38130>>1])+D(w[h-2>>1],w[e+38128>>1])|0)+D(w[h+2>>1],w[e+38132>>1])|0)+D(w[h+4>>1],w[e+38134>>1])|0)/16384<<8;e=h;e=zua(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Xb(f,-16777216,16776704);e=zua(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Kf(a);while(1){if(Vg(b,c)){b=x[zb(i+8|0,o)>>2];j=rd(x[i+12>>2]);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;e=fb-16|0;fb=e;a:{b:{if(!kc(b,x[zb(e+12|0,ng(a))>>2])){g=y[j|0];l=y[rd(b)|0];if(!wo(g,l)){break b}}x[e+12>>2]=b;g=zb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!kc(d,x[g>>2])){d=x[wB(e+12|0)>>2];l=y[rd(d)|0];g=y[j|0];if(!wo(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=RA(a,f,g);break a}if(wo(l,g)){d:{d=uB(b);if(!kc(d,x[zb(e+12|0,ng(a))>>2])){g=y[j|0];if(!wo(g,y[rd(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=RA(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=dc(a);f=h+12|0;e=zh(f,Dc(24),Jg(b+8|0,e));AS(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=dc(e),q=1,v[p+4|0]=q;fb=b+16|0;Xg(a,x[h+28>>2],d,x[h+12>>2]);b=ie(f);Zl(f);n=1}Wg(k+8|0,x[zb(h+12|0,b)>>2],n);fb=h+32|0;fb=k+16|0;zb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[Yg(i+12|0)>>2];continue}else{fb=i+16|0}break}}function Z6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1240;b=Ae(a+24|0,a+32|0,a+20|0);ad(a+16|0,x[e+28>>2]);x[31721]=0;h=R(1219,x[a+16>>2])|0;i=x[31721];x[31721]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31721]=0;c=na(1249,a+444|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Cd(y[g+11|0])){wd(x[g>>2],0);Wd(g,0);break d}wd(g,0);Ke(g,0)}if(y[a+15|0]){x[31721]=0;c=P(1236,h|0,45)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[31721]=0;O(36,g|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}}x[31721]=0;d=P(1236,h|0,48)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31721]=0;U(1254,g|0,c|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break c}break a}x[31721]=0;c=P(1224,a+444|0,a+440|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Yb(a+16|0);Jc(b);fb=a+448|0;return c|0}}}c=N()|0;Yb(a+16|0);Jc(b);Q(c|0);p()}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(m,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38130>>1])+D(v[g-1|0],w[e+38128>>1])|0)+D(v[g+1|0],w[e+38132>>1])|0)+D(v[g+2|0],w[e+38134>>1])<<8)/16384<<8;e=o;g=zua(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function dT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}if(h=Ob(e,103),i=0,j=(f|0)!=65535,j?h:i){break c}if(h=Ob(e,49),i=0,j=(f|0)!=65535,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Yc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Vb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Tf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=D(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+l>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=m<<1;q=(c<<2)+k|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}r=x[q>>2]+o|0,s=dd(j),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function fK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!ql(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}j=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;i=v[f|0];f:{if((i-48&255)>>>0<10){break f}g=-87;if((i-97&255)>>>0<26){break f}g=-55;if((i-65&255)>>>0>25){break e}}i=g+i|0;if((i|0)>=(m|0)){break e}If(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=zua(k,h,m,0);p=hb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[31596]=68;a=d&1;j=a?0:j;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|j)){x[31596]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[31596]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Tf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=D(f,g);o=D(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c+o<<1)+l|0;j=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=dd(k),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function Eo(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!Sc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Sc(e)){break c}if((z[Zb(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function O9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-32|0;fb=f;m=x[d>>2];g=x[d+4>>2];x[f+28>>2]=g;k=b+36|0;d=m;while(1){a:{if(!g){break a}h=0;j=fb-32|0;fb=j;i=b+36|0;e=b+228|0;l=c&-4096;b:{c:{while(1){if((h|0)==16){break c}d:{g=x[xb(e,h)>>2];if(y[Dd(i,g)+8|0]){if(x[Dd(i,g)>>2]==(l|0)){break d}}h=h+1|0;continue}break}i=x[xb(e,h)>>2];h=e+(h<<2)|0;ir(e,h,h+4|0);o=xb(e,0),p=i,x[o>>2]=p;break b}h=x[xb(e,15)>>2];ir(e,b+288|0,b+292|0);o=xb(e,0),p=h,x[o>>2]=p;g=x[xb(e,0)>>2];e=Dd(i,g);x[e>>2]=l;dz(j+16|0,x[b+24>>2],g);i=x[x[b>>2]+44>>2];h=x[j+20>>2];x[j+8>>2]=x[j+16>>2];x[j+12>>2]=h;ib[i|0](j+24|0,b,l,j+8|0);x[e+4>>2]=x[j+28>>2];v[e+8|0]=1}fb=j+32|0;i=c-x[Dd(k,g)>>2]|0;x[f+12>>2]=4096-i;o=f,p=x[Gb(f+12|0,f+28|0)>>2],x[o+24>>2]=p;if(i>>>0<A[Dd(k,g)+4>>2]){e=x[Dd(k,g)+4>>2]-i|0}else{e=0}x[f+20>>2]=e;e=x[Gb(f+24|0,f+20|0)>>2];dz(f+12|0,x[b+24>>2],g);h=x[f+12>>2];dz(f+4|0,x[b+24>>2],g);Qi(h+i|0,e+(i+x[f+4>>2]|0)|0,d);g=x[f+28>>2]-e|0;x[f+28>>2]=g;n=e+n|0;if(e>>>0<A[f+24>>2]){break a}c=c+e|0;d=d+e|0;continue}break}ac(a,m,n);fb=f+32|0}function lua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=V$(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Gb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}cc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function kta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=Xd(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[af(c,d+4|0)|0];f=LD(c,b);l=or(f);x[31721]=0;c=R(205,b|0)|0;e=x[31721];x[31721]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;uc(d+1068|0,x[Gb(d+4|0,d)>>2]<<3);x[31721]=0;m=x[d+1068>>2];k=P(344,a|0,m|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;c=8;h=P(161,f|0,8)|0;a=x[31721];x[31721]=0;b:{if((a|0)!=1){c:{o=vb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[31721]=0;j=P(161,f|0,c|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=vb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=or(f);x[31721]=0;P(152,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}}c=N()|0;cc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function VX(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!wf(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!wf(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!wf(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!wf(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!wf(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function $0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;vc(b);Ap(a);a:{if(!Ow(b,d+60|0)){break a}if(!HF(d+60|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],_b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}ex(a);g=d,h=dx(),x[g+40>>2]=h;e=d+40|0;cx(hj(x[a+4>>2])+32|0,e);as(e);c=x[hj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31721]=0;S(189,e|0,b|0,_b(f)-28|0);b=x[31721];x[31721]=0;c:{d:{if((b|0)!=1){Gn(d+32|0,d+40|0);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31721]=0;b=ba(190,x[d+32>>2],x[d+36>>2],c|0,_b(b)|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}Ic(d+40|0);e=0;if(!b){break a}le(d+16|0,x[c>>2],x[c+4>>2]);jf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Jd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=ax(d+40|0,x[d+24>>2],x[d+28>>2],d);gd(hj(x[a+4>>2])+12|0,b);ub(b);break b}e=ta(124984,24424)|0;b=gb;break c}e=ta(124984,24424)|0;b=gb;Ic(d+40|0)}e:{if(($(124984)|0)==(b|0)){break e}if(($(24424)|0)==(b|0)){break e}Q(e|0);p()}Y(e|0)|0;Z();e=0;break a}e=1}fb=d+96|0;return e|0}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Jd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=ax(c+60|0,d,b,c+8|0);x[31721]=0;d=R(205,b|0)|0;e=x[31721];x[31721]=0;a:{if((e|0)==1){break a}x[31721]=0;d=U(957,b|0,c+19|0,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Ld((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Ld((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Ld((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;au(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);i=x[a+44>>2];h=Gc(i,0);i=Gc(i,1);j=x[a+56>>2];n=Gc(j,0);j=Gc(j,1);k=a+4208|0;g=nc(x[k>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){wk(k,e)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;v=xb(k,g);f=B[xb(k,g|1)>>2];s=B[h>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;w=xb(k,g),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=xb(k,g|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;Hk(e,e+h|0,n);Hk(i,i+h|0,j)}h=a;a=x[a+56>>2];Li(h,b,c,Gc(a,0),Gc(a,1),d)}function eD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function po(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Kj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Kj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=GR(KX(c+40|0,1),f&255,0,0);x[31721]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1099,c+68|0,a|0,0,c+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}j=c,k=wb(x[c+68>>2]),x[j+36>>2]=k;d=wb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Ui(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31721]=0;O(1134,g|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){cv(c+36|0);continue}break}break}a=N()|0;Ui(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=$b(8);x[31721]=0;d=P(37,c+40|0,7310)|0;a=x[31721];x[31721]=0;if((a|0)!=1){mc(b,d);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;ic(b)}lf(g);Q(a|0)}p()}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!wi(a+44|0)){break a}f=x[a+44>>2];l=Gc(f,0);m=Gc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Gc(f,0);o=q;r=Gc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=xb(k,f);g=B[l>>2];B[h>>2]=g;y=xb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(VP(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[xb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[xb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Li(a,b,c,q,r,d)}break}}}function U$(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{if((y[a|0]-16&255)>>>0<241){break a}c=a+1954|0;d=a+1698|0;while(1){if((d|0)==(c|0)){d=0;c=0;while(1){if((d|0)==32){g=c;break a}g=0;e=D(d,13)+a|0;if(y[zc(e+2|0)|0]){break a}b=(d<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break a}h=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(h>>>0>1048575){break a}if(y[zc(e+930|0)|0]){break a}e=(D(d,11)+a|0)+1346|0;if(y[vb(e,0)|0]>15){break a}if(y[vb(e,5)|0]>3){break a}if(y[vb(e,10)|0]>3){break a}b:{c:{d:{if(h){i=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(i>>>0<=1048574&(h>>>0<i>>>0|(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0>i>>>0)){break a}if(c|h){break c}break d}if(c){break c}}v[f+7|0]=0;v[f+8|0]=0;v[f+9|0]=0;v[f+10|0]=0;x[f>>2]=0;x[f+4>>2]=0;g=e+11|0;c=f;while(1){e:{b=(e|0)==(g|0);if(b){break e}if(!T$(y[e|0],y[c|0])){break e}c=c+1|0;e=e+1|0;continue}break}c=0;if(b){break b}}c=1}d=d+1|0;continue}}b=v[d|0];d=d+1|0;if((b|0)>-2){continue}break}}fb=f+16|0;return g&1}function OB(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(b&5){if((b|0)==1){e=zua(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(Bua(e,c,8287,0),hb),x[f+24>>2]=g}cV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Jf(a+40|0,15);Jf(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=ui(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Yk(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=vb(a,8);v[b|0]=y[b|0]&3;a=vb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function Ko(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Ob(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;Oo(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function kT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=zua(c,c>>31,5e4,0);e=hb;b=x[$c(d+12|0,d+8|0)>>2];c=Fc(Aua(c,e,b,b>>31),hb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=zua(c,c>>31,1e4,0);e=hb;b=x[$c(d+12|0,d+8|0)>>2];c=Fc(Aua(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(zua(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!Ge(c,x[a+484348>>2],e)){break d}c=Vb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=FR(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!kc(e,c)){f=f*+A[xb(e,A[b+48>>2]%(nc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=zua(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function Lha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb+-64|0;fb=b;g=Nb(a);x[31721]=0;W(962,g|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){a=43024;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==43336){fb=b- -64|0;return g|0}k:{h=iu(44);if(h){x[31721]=0;d=P(37,b+36|0,x[a+4>>2])|0;c=x[31721];x[31721]=0;if((c|0)==1){break k}c=x[a>>2];x[31721]=0;O(963,b+48|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break j}x[31721]=0;e=P(37,b+12|0,x[a+8>>2])|0;f=x[31721];x[31721]=0;if((f|0)==1){break i}x[31721]=0;O(963,b+24|0,e|0);f=x[31721];x[31721]=0;if((f|0)==1){break h}x[31721]=0;c=ba(964,h|0,c|0,b+48|0,b+24|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break g}Eb(b+24|0);tb(e);Eb(b+48|0);tb(d);x[b+60>>2]=c;x[31721]=0;O(965,g|0,b+60|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Eb(b+24|0)}tb(e)}Eb(b+48|0)}tb(d)}Db(h);break a}a=N()|0;break a}a=N()|0}sc(g);Q(a|0);p()}function d7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1240;b=Ae(a+24|0,a+32|0,a+20|0);ad(a+16|0,x[e+28>>2]);x[31721]=0;h=R(28,x[a+16>>2])|0;i=x[31721];x[31721]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31721]=0;c=na(1241,a+140|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}qf(g);if(y[a+15|0]){x[31721]=0;c=P(29,h|0,45)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[31721]=0;O(118,g|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}}x[31721]=0;d=P(29,h|0,48)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31721]=0;U(1247,g|0,c|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break c}break a}x[31721]=0;c=P(1209,a+140|0,a+136|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Yb(a+16|0);Jc(b);fb=a+144|0;return c|0}}}c=N()|0;Yb(a+16|0);Jc(b);Q(c|0);p()}function CL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){vl(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Fm(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}ec(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}ec(a,21);return 0}_(7552,13258,1887,6586);p()}function aS(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=Ou(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a>>2];c=Rd(d,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;c=b-c|0;b=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=fb-16|0;fb=d;c=fv(d+4|0,a,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){gc(c);fb=d+16|0}else{dW(a);a=a+12|0;x[c+4>>2]=a;continue}break}break a}b=Ab(a);e=vm(h+12|0,Ep(a,Rd(x[a>>2],d)+c|0),Rd(x[a>>2],x[a+4>>2]),b);b=fb-16|0;fb=b;c=cW(b+4|0,e+8|0,c);d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){dW(d);d=x[c>>2]+12|0;x[c>>2]=d;continue}break}ee(c);fb=b+16|0;g=fb-16|0;fb=g;c=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[e+4>>2]);c=x[c>>2];d=x[d>>2];f=fb-16|0;fb=f;x[f+8>>2]=x[b>>2];x[f+12>>2]=c;while(1){b=x[f+8>>2];if(Pg(c,d)){bW(lx(b),Pn(c));b=um(f+12|0);um(f+8|0);c=x[b>>2];continue}break}fb=f+16|0;x[e+4>>2]=b;wc(a,e+4|0);wc(a+4|0,e+8|0);wc(Ab(a),zc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];while(1){a=x[e+8>>2];if((a|0)!=(b|0)){a=a-12|0;x[e+8>>2]=a;eW(a);continue}break}a=x[e>>2];if(a){hs(e);Db(a)}}fb=h+32|0;return}if(b>>>0<c>>>0){fW(a,d+D(b,12)|0)}}function xL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;a=4;b=4;e=2;while(1){f=a;a=(a+b|0)+4|0;x[(d+16|0)+(e<<2)>>2]=a;e=e+1|0;b=f;if(a>>>0<h>>>0){continue}break}f=(g+h|0)-4|0;b:{if(f>>>0<=g>>>0){b=0;e=1;h=0;a=1;f=0;break b}e=1;a=1;while(1){c:{if((e&3)==3){Sy(g,c,a,d+16|0);vt(d+8|0,2);a=a+2|0;break c}b=a-1|0;d:{if(A[(d+16|0)+(b<<2)>>2]>=f-g>>>0){ut(g,c,e,x[d+12>>2],a,0,d+16|0);break d}Sy(g,c,a,d+16|0)}if((a|0)==1){tt(d+8|0,1);a=0;break c}tt(d+8|0,b);a=1}b=x[d+8>>2];e=b|1;x[d+8>>2]=e;g=g+4|0;if(f>>>0>g>>>0){continue}break}h=b>>>0>1;b=x[d+12>>2];f=(b|0)!=0}ut(g,c,e,b,a,0,d+16|0);if(!(f|((a|0)!=1|h))){break a}while(1){e:{if((a|0)<=1){f=qL(e,b);vt(d+8|0,f);b=x[d+12>>2];e=x[d+8>>2];a=a+f|0;break e}e=d+8|0;tt(e,2);x[d+8>>2]=x[d+8>>2]^7;vt(e,1);b=g-4|0;h=d+16|0;f=a-2|0;ut(b-x[h+(f<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],a-1|0,1,h);tt(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;a=b;b=x[d+12>>2];ut(a,c,e,b,f,1,h);a=f}g=g-4|0;if((a|0)!=1|(e|0)!=1|b){continue}break}}fb=d+208|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31721]=0;W(1029,a|0);e=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31721]=0;W(1005,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break e}e=0;x[31721]=0;W(1030,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break e}a=Tb(c,0,d);if(!y[b|0]){break b}if(ki(b,47344)|(d|0)!=8){break d}x[a+4>>2]=1031;x[a>>2]=1032;break c}Y(T(0)|0)|0;x[31721]=0;V(991,12344,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();return 0}if(!(ki(b,47356)|(d|0)!=64)){x[a+60>>2]=1033;x[a+56>>2]=1034;x[a+52>>2]=1035;x[a+48>>2]=1036;x[a+44>>2]=1037;x[a+40>>2]=1038;x[a+36>>2]=1039;x[a+32>>2]=1040;x[a+28>>2]=1041;x[a+24>>2]=1042;x[a+20>>2]=1043;x[a+16>>2]=1044;x[a+12>>2]=1045;x[a+8>>2]=1046;x[a+4>>2]=1047;x[a>>2]=1048;break c}if(!(ki(b,47368)|(d|0)!=24)){x[a+20>>2]=1049;x[a+16>>2]=1050;x[a+12>>2]=1051;x[a+8>>2]=1052;x[a+4>>2]=1053;x[a>>2]=1054;break c}if(ki(b,47381)|(d|0)!=4){break b}x[a>>2]=1055}e=1}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Pha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=fb-32|0;fb=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=ib[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Gb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[31721]=0;O(290,e+4|0,b+4|0);b=x[31721];x[31721]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];le(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=fb-16|0;fb=e;x[e+12>>2]=0;lQ(b,e+12|0);fb=e+16|0;b=x[x[a>>2]+184>>2];x[31721]=0;O(b|0,a|0,-1);b=x[31721];x[31721]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+188>>2];x[31721]=0;W(d|0,a|0);d=x[31721];x[31721]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31721]=0;g=E(_a(b|0,a|0,d|0));b=x[31721];x[31721]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;lQ(c+16|0,c+8|0);continue}break}d=T(124984)|0;break c}d=T(124984)|0;break c}d=T(124984)|0}if((gb|0)!=($(124984)|0)){break a}Y(d|0)|0;To(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(d|0);p()}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(n,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(k<<16)|0;e=k;g=zua(e,e>>31,o,w);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function Fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Bg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];cg(b,f,rf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=(f<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);_d(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=zg(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{$d(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);_d(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(n,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=zua(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function HW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;TB(a,aV(a),c+48|0);b=oc(c+40|0,14192);pf(Me(a,0),x[b>>2],x[b+4>>2]);b=oc(c+32|0,14270);pf(Me(a,1),x[b>>2],x[b+4>>2]);b=oc(c+24|0,5496);pf(Me(a,3),x[b>>2],x[b+4>>2]);b=oc(c+16|0,15739);pf(Me(a,4),x[b>>2],x[b+4>>2]);b=oc(c+8|0,9265);pf(Me(a,8),x[b>>2],x[b+4>>2]);e=Me(a+288|0,0);b=fb-16|0;fb=b;d=e;e=oc(b+8|0,4932);pf(d,x[e>>2],x[e+4>>2]);fb=b+16|0;e=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){aw(a+28|0,4084);x[31721]=0;O(292,a+16|0,a+60|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}x[31721]=0;S(293,a+40|0,a+28|0,a+16|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=a+40|0;ve(a+52|0,d);pf(Me(e,b),x[a+52>>2],x[a+56>>2]);tb(d);tb(a+16|0);Eb(a+28|0);break d}b=N()|0;tb(a+16|0);break b}d=oc(a+8|0,22250);pf(Me(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;kd(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Lc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Lc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41162|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function Bua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>yua(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=yua(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=jg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=zua(e,e>>31,o,A);k=hb;h=e;e=Xb(b,-16777216,16776704);e=zua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=zua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Cg(a,l,s);fb=g+16|0}function sM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=D(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=xb(x[b>>2],a);i=d;d=x[(a+o<<2)+m>>2]+(x[d>>2]>>1)|0;q=d;d=It(k)+d&-4096;x[i>>2]=q-d;i=x[(a<<2)+l>>2]+(n<<1)|0;d=od(d|2048,12);d=(d|0)>=32767?32767:d;w[i>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function mM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=D(e,h);o=D(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=xb(x[b>>2],a);q=d;d=x[(a+n<<2)+m>>2]+(x[d>>2]>>1)|0;r=d;d=It(k)+d&-4096;x[q>>2]=r-d;d=od(d|2048,12);d=(d|0)>=32767?32767:d;w[(a+o<<1)+l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=jg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=zua(e,e>>31,o,A);k=hb;h=e;e=Xb(b,-16777216,16776704);e=zua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=zua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Cg(a,l,s);fb=g+16|0}function BL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15828,13258,2423,9211);p()}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function TB(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function lsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=Wh(b,c);n=e,o=Cb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;ch(d,z[Lc(e+14|0,e+12|0)>>1]);n=d,o=Cb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Cb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Cb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Cb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;h=x[d>>2];j=x[d+4>>2];b=y[d+12|0]&-2|kc(h,j)^1;v[d+12|0]=b;b=Cb(y[a+12|0]|y[a+13|0]<<8)>>>3&2|b&-3;v[d+12|0]=b;n=d,o=Cb(y[a+12|0]|y[a+13|0]<<8)>>>3&4|b&251,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}k=b-i|0;l=k>>>1|0;b=0;while(1){if(Pd(h,j)>>>0<=b>>>0){fb=e+16|0}else{d=xb(h,b);w[d>>1]=m;f=(b<<2)+a|0;c=we((y[f+28|0]|y[f+29|0]<<8)<<16>>16)+i|0;g=c;c=c>>31<<6|c>>>26;g=l+(g<<6)|0;c=g>>>0<l>>>0?c+1|0:c;n=d,o=Zg(Fc(Aua(g,c,k,0),hb)),v[n+2|0]=o;n=e,o=Cb(y[f+26|0]|y[f+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;m=z[oe(e+10|0,e+8|0)>>1]+m|0;continue}break}}function _ta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-144|0;fb=f;x[31721]=0;l=R(276,a|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31721]=0;O(295,a|0,f+8|0);e=x[31721];x[31721]=0;if((e|0)!=1){b:{e=Cb(z[f+8>>1]);if((e-1&65535)>>>0>=z[m>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Wh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Sb(f+4|0,f+7|0)|0];x[31721]=0;h=h+1&255;O(296,e|0,h|0);g=x[31721];x[31721]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Cb(z[i+8>>1]);k=xb(g,e);w[k>>1]=n;i=Cb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Qf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function Zsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-288|0;fb=e;qf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=e+32|0;mo(e+8|0,d,gr(d));jc(e+20|0,x[a>>2],x[a+8>>2],x[e+8>>2],x[e+12>>2]);x[e+28>>2]=x[e+24>>2];o=e,q=c-Xc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Gb(e+28|0,e+4|0)>>2];if(!d){break a}k=e+32|0;m=d+k|0;j=Ii(k,m,0);d=x[zb(e,zf(b))>>2];l=fb-16|0;fb=l;h=Bk(d,xd(b));b:{c:{d=k;f=Tj(d,j);d:{if(!f){xd(b);break d}if(!Az(b,d)){i=Bb(x[b+4>>2],y[b+11|0]);g=Kc(b);e:{if(f>>>0<=g-i>>>0){g=Jb(b);if((h|0)==(i|0)){break e}n=h+g|0;Ri(f+n|0,n,i-h|0);break e}Om(b,g,(f+i|0)-g|0,i,h,0,f);g=x[b>>2]}f=f+i|0;kg(b,f);ed(f+g|0,0);f=h+g|0;while(1){if((d|0)!=(j|0)){ed(f,y[d|0]);d=d+1|0;f=f+1|0;continue}break}Ne(xd(b),h);break d}d=oi(l+4|0,d,j);i=xd(d);g=zf(d);x[31721]=0;ha(367,b|0,f|0,h|0,i|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break c}tb(d)}fb=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Ub(a,j-k|0);if(j>>>0>=m>>>0){continue}break}Ub(a,1)}fb=e+288|0}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);i=zua(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38130>>1])+D(w[h-2>>1],w[e+38128>>1])|0)+D(w[h+2>>1],w[e+38132>>1])|0)+D(w[h+4>>1],w[e+38134>>1])|0)/16384<<8;e=h;e=zua(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Xb(f,-16777216,16776704);e=zua(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Pb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function kD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Zg(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+24960|0]}be(e,a,d+15|0);fb=d+16|0}function TU(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Oj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Sc(e),n?l:m);a:{b:{c:{if(!Ob(d+1074312|0,34)){break c}d=e&255;if(!d){break c}if(d>>>0<121){break b}}d=x[a+656>>2];break a}d=x[a+656>>2];e=y[vb(d+108|0,(e&255)-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];f=((e&255)+c|0)-61<<16>>16;d:{e:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){g=x[d+36>>2];if(g){break e}}b=Tm(d,c+f<<16>>16);break d}j=g+1|0;h=Yz(c,j);e=Zz(c,j);b=E(1);i=w[d+28>>1];c=f+h<<16>>16;f:{if((i|0)>(c|0)){break f}f=x[d+4>>2];if((c|0)>(nc(f,x[d+8>>2])+i|0)-1<<16>>16){break f}if(!e){b=B[xb(f,c-i|0)>>2];break d}g:{h:{i:{switch(z[d>>1]-1|0){case 2:g=x[d+16>>2];if(!nc(g,x[d+20>>2])){break h}b=B[xb(g,e-1|0)>>2];break g;case 0:break i;default:break h}}h=x[d+16>>2];if(!nc(h,x[d+20>>2])){break h}b=B[xb(h,(e+D(g,aA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break g}b=Ce(E(Tm(d,c+1<<16>>16)/Tm(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[xb(f,c-i|0)>>2])}}l=a,m=Ck(E(E(k*b)*E(16))),x[l+700>>2]=m}}function JK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=fb-1040|0;fb=i;r=x[31596];a:{b:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+123440>>1]+121516|0;c=x[x[124227]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=Am(x[c+8>>2],e);f=Am(x[c+12>>2],e);d=Am(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=Am(x[d>>2],e);d=Am(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=ki(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=Am(x[f>>2],e);e=Am(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=gf(g);d:{if(c>>>0>=1024){yc(a,g,1023);v[a+1023|0]=0;g=68;break d}yc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=22250}break a}va();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;wy(a,1024,13075,i)}x[31596]=r;Cc(q,a);fb=i+1040|0}function Gla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Bg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];cg(b,f,rf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=f+p|0;b=l;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(g,v[f+x[e+12>>2]|0]<<6);_d(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=zg(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{$d(g,v[f+x[e+12>>2]|0]<<6);_d(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function tk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;ad(i+4|0,x[d+28>>2]);c=0;x[31721]=0;j=R(28,x[i+4>>2])|0;b=x[31721];x[31721]=0;if((b|0)!=1){Yb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(ph(i+12|0,i+8|0)){break b}c:{if((ll(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=ll(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=ll(j,v[g+2|0])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,k)|0,x[l+12>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(Ff(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(Ff(b,1,v[g|0])){continue}}break}while(1){if(ph(i+12|0,i+8|0)){break c}b=tl(x[i+12>>2]);if(!Ff(x[j+8>>2],1,b)){break c}Cm(i+12|0);continue}}if((py(j,tl(x[i+12>>2]))|0)==(py(j,v[g|0])|0)){g=g+1|0;Cm(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(ph(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Yb(i+4|0);Q(a|0);p()}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(k,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38130>>1])+D(v[g-1|0],w[e+38128>>1])|0)+D(v[g+1|0],w[e+38132>>1])|0)+D(v[g+2|0],w[e+38134>>1])<<8)/16384<<8;e=m;g=zua(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function zi(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kj(a)&2047;c=kj(5551115123125783e-32);a:{if(e-c>>>0>=kj(512)-c>>>0){if(c>>>0>e>>>0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(kj(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(kj(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return As(3105036184601418e216)}if(c>>>0<3230714880){break b}return As(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){kI(EI()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ad(g,x[d+28>>2]);x[31721]=0;b=R(1219,x[g>>2])|0;a=x[31721];x[31721]=0;d:{e:{f:{g:{if((a|0)!=1){Yb(g);ad(g,x[d+28>>2]);x[31721]=0;a=R(1220,x[g>>2])|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}Yb(g);x[31721]=0;O(1221,g|0,a|0);d=x[31721];x[31721]=0;if((d|0)==1){b=N()|0;break d}x[31721]=0;O(1222,g|12,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break f}x[31721]=0;d=g+24|0;a=sa(1223,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Rb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Yb(g);break d}b=N()|0;Yb(g);break d}b=N()|0;Rb(g);break d}b=N()|0;while(1){d=Rb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function i8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ad(g,x[d+28>>2]);x[31721]=0;b=R(28,x[g>>2])|0;a=x[31721];x[31721]=0;d:{e:{f:{g:{if((a|0)!=1){Yb(g);ad(g,x[d+28>>2]);x[31721]=0;a=R(1203,x[g>>2])|0;d=x[31721];x[31721]=0;if((d|0)==1){break g}Yb(g);x[31721]=0;O(1204,g|0,a|0);d=x[31721];x[31721]=0;if((d|0)==1){b=N()|0;break d}x[31721]=0;O(1205,g|12,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break f}x[31721]=0;d=g+24|0;a=sa(1206,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Yb(g);break d}b=N()|0;Yb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function ata(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,32);g=b,h=_b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=_b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=_b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=_b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Cb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}am(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Sb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function Vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=yv(c,d);d=b&63;if(e>>>0>d>>>0){c=DY(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Hf(a);e=fb-32|0;fb=e;a:{b:{if(Rg(a)>>>0<=14){if(Gh(1073741823)>>>0<=14){break b}f=Ab(a);f=ig(e+12|0,15,nc(x[a>>2],x[a+4>>2]),f);Id(a,f);hg(f)}fb=e+32|0;break a}cd();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=_l(g+12|0,h&65535,y[Sb(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[Ab(a)>>2]){zY(a,f);break d}i=fb-32|0;fb=i;e=Ab(a);e=ig(i+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),e);Wo(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;Id(a,e);hg(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|kc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function sk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;ad(i+4|0,x[d+28>>2]);b=0;x[31721]=0;j=R(1219,x[i+4>>2])|0;c=x[31721];x[31721]=0;if((c|0)!=1){Yb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(ii(i+12|0,i+8|0)){break b}c:{if((rk(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=rk(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=rk(j,x[g+8>>2])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+8|0;break c}if(uj(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(uj(j,1,x[g>>2])){continue}}break}while(1){if(ii(i+12|0,i+8|0)){break c}if(!uj(j,1,sl(x[i+12>>2]))){break c}ao(i+12|0);continue}}if((hm(j,sl(x[i+12>>2]))|0)==(hm(j,x[g>>2])|0)){g=g+4|0;ao(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(ii(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Yb(i+4|0);Q(a|0);p()}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(Qo(a)){c=x[a>>2];k=Gg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Gb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=wb(x[b>>2]);e=wb(x[b+4>>2]);f=fb-16|0;fb=f;h=XD(i,e);b:{if(h>>>0<=Cn(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Yc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;GU(f+12|0,d);d=x[f+12>>2]}j=fb-16|0;fb=j;IU(j+8|0,i,d,m);d=x[j+12>>2];fb=j+16|0;if(!n){KU(c,x[f+12>>2],e,h-Yc(x[c>>2],x[c+4>>2])|0);break b}yn(c,d);break b}JU(c);pC(c,jk(c,h));KU(c,i,e,h)}fb=f+16|0;ds(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){KB(a,1-k|0,b);break a}BU(a,x[a>>2]+32|0);break a}if(x[a>>2]){DU(a);e=x[a>>2];Qo(a);Db(e);o=Ab(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=Iq(a,1);e=fb-16|0;fb=e;if(Gh(134217727)>>>0<d>>>0){cd();p()}tV(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=Ab(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;fb=e+16|0;KB(a,1,b)}fb=g+16|0}function jx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Wf(g+16|0,a,b,c,e,h-15233|0);Wm(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function Cf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];fg(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Oc(d+12|0,c,4);if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){gy(a)}a:{if(!x[a+8>>2]){break a}Oc(d+12|0,c,6);if(Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Oc(d+24|0,c,7);if(Hb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Ei(f,g,e,0)}Oc(d+12|0,c,5);c=0;b:{if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=lj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;h=sf(x[a+52>>2],g);f=x[h>>2];c:{j=x[a+40>>2];if(Rc(j,x[a+44>>2])>>>0<=f>>>0){break c}f=rl(d+12|0,vb(j,f),z[h+20>>1]);h=xy(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=sf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Ei(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=sf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function _p(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function iH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=Ds(e+28|0,b);d=x[f>>2];if(!yd(d)){x[31721]=0;b=P(37,e+4|0,b|0)|0;a=x[31721];x[31721]=0;b:{c:{d:{if((a|0)!=1){x[31721]=0;S(1019,e+16|0,17686,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}x[31721]=0;W(1347,e+16|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}Rp(d);if(!Cs(a+8|0,22250,x[f>>2])){v[a+8|0]=127}if(!Cs(a+9|0,22250,x[f>>2])){v[a+9|0]=127}x[31721]=0;O(275,a+12|0,22250);b=x[31721];x[31721]=0;e:{f:{if((b|0)==1){break f}x[31721]=0;b=a+24|0;O(275,b|0,22250);d=x[31721];x[31721]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31721]=0;O(275,a+36|0,22250);d=x[31721];x[31721]=0;if((d|0)==1){break f}x[31721]=0;O(275,a+48|0,22250);d=x[31721];x[31721]=0;if((d|0)==1){break f}x[31721]=0;b=P(73,e+16|0,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}ei(a- -64|0,c);ei(a+68|0,c);tb(b);il(f);fb=e+32|0;return}il(f);Q(a|0);p()}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Tf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=D(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=x[(a+m<<2)+k>>2];n=Ht(i);o=x[(a<<2)+j>>2]+(l<<1)|0;e=od((od(n,21)+e|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=LD(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[31721]=0;W(326,d|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[31721]=0;j=P(161,d|0,1)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31721]=0;k=P(161,d|0,1)|0;e=x[31721];x[31721]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(28832)|0;break b}a=T(28832)|0;break b}a=T(28832)|0}if((gb|0)==($(28832)|0)){Y(a|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=or(d);ub(d);fb=f+2608|0;return a|0}function Rz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Rc(d,b)>>>0<4){break b}le(c+16|0,d,b);b=Jd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=A_(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31721]=0;b=R(154,d|0)|0;f=x[31721];x[31721]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31721]=0;f=R(b|0,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Rc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31721]=0;O(e|0,a|0,-1);e=x[31721];x[31721]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31721]=0;W(b|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}x[31721]=0;g=E(xa(477,d|0));e=x[31721];x[31721]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31721]=0;wa(e|0,a|0,b|0,E(Sm(g)?g:E(0)));e=x[31721];x[31721]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function zz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=x[f>>2];c=x[a+40>>2];h:{if(Ib(e,c)){qc(d+12|0);break h}po(d,a);x[31721]=0;c=R(1064,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}x[d+12>>2]=c;lf(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=f,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((lj(f,x[e+4>>2])|0)>(b|0)){break e}}b=$b(8);x[31721]=0;c=P(37,d|0,10966)|0;a=x[31721];x[31721]=0;if((a|0)==1){break f}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;lf(d);break c}a=N()|0;ic(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;_j(b+484360|0,y[sf(f,c)+16|0]);b=sf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31721]=0;+oa(1096,a|0,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}a=N()|0}xl(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;xl(d+12|0);fb=d+16|0}function Sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;d=x[a+8>>2];h=zc(a);a:{if((d|0)!=x[h>>2]){break a}j=a+4|0;c=x[a+4>>2];e=x[a>>2];if(c>>>0>e>>>0){f=fb-16|0;fb=f;m=f+8|0;a=fb-16|0;fb=a;k=a+8|0;l=((c-e>>1)+1|0)/-2<<1;e=l+c|0;h=fb-16|0;fb=h;while(1){if((c|0)!=(d|0)){e=v$(e,c)+2|0;c=c+2|0;continue}break}x[h+12>>2]=e;Ud(k,d,h+12|0);fb=h+16|0;c=x[a+8>>2];x[a+4>>2]=x[a+12>>2];Ud(m,c,a+4|0);fb=a+16|0;fb=f+16|0;d=x[f+12>>2];x[i>>2]=d;x[j>>2]=l+x[j>>2];break a}x[g+8>>2]=d-e;x[g+28>>2]=1;d=g+8|0;c=x[$c(d,g+28|0)>>2];d=ik(d,c,c>>>2|0,x[a+16>>2]);c=zb(g+4|0,x[a+4>>2]);e=x[zb(g,x[a+8>>2])>>2];f=fb-16|0;fb=f;c=x[c>>2];x[f+12>>2]=c;e=sp(f,d+8|0,XD(c,e));c=x[e>>2];while(1){if(x[e+4>>2]!=(c|0)){k=c;c=x[f+12>>2];ej(k,y[c|0]|y[c+1|0]<<8);c=x[e>>2]+2|0;x[e>>2]=c;Od(f+12|0);continue}break}ee(e);fb=f+16|0;wc(a,d);wc(j,d+4|0);wc(i,d+8|0);wc(h,zc(d));fj(d);d=x[a+8>>2]}ej(d,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Tf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=D(b,d);n=D(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=od((x[(a+m<<2)+l>>2]+od(Ht(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a+n<<1)+k>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function Vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function II(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function gA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-16|0;fb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;ch(b,x[qd(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=Pd(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=xb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[xb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=xb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[ak(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}fb=d+16|0}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=kk(d,x[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;f=b-c|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){gc(b);fb=c+16|0}else{eu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=Ab(a);i=g+12|0;b=a;e=kk(x[a>>2],c)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=e>>>0){d=Tz(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}cd();p()}d=BQ(i,a,kk(x[b>>2],x[b+4>>2]),h);c=d;e=fb-16|0;fb=e;a=e+4|0;x[a>>2]=x[c+8>>2];h=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=h+(f<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){eu(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}ee(a);fb=e+16|0;Id(b,d);AQ(d)}fb=g+32|0;return}if(b>>>0<c>>>0){zQ(a,d+(b<<11)|0)}}function Ac(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=fb-48|0;fb=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Ii(c,c+d|0,0);x[31721]=0;U(72,f|0,c|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31721]=0;b=U(72,f|0,c|0,c+d|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break g}c=xd(b);d=zf(b);g=xd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=je(a+12|0);je(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31721]=0;c=P(73,e+24|0,b|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break f}x[31721]=0;d=P(37,e+12|0,18424)|0;a=x[31721];x[31721]=0;if((a|0)==1){break e}x[31721]=0;S(74,e+36|0,c|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}a=e+36|0;yb(b,a);tb(a);tb(d);tb(c)}fb=e+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(f);Q(a|0);p()}}function er(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=wb(x[a+484344>>2]);x[e+12>>2]=c;a=wb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[kn(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function Z1(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-48|0;fb=b;e=Fb(a);x[31721]=0;a=ca(120)|0;c=x[31721];x[31721]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[31721]=0;c=P(1,b+24|0,8963)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;a=ca(120)|0;d=x[31721];x[31721]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31721]=0;x[b+8>>2]=a;O(129,b+12|0,b+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break h}x[31721]=0;S(2,b+36|0,c|0,b+12|0);a=x[31721];x[31721]=0;if((a|0)==1){break g}d=b+36|0;a=yb(e,d);tb(d);tb(b+12|0);tb(c);x[31721]=0;c=ca(122)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}if(!c){break e}x[31721]=0;P(130,a|0,17520)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(b+12|0)}tb(c);break a}x[31721]=0;c=ca(121)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}if(!c){break d}x[31721]=0;P(130,a|0,16806)|0;a=x[31721];x[31721]=0;if((a|0)==1){break b}}fb=b+48|0;return}a=N()|0;break a}a=N()|0}tb(e);Q(a|0);p()}function xf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function hz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=De(Dg(C[(a+k<<3)+i>>3])*134217728);m=x[(a<<2)+h>>2]+(j<<2)|0,n=E(+(on(l)|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-160|0;fb=e;d=e+24|0;f=d+56|0;c=yt(f);x[d>>2]=94140;x[c>>2]=94160;x[d+56>>2]=94200;x[d>>2]=94180;i=f;f=d+4|0;ho(i,f);x[d>>2]=94140;x[c>>2]=94160;c=wt(f);x[c>>2]=93624;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[31721]=0;f=ca(107)|0;i=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}x[31721]=0;S(108,e+20|0,c+d|0,f|0);c=x[31721];x[31721]=0;if((c|0)==1){break f}Yb(e+20|0);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;pn(x[x[d>>2]-12>>2]+d|0,x[c+12>>2]);j=C[b>>3];x[31721]=0;b=Sa(1138,d|0,+j)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(1139,e+8|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}x[31721]=0;O(306,h|0,e+8|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}tb(e+8|0);Zp(b);fb=e+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(e+8|0)}Zp(d);Q(a|0);p()}Nh(a,h);tb(h);fb=g+16|0}function gz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=E(+(on(De(Dg(C[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Bg(i,b,j);m=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];cg(b,g,rf(i,k,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=j;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);_d(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=zg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,k);c=c+8|0;continue b}else{$d(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);_d(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Rs(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=kj(a)&2047;c=kj(5551115123125783e-32);if(d-c>>>0<kj(512)-c>>>0){i=d;break b}if(c>>>0>d>>>0){return a+1}if(kj(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;b=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(kj(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return As(12882297539194267e-247)}return As(3105036184601418e216)}b=C[170];e=C[169]*a+b;b=e-b;a=b*C[172]+(b*C[171]+a);b=a*a;f=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+e);j(1)|0;h=j(0)|0;c=h<<4&2032;a=f+(b+(C[c+1464>>3]+a));c=c+1472|0;g=x[c>>2];d=x[c+4>>2];c=g;g=0;c=c+g|0;d=(h<<13)+d|0;d=c>>>0<g>>>0?d+1|0:d;if(!i){c:{if(!(h&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();e=b*a;a=e+b;if(a<1){kI(EI()*22250738585072014e-324);f=a+1;a=f+(e+(b-a)+(a+(1-f)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=D(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=x[(a<<2)+i>>2]+(k<<1)|0;f=od(x[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=D(b,g);m=D(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=od(x[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a+m<<1)+j>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function xsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;kd(b,32);_o(b);f=b,g=Cb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((we((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=we((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(Bua(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=_b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=_b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=_b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+_b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Cb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Cb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=_b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=we((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){am(b,+(c|0)/96);c=we((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function i2(){var a=0,b=0,c=0,d=0;c=fb-32|0;fb=c;a:{b=Cc(c+20|0,15621);if(!Xc(x[b+4>>2],y[b+11|0])){break a}b:{if((Og(b,14624)|0)!=-1){a=Og(b,14624);x[31721]=0;V(124,c+8|0,b|0,a+1|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,16804)|0)!=-1){a=Og(b,16804);x[31721]=0;V(124,c+8|0,b|0,a+1|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13898)|0)!=-1){a=Og(b,13898);x[31721]=0;V(124,c+8|0,b|0,0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13773)|0)!=-1){a=Og(b,13773);x[31721]=0;V(124,c+8|0,b|0,0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13816)|0)!=-1){a=Og(b,13816);x[31721]=0;V(124,c+8|0,b|0,0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}x[31721]=0;a=R(125,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break a}}c=N()|0;tb(b);Q(c|0);p()}tb(b);fb=c+32|0;return a|0}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-32|0;fb=j;e=Fn(j+12|0,a);c=fb-48|0;fb=c;k=-1;a:{if(!IF(e,c+12|0)){break a}k=0;if(!NF(c+12|0)){break a}l=gf(13165);if(l){o=x[e+12>>2];b:{if(!Yl(e,y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))){break b}while(1){c:{if((y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))>>>0>n>>>0){if(hh(e,5)){break c}}f=m&1;break b}f=0;g=1;d:{if((y[c+16|0]|y[c+17|0]<<8)>>>0>=64){d=yr(e);a=d&63;h=d<<24>>24;e:{if(!(d&64)){break e}d=6;while(1){i=yr(e);a=(i&127)<<d|a;if(i<<24>>24>=0){break e}i=d>>>0<25;d=d+7|0;if(i){continue}break}}if((((h|0)<0?(a|0)<0?-2147483648:0-a|0:a)|0)<=0){break d}}while(1){d=yr(e);if(d){h=f>>>0>=l>>>0;a=h&g;if(!((g^1)&1|h)){a=(yq(d<<24>>24)&255)==y[f+13165|0]}g=a;f=f+1|0;continue}break}fd(e,4);m=(f|0)==(l|0)?g&1?1:m:m}n=n+1|0;continue}}Yl(e,o)}if(!f){break a}k=te(e,b,LF(c+12|0),0)}fb=c+48|0;fb=j+32|0;return k|0}function Qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!wi(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Gc(e,0),x[D+8>>2]=G;D=g,G=Gc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Gc(e,0);x[g>>2]=o;p=Gc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[xb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=xb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}Li(a,b,c,o,p,d)}fb=g+16|0}function fy(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=iy(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=y[(a>>2)+111712|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((y[a-1|0]&95)!=(y[c|0]&127)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function lq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Hf(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Hf(c);return}wk(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=Ce(E(Tm(a,e+1<<16>>16)/Tm(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=Ce(g,E(b>>>0));n=xb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Hf(c);return}wk(c,D(b,e));h=z[a+30>>1];j=aA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=aA(c+j<<16>>16,h);f=Tm(a,d+1<<16>>16);d=d<<16>>16;f=Ce(E(f/Tm(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=Ce(f,E(d>>>0));n=xb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Hf(a+16|0);return;default:break b}}Hf(a+16|0);x[a+36>>2]=0}}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(l,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(i<<16)|0;e=i;g=zua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-80|0;fb=e;x[e+76>>2]=c;a=pe(a,e+76|0);c=qc(a+4|0);g=qc(a+24|0);h=qc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31721]=0;O(999,a|0,d|0);f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=l;x[e+40>>2]=f;x[e+44>>2]=k;b=Jd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31721]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;S(988,e+56|0,e+16|0,e+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,e+56|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(e+56|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}Uc(e+76|0);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Qd(j);lf(i);Al(h);sh(g);rh(c);Uc(a);Uc(e+76|0);Q(d|0);p()}function ly(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Ii(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=y[a+111712|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)&(y[a-1|0]&95)!=(y[c|0]&127)){break b}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=zua(l,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=zua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=zua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Qc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function lqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;VX(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!wf(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}fb=e+16|0}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Gc(f,0);l=Gc(f,1);g=x[a+56>>2];s=Gc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Gc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=xb(j,e);n=B[xb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=xb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=xb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Li(a,b,c,s,t,d)}break}}}function yK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[We(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=$u(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(MK(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=$u(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((jt(uf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=uf(v[c+23|0]);x[a+48>>2]=d;break a}d=uf(v[c+23|0]);break a}d=-1}fb=c+32|0;return d}function IM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;no(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(b+8|0,x[zb(b+4|0,a)>>2]);c:{if(c){x[31721]=0;O(1145,a|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}DM(a,c)}c=b+8|0;Md(c);$i(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;no(b);h=mz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;no(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(b+8|0,x[zb(b+4|0,a)>>2]);f:{if(c){x[31721]=0;O(1144,a|0,c|0);g=x[31721];x[31721]=0;if((g|0)==1){break a}DM(a,c)}c=b+8|0;Md(c);$i(c);fb=b+16|0;break f}Jd(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;no(c);h=mz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;$i(b+8|0);Q(a|0);p()}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=jg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=zua(e,e>>31,m,y);i=hb;h=e;e=Xb(b,-16777216,16776704);e=zua(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=zua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Cg(a,j,q);fb=g+16|0}function Raa(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31721]=0;g=P(21,d+8|0,a|0)|0;c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Bd(y[g|0])){break d}ad(d+4|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31721]=0;c=R(1140,x[d+4>>2])|0;e=x[31721];x[31721]=0;e:{f:{if((e|0)!=1){Yb(d+4|0);e=ip(d,a);f=x[x[a>>2]-12>>2];x[31721]=0;f=a+f|0;h=R(22,f|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break f}e=x[e>>2];x[31721]=0;c=Ra(1141,c|0,e|0,f|0,h|0,+b)|0;e=x[31721];x[31721]=0;if((e|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31721]=0;O(24,a+c|0,5);c=x[31721];x[31721]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Yb(d+4|0);break e}c=T(0)|0}gm(g);break c}gm(g);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31721]=0;W(25,a+c|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Ar(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[qd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function Vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=x[b>>2];e=Ek(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){i=fb-32|0;fb=i;f=c-e|0;e=x[Ab(b)>>2];d=x[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){g=fb-16|0;fb=g;d=Tu(g+4|0,b,f);e=x[d+4>>2];f=x[d+8>>2];while(1){if((e|0)==(f|0)){gc(d);fb=g+16|0}else{rr(e);e=e+16|0;x[d+4>>2]=e;continue}break}break b}e=Ab(b);e=xV(i+12|0,yV(b,Ek(x[b>>2],d)+f|0),Ek(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=g+4|0;x[d>>2]=x[e+8>>2];j=x[e+8>>2];x[d+8>>2]=e+8;x[d+4>>2]=(f<<4)+j;f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){rr(f);f=x[d>>2]+16|0;x[d>>2]=f;continue}break}ee(d);fb=g+16|0;Id(b,e);d=x[e+4>>2];f=x[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;x[e+8>>2]=f;continue}break}d=x[e>>2];if(d){hs(e);Db(d)}}fb=i+32|0;break a}if(c>>>0<e>>>0){zV(b,d+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];ac(h+8|0,c,Ek(c,x[b+4>>2])<<4);pd(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Ag(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Bg(i,b,j);m=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];cg(b,g,rf(i,k,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=j;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){$d(f,v[x[e+12>>2]+g|0]<<6);_d(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=zg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,k);c=c+8|0;continue b}else{$d(f,v[x[e+12>>2]+g|0]<<6);_d(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Xc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Td(f,g)>>2];if(b>>>0>=2097152){x[31721]=0;O(971,d|0,63);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31721]=0;O(971,d|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31721]=0;O(971,d|0,(a|i)<<24>>24);h=x[31721];x[31721]=0;a=e;break e}x[31721]=0;a=a-1|0;O(971,d|0,v[a+(c+10|0)|0]|-128);h=x[31721];x[31721]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function CI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function GL(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){ec(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){ec(a,1);break a}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(y[125908]|y[125909]<<8|(y[125910]<<16|y[125911]<<24))){ec(a,21);break a}if(y[c+4|0]){ec(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}ec(a,21);break a}if(v[c+5|0]&1){break d}ec(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){ec(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}ec(a,1)}return 0}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=jg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=zua(e,e>>31,m,y);i=hb;h=e;e=Xb(b,-16777216,16776704);e=zua(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=zua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Qc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Cg(a,j,q);fb=g+16|0}function oV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25424|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}be(a,b,e+15|0);fb=e+16|0}function zK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[We(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=$u(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(MK(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=$u(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((jt(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}fb=c+32|0;return d}function pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function GI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;i=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(i>>>0<=b>>>0){break a}if(!c|Lj(a)>>>0>=i>>>0){break a}Qf(f+12|0,i-b&65535);k=f,l=fm(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];kY(a,d+z[oe(f+14|0,f+8|0)>>1]|0);h=f+4|0;c=x[a>>2];e=a;if(Yc(c,x[a+4>>2])>>>0<b>>>0){sg(e,b);c=x[e>>2]}a=x[zb(h,HU(wb(c),b))>>2];j=f+10|0;h=fb-32|0;fb=h;b=a;a=x[e>>2];g=(ep(b,wb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Ab(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){kp(e,a-c|0,j);b=c;if((d|0)==(g|0)){break b}}FU(e,g,d,(a<<1)+g|0);tv(g,b,((g>>>0<=j>>>0?A[e+4>>2]>j>>>0?a:0:0)<<1)+j|0);break b}b=Ab(e);b=ik(h+8|0,jk(e,Yc(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);$E(b,a,j);g=jr(e,b,g);fj(b)}zb(h+28|0,g);fb=h+32|0;if(Yc(x[e>>2],x[e+4>>2])>>>0<=i>>>0){break a}sg(e,i)}fb=f+16|0}function hE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=RU(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;xA(b+48|0,c+48|0);xA(b+68|0,c+68|0);xA(b+88|0,c+88|0);yc(b+108|0,c+108|0,448);d=b;wv(c);break b}b=iu(556);if(!b){x[e>>2]=0;break a}d=RU(b,c);x[e>>2]=d}g=a,h=z[oe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function Et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=E(x[(a+k<<2)+j>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function R0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Xc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Td(f,g)>>2];if(b>>>0>=2097152){x[31721]=0;O(51,d|0,63);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31721]=0;O(51,d|0,a&255);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31721]=0;O(51,d|0,a|i&255);h=x[31721];x[31721]=0;a=e;break e}x[31721]=0;a=a-1|0;O(51,d|0,y[a+(c+10|0)|0]|128);h=x[31721];x[31721]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function Kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;vc(b);OC(b,d+380|0,d+300|0,d+16|0);k=d,l=Zg((m=y[d+431|0]+1|0,n=1,o=_b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Sb(25152,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Cb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=_b(x[d+300>>2]);if(e>>>0<g>>>0){if(bd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!bd(b,_b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!bd(b,gp(b))){break d}e:{if(!c){j=Xd(b);break e}j=Rk(b)}w[d+10>>1]=j;k=d,l=z[oe(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=_b(x[d+300>>2]);OC(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Gw(a);break a}hY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function ira(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Dc(64);x[31721]=0;d=R(881,c|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{if((f|0)!=1){c=tf(b,d);d=x[c>>2];x[31721]=0;O(882,d|0,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}a=x[c>>2];x[31721]=0;a=U(883,a|0,b+10|0,b+4|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}d:{if(!a){qc(b+12|0);break d}a=x[c>>2];x[31721]=0;O(884,a|0,15);a=x[31721];x[31721]=0;if((a|0)==1){break c}pe(b+12|0,c)}Hg(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;Hg(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31721]=0;c=P(1,e|0,(a<<2)+30560|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;S(503,b|0,a|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}Hg(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function Gt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=E(x[(a+k<<2)+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function $A(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[(D(c,872)+b|0)+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[g+1428|0]}f=x[a+480180>>2];if(!e){h=su(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){IS(b,c,240-a|0);return}if(!(a>>>0<224|e)){HS(g,224-a|0);return}GS(g,0-a|0);return}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}YA(a,g,f);return}if(x[a+480180>>2]==524288){break d}XA(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}yk(a,g,b+1316|0,0-(e<<2)|0,0)}}function iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;UX(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!wf(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}fb=e+16|0}function tG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Wf(g+16|0,a,b,c,e,f-16129|0);Wm(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=fb-16|0;fb=h;if(wi(a+44|0)){f=x[a+44>>2];g=Gc(f,0);x[h+8>>2]=g;f=Gc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Gc(j,0);x[h>>2]=m;j=Gc(j,1);x[h+4>>2]=j;a:{if(B[xb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;yc(m,e,g);yc(j,f,g);f=x[a+56>>2];m=Gc(f,0);j=Gc(f,1)}Li(a,b,c,m,j,d)}fb=h+16|0}function aB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[(D(c,872)+b|0)+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[g+1427|0]}f=x[a+480180>>2];if(!e){h=su(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){IS(b,c,a-240|0);return}if(!(a>>>0<224|e)){HS(g,a-224|0);return}GS(g,a);return}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}ZA(a,g,f);return}if(x[a+480180>>2]==524288){break d}_A(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}yk(a,g,b+1316|0,e<<2,0)}}function DC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;h=fb-16|0;fb=h;kd(b,1);g=Cb(y[a+22|0]|y[a+23|0]<<8)<<1;x[b>>2]=g;v[b+37|0]=y[a+24|0]<<4;v[h+15|0]=y[a+25|0];v[h+14|0]=64;l=b,m=y[Sb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Cb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;k=Cb(y[a+28|0]|y[a+29|0]<<8);j=k<<1;e=k>>>0>=2?e+j>>>0<=g>>>0?e:f+j>>>0>g>>>0?e:f:e;a:{b:{switch(g|0){case 2:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=g>>>0){e=g-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=h+16|0;d=i+8|0;Wk(d,3,a);b=i+20|0;Ac(b,d);c=xc(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=FC(a);fb=i+32|0;return a}function Ana(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;lR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);lR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Lc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=y[c+d|0];j=Zb(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=Zb(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;Wk(d,3,a+4|0);c=g+20|0;Ac(c,d);xc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function rH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;vA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=wM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=xM(d,x[Jr(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function K$(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24640|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch((c&240)-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}be(a,d,e+15|0);fb=e+16|0}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=C[(a+k<<3)+j>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;ZW(a,c+11|0);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){ZW(a,c+11|0);v[b|0]=1;b=0}else{b=1}a=fb-176|0;fb=a;d=a+12|0;Dw(d,(c+11|0)+b|0);x[31721]=0;O(127,a+24|0,d|0);b=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31721]=0;b=P(106,a+36|0,a+24|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break e}tb(a+24|0);tb(a+12|0);d=x[x[b>>2]-12>>2];x[31721]=0;e=ca(107)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;S(108,a+8|0,b+d|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}Yb(a+8|0);x[31721]=0;w[a+24>>1]=0;d=P(690,b|0,a+24|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}b=qk(x[(d+x[x[d>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Bf(d);fb=a+176|0;a=(b?0:e)&65535;break a}c=N()|0;break d}c=N()|0;tb(a+24|0)}tb(a+12|0);break b}c=N()|0;Bf(b)}Q(c|0);p()}fb=c+16|0;return a|0}function Lm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Bd(y[Dm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31721]=0;c=R(86,c|0)|0;d=x[31721];x[31721]=0;d:{if((d|0)!=1){if(!kc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31721]=0;d=R(86,d|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break e}if(kc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Bm(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break f}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Qb()}p()}c=2}$j(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Fm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;vl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Em(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}ec(a,21);x[a+1396>>2]=0}return-1}_(11378,13258,1705,5445);p()}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=C[(a+k<<3)+i>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function vy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[125018];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if((j|0)!=(d|0)|!j){break g}h=h-1|0;if(!h){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function $O(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];zb(g+12|0,b);a:{b:{c:{d:{e:{if(yd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31721]=0;d=ca(71)|0;e=x[31721];x[31721]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125568)|0;if((gb|0)!=($(125568)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31721]=0;W(59,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Qb();p()}return x[a+28>>2]&f}function pq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=zua(b,d,5e4,0);f=hb;b=x[$c(c+8|0,c)>>2];b=Fc(Aua(e,f,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=zua(x[a+1074420>>2],0,zua(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=zua(b,0,6e5,0);d=c+8|0;f=b;e=hb;b=Bw(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=Bua(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=zua(b,d,1e4,0);f=hb;b=x[$c(c+8|0,c)>>2];b=Fc(Aua(e,f,b,b>>31),hb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=zua(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Fc(Aua(b,a,65536,0),hb);x[d>>2]=a>>>0<=1?1:a;fb=c+16|0}function yG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:ne(a,0,c);break a;case 1:ne(a,1,c);break a;case 2:ne(a,2,c);break a;case 3:ne(a,3,c);break a;case 4:ne(a,4,c);break a;case 5:ne(a,5,c);break a;case 6:ne(a,6,c);break a;case 7:ne(a,7,c);break a;case 8:ne(a,8,c);break a;case 9:ne(a,9,c);break a;case 10:ne(a,10,c);break a;case 11:ne(a,11,c);break a;case 12:ne(a,12,c);break a;case 13:ne(a,13,c);break a;case 14:ne(a,14,c);break a;case 15:ne(a,15,c);break a;case 16:ne(a,16,c);break a;case 17:ne(a,17,c);break a;case 18:ne(a,18,c);break a;case 19:ne(a,19,c);break a;case 20:xG(a,71440,c);break a;case 21:xG(a,72464,c);break a;case 22:ne(a,20,c);break a;case 23:ne(a,21,c);break a;case 24:ne(a,22,c);break a;case 25:ne(a,23,c);break a;case 26:ne(a,24,c);break a;case 27:ne(a,25,c);break a;case 28:ne(a,26,c);break a;default:break b}}Fb(a)}}function pE(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:qe(a,0,c);break a;case 1:qe(a,1,c);break a;case 2:qe(a,2,c);break a;case 3:qe(a,3,c);break a;case 4:qe(a,4,c);break a;case 5:qe(a,5,c);break a;case 6:qe(a,6,c);break a;case 7:qe(a,7,c);break a;case 8:qe(a,8,c);break a;case 9:qe(a,9,c);break a;case 10:qe(a,10,c);break a;case 11:qe(a,11,c);break a;case 12:qe(a,12,c);break a;case 13:qe(a,13,c);break a;case 14:qe(a,14,c);break a;case 15:qe(a,15,c);break a;case 16:qe(a,16,c);break a;case 17:qe(a,17,c);break a;case 18:qe(a,18,c);break a;case 19:qe(a,19,c);break a;case 20:oE(a,71440,c);break a;case 21:oE(a,72464,c);break a;case 22:qe(a,20,c);break a;case 23:qe(a,21,c);break a;case 24:qe(a,22,c);break a;case 25:qe(a,23,c);break a;case 26:qe(a,24,c);break a;case 27:qe(a,25,c);break a;case 28:qe(a,26,c);break a;default:break b}}Fb(a)}}function Fw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=fc(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Gb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;rF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=fc(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Gb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;qF(e,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-e^-1)}fb=a+16|0}fb=g+16|0}function rka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Bd(y[b+223884|0])){qT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Mn(b)>>>0>=c>>>0){g=x[b>>2];h=fh(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Gb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){BS(b,c-h|0,d);break a}$F(b,x[b>>2]+(c<<3)|0);break a}IT(b);XT(b,Yr(b,c));BS(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Ko((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<64){break c}x[31721]=0;c=R(187,b|0)|0;f=x[31721];x[31721]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31721]=0;P(37,a|0,22250)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}break a}x[31721]=0;c=R(205,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){g=d,h=qh(c),x[g+12>>2]=h;c=x[qd(d+16|0,d+12|0)>>2];x[31721]=0;O(117,e|0,c|0);c=x[31721];x[31721]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31721]=0;c=R(200,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break f}if(!c){break e}x[31721]=0;U(896,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[31721];x[31721]=0;if((c|0)!=1){continue}}break}break a}x[31721]=0;P(186,b|0,4)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}Zc(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=UB(c+4|0,a);Vz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=Ab(a);c=ig(h+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),c);Vz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;f=fb-16|0;fb=f;b=zb(f+12|0,x[a+4>>2]);d=zb(f+8|0,x[a>>2]);g=zb(f+4|0,x[c+4>>2]);e=x[b>>2];i=x[d>>2];b=fb-16|0;fb=b;x[b+8>>2]=x[g>>2];x[b+12>>2]=e;while(1){g=x[b+8>>2];if(Pg(e,i)){d=fb-16|0;fb=d;x[d+12>>2]=g;fY(d+12|0,-1);fb=d+16|0;Vz(x[d+12>>2],pi(e));e=FQ(b+12|0);FQ(b+8|0);e=x[e>>2];continue}break}fb=b+16|0;x[c+4>>2]=g;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),zc(c));x[c>>2]=x[c+4>>2];fb=f+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;Hg(b);continue}break}a=x[c>>2];if(a){Iz(c);Db(a)}fb=h+32|0}function pua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Cr(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=Cr(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(hw(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Sb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function VZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?((i|0)==10&y[d-1|0]==13)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}qf(a);ls(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Fp(a,e);c=c+1|0;continue}break}}function KL(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}JL(e+48|0);JL(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87584>>2];m=B[d+87620>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function FP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[xb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[xb(e,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);e=a+4272|0;c=ok(10,f*+A[xb(e,4)>>2]);g=a+4232|0;n=xb(g,0),o=E(c),B[n>>2]=o;c=ok(10,f*+A[xb(e,5)>>2]);n=xb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=ok(10,+CP(B[xb(d,0)>>2])*.05);b=4/M(c)*f;c=ok(10,+CP(B[xb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[xb(e,d)>>2];k=d>>>1|0;i=ok(10,m*+(x[xb(e,d)>>2]+x[xb(e,k+4|0)>>2]>>>0));b=ok(10,f*+(h>>>0));j=B[xb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=xb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=xb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=SI(a,0);h=fb-32|0;fb=h;c=vI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31721]=0;a=P(1356,h+12|0,b|0)|0;b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){x[31721]=0;O(1357,c|0,a|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}Fs(a);fb=h+32|0;break a}b=N()|0;break b}b=N()|0;Fs(a)}tb(l);tb(k);tb(j);a=tb(g);while(1){a=tb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=tb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=tb(d-12|0);if((i|0)!=(d|0)){continue}break}Hs(c);Q(b|0);p()}x[f+8>>2]=116588;x[f>>2]=116512;return f|0}function t4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=RI(a,0);h=fb-16|0;fb=h;c=vI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31721]=0;a=P(1358,h+4|0,b|0)|0;b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){x[31721]=0;O(1359,c|0,a|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}Is(a);fb=h+16|0;break a}b=N()|0;break b}b=N()|0;Is(a)}Rb(l);Rb(k);Rb(j);a=Rb(g);while(1){a=Rb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=Rb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=Rb(d-12|0);if((i|0)!=(d|0)){continue}break}Hs(c);Q(b|0);p()}x[f+8>>2]=116884;x[f>>2]=116808;return f|0}function gO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Lj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[Zb(x[Wb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!vn(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Vb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;NR(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;pv(b,c,g?7:1,e);j=a,k=C[HB(x[e+56>>2])>>3],C[j+16>>3]=k;Ui(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=Cf(a,c);Zd(e,x[a+36>>2]);i=a;a:{if(!c){Oc(e,a+32|0,5);d=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-32|0;fb=d;f=x[a+36>>2];lg(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){j=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;h=rc(a+4|0,15964);Zc(g,h);tb(h);fb=a+16|0;x[31721]=0;S(494,d+16|0,g|0,d+30|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}a=x[j+1298472>>2];x[31721]=0;S(389,a|0,2,d+16|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}tb(d+16|0);Eb(d+4|0);a=4e3}sg(Sj(x[b>>2],0),a);b=Sj(x[b>>2],0);k=d,l=wb(x[b>>2]),x[k+16>>2]=l;b=wb(x[b+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){a=x[d+16>>2];if(Ib(a,b)){lg(f,d+4|0);w[a>>1]=z[d+4>>1];Od(d+16|0);continue}break}fb=d+32|0;d=c}cf(i,d);fb=e+16|0}function dK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function lR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;v[k+15|0]=c;v[k+14|0]=12;ch(b,y[Sb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=Pd(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(kc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=xb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=xb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=xb(l,c);j=z[i>>1];n=xb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+38134>>1];q=w[e+38132>>1];r=w[e+38130>>1];e=w[e+38128>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;kd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41162|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function PA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Gj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!yd(f)){break a}if(!yS(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){c=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=x[(D(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=x[(D(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function S6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=oJ(c);b:{if(b){b=k+4|0;kl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jl(b,a);break b}b=k+4|0;Ns(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gi(b,a)}lh(i,b);Rb(b);l=e,m=qj(a),x[l>>2]=m;l=f,m=rj(a),x[l>>2]=m;b=k+4|0;oh(b,a);yb(g,b);tb(b);hi(b,a);lh(h,b);Rb(b);a=Lk(a);break a}a=nJ(c);c:{if(b){b=k+4|0;kl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jl(b,a);break c}b=k+4|0;Ns(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gi(b,a)}lh(i,b);Rb(b);l=e,m=qj(a),x[l>>2]=m;l=f,m=rj(a),x[l>>2]=m;b=k+4|0;oh(b,a);yb(g,b);tb(b);hi(b,a);lh(h,b);Rb(b);a=Lk(a)}x[j>>2]=a;fb=k+16|0}function Mja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=30608;a=Nb(a);a:{while(1){b:{if((e|0)==31040){e=31040;break b}c=oc(b+40|0,x[e+4>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!kc(x[a>>2],d)){c=x[c>>2];d=oc(b+32|0,x[pi(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(!mC(c,f,b+8|0)){break c}}x[31721]=0;O(892,a|0,e+4|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}}e=e+8|0;continue}break}d:{while(1){if((e|0)==31088){break d}c=oc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!kc(x[a>>2],d)){g=x[c>>2];d=oc(b+24|0,x[pi(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(!mC(g,f,b)){break f}}c=x[c>>2];x[31721]=0;x[b+20>>2]=c;O(893,a|0,b+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}fb=b+48|0;return}b=N()|0;sc(a);Q(b|0);p()}function OV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-16|0;fb=f;l=x[a+20>>2];g=z[a+34>>1]&65;x[f+12>>2]=g;x[f+8>>2]=g^65;g=b;m=d+1298224|0;e=d+1074992|0;i=Ej(d);n=a+4|0;o=a+12|0;p=a+8|0;q=a+16|0;r=d+480180|0;while(1){if((e|0)!=(m|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=g}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){uc(e+76|0,c);b=x[e+104>>2]}d=x[e+88>>2];b=BF(d,b);h=x[(b?o:n)>>2];x[e+84>>2]=x[(b?q:p)>>2];x[e+80>>2]=h;b=d|x[f+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[f+8>>2]^-1);d=x[e+704>>2];b=x[a+24>>2];a:{if(!d|!b){break a}if(qn(x[r>>2])){break a}h=zua(x[e+700>>2],0,i?b:d,0);d=i?d:b;j=h+(d>>>1|0)|0;k=hb;s=e,t=Bc(Bua(j,h>>>0>j>>>0?k+1|0:k,d,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=g;NB(l);fb=f+16|0}function W6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=sJ(c);b:{if(b){b=k+4|0;kl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jl(b,a);break b}b=k+4|0;Ns(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gi(b,a)}yb(i,b);tb(b);l=e,m=qj(a),v[l|0]=m;l=f,m=rj(a),v[l|0]=m;b=k+4|0;oh(b,a);yb(g,b);tb(b);hi(b,a);yb(h,b);tb(b);a=Lk(a);break a}a=rJ(c);c:{if(b){b=k+4|0;kl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;jl(b,a);break c}b=k+4|0;Ns(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;gi(b,a)}yb(i,b);tb(b);l=e,m=qj(a),v[l|0]=m;l=f,m=rj(a),v[l|0]=m;b=k+4|0;oh(b,a);yb(g,b);tb(b);hi(b,a);yb(h,b);tb(b);a=Lk(a)}x[j>>2]=a;fb=k+16|0}function fka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Tb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=DV(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=UA(c+223860|0);f=b+8|0;Tb(f,0,108);ZB(b+120|0,48e3);Tb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Tb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=tq(e,f)+872|0;continue}break}x[31721]=0;O(556,d|0,32);a=x[31721];x[31721]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;uq(g);cc(d);Q(a|0);p()}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31721]=0;W(1005,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}x[31721]=0;W(1005,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31721]=0;d=P(37,e+20|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break g}x[31721]=0;c=P(37,e+8|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break f}x[31721]=0;V(1020,f|0,d|0,c|0,1);b=x[31721];x[31721]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31721]=0;V(991,6409,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;x[31721]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=R(1157,d+32|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){a:{b:{if(e){x[31721]=0;O(1158,d+72|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=d+80|0;yp(b,x[d+72>>2],x[d+76>>2]);e=Af(d+88|0,b);f=Af(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;zp(a,d+8|0,d);break b}break a}x[31721]=0;O(1159,d+72|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=d+80|0;yp(b,x[d+72>>2],x[d+76>>2]);e=Af(d+56|0,b);f=Af(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;zp(a,d+24|0,d+16|0)}he(b);he(d+72|0);he(c);fb=d+96|0;return}}a=N()|0;he(c);Q(a|0);p()}function Rn(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31721]=0;O(d|0,f+4|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Rd(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=$b(8);x[31721]=0;b=P(1059,d|0,7429)|0;e=x[31721];x[31721]=0;if((e|0)==1){break g}x[31721]=0;S(100,b|0,125344,165);b=x[31721];x[31721]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=wg(22250);break j}b=wg(Jb(Dd(d,b)))}Qd(f+4|0);break d}b=T(0)|0;ic(d)}Qd(f+4|0)}Y(b|0)|0;b=0;x[31721]=0;V(991,c|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break a}T(0)|0;Qb()}p()}Q(a|0);p()}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Mi(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45196;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=xb(a,0),g=1063675494,x[f>>2]=g;f=xb(a,1),g=1065185444,x[f>>2]=g;f=xb(a,2),g=0,x[f>>2]=g;f=xb(a,3),g=1032805417,x[f>>2]=g;f=xb(a,4),g=1053079357,x[f>>2]=g;f=xb(a,5),g=1059859440,x[f>>2]=g;f=xb(a,6),g=1047457519,x[f>>2]=g;f=xb(a,7),g=1062836634,x[f>>2]=g;f=xb(a,8),g=1038174126,x[f>>2]=g;f=xb(a,9),g=1065353216,x[f>>2]=g;f=xb(a,10),g=1065353216,x[f>>2]=g;f=xb(a,11),g=1048525618,x[f>>2]=g;f=xb(a,12),g=1059760811,x[f>>2]=g;x[31721]=0;O(949,b+44|0,2);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;while(1){c=sc(c-24|0);if((e|0)!=(c|0)){continue}break}Vf(b);Q(a|0);p()}return b|0}function a3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=Nb(a);a=0;a:{b:{c:{while(1){if((Bx(b,c,a)|0)==-1){break b}f=Bx(b,c,a);x[31721]=0;V(103,d+4|0,b|0,a|0,f-a|0);f=x[31721];x[31721]=0;if((f|0)!=1){x[31721]=0;O(104,e|0,d+4|0);f=x[31721];x[31721]=0;if((f|0)==1){break c}tb(d+4|0);a=Bx(b,c,a)+Xc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(kc(x[e>>2],x[e+4>>2])){x[31721]=0;V(103,d+4|0,b|0,a|0,-1);c=x[31721];x[31721]=0;if((c|0)==1){break f}c=Xc(x[d+8>>2],y[d+15|0]);tb(d+4|0);if(!c){break g}}x[31721]=0;V(103,d+4|0,b|0,a|0,-1);a=x[31721];x[31721]=0;if((a|0)==1){break e}x[31721]=0;O(104,e|0,d+4|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}tb(d+4|0)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Qd(e);Q(a|0);p()}function SJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[31596];x[31596]=0;g=fb-16|0;fb=g;Kd();e=fb-16|0;fb=e;f=fb-16|0;fb=f;sy(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;fb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;fb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;fb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[31596];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[31596]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;fb=h+32|0}function Fq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;a:{g=x[a>>2];e=x[a+4>>2];if(kc(g,e)){break a}i=Pd(g,e)-1|0;while(1){b:{c:{if(Pd(g,e)-1>>>0<=f>>>0){f=i;break c}if(z[Mc(g,e,f)>>1]<(b|0)){break b}e=x[a+4>>2];g=x[a>>2]}i=z[Mc(g,e,f)>>1];g=0;x[h+12>>2]=0;d:{if((b|0)>=(i|0)){j=h,k=(y[Mc(x[a>>2],x[a+4>>2],f)+2|0]<<16>>>0)/(d>>>0)|0,x[j+12>>2]=k;break d}e=0;if(f){e=f-1|0;g=(y[Mc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=g;e=z[Mc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break d}a=((y[Mc(x[a>>2],x[a+4>>2],f)+2|0]<<16>>>0)/(d>>>0)|0)-g|0;d=a;f=a>>31;a=b-e|0;b=zua(d,f,a,a>>31);a=i-e|0;j=h,k=Fc(Aua(b,hb,a,a>>31),hb)+g|0,x[j+12>>2]=k}Ee(h+12|0,0,65536);f=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}f=f+1|0;e=x[a+4>>2];g=x[a>>2];continue}}fb=h+16|0;return f}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38134>>1];q=w[e+38132>>1];r=w[e+38130>>1];e=w[e+38128>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function dr(a,b){var c=0;c=fb-16|0;fb=c;a=Sr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:BA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Zf(a,107);break a;case 3:BA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Zf(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}BA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((kk(x[a>>2],x[a+4>>2])|0)==2){if((kk(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31721]=0;O(951,a|0,2);c=x[31721];x[31721]=0;c:{if((c|0)==1){break c}x[31721]=0;O(951,a+12|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;O(952,a+24|0,2);c=x[31721];x[31721]=0;if((c|0)==1){break c}x[31721]=0;O(952,a+36|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Or(x[c+12>>2],a);f=xb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=Or(x[a>>2],d);f=xb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;Uz(a);DQ(a);b=a+12|0;Uz(b);DQ(b);b=a+24|0;Hf(b);CQ(b);a=a+36|0;Hf(a);CQ(a);Z()}return}Q(b|0);p()}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;j=c,k=hf(a)>>>5|0,w[j+32>>1]=k;w[c+20>>1]=3999;i=b+480190|0;d=z[Lc(c+32|0,c+20|0)>>1];w[i>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=qi(b,f);e=c+32|0;lr(a,e);kd(d,0);h=c+8|0;si(h,2,e);e=c+20|0;Ac(e,h);xc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;j=c,k=Cb(y[c+60|0]|y[c+61|0]<<8),w[j+20>>1]=k;w[c+8>>1]=64;j=d,k=z[Lc(e,h)>>1]<<2,w[j+30>>1]=k;j=d,k=_b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[j>>2]=k;e=Cb(y[c+62|0]|y[c+63|0]<<8);j=xb(d+68|0,0),k=e,x[j>>2]=k;e=Cb(y[c+56|0]|y[c+57|0]<<8);f=Cb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[i>>1];continue}break}fb=c- -64|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;k=Cf(a,c);Zd(f,x[a+36>>2]);l=a;a:{if(!k){Oc(f,a+32|0,5);c=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;i=x[a+36>>2];nl(i,e+40|0);g=x[e+44>>2];if(!g&A[e+40>>2]>=257|g){x[e+40>>2]=256;x[e+44>>2]=0}g=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=g>>>0){break b}lg(i,e+38|0);h=Fb(e+24|0);x[31721]=0;P(502,i|0,h|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;S(500,e+12|0,d|0,h|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}x[31721]=0;a=P(939,b|0,e+38|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break d}j=a;a=e+12|0;yb(j,a);tb(a);tb(h);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(h);Q(c|0);p()}fb=e+48|0;c=k}cf(l,c);fb=f+16|0}function vd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=Ay(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function Oha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(kk(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=Or(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;uc(c+8|0,512);e=c+16|0;FA(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Lz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Lz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=pe(a,e+60|0);c=qc(a+4|0);g=qc(a+24|0);h=qc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31721]=0;O(999,a|0,d|0);f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){le(e+24|0,x[b>>2],x[b+4>>2]);jf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Jd(e+16|0);x[31721]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ys(1003,e+40|0,x[e+32>>2],x[e+36>>2],e+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,e+40|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(e+40|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Qd(j);lf(i);Al(h);sh(g);rh(c);Uc(a);Uc(e+60|0);Q(d|0);p()}Uc(e+60|0);fb=e- -64|0;return a|0}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=Tu(d+4|0,a,1);pz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;gc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=xV(h+12|0,yV(a,Ek(x[a>>2],x[a+4>>2])+1|0),Ek(x[a>>2],x[a+4>>2]),d);pz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){pz(TM(b),f-16|0);b=qz(e+12|0);qz(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),zc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;b=x[c+4>>2];while(1){a=x[c+8>>2];if((a|0)!=(b|0)){a=a-16|0;x[c+8>>2]=a;Ik(a);continue}break}a=x[c>>2];if(a){hs(c);Db(a)}fb=h+32|0}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(wi(a+44|0)){g=x[a+44>>2];r=h,s=Gc(g,0),x[r+8>>2]=s;r=h,s=Gc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Gc(g,0);x[h>>2]=l;m=Gc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=VP(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Li(a,b,c,l,m,d)}break}}fb=h+16|0}function Rca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=pe(a,f+60|0);d=qc(a+4|0);g=qc(a+24|0);h=qc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31721]=0;O(999,a|0,e|0);k=x[31721];x[31721]=0;a:{b:{c:{d:{if((k|0)!=1){ac(f+24|0,b,c);jf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Jd(f+16|0);x[31721]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;ys(1003,f+40|0,x[f+32>>2],x[f+36>>2],f+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,f+40|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(f+40|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Qd(j);lf(i);Al(h);sh(g);rh(d);Uc(a);Uc(f+60|0);Q(e|0);p()}Uc(f+60|0);fb=f- -64|0;return a|0}function zo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=dd(Fq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[xb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function HQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(nc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Dc(64);x[31721]=0;g=R(881,f|0)|0;h=x[31721];x[31721]=0;a:{b:{if((h|0)!=1){f=tf(d+8|0,g);g=x[f>>2];x[31721]=0;g=U(946,g|0,b|0,c|0)|0;h=x[31721];x[31721]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}qc(d+12|0);break c}a=N()|0;Hg(f);break b}pe(d+12|0,f)}Hg(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!yd(d)){x[31721]=0;b=P(944,b|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;cZ(e+12|0,ie(b));Hg(b);d=x[e+12>>2]}if(!yd(d)){break e}x[31721]=0;O(504,a|0,e+12|0);a=x[31721];x[31721]=0;i=d;if((a|0)!=1){break e}}a=N()|0;Hg(e+12|0);Q(a|0);p()}Hg(e+12|0)}fb=e+16|0;return i}function jq(a){var b=E(0),c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Bi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Bi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Ci(f+1.5707963267948966);break a}b=Ci(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Bi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Ci(-4.71238898038469-+a);break a}b=Ci(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Oy(a,c+8|0)&3){case 0:b=Bi(C[c+8>>3]);break a;case 1:b=Ci(-C[c+8>>3]);break a;case 2:b=E(-Bi(C[c+8>>3]));break a;default:break b}}b=Ci(C[c+8>>3])}a=b;fb=c+16|0;return a}function DH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31721]=0;W(c|0,d+8|0);c=x[31721];x[31721]=0;d:{e:{if((c|0)!=1){h=d,i=wb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=wb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=wg(Jb(e));Qd(d+8|0);tb(e);break b}if(!f){x[31721]=0;P(993,e|0,14599)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31721]=0;P(844,e|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}Uq(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Qd(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31721]=0;V(991,b|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){T(0)|0;Qb();p()}Q(a|0);p()}function zM(a,b){var c=0,d=0,e=0;x[a+4>>2]=b;x[a>>2]=126928;x[a+8>>2]=b;e=(b|0)!=0;x[a+12>>2]=e;c=b&31;if((b&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;c=c&65536;x[a+28>>2]=c;d=c^65536;a:{if((c|0)==(d|0)|c>>>0>d>>>0){c=b;break a}c=b>>>e|0;x[a+8>>2]=c;e=b?2:1;x[a+12>>2]=e;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}x[a+24>>2]=0;x[a+28>>2]=d&65536}x[a+16>>2]=e-((b>>>0)%(e>>>0)|0);d=63-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+48>>2]=b;x[a+52>>2]=d;d=64-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+40>>2]=c?b:0;x[a+44>>2]=c?d:0;c=c+1|0;b=c&31;if((c&63)>>>0>=32){c=-1<<b}else{c=(1<<b)-1&-1>>>32-b|-1<<b}x[a+32>>2]=0;x[a+36>>2]=c&65536;return a}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Bd(y[Dm(c+27|0,a,0)|0])){ad(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31721]=0;e=R(1183,x[c+16>>2])|0;d=x[31721];x[31721]=0;a:{b:{if((d|0)!=1){d=ip(c+12|0,a);f=qc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31721]=0;ja(1185,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31721];x[31721]=0;if((e|0)!=1){break b}}b=T(0)|0;Yb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Bm(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Qb()}p()}Yb(c+16|0);x[b>>2]=x[c+20>>2]}$j(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function aF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31721]=0;f=P(21,e+8|0,a|0)|0;d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Bd(y[f|0])){break e}g=ip(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31721]=0;i=R(22,d|0)|0;j=x[31721];x[31721]=0;if((j|0)==1){break d}g=x[g>>2];x[31721]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31721]=0;O(24,a+b|0,5);b=x[31721];x[31721]=0;if((b|0)!=1){break e}break d}gm(f);break b}b=T(0)|0;gm(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31721]=0;W(25,a+b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){T(0)|0;Qb();p()}Q(a|0);p()}function uP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31721]=0;a=P(984,(d?d:985)|0,e|0)|0;b=x[31721];x[31721]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=x[pe(j+28|0,j+24|0)>>2];b=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=b;x[31721]=0;b=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=b;c=+pa(986,j+8|0,+c,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}Uc(j+24|0);break b}a=T(0)|0;break c}a=T(0)|0;Uc(j+24|0)}Y(a|0)|0;x[31721]=0;ga(987,15038,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=QM(),x[j+12>>2]=k;g=a+24|0;c=d+12|0;OM(g,ie(c));sh(c);w[a+28>>1]=0;EP();f=fb-16|0;fb=f;e=Dc(144);x[31721]=0;h=P(1136,e|0,4)|0;i=x[31721];x[31721]=0;a:{if((i|0)!=1){e=x[tf(f+12|0,h)>>2];fb=f+16|0;break a}a=N()|0;Db(e);Q(a|0);p()}x[d+12>>2]=e;NM(a+32|0,ie(c));Al(c);j=d,k=PM(x[a>>2]),x[j+12>>2]=k;MM(a+4|0,ie(c));rh(c);oo(x[g>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;j=d,k=Xi(x[b>>2]),x[j+12>>2]=k;e=Kf(b);b:{while(1){b=x[d+12>>2];if(!Vg(b,e)){break b}c=rd(b);b=gg(d,c);x[31721]=0;V(1020,a|0,b|0,c+12|0,0);c=x[31721];x[31721]=0;if((c|0)!=1){tb(b);Yg(d+12|0);continue}break}a=N()|0;tb(b);Q(a|0);p()}fb=d+16|0}function e1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;bd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31721]=0;O(182,h|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31721]=0;e=U(153,f|0,e|0,4)|0;f=x[31721];x[31721]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31721]=0;e=P(183,b|0,e|0)|0;f=x[31721];x[31721]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Rd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31721]=0;O(184,h|0,g+12|0);e=x[31721];x[31721]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;sc(h);Q(a|0);p()}function L3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;Tb(d+116|0,0,44);while(1){if((c|0)==7){a:{c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14273,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+172|0,e);fa(e|0,100,13333,f|0,x[a>>2])|0;id(g+316|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14286,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+4|0,e);fa(e|0,100,13540,f|0,x[a>>2])|0;id(g+88|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+472|0,c);c=d+4|0;Es(c,a,99,b);yb(a+484|0,c);tb(c);Es(c,a,114,b);yb(a+496|0,c);tb(c);Es(c,a,120,b);yb(a+508|0,c);tb(d+4|0);Es(c,a,88,b);yb(a+520|0,c);tb(d+4|0);fb=d+160|0}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];l=y[b+4244|0];k=b+4208|0;Uj(k,33);d=x[k>>2];v[d+32|0]=l;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;le(c+8|0,x[k>>2],x[b+4212>>2]);fc(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function YP(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Ci(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Bi(d+1.5707963267948966));break a}a=Bi(d+-1.5707963267948966);break a}a=Ci(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Bi(d+4.71238898038469);break a}a=E(-Bi(d+-4.71238898038469));break a}a=Ci(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Oy(a,b+8|0)&3){case 0:a=Ci(C[b+8>>3]);break a;case 1:a=Bi(C[b+8>>3]);break a;case 2:a=Ci(-C[b+8>>3]);break a;default:break b}}a=E(-Bi(C[b+8>>3]))}fb=b+16|0;return a}function kqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;VX(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!wf(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function JL(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-80|0;fb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Jd(c+72|0);e=b-d|0;g=Ru(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){Nq(c+60|0,x[a>>2],d);fc(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=No(c+60|0);x[31721]=0;b=P(763,a|0,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}x[31721]=0;O(764,d|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;fn(c+44|0,x[a>>2]);Nq(c+32|0,x[a>>2],x[a+4>>2]);fn(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;TW(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);fc(f,x[c+52>>2],x[c+56>>2]);VB(a,d);yf(d)}a=fc(c+16|0,x[f>>2],x[f+4>>2]);Fw(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}fb=c+80|0;return}a=N()|0;yf(d);Q(a|0);p()}function eB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Ob(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function ns(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Bd(y[Dm(d+27|0,a,0)|0])){ad(d+20|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31721]=0;g=R(1183,x[d+20>>2])|0;e=x[31721];x[31721]=0;d:{e:{if((e|0)==1){break e}e=ip(d+16|0,a);f=qc(d+12|0);h=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31721]=0;ja(c|0,g|0,e|0,f|0,a+h|0,d+28|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break e}Yb(d+20|0);break d}b=T(0)|0;Yb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Bm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Qb()}p()}return a}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=Nf(x[x[a+48>>2]+12>>2]);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Kk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=wb(x[a>>2]);a=wb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=gu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;qg(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=mZ(e+20|0,c,e+12|0);cR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=Ab(c);g=Ab(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Ok(c);x[a+12>>2]=b}fb=e+32|0}function EX(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Cb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=wC(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Ft(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function FE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=x[b>>2];d=Yc(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=x[Ab(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=fb-16|0;fb=f;e=vi(f+4|0,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){gc(e);fb=f+16|0}else{jp(d);d=d+2|0;x[e+4>>2]=d;continue}break}break b}f=Ab(b);e=ik(i+12|0,jk(b,Yc(x[b>>2],e)+d|0),Yc(x[b>>2],x[b+4>>2]),f);h=fb-16|0;fb=h;d=sp(h+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){jp(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}ee(d);fb=h+16|0;Id(b,e);fj(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){yn(b,e+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){d=x[b>>2];ac(g+8|0,d,Yc(d,x[b+4>>2])<<1);pd(g,a,x[g+8>>2],x[g+12>>2])}fb=g+16|0;return c|0}function Ao(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!Ge(i,x[a+484348>>2],b)){break a}g=Vb(i,b);k=x[g+48>>2];b=jd(x[g>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Gb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(Nf(x[k+12>>2]),6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function BB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;i=Pl(a,b);a:{if((i|0)==255){break a}if(Ak(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}g=c;f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=20-f|0;j=c&31;if((c&63)>>>0>=32){c=g<<j;g=0}else{c=(1<<j)-1&g>>>32-j;g=g<<j}g=g+24858e3|0;if(g>>>0<24858e3){c=c+1|0}c=Bc(Bua(g,c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Lc(h+14|0,h+12|0)>>1]}g=Nu(i);e=a+8|0;k=vb(e,i),l=(f<<10|c)>>>8|(d?0:32),v[k|0]=l;wh(x[a>>2],x[a+4>>2],b,g|160,c&255);c=vb(e,i);wh(x[a>>2],x[a+4>>2],b,g|176,y[c|0]);v[a+534|0]=1}fb=h+16|0}function NZ(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=xd(b);x[e+12>>2]=a;f=zf(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31721]=0;O(36,d|0,65533);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31721]=0;O(36,d|0,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31721]=0;O(36,d|0,65533);g=x[31721];x[31721]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31721]=0;O(36,d|0,c|0);a=x[31721];x[31721]=0;c=0;if((a|0)==1){break a}}a=x[je(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Rb(d);Q(a|0);p()}function jqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;UX(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!wf(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Bl(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}ER(d,1);break a}f=e+8|0;yc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];Mt(f,x[e+40>>2]);Io(f,c);wA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=Dj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=Dj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function uk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-32|0;fb=b;a:{b:{while(1){f=(b+8|0)+(d<<2)|0;e=1<<d&2147483647;if(e|1){e=pK(d,e?a:22250)}else{e=x[d<<2>>2]}x[f>>2]=e;if((e|0)==-1){break b}d=d+1|0;if((d|0)!=6){continue}break}if(!oK(0)){c=121468;if(!hd(b+8|0,121468,24)){break a}c=121492;if(!hd(b+8|0,121492,24)){break a}d=0;if(!y[500128]){while(1){g=(d<<2)+500080|0,h=pK(d,22250),x[g>>2]=h;d=d+1|0;if((d|0)!=6){continue}break}v[500128]=1;x[125026]=x[125020]}c=500080;if(!hd(b+8|0,500080,24)){break a}c=500104;if(!hd(b+8|0,500104,24)){break a}c=Ed(24);if(!c){break b}}a=x[b+12>>2];x[c>>2]=x[b+8>>2];x[c+4>>2]=a;a=x[b+28>>2];x[c+16>>2]=x[b+24>>2];x[c+20>>2]=a;a=x[b+20>>2];x[c+8>>2]=x[b+16>>2];x[c+12>>2]=a;break a}c=0}fb=b+32|0;return c}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=x[b>>2];d=Gg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=x[Ab(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=fb-16|0;fb=f;e=WB(f+4|0,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){gc(e);fb=f+16|0}else{rV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}f=Ab(b);e=Su(i+12|0,Iq(b,Gg(x[b>>2],e)+d|0),Gg(x[b>>2],x[b+4>>2]),f);h=fb-16|0;fb=h;d=sV(h+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){rV(f);f=x[d>>2]+32|0;x[d>>2]=f;continue}break}ee(d);fb=h+16|0;Id(b,e);uV(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){GX(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];ac(g+8|0,c,Gg(c,x[b+4>>2])<<5);pd(g,a,x[g+8>>2],x[g+12>>2])}fb=g+16|0}function UR(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:oq(a,E(1));xk(a,E(3.725290298461914e-9));nq(a,E(268435456));mq(a,0);break b;case 1:oq(a,E(32));xk(a,E(4.656612873077393e-10));nq(a,E(2147483648));mq(a,0);break b;case 2:oq(a,E(2));xk(a,E(7.450580596923828e-9));nq(a,E(134217728));mq(a,1);break b;default:oq(a,E(1));xk(a,E(7.450580596923828e-9));nq(a,E(134217728));mq(a,1);qA(a,0);pA(a,1);oA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}oq(a,E(.75));xk(a,E(7.450580596923828e-9));nq(a,E(134217728));mq(a,1);qA(a,0);b=(b|0)==4;pA(a,b?2:3);oA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}qA(a,1);pA(a,0);oA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function hL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function NX(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){sg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(gh(x[a>>2])&-2)){break c}bd(a,c+(f<<10)|0);if(!BC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((gh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}bd(a,c+D(f,z[e>>1])|0);h=BC(a,64,1)?h:k}bd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(gh(x[a>>2])|0)){break d}}if(c>>>0>=255){AC(b,254,65534);AC(b,255,65535)}l=h}a=l&65535}else{j=z[Zb(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function L2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;Xk(b,a);x[31721]=0;O(105,c+24|0,b|0);a=x[31721];x[31721]=0;a:{b:{c:{d:{if((a|0)!=1){x[31721]=0;a=P(106,c+36|0,c+24|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break d}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31721]=0;d=ca(107)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;S(108,c+8|0,a+b|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}Yb(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31721]=0;b=P(109,a|0,c+24|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}a=qk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Bf(b);fb=c+176|0;return(a?0:d)|0}b=N()|0;break c}b=N()|0;tb(c+24|0)}tb(c+12|0);break a}b=N()|0;Bf(a)}Q(b|0);p()}function Yp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}f=1072693248;g=-1023;if((b|0)!=1072693248){f=b;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;f=b;g=-1077}b=f+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function RS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!rA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Fq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=wq(a,b,!(x[b+88>>2]&32768),d);break a}if(Oj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=dd(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Ej(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;xi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36576:35552)|0;break b}xi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35552:36576)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Fc(Aua(zua(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(gq(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=zb(h+12|0,Ne(Ne(xd(b),e),1));d=zb(h+8|0,zf(b));Lr(b,x[c>>2],x[d>>2]);break c}if(!Xc(x[b+4>>2],y[b+11|0])){break c}f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=v[d|0];d=d+1|0;if(!kc(v[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}Zc(a,b)}fb=h+16|0}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=zc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Nv(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[$c(d,g+28|0)>>2];c=ig(d,c,c>>>2|0,x[a+16>>2]);e=zb(g+4|0,x[a+4>>2]);f=x[zb(g,x[a+8>>2])>>2];d=fb-16|0;fb=d;e=x[e>>2];x[d+12>>2]=e;e=Bn(d,c+8|0,vv(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];Wo(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Pe(d+12|0);continue}break}ee(e);fb=d+16|0;wc(a,c);wc(i,c+4|0);wc(h,c+8|0);wc(j,zc(c));hg(c);c=x[a+8>>2]}Wo(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(nu(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=zb(h+12|0,Ne(Ne(xd(b),e),1));d=zb(h+8|0,zf(b));Lr(b,x[c>>2],x[d>>2]);break c}if(!Xc(x[b+4>>2],y[b+11|0])){break c}f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=y[d|0];d=d+1|0;if(!kc(y[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}Zc(a,b)}fb=h+16|0}function vK(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Sd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Sd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Sd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Sd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Sd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;f=b;g=a;d=ae(a);a:{if(d){b=dc(g);while(1){a=d;d=a+13|0;if(Yu(f,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Yu(d,f)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=dc(g);b=a}x[c+12>>2]=a;d=b;b=x[b>>2];if(!b){f=fb-16|0;fb=f;a=dc(g);h=zh(c,Dc(20),Jg(f+8|0,a));b=x[h>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=dc(h),j=1,v[i+4|0]=j;fb=f+16|0;Xg(g,x[c+12>>2],d,x[c>>2]);b=ie(c);a=x[c>>2];x[c>>2]=0;if(a){dc(c);Db(a)}h=1}Wg(e+8|0,x[zb(c,b)>>2],h);fb=c+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Oy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=mL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function Opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;d=-1;a:{if(!hh(a,1468)){break a}Yl(a,1464);c=b+524|0;RX(a,c);if(!me(c,25236)){d=0;if(!me(b+524|0,15569)){break a}}Yl(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}d=OX(a,b);if(!d){AX(b)}if(d){c=c+1|0;e=FC(b)+e|0;continue}break}d=-1;break a}d=0;if(e>>>0>40){break a}e=b+522|0;c=fb-16|0;fb=c;c:{if(!hh(a,2)){v[c|0]=0;bF(e,c);break c}tp(c+8|0,e);EC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}e=Hc(b+522|0);c=fb-16|0;fb=c;d:{if(!hh(a,512)){zX(b);break d}dE(c+8|0,b);EC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;d=1;a=y[e|0];while(1){if((c|0)==512){break a}e=b+c|0;c=c+1|0;if(a>>>0>=y[e|0]){continue}break}d=0}fb=b+528|0;return d|0}function GC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;ch(b,y[Sb(f+15|0,f+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[((d|0)==4?a+2|0:a+3|0)|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];h=x[b>>2];e=Pd(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(e|0)){i=xb(h,b);g=(b<<2)+a|0;d=y[g+6|0]|y[g+7|0]<<8;w[i>>1]=d;a:{if(!b){break a}j=d;d=z[xb(h,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[i>>1]=d+1}k=i,l=Xb((y[g+8|0]|y[g+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=f+16|0}function uH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=pe(a,f+44|0);c=qc(a+4|0);h=qc(a+24|0);i=qc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31721]=0;O(999,a|0,d|0);g=x[31721];x[31721]=0;a:{b:{c:{d:{if((g|0)!=1){le(f+16|0,x[b>>2],x[b+4>>2]);b=Jd(f+8|0);x[31721]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;ys(e,f+24|0,x[f+16>>2],x[f+20>>2],f);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,f+24|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(f+24|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Qd(k);lf(j);Al(i);sh(h);rh(c);Uc(a);Uc(f+44|0);Q(d|0);p()}Uc(f+44|0);fb=f+48|0;return a}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;x[31721]=0;e=R(1161,b|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){a:{b:{if(e){x[31721]=0;O(1162,d+56|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=d- -64|0;yp(b,x[d+56>>2],x[d+60>>2]);e=Af(d+72|0,b);f=Af(d+48|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;zp(a,d+8|0,d);break b}break a}x[31721]=0;O(1163,d+56|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}b=d- -64|0;yp(b,x[d+56>>2],x[d+60>>2]);e=Af(d+40|0,b);f=Af(d+32|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;zp(a,d+24|0,d+16|0)}he(b);he(d+56|0);he(c);fb=d+80|0;return}}a=N()|0;he(c);Q(a|0);p()}function kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;c=Cf(a,c);Zd(f,x[a+36>>2]);i=a;a:{if(!c){Oc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;aN(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Sb(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Hi(g,a+4|0);if((d|0)==1){break b}Hi(g,a);if(d>>>0<3){break b}Hi(g,a+10|0);h=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|h)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;RB(b,x[Gb(a+4|0,a)>>2]);e=0;while(1){h=Bb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Lm(g,d-h|0)}fb=a+16|0}else{zj(g,bc(b,e),1);e=e+1|0;continue}break}d=c}cf(i,d);fb=f+16|0}function qH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;vA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=wM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=xM(d,x[Jr(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function BX(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}yC(c+8|0,b);pd(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function px(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31721]=0;O(117,d|0,Xc(e,a)|0);a=x[31721];x[31721]=0;if((a|0)!=1){a:{while(1){if(Xc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Td(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[31721]=0;O(118,d|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31721]=0;O(118,d|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}x[31721]=0;O(118,d|0,63);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;a=x[a+4>>2];Zw(d+16|0,b);x[31721]=0;b=P(1,d+4|0,18377)|0;e=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31721]=0;S(2,d+28|0,d+16|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break h}x[31721]=0;S(493,d+40|0,d+28|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break g}x[31721]=0;O(1067,d+52|0,d+40|0);c=x[31721];x[31721]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[31721]=0;O(c|0,a|0,d+52|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}tb(d+52|0);tb(d+40|0);tb(d+28|0);tb(b);tb(d+16|0);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;kd(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Sb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Mk(e,2,b+1|0);Ac(d,e);ye(c+43|0,d);tb(d);d=Wc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}ed(d,16);tg(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function LZ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-176|0;fb=b;c=b+12|0;Pf(c,a);x[31721]=0;O(127,b+24|0,c|0);a=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31721]=0;a=P(106,b+36|0,b+24|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break e}tb(b+24|0);tb(b+12|0);c=x[x[a>>2]-12>>2];x[31721]=0;d=ca(107)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}x[31721]=0;S(108,b+8|0,a+c|0,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}Yb(b+8|0);x[31721]=0;x[b+24>>2]=0;x[b+28>>2]=0;c=P(413,a|0,b+24|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}a=qk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);e=C[b+24>>3];Bf(c);fb=b+176|0;e=a?0:e;break a}c=N()|0;break d}c=N()|0;tb(b+24|0)}tb(b+12|0);break b}c=N()|0;Bf(a)}Q(c|0);p()}return+e}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Rm(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;fg(d,e);a:{b:{if(Bd(y[Dm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31721]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(945,c+40|0,d|0,c+8|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){b=di(c+24|0,-1,-1);b=Vn(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Bm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Qb()}p()}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=pe(a,e+44|0);f=qc(a+4|0);g=qc(a+24|0);h=qc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31721]=0;O(999,a|0,d|0);c=x[31721];x[31721]=0;a:{b:{c:{d:{if((c|0)!=1){c=Jd(e+16|0);x[31721]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;S(1123,e+24|0,b|0,e+8|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,e+24|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(e+24|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Qd(j);lf(i);Al(h);sh(g);rh(f);Uc(a);Uc(e+44|0);Q(d|0);p()}Uc(e+44|0);fb=e+48|0;return a|0}function Mh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=IP(a);h=a+4208|0;c=E(E(B[xb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=Ce(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[xb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(Ce(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-jq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!Sm(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=Xf(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+38134>>1];o=w[e+38132>>1];p=w[e+38130>>1];e=w[e+38128>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function IH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=pe(a,g+44|0);d=qc(a+4|0);h=qc(a+24|0);i=qc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31721]=0;O(999,a|0,e|0);l=x[31721];x[31721]=0;a:{b:{c:{d:{if((l|0)!=1){ac(g+16|0,b,c);b=Jd(g+8|0);x[31721]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;ys(f,g+24|0,x[g+16>>2],x[g+20>>2],g);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(1e3,a|0,g+24|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}ub(g+24|0);x[31721]=0;W(1001,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Qd(k);lf(j);Al(i);sh(h);rh(d);Uc(a);Uc(g+44|0);Q(e|0);p()}Uc(g+44|0);fb=g+48|0;return a}function Qfa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31721]=0;W(992,b+8|0);a=x[31721];x[31721]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=wb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=wg(Jb(c));Qd(b+8|0);tb(c);break b}if(!d){x[31721]=0;P(993,c|0,14599)|0;a=x[31721];x[31721]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31721]=0;P(844,c|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break d}Uq(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Qd(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31721]=0;V(991,7040,0,0,0);c=x[31721];x[31721]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){T(0)|0;Qb();p()}Q(b|0);p()}function pK(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=vy(13900);if(y[b|0]?b:0){break a}b=vy(D(a,12)+95760|0);if(y[b|0]?b:0){break a}b=vy(14156);if(y[b|0]?b:0){break a}b=14732}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14732;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!ki(e,14732)){break e}if(ki(e,13638)){break d}}if(!a){c=95832;if(y[e+1|0]==46){break c}}return 0}c=x[125019];if(c){while(1){if(!ki(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Ed(36);if(c){x[c+4>>2]=20;x[c>>2]=95728;b=c+8|0;yc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125019];x[125019]=c}c=a|c?c:95832}return c}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=jg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Cg(a,j,l);fb=b+16|0}function S8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Jb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];$n(b,e,c+e|0,h)}if(f&16){Dy(b,x[b+20>>2],x[b+28>>2]);lt(b,c)}m=c;n=d}di(a,m,n)}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;d=x[zb(i+12|0,wb(x[a+4>>2]))>>2];h=fb-32|0;fb=h;e=d;d=x[a>>2];f=(ep(e,wb(d))<<1)+d|0;e=sB(b,c);a:{if((e|0)<=0){break a}d=x[Ab(a)>>2];g=x[a+4>>2];if((e|0)<=d-g>>1){k=g-f|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[h+8>>2]=b;w$(h+8|0,j);d=x[h+8>>2];JB(a,d,c,e-j|0);if((k|0)<=0){break a}}FU(a,f,g,(e<<1)+f|0);Hk(b,d,f);break a}d=Ab(a);e=ik(h+8|0,jk(a,Yc(x[a>>2],g)+e|0),f-x[a>>2]>>1,d);g=fb-16|0;fb=g;c=sp(g+4|0,e+8|0,sB(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){ck(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}ee(c);fb=g+16|0;f=jr(a,e,f);fj(e)}zb(h+28|0,f);fb=h+32|0;fb=i+16|0;return a|0}function iN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break e}}a=$b(8);x[31721]=0;b=P(37,f+4|0,10735)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;x[d>>2]=c|x[d>>2]&-134218753;d=(a+D(b,872)|0)+1075080|0;x[d>>2]=c|x[d>>2]&-134218753;a=z[a+480188>>1];d=a>>>0<=256?256:a;b=b+1|0;g=x[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+D(a,872)|0;if((b|0)==z[e+1075778>>1]){e=e+1075080|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;continue}}c=N()|0;ic(a)}Q(c|0)}p()}fb=f+16|0}function Do(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Co(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Bo(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Xb(c,0,256),x[h+688>>2]=i}function g2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;Pf(b,a);x[31721]=0;O(127,c+24|0,b|0);a=x[31721];x[31721]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31721]=0;a=P(106,c+36|0,c+24|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31721]=0;d=ca(107)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}x[31721]=0;S(108,c+8|0,a+b|0,d|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}Yb(c+8|0);x[31721]=0;x[c+24>>2]=0;b=P(128,a|0,c+24|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}a=qk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Bf(b);fb=c+176|0;a=a?0:d;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Bf(a)}Q(b|0);p()}return a|0}function j0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Cr(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=Cr(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Sb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(hw(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{if(b){x[31721]=0;O(743,a|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){gc(d);fb=f+16|0}else{c=Tb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Md(b);MV(b);fb=e+16|0;return a|0}a=N()|0;MV(e+8|0);Q(a|0);p()}function ls(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Kc(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Ah(x[$c(d+12|0,d+8|0)>>2]);if((Kc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Bb(x[a+4>>2],y[a+11|0]);b:{c:{h=Pk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Kc(a)>>>0<b>>>0){og(e+8|0,c);break e}x[31721]=0;O(119,e+8|0,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Bb(x[a+4>>2],c)}b=xg(b,g,c+1|0);if(i){Db(g)}if(!h){mf(a,j);Wd(a,f);wd(a,b);break b}Ke(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}nf();p()}function aU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Kc(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Ah(x[$c(d+12|0,d+8|0)>>2]);if((Kc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Bb(x[a+4>>2],y[a+11|0]);b:{c:{h=Pk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Kc(a)>>>0<b>>>0){og(e+8|0,c);break e}x[31721]=0;O(53,e+8|0,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Bb(x[a+4>>2],c)}b=Tg(b,g,c+1|0);if(i){Db(g)}if(!h){mf(a,j);Wd(a,f);wd(a,b);break b}Ke(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}nf();p()}function Mi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=42760;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31721]=0;O(949,b|0,0);g=x[31721];x[31721]=0;if((g|0)==1){a=N()|0;sc(f);sc(e);_t(d);_t(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31721]=0;d=R(950,a+92|0)|0;e=x[31721];x[31721]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((sd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;mQ(b);Q(a|0);p()}return a}function bf(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31721]=0;O(117,d|0,Xc(e,a)|0);a=x[31721];x[31721]=0;if((a|0)!=1){a:{while(1){if(Xc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Td(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31721]=0;O(118,d|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31721]=0;O(118,d|0,a<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}x[31721]=0;O(118,d|0,63);a=x[31721];x[31721]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function TA(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(jh(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}fb=d- -64|0;return e}function LQ(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=fb-48|0;fb=e;d=Fb(e+36|0);x[31721]=0;O(940,b|0,e+24|0);g=x[31721];x[31721]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];qf(d);x[31721]=0;g=!g&f>>>0>=255|g?255:f;O(47,d|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=A$(Jb(d),Bb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31721]=0;O(47,d|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break c}break b}f=bc(d,h);x[31721]=0;P(941,b|0,f|0)|0;f=x[31721];x[31721]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[31721]=0;S(500,e+12|0,a|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}a=e+12|0;yb(c,a);tb(a);tb(d);fb=e+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;kd(b,4);w[b+30>>1]=y[a+12|0]<<2;Qf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Cc(g+4|0,22250);ye(b+43|0,a);tb(a);fb=g+16|0}function gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(mn(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=ln(x[$c(d+12|0,d+8|0)>>2]);if((mn(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=mn(a);g=Bb(x[a+4>>2],y[a+11|0]);b:{c:{j=Oq(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Rj(e+8|0,f);break e}x[31721]=0;O(55,e+8|0,f|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);h=Jb(a);c=Bb(x[a+4>>2],c)}b=Vi(b,h,c+1|0);if(i){Db(h)}if(!j){mf(a,f);Wd(a,g);wd(a,b);break b}Ke(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}nf();p()}function Xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);b:{c=Kk(x[b>>2],x[b+4>>2]);if(!c){break b}x[31721]=0;O(464,a|0,c|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31721]=0;fu(a,f,e,c);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}a=N()|0;cm(d+8|0);Q(a|0);p()}c=d+8|0;Md(c);cm(c);fb=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[31721]=0;d=P(927,a+24|0,b+24|0)|0;c=x[31721];x[31721]=0;c:{d:{if((c|0)!=1){x[31721]=0;P(73,a+36|0,b+36|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;sc(d)}Ok(a);Q(b|0);p()}}function Kg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(Ge(d,e,b)){break b}c:{d:{if(Uk(d,e)>>>0<=b>>>0){d=eA(f+12|0,a);x[31721]=0;S(202,a|0,b+1|0,d|0);e=x[31721];x[31721]=0;if((e|0)==1){break d}Fl(d);d=x[a>>2]}x[31721]=0;O(203,dj(d,b)|0,c|0);c=x[31721];x[31721]=0;e:{if((c|0)!=1){c=dj(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31721]=0;W(204,dj(c,b)|0);c=x[31721];x[31721]=0;if((c|0)!=1){break e}}b=T(124984)|0;a=gb;break c}a=dj(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(124984)|0;a=gb;Fl(d)}if(($(124984)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38134>>1];o=w[e+38132>>1];p=w[e+38130>>1];e=w[e+38128>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function hT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=Ao(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[$c(f+4|0,f+108|0)>>2]<<3;e=zua(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}Jv(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[xb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Eo(a,b,e+h|0);fb=f+112|0}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Py(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=jg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Cg(a,j,l);fb=b+16|0}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=of(e+20|0,1,0);a:{b:{c:{while(1){c=Jb(d);j=Bb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((f|0)>0|(f|0)>=0|(c|0)==(j|0))){v[c|0]=45;i=yN(i,f);f=hb;c=c+1|0}xN(k,c,j,i,f);if(!x[e+16>>2]){break c}c=mi(Bb(x[d+4>>2],y[d+11|0]));x[31721]=0;O(46,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Jb(d);x[31721]=0;O(47,d|0,b-c|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(306,h|0,d|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Nh(a,h);tb(h);fb=g+16|0}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function NF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{if((e|0)==1){break c}x[31721]=0;W(1005,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break c}x[31721]=0;W(1005,c|0);f=x[31721];x[31721]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=oc(d+24|0,b);c=oc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31721]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;zs(1026,f,d+8|0,g,c,1);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,5507,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function RQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Hf(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;WQ(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Hf(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Lc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=Ce(i,E(E(1)/E(b|0)));wk(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){lq(a)}else{j=Ce(i,E(d|0));k=xb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function AO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=0;c=x[b+24>>2];c=Iu(x[c+484344>>2],x[c+484348>>2]);x[31721]=0;O(179,e|0,c|0);c=x[31721];x[31721]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(Iu(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[31721]=0;O(1074,d+8|0,Vb(f,a)|0);c=x[31721];x[31721]=0;if((c|0)!=1){c=x[b+24>>2];x[31721]=0;S(1061,d+20|0,c|0,d+8|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(181,e|0,d+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}a=a+1|0;tb(d+20|0);tb(d+8|0);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0);break a}fb=d+32|0;return}a=N()|0}Qd(e);Q(a|0);p()}function fU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Lu(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);x[31721]=0;O(804,a|0,2048);c=x[31721];x[31721]=0;a:{if((c|0)!=1){h=fb-16|0;fb=h;g=Vr(h+4|0,a,2048);c=x[g+4>>2];j=x[g+8>>2];while(1){if((c|0)==(j|0)){gc(g);fb=h+16|0}else{x[c>>2]=0;x[c+4>>2]=0;c=c+8|0;x[g+4>>2]=c;continue}break}c=e+8|0;Md(c);Ku(c);fb=e+16|0;break a}a=N()|0;Ku(e+8|0);Q(a|0);p()}while(1){b:{d=1;if((f|0)!=1024){if((f|0)==2048){break b}d=+(f-1024|0);k=Lu(M(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=k*Ti(d)/(i*d)}l=Re(x[a>>2],f),m=d*.011841342921061943,C[l>>3]=m;f=f+1|0;continue}break}}function Gz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[d+4>>2]){break a}a=x[d>>2];h=x[d+4>>2];c=30608;while(1){if((c|0)==31040){c=31040;while(1){f=(c|0)!=31088;if((c|0)==31088){break a}x[b+40>>2]=a;x[b+44>>2]=h;e=oc(b+32|0,x[c+8>>2]);g=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=g;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;c=c+12|0;if(!uR(b+8|0,b)){continue}break}break a}x[b+56>>2]=a;x[b+60>>2]=h;f=oc(b+48|0,x[c+4>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=e;c=c+8|0;if(!uR(b+24|0,b+16|0)){continue}break}f=1}fb=b- -64|0;fb=d+16|0;return f}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[31721]=0;O(1132,d|0,b|0);f=x[31721];x[31721]=0;if((f|0)!=1){d=d+16|0;x[e+28>>2]=d;b=b+16|0;continue}break}Y(T(0)|0)|0;a=UM(e+12|0,a,e+24|0,e+28|0);b=fb-16|0;fb=b;d=zb(b+12|0,x[x[a+8>>2]>>2]);e=x[zb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Pg(a,e)){Ik(TM(a));a=x[qz(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0;x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}fb=e+32|0;return d|0}T(0)|0;Qb()}p()}function Wu(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;HV(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;HV(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=Vu(c,y[b|0]|y[b+1|0]<<8);a:{if(!Pj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=Vu(c,y[b|0]|y[b+1|0]<<8);if(!Pj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=Vu(c,y[b|0]|y[b+1|0]<<8);if(!Pj(b)){break a}b=x[a+12>>2];b=(y[b|0]|y[b+1|0]<<8)<<16>>16;c=x[d+12>>2];c=we((y[c|0]|y[c+1|0]<<8)<<16>>16);b=we(b);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Pj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=Vu(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=Cd(b);fb=e+48|0;return a}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[31721]=0;O(1168,d|0,b|0);f=x[31721];x[31721]=0;if((f|0)!=1){d=d+12|0;x[e+28>>2]=d;b=b+12|0;continue}break}Y(T(0)|0)|0;a=UM(e+12|0,a,e+24|0,e+28|0);b=fb-16|0;fb=b;d=zb(b+12|0,x[x[a+8>>2]>>2]);e=x[zb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Pg(a,e)){Eb(lx(a));a=x[um(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0;x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}fb=e+32|0;return d|0}T(0)|0;Qb()}p()}function MA(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!d|!(e&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Xb(a+c|0,0,256),x[f+692>>2]=g}}function RK(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31721]=0;c=P(1189,d+8|0,a|0)|0;b=x[31721];x[31721]=0;c:{if((b|0)!=1){d:{if(!Bd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31721]=0;b=R(1190,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31721]=0;W(1191,a+b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}}b=T(0)|0;QK(c);break c}QK(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31721]=0;W(25,a+c|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function j7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;IJ(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=nc(e,x[h+12>>2]);a=Di(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){Zn(12661);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;Tp(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){NK(c+12|0,x[e>>2]);e=e+4|0;continue}break}Qj(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ud(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;b=-1;a:{if(!tm(a,80)){break a}b:{c:{if(!Yl(a,60)){break c}if(!DW(a,d+140|0)){break c}c=15;if(gv(d+140|0,15)){break b}}if(!tm(a,144)){break a}b=0;if(!Yl(a,124)){break a}if(!DW(a,d+140|0)){break a}c=31;if(!gv(d+140|0,31)){break a}}VD(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(BW(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!fd(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;e=d+10|0;CC(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){tC(e)}if(!a){break a}b=CW(y[d+10|0])}fb=d+160|0;return b|0}function wn(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31721]=0;c=P(21,d+8|0,a|0)|0;b=x[31721];x[31721]=0;c:{if((b|0)!=1){d:{if(!Bd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31721]=0;b=R(31,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31721]=0;O(24,a+b|0,1);b=x[31721];x[31721]=0;if((b|0)!=1){break d}}b=T(0)|0;gm(c);break c}gm(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31721]=0;W(25,a+c|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Xn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Ii(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111712|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111712|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function T8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;a:{b:{if(!kc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}h=x[a+20>>2];k=x[a+44>>2];x[31721]=0;g=a+32|0;O(118,g|0,0);e=x[31721];x[31721]=0;if((e|0)==1){break b}e=Kc(g);x[31721]=0;O(47,g|0,e|0);e=x[31721];x[31721]=0;if((e|0)==1){break b}c=Jb(g);Dy(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);lt(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[$c(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Jb(a+32|0);$n(a,c,c+(j-i|0)|0,d)}c=XK(a,b<<24>>24);break a}c=Cy(b);break a}Y(T(0)|0)|0;Z()}fb=f+16|0;return c|0}function Nqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=u$(d+4|0,a);RC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;gc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=s$(h+12|0,t$(a,vr(x[a>>2],x[a+4>>2])+1|0),vr(x[a>>2],x[a+4>>2]),d);RC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){RC(q$(b),tr(f));b=_v(e+12|0);_v(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),zc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;r$(c);fb=h+32|0}function $la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Zj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=u$(d+4|0,a);WD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;gc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=s$(h+12|0,t$(a,vr(x[a>>2],x[a+4>>2])+1|0),vr(x[a>>2],x[a+4>>2]),d);WD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){WD(q$(b),tr(f));b=_v(e+12|0);_v(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),zc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;r$(c);fb=h+32|0}function Wn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=iy(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111712|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111712|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;g=P(841,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(842,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31721]=0;S(188,d+12|0,b|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break a}f=d+12|0;h=hc(d+32|0,f);gd(e+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31721]=0;P(186,b|0,2-c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break d}break a}Qk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38130>>1])+D(w[h-2>>1],w[e+38128>>1])|0)+D(w[h+2>>1],w[e+38132>>1])|0)+D(w[h+4>>1],w[e+38134>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function gs(a){var b=0,c=0;b=fb-32|0;fb=b;c=b+8|0;Cc(c,15380);x[31721]=0;S(126,b+20|0,1,c|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)!=1){x[31721]=0;O(12,a|0,b+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}Rb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Rb(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31721]=0;b=ca(120)|0;c=x[31721];x[31721]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31721]=0;b=ca(121)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31721]=0;b=ca(122)|0;c=x[31721];x[31721]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31721]=0;W(123,a+20|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function Tra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=pr(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=U_(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){gc(b);fb=d+16|0}else{IY(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);d=R_(f+12|0,S_(a,pr(x[a>>2],e)+c|0),pr(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){IY(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}ee(b);fb=e+16|0;Q_(a,d);P_(d)}fb=f+32|0;return}if(b>>>0<d>>>0){N_(a,c+D(b,40)|0)}}function SS(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Oj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=uh(a,tu(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function Ora(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Bv(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}NY(c+16|0,c+32|0);jc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Ub(d,h);NY(c+8|0,c+32|0);jc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Ub(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function MF(a){a=a|0;var b=0,c=0,d=0,e=0;b=JE(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31721]=0;c=P(21,d+8|0,a|0)|0;e=x[31721];x[31721]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Bd(y[c|0])){break e}e=ip(d+4|0,a);x[31721]=0;b=P(30,e|0,b|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31721]=0;O(24,a+b|0,1);b=x[31721];x[31721]=0;if((b|0)!=1){break e}}b=T(0)|0;gm(c);break d}gm(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31721]=0;W(25,a+c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}return wn(a)|0}function lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Jk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31721]=0;w[d+14>>1]=0;e=U(499,a|0,g|0,255)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}if(!e){break d}x[31721]=0;O(488,a|0,d+14|0);e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;S(500,d|0,c|0,g|0);e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;e=P(501,b|0,d+14|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break e}yb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function HH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31721]=0;W(1005,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31721]=0;e=P(37,f+8|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break e}x[31721]=0;S(d|0,f+20|0,g|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}a=f+20|0;b=wg(Jb(a));tb(a);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31721]=0;V(991,c|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38130>>1])+D(v[h-1|0],w[e+38128>>1])|0)+D(v[h+1|0],w[e+38132>>1])|0)+D(v[h+2|0],w[e+38134>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31721]=0;O(250,h|0,f|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}a=N()|0;break a}c=KR(c,e);x[31721]=0;c=P(37,d+8|0,c|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break b}e=zd(x[d+12>>2],y[d+19|0]);x[31721]=0;g=P(844,f|0,c|0)|0;j=x[31721];x[31721]=0;d:{if((j|0)==1){break d}x[31721]=0;P(993,g|0,22225)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function kra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;lg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31721]=0;w[d+14>>1]=0;e=P(502,a|0,g|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break b}if(!e){break d}x[31721]=0;O(488,a|0,d+14|0);e=x[31721];x[31721]=0;if((e|0)==1){break b}x[31721]=0;S(500,d|0,c|0,g|0);e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;e=P(501,b|0,d+14|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break e}yb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function Gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;c=P(837,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(838,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[31721]=0;c=_b(c);c=c?c:-1;S(188,d+12|0,b|0,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break a}f=d+12|0;g=hc(d+32|0,f);gd(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[31721]=0;P(186,b|0,2-c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break d}break a}Qk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function g7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=sJ(b);kl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;jl(a,b);yb(i,a);tb(a);gi(a,b);yb(h,a);tb(a);m=d,n=qj(b),v[m|0]=n;m=e,n=rj(b),v[m|0]=n;oh(a,b);yb(f,a);tb(k+4|0);hi(a,b);yb(g,a);tb(k+4|0);a=Lk(b);break a}a=k+4|0;b=rJ(b);kl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;jl(a,b);yb(i,a);tb(a);gi(a,b);yb(h,a);tb(a);m=d,n=qj(b),v[m|0]=n;m=e,n=rj(b),v[m|0]=n;oh(a,b);yb(f,a);tb(k+4|0);hi(a,b);yb(g,a);tb(k+4|0);a=Lk(b)}x[l>>2]=a;fb=k+16|0}function A0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;kd(b,0);e=c+16|0;f=of(e,1,v[a+1|0]);ye(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Sb(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=y[vb(c+16|0,d)|0];g=vb(c+12|0,d),h=e,v[g|0]=h;d=d+1|0;continue}break}d=$f(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function F9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31721]=0;O(250,h|0,f|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31721]=0;e=P(37,c+8|0,LR(e,d)|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break b}d=zd(x[c+12>>2],y[c+19|0]);x[31721]=0;g=P(844,f|0,e|0)|0;j=x[31721];x[31721]=0;d:{if((j|0)==1){break d}x[31721]=0;P(993,g|0,22225)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function lC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Rc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=vb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Kb(c,x[a+24>>2],b);Ef(c,0);break b;case 2:i=vb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Ef(c,1);break b;case 4:break c;default:break b}}i=vb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Ef(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(kc(x[f>>2],c)){break a}c=YW(c);if(y[vb(x[c>>2],b)|0]==y[vb(x[a>>2],b)|0]){Kb(g+8|0,x[c+24>>2],b);c=Hb(x[x[g+8>>2]>>2],x[g+12>>2]);Kb(g,x[a+24>>2],b);if((Hb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Bb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(gq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=zb(g+12|0,xd(b));d=zb(g+8|0,Ne(xd(b),f));Lr(b,x[c>>2],x[d>>2]);break c}f=Xc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Bb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Bb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!gq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Zc(a,b)}fb=g+16|0}function $6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=oJ(b);kl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;jl(a,b);lh(i,a);Rb(a);gi(a,b);lh(h,a);Rb(a);m=d,n=qj(b),x[m>>2]=n;m=e,n=rj(b),x[m>>2]=n;oh(a,b);yb(f,a);tb(a);hi(a,b);lh(g,a);Rb(k+4|0);a=Lk(b);break a}a=k+4|0;b=nJ(b);kl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;jl(a,b);lh(i,a);Rb(a);gi(a,b);lh(h,a);Rb(a);m=d,n=qj(b),x[m>>2]=n;m=e,n=rj(b),x[m>>2]=n;oh(a,b);yb(f,a);tb(a);hi(a,b);lh(g,a);Rb(k+4|0);a=Lk(b)}x[l>>2]=a;fb=k+16|0}function S1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Bb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(nu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=zb(g+12|0,xd(b));d=zb(g+8|0,Ne(xd(b),f));Lr(b,x[c>>2],x[d>>2]);break c}f=Xc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Bb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Bb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!nu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Zc(a,b)}fb=g+16|0}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;g=P(917,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(918,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31721]=0;S(188,d+12|0,b|0,g|0);f=x[31721];x[31721]=0;if((f|0)==1){break a}f=d+12|0;h=hc(d+32|0,f);gd(e+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31721]=0;P(186,b|0,1)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break d}break a}Qk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;c=P(833,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(834,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[31721]=0;c=_b(c);S(188,d+12|0,b|0,c|0);f=x[31721];x[31721]=0;if((f|0)==1){break a}f=d+12|0;g=hc(d+32|0,f);gd(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[31721]=0;P(186,b|0,2-c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break d}break a}Qk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function AA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=x[a>>2];if(!kc(c,x[a+4>>2])){d=wb(c);x[e+12>>2]=d;c=wb(x[a+4>>2]);while(1){if(Ib(d,c)){wp(d,4194304,67108864);f=x[d>>2];g=f+g|0;b=g>>>0<f>>>0?b+1|0:b;d=x[Pe(e+12|0)>>2];continue}else{f=x[a>>2];c=nc(f,x[a+4>>2]);k=e,l=wb(f),x[k+8>>2]=l;d=c<<24;g=Bua(g,b,c,0);c=g;h=((hb&1)<<31|c>>>1)&2147483647;i=wb(x[a+4>>2]);while(1){b=x[e+8>>2];if(Ib(b,i)){f=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+j|0;b=Bc(Bua(c,c>>>0<h>>>0?b+1|0:b,g,j),hb);x[f>>2]=b;d=d-b|0;Pe(e+8|0);continue}else{b=x[a>>2];if(!nc(b,x[a+4>>2])){sw();p()}x[b>>2]=x[b>>2]+d}break}}break}}fb=e+16|0}
function fqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=ni(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=dd(g),w[m>>1]=n;a=a+1|0;continue}}}_(17357,8983,27,9525);p()}_(17307,8983,28,9525);p()}fb=c+16|0}function Waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=iP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=yM(zM(g+8|0,32));break a}e=G(c);e=zM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=yM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=xb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=rP(l,d,wP(d));nP(a,d);Um(d);fb=f- -64|0;d=mz(a+120|0,a,b);v[d+20|0]=1;x[31721]=0;O(1146,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){a=N()|0;no(d);Q(a|0);p()}return a|0}function w3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(ki(b,14271)){d=Ds(c+28|0,b);e=x[d>>2];if(!yd(e)){x[31721]=0;b=P(37,c+4|0,b|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}x[31721]=0;S(1019,c+16|0,17796,b|0);a=x[31721];x[31721]=0;d:{e:{if((a|0)!=1){x[31721]=0;W(1347,c+16|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}Rp(e);if(!Cs(a+8|0,16776,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!Cs(a+9|0,22250,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31721]=0;O(275,a+12|0,22250);a=x[31721];x[31721]=0;if((a|0)==1){break b}il(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}il(d);Q(a|0);p()}function IO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480192>>1];x[31721]=0;O(179,f|0,b|0);c=x[31721];x[31721]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=x[a+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=KR(c,d);x[31721]=0;c=P(37,e+8|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=x[a+24>>2];x[31721]=0;S(1061,e+20|0,d|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;O(181,f|0,e+20|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}tb(e+20|0);tb(c);b=b+1|0;continue}break}b=N()|0;break a}b=N()|0;break c}b=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}b=N()|0}Qd(f);Q(b|0);p()}function bG(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=fh(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=fb-16|0;fb=d;b=Vr(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){gc(b);fb=d+16|0}else{dl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);d=Xr(f+12|0,Yr(a,fh(x[a>>2],e)+c|0),fh(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=(c<<3)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){dl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}ee(b);fb=e+16|0;Id(a,d);Wr(d)}fb=f+32|0;return}if(b>>>0<d>>>0){$F(a,c+(b<<3)|0)}}function kN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}a=$b(8);x[31721]=0;d=P(37,d+4|0,10735)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}mc(a,d);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=$b(8);x[31721]=0;d=P(37,d+4|0,11752)|0;b=x[31721];x[31721]=0;if((b|0)!=1){mc(a,d);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;ic(a);break b}e=(a+D(b,872)|0)+1075740|0,f=Wi(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;ic(a)}Q(b|0)}p()}function eqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=ni(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=TX(g),v[m|0]=n;a=a+1|0;continue}}}_(17357,8983,27,9525);p()}_(17307,8983,28,9525);p()}fb=c+16|0}function vO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480190>>1];x[31721]=0;O(179,f|0,b|0);d=x[31721];x[31721]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=x[a+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[31721]=0;d=P(37,e+8|0,LR(d,c)|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){c=x[a+24>>2];x[31721]=0;S(1061,e+20|0,c|0,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(181,f|0,e+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}tb(e+20|0);tb(d);b=b+1|0;continue}break}b=N()|0;break a}b=N()|0;break c}b=N()|0;tb(e+20|0)}tb(d);break a}fb=e+32|0;return}b=N()|0}Qd(f);Q(b|0);p()}function Hw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;ch(b,y[Sb(i,e)|0]);g=y[Sb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Hd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Sb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Hd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Sb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Xb(y[e+6|0]+c<<24>>24,0,64);d=xb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=xb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=ae(a);a:{if(d){f=dc(g);while(1){a=d;d=a+16|0;if(Du(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Du(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=dc(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=dc(g);b=zh(c,Dc(40),Jg(a+8|0,b));Fb(Zc(x[b>>2]+16|0,x[e+4>>2])+12|0);i=dc(b),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[c+12>>2],f,x[c>>2]);b=ie(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[dc(c)+4|0]){Zm(a+16|0)}Db(a)}h=1}Wg(e+8|0,x[zb(c,b)>>2],h);fb=c+16|0;a=rd(x[e+8>>2]);fb=e+16|0;return a+12|0}function T2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(jh(a,x[b+8>>2],f)){Gx(b,c,d,e);return}g=y[b+53|0];i=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Cx(x[m>>2],x[a+20>>2],b,c,d,e,f);j=y[b+53|0];l=g|j;k=y[b+52|0];h=h|k;g=a+24|0;i=(i<<3)+m|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(k){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!j){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Cx(x[g>>2],x[g+4>>2],b,c,d,e,f);j=y[b+53|0];l=j|l;k=y[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}v[b+53|0]=(l&255)!=0;v[b+52|0]=(h&255)!=0}function rY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=_b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=_b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=_b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=_b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Re(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Bw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function kL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Tb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((jL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(g0(a)){break b}}c=jL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}fb=f+208|0;return e}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(Nf(x[x[a+48>>2]+12>>2]),f?b-c|0:c-b|0);d=wb(x[a+4>>2]);c:{if(f){d=zb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31721]=0;V(666,a|0,d|0,c|0,e+20|0);c=x[31721];x[31721]=0;if((c|0)!=1){break c}a=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(a|0)|0;Z();break b}c=zb(e+16|0,uD(d,c));d=x[zb(e+12|0,wb(x[a+4>>2]))>>2];f=fb-16|0;fb=f;g=x[c>>2];c=x[a>>2];c=D(gu(g,wb(c)),6)+c|0;if(Ib(g,d)){$C(a,dR(c+D(gu(d,g),6)|0,x[a+4>>2],c))}zb(f+12|0,c);fb=f+16|0}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function lQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;kh(e+8|0,b);f=fb-16|0;fb=f;jf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;k=h,l=wb(a),x[k+12>>2]=l;a=b;b=fb-16|0;fb=b;j=x[h+12>>2];c=j;d=x[c+8>>2];c=x[c+12>>2];i=c;a:{if((c|0)<0){break a}c=x[j+4>>2];if(!i&c>>>0<d>>>0|i){break a}x[b+8>>2]=c-d;x[b+12>>2]=0-(i+(d>>>0>c>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;c=X$(b+8|0,b);if((Cu(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}Qi(g,a+g|0,d+x[j>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)!=(b|0)){e=fb-16|0;fb=e;d=x[b>>2];b=x[b+4>>2];f=Pd(d,b);a:{if(f>>>0<=Rg(a)>>>0){h=b;i=x[a>>2];c=nc(i,x[a+4>>2]);j=c>>>0>=f>>>0;if(!j){x[e+12>>2]=d;KC(e+12|0,c);h=x[e+12>>2]}g=fb-16|0;fb=g;c=fb-32|0;fb=c;Tp(c+24|0,d,h);Gk(c+16|0,x[c+24>>2],x[c+28>>2],i);d=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ud(g+8|0,d,c+12|0);fb=c+32|0;c=x[g+12>>2];fb=g+16|0;if(!j){to(a,h,b,f-nc(x[a>>2],x[a+4>>2])|0);break a}Xh(a,c);break a}if(x[a>>2]){Hf(a);Vx(Ls(a),x[a>>2],Rg(a));k=Ab(a),l=0,x[k>>2]=l;x[a>>2]=0;x[a+4>>2]=0}cJ(a,Uf(a,f));to(a,d,b,f)}fb=e+16|0}return a|0}function Dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=xd(b),x[i+12>>2]=j;c=Xc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[bc(b,0)|0]!=43){if(y[bc(b,0)|0]!=45){break b}}d=d+1|0;WU(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[zb(g+8|0,x[g+12>>2])>>2];c=d-Xc(x[b+4>>2],y[b+11|0])|0;c:{e=Bk(e,xd(b));d=Bb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Kc(b);d:{if(c>>>0<=f-d>>>0){f=Jb(b);if((d|0)==(e|0)){break d}h=e+f|0;Ri(c+h|0,h,d-e|0);break d}DB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}bm(e+f|0,c,48);c=c+d|0;kg(b,c);ed(c+f|0,0)}break c}Rl();p()}xd(b)}Zc(a,b);fb=g+16|0}function rua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;Z$(c,a);Y$(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Gb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;ch(b,y[Sb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Pd(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=xb(e,0);break b}g=z[xb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=We(d+12|0,d+8|0);c=xb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function SU(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function Ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;kd(b,0);f=d+8|0;hk(f,1,a);c=d+20|0;Ac(c,f);ye(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;am(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Sb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}function jD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;ch(b,Hd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Pd(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){iD(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=oe(e+14|0,e+12|0);i=xb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Sb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function wS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!ge(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31648|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=bl(f);ac(d+8|0,g+D(c,b)|0,b);i=d,j=wb(x[d+8>>2]),x[i+4>>2]=j;f=Vk(x[d+8>>2],x[d+12>>2]);while(1){b=x[d+4>>2];if(Ib(b,f)){v[b|0]=y[b|0]^-1;je(d+4|0);continue}else{Mj(e,a)}break}}fb=d+16|0}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;f=c;e=fb-16|0;fb=e;g=b;d=ae(b);a:{if(d){c=dc(g);while(1){b=d;d=b+16|0;if(rR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!rR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=dc(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=dc(g);d=zh(e,Dc(28),Jg(b+8|0,d));i=x[d>>2];x[31721]=0;O(895,i+16|0,f|0);f=x[31721];x[31721]=0;b:{if((f|0)!=1){j=dc(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;qR(d);Q(a|0);p()}Xg(g,x[e+12>>2],c,x[e>>2]);b=ie(e);qR(e);i=1}c=h+8|0;Wg(c,x[zb(e,b)>>2],i);fb=e+16|0;QU(a,c);fb=h+16|0}function nta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;e=b;b=x[a>>2];b=Bk(e,wb(b))+b|0;e=HD(c,d);a:{if((e|0)<=0){break a}g=x[Ab(a)>>2];h=x[a+4>>2];if((e|0)<=(g-h|0)){x[f+8>>2]=d;g=h-b|0;if((g|0)<(e|0)){x[f+8>>2]=c;x_(f+8|0,g);GD(a,x[f+8>>2],d,e-g|0);if((g|0)<=0){break a}}w_(a,b,h,b+e|0);Pv(c,x[f+8>>2],b);break a}g=Ab(a);h=hn(f+8|0,Wl(a,Rc(x[a>>2],h)+e|0),b-x[a>>2]|0,g);e=fb-16|0;fb=e;x[e+12>>2]=c;c=fC(e,h+8|0,HD(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){wl(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;je(e+12|0);continue}break}ee(c);fb=e+16|0;b=jr(a,h,b);gn(h)}zb(f+28|0,b);fb=f+32|0}function hR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;ch(g,y[Sb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Pd(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=xb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[xb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=xb(j,b),p=i,w[o>>1]=p}o=m,p=Hd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;fb=h+16|0}function bka(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){mu(a+484344|0);qf(a+1298308|0);qf(a+1298320|0);qf(a+1298332|0);Vv(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=Dj(b);while(1){if((b|0)==(c|0)){break a}H$(b);b=b+160|0;continue}}d=x[b>>2];if(d){Db(wv(d))}x[b>>2]=0;b=b+4|0;continue}}}else{jn(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function it(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:500068;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124227]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+111504>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31596]=25;e=-1}return e}x[g>>2]=d;return-2}function gsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;c=P(414,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(415,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=_b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=x[$c(c+12|0,c+8|0)>>2];fb=c+16|0;x[31721]=0;S(188,d+12|0,b|0,f-8|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=hc(d+32|0,b);gd(e+8|0,c);ub(c);ub(b);Qk(a,e)}Fd(e);fb=d+80|0}function Ei(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;fg(f,g);a:{b:{if(Bd(y[Dm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31721]=0;zs(89,e+24|0,f,b,c,d);b=x[31721];x[31721]=0;c:{if((b|0)!=1){b=di(e+8|0,-1,-1);d=Vn(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Bm(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Qb()}p()}function Zfa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Jd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31721]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;S(988,d+56|0,d+8|0,d|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){a=x[pe(d+28|0,d+76|0)>>2];x[31721]=0;b=+pa(989,d+56|0,+b,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}ub(d+56|0);Uc(d+76|0);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Uc(d+76|0);Q(a|0);p()}function Cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=ae(a);a:{if(c){b=dc(g);while(1){a=c;c=z[a+14>>1];if(Uo(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!Uo(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=dc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=dc(g);f=zh(d,Dc(20),Jg(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=dc(f),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[d+12>>2],b,x[d>>2]);a=ie(d);Zl(d);h=1}Wg(e+8|0,x[zb(d,a)>>2],h);fb=d+16|0;a=Yo(x[e+8>>2]);fb=e+16|0;return a+2|0}function IZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=ae(a);a:{if(c){b=dc(g);while(1){a=c;c=x[a+16>>2];if(YD(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!YD(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=dc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=dc(g);f=zh(d,Dc(24),Jg(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=dc(f),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[d+12>>2],b,x[d>>2]);a=ie(d);Zl(d);h=1}Wg(e+8|0,x[zb(d,a)>>2],h);fb=d+16|0;a=rd(x[e+8>>2]);fb=e+16|0;return a+4|0}function G7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}ad(f+16|0,x[c+28>>2]);x[31721]=0;a=R(1220,x[f+16>>2])|0;b=x[31721];x[31721]=0;b:{if((b|0)!=1){Yb(f+16|0);c:{if(e){hi(f+16|0,a);break c}gi(f+16|0,a)}g=f,h=xd(f+16|0),x[g+12>>2]=h;while(1){a=ml(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];Rb(f+16|0);break a}a=x[b>>2];x[31721]=0;P(1234,f+28|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){Pe(f+12|0);continue}break}c=N()|0;Rb(f+16|0);break b}c=N()|0;Yb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function At(a,b,c){var d=0,e=0;d=a,e=xj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=xj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function UW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;Ec(a+8|0,0);d=x[b+4>>2];if(d){Kr(a,d);fn(c+8|0,x[b>>2]);Nq(c,x[b>>2],x[b+4>>2]);b=fb-32|0;fb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+SW(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}pp(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;TW(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);fb=b+32|0}fb=c+16|0;return a|0}function Q7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}ad(f+16|0,x[c+28>>2]);x[31721]=0;a=R(1203,x[f+16>>2])|0;b=x[31721];x[31721]=0;b:{if((b|0)!=1){Yb(f+16|0);c:{if(e){hi(f+16|0,a);break c}gi(f+16|0,a)}g=f,h=xd(f+16|0),x[g+12>>2]=h;while(1){a=zf(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];tb(f+16|0);break a}a=v[b|0];x[31721]=0;P(30,f+28|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){je(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Yb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function I2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-32|0;fb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;x[31721]=0;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ia(1102,a|0,b|0,c|0)|0;b=x[31721];x[31721]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31721]=0;ga(987,10415,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}return a|0}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function ZG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Gb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Nm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Nm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function hy(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;ad(f+12|0,b);x[31721]=0;b=R(1219,x[f+12>>2])|0;g=x[31721];x[31721]=0;a:{if((g|0)==1){break a}x[31721]=0;V(1230,b|0,111712,111744,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;b=R(1220,x[f+12>>2])|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;c=R(1231,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}x[d>>2]=c;x[31721]=0;c=R(1228,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[e>>2]=c;x[31721]=0;O(1229,a|0,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Yb(f+12|0);fb=f+16|0;return}a=N()|0;Yb(f+12|0);Q(a|0);p()}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=dU(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10069];d=c+32|0;x[d+8>>2]=x[10068];x[d+12>>2]=e;e=x[10067];x[d>>2]=x[10066];x[d+4>>2]=e;yB(d,h*+(b>>>0));ZT(c+48|0,C[c+32>>3],C[c+40>>3]);d=Vd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Ol(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;kA(f,0,g,c);fb=c- -64|0;return f|0}function Xg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[dc(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Ph(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Ph(d)){ar(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;$q(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Ph(d)){$q(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ar(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=Ab(a);x[a>>2]=x[a>>2]+1}function $m(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function my(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;ad(f+12|0,b);x[31721]=0;b=R(28,x[f+12>>2])|0;g=x[31721];x[31721]=0;a:{if((g|0)==1){break a}x[31721]=0;V(1217,b|0,111712,111744,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}x[31721]=0;b=R(1203,x[f+12>>2])|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;c=R(1218,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}v[d|0]=c;x[31721]=0;c=R(1215,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}v[e|0]=c;x[31721]=0;O(1216,a|0,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Yb(f+12|0);fb=f+16|0;return}a=N()|0;Yb(f+12|0);Q(a|0);p()}function ch(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=nc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=th(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){gc(b);fb=c+16|0}else{Gw(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Ab(a);c=ig(e+12|0,Uf(a,nc(x[a>>2],d)+b|0),nc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Bn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Gw(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);hg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Xh(a,d+(b<<2)|0)}}function x3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(ki(b,14271)){d=Ds(c+28|0,b);e=x[d>>2];if(!yd(e)){x[31721]=0;b=P(37,c+4|0,b|0)|0;a=x[31721];x[31721]=0;c:{d:{e:{if((a|0)!=1){x[31721]=0;S(1019,c+16|0,17729,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}x[31721]=0;W(1347,c+16|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}Rp(e);Op(a+8|0,16776,x[d>>2]);Op(a+12|0,22250,x[d>>2]);x[31721]=0;O(275,a+16|0,22250);a=x[31721];x[31721]=0;if((a|0)==1){break b}il(d)}fb=c+32|0;return}a=N()|0}il(d);Q(a|0);p()}function FL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(df(a)){ec(a,31);return 0}g=a,h=df(a),v[g+1375|0]=h;d=wj(a);b=wj(a);wj(a);g=a,h=wj(a),x[g+1112>>2]=h;wj(a);c=df(a);x[a+1116>>2]=c;if(!Wy(a,a+1120|0,c)){ec(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function fl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){mo(e,f,gG(f));pd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=$b(8);x[31721]=0;b=R(164,a|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,28832,165);p()}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)==1){break c}x[31721]=0;W(1005,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(c+12|0,b);x[31721]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;V(1017,c+20|0,d|0,c|0,1);b=x[31721];x[31721]=0;if((b|0)==1){break c}a=c+20|0;b=wg(Jb(a));tb(a);break b}Y(T(0)|0)|0;b=0;x[31721]=0;V(991,5535,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=c+32|0;return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Dm(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;v[a|0]=0;a:{d=x[x[b>>2]-12>>2]+b|0;b:{if(!x[d+16>>2]){d=x[d+72>>2];if(d){wn(d)}c:{if(c){break c}c=x[x[b>>2]-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}ad(e+12|0,x[c+28>>2]);x[31721]=0;f=R(28,x[e+12>>2])|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}Yb(e+12|0);c=ip(e+8|0,b);d=qc(e+4|0);while(1){d:{if(ph(c,d)){break d}g=tl(x[c>>2]);if(!Ff(x[f+8>>2],1,g)){break d}Cm(c);continue}break}if(!ph(c,d)){break c}$j(x[x[b>>2]-12>>2]+b|0,6)}v[a|0]=!x[(x[x[b>>2]-12>>2]+b|0)+16>>2];break b}$j(d,4)}fb=e+16|0;return a}a=N()|0;Yb(e+12|0);Q(a|0);p()}function Bta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{b:{if(b){x[31721]=0;O(324,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=qr(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){gc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Md(b);cm(b);fb=c+16|0;break a}a=N()|0;cm(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function Zd(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=di(a,-1,-1);a:{b:{if(Bd(y[Dm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31721]=0;zs(89,c+8|0,d,0,0,1);d=x[31721];x[31721]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Bm(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Qb()}p()}function B4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=fb+-64|0;fb=g;Un(g+16|0,c);x[31721]=0;c=g+28|0;O(94,c|0,d|0);d=x[31721];x[31721]=0;b:{c:{d:{if((d|0)==1){break d}x[31721]=0;c=g+40|0;O(94,c|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}x[31721]=0;c=g+52|0;O(94,c|0,f|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}Rx(g+8|0,g+16|0);x[31721]=0;V(95,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}pI(g+16|0);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;pI(g+16|0)}Q(a|0);p()}}function $_(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function OM(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31721]=0;W(859,c|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=zb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;Hg(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Rg(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;hS(c+1298412|0);IA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);HA(c+1298304|0);GA(c+1298300|0);zu(c+1298264|0);WA(c+1074376|0);fS(c+906300|0);LB(c+484360|0);ZR(c+484344|0);sc(c+480248|0);break a}T(0)|0;Qb();p()}Db(c)}}function Psa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if(Yc(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[Zb(e,b)>>1];b:{if(!_i(a,b)){break b}c=x[a+24>>2];d=wb(x[c+484360>>2]);x[g+12>>2]=d;h=wb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=fm(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[Zb(x[d>>2],f)>>1]){break c}c=sX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=Zb(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[cv(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function G2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31721]=0;W(1005,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break d}e=x[a+24>>2];b=oc(c+8|0,b);x[31721]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;zs(1025,e,c,f,d,1);d=x[31721];x[31721]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31721]=0;V(991,8642,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}return b|0}function LF(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=xb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Rq(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function lr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;wE(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function sL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[496800]){f=496801,g=Qa()|0,v[f|0]=g;v[496800]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[496801]){break c}d=+Ga();break a}x[31596]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(zua(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=jg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Cg(a,h,j);fb=b+16|0}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function os(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=zb(h+12|0,x[a+4>>2]);e=zb(h+8|0,x[a>>2]);j=zb(h+4|0,x[b+4>>2]);k=fb-16|0;fb=k;f=fb-16|0;fb=f;l=fb-16|0;fb=l;m=fb-16|0;fb=m;i=x[g>>2];g=x[e>>2];e=i-g|0;i=D((e|0)/(d|0)|0,c);d=x[j>>2];j=i+d|0;i=$h(j,g,e);e=D((e|0)/(c|0)|0,c);x[m+12>>2]=i+e;Ud(l+8|0,e+g|0,m+12|0);fb=m+16|0;Ud(f+8|0,g,zb(l+4|0,d+D((j-d|0)/(c|0)|0,c)|0));fb=l+16|0;c=x[f+8>>2];x[f+4>>2]=x[f+12>>2];Ud(k+8|0,c,f+4|0);fb=f+16|0;fb=k+16|0;x[b+4>>2]=x[k+12>>2];wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function $5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=nc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){Qu(a,e);break a}f=Ls(a);d=Uf(a,nc(x[a>>2],c)+e|0);g=nc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Fg(b+12|0,f);b:{if(!d){f=0;d=0;break b}MI(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=zc(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;SQ(b,e);Id(a,b);OP(b);a=x[b>>2];if(a){Vx(x[b+16>>2],a,Iz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Xh(a,c+(b<<2)|0)}}function un(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];zr(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;pg(g+15|0,g+13|0);pg(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;be(a,0,g+9|0);break a}d=y[g+15|0];e=Th(d);c=y[g+13|0];if(e>>>0>Th(c)>>>0){pg(g+15|0,g+13|0);pg(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;be(a,d,g+14|0)}fb=g+16|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(lu(a)>>>0>=b>>>0){e=x[a>>2];g=Uk(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Gb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=bR(e,c)+52|0;continue}break}if(b>>>0>g>>>0){dA(a,b-g|0,c);break a}$Q(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){mu(a);d=x[a>>2];lu(a);Db(d);h=Ab(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=_Q(a,b);d=fb-16|0;fb=d;if(Gh(82595524)>>>0<e>>>0){cd();p()}ZQ(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=Ab(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;dA(a,b,c)}fb=f+16|0}function Tfa(a){a=a|0;var b=0;b=8016;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22250;break a}b=8049;break a}b=18172;break a;case 0:b=5011;break a;case 9:b=8072;break a;case 10:b=8086;break a;case 11:b=5388;break a;case 12:b=5408;break a;case 19:b=8098;break a;case 20:b=8030;break a;case 21:b=12898;break a;case 22:b=12221;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6019;break a}b=7983}return wg(b)|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31721]=0;W(1004,a|0);e=x[31721];x[31721]=0;a:{b:{c:{if((e|0)==1){break c}x[31721]=0;W(1005,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break c}e=x[a+24>>2];b=oc(d+8|0,b);x[31721]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1022,e|0,d|0,(c|0)!=0|0,1);c=x[31721];x[31721]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,10005,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function fQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Mi(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44732;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=xb(b,0),g=1056964608,x[f>>2]=g;f=xb(b,1),g=1036831949,x[f>>2]=g;f=xb(b,2),g=1038174126,x[f>>2]=g;f=xb(b,3),g=1065353216,x[f>>2]=g;f=xb(b,4),g=1061158912,x[f>>2]=g;f=xb(b,5),g=1059082943,x[f>>2]=g;f=xb(b,6),g=1061997773,x[f>>2]=g;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;sc(d);sc(c);Vf(a);Q(b|0);p()}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function r8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(kc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=kc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(Zq(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((jt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function H2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31721]=0;W(1005,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}c=x[a+24>>2];b=oc(d+8|0,b);x[31721]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=OH(c,d,1);e=x[31721];x[31721]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31721]=0;V(991,8673,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}gb=a;return b|0}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);fs(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(306,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function Pq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);fs(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(306,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function v8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(kc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Nk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Zq(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Nk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Nk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Cy(b);break a}d=-1}fb=c+32|0;return d|0}function p_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);lw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(48,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function nha(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Fc(Aua(zua(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31721]=0;x[c+12>>2]=0;S(955,a+4264|0,b|0,c+12|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[31721]=0;x[c+12>>2]=0;S(955,a+4276|0,b|0,c+12|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}b=T(124984)|0;break c}x[c+12>>2]=0;b=c+12|0;bQ(a+4288|0,b);x[c+12>>2]=0;bQ(a+4300|0,b);break b}b=T(124984)|0}if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function Ev(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);lw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(48,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function Dp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);fs(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(48,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function mz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{b:{if(c){x[31721]=0;O(1143,a|0,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=th(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){gc(d);fb=f+16|0}else{x[c>>2]=0;qc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Md(c);_g(c);fb=e+16|0;break a}a=N()|0;_g(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=XR(b);continue}break}x[f>>2]=c;xo(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function iK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}f=a&255;c=(f>>>0)/3|0;g=x[((D(c,-3)+a&255)<<2)+99032>>2];e=c;c=a>>>8|0;d=x[(((D(g,y[(e+D(y[c+100416|0],86)|0)+100416|0])>>>11>>>0)%6|0)+y[c+103088|0]<<2)+99056>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;i=y[(e<<1)+100016|0];if((i|0)==(f|0)){c=x[(y[(e<<1)+100017|0]<<2)+99056>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}g=e;e=f>>>0<i>>>0;c=e?c:g;d=e?h:d-h|0;if(d){continue}break}}return a}function cs(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b|0){case 0:x[31721]=0;b=P(1,d+4|0,15894)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}yb(a,b);tb(b);break b;case 1:x[31721]=0;b=P(1,d+4|0,15919)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(a,b);tb(b);break b}break a;case 2:x[31721]=0;b=P(1,d+4|0,15867)|0;c=x[31721];x[31721]=0;if((c|0)!=1){yb(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[31721]=0;b=P(1,d+4|0,15841)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}yb(a,b);tb(b)}fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=jg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Cg(a,h,j);fb=b+16|0}function RU(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;PB(a+48|0);PB(a+68|0);PB(a+88|0);Ou(a+492|0);Ou(a+524|0);gk(a,0,0);fk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;xv(a,b);b=a+108|0;d=wC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function Cfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)==1){break c}x[31721]=0;W(1005,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(e+8|0,b);x[31721]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1024,d|0,e|0,+c,1);d=x[31721];x[31721]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,5926,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function C8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(bo(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Nk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Zq(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Nk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Nk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=bo(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function Xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31721]=0;c=U(153,d|0,c|0,1)|0;d=x[31721];x[31721]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31721]=0;W(520,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;c=R(200,a|0)|0;d=x[31721];x[31721]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31721]=0;d=P(521,a|0,e+15|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break c}f=y[e+15|0];if(d&f>>>0<64){yc(DY(x[b>>2],f),e+15|0,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function Z5(a){a=a|0;if(y[500496]){return x[125123]}if(!y[501600]){v[501600]=1}td(501312,120476);td(501324,120508);td(501336,120544);td(501348,120568);td(501360,120592);td(501372,120608);td(501384,120628);td(501396,120648);td(501408,120676);td(501420,120716);td(501432,120748);td(501444,120784);td(501456,120820);td(501468,120836);td(501480,120852);td(501492,120868);td(501504,120592);td(501516,120884);td(501528,120900);td(501540,120916);td(501552,120932);td(501564,120948);td(501576,120964);td(501588,120980);v[500496]=1;x[125123]=501312;return 501312}function y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(bo(b)){if(d){break a}b=x[a+48>>2];e=a,f=bo(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Zq(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((jt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(714,a|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){gc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Md(b);hW(b);fb=d+16|0;return a|0}a=N()|0;hW(d+8|0);Q(a|0);p()}function oX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!nv(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=nv(a);a=a+34|0;if(b){continue}break}}return d}function ps(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];TG(e+52|0,c,73);x[31721]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31721];x[31721]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;lV(b,e+4|0,x[e+52>>2]);x[31721]=0;V(302,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(303,e+40|0,e+28|0,e+52|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}b=a;a=e+40|0;Nh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Ch(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Ch(e+52|0);Q(c|0);p()}function dD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(Xq(y[a+1|0]),c)|0}return c}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-48|0;fb=d;c=d+28|0;Yj(c,b,1819307379);gd(a+40|0,c);ub(c);Yj(c,b,1953721961);gd(a+60|0,c);ub(c);Yj(c,b,543520099);gd(a+120|0,c);ub(c);Yj(c,b,1414744396);x[31721]=0;c=P(416,c|0,13830)|0;e=x[31721];x[31721]=0;a:{if((e|0)!=1){b:{if(c){x[31721]=0;S(813,d+8|0,d+28|0,2);c=x[31721];x[31721]=0;if((c|0)==1){break b}c=d+8|0;lv(a+140|0,c);fe(c)}x[31721]=0;S(814,d+8|0,b|0,1634890872);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;gd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=Cf(a,c);Zd(e,x[a+36>>2]);a:{b:{if(!h){Oc(e,a+32|0,5);c=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;kq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Gb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;lz(g+8|0,f);f=x[g+12>>2];if(Qp(-1,2147483647,c,0)^1){i=Qp(c,0,0,-2147483648)^1}else{i=0}if(i){Ei(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}cf(a,d);fb=e+16|0}function mw(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=of(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);lw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=mi(Bb(x[c+4>>2],y[c+11|0]));x[31721]=0;O(46,c|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31721]=0;O(47,c|0,b-d|0);b=x[31721];x[31721]=0;d:{if((b|0)!=1){x[31721]=0;O(48,g|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Nh(a,g);tb(g);fb=f+16|0}function fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=jg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Cg(a,h,k);fb=b+16|0}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)==1){break c}x[31721]=0;W(1005,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(c+8|0,b);x[31721]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1015,d|0,c|0,1);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,5963,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;h=z[c>>1];i=c;e=fb-16|0;fb=e;f=b;d=ae(b);a:{if(d){c=dc(f);while(1){b=d;d=z[b+14>>1];if(al(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!al(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=dc(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=dc(f);d=zh(e,Dc(16),Jg(b+8|0,d));ck(x[d>>2]+14|0,z[i>>1]);k=dc(d),l=1,v[k+4|0]=l;fb=b+16|0;Xg(f,x[e+12>>2],c,x[e>>2]);b=ie(e);Zl(e);j=1}c=g+8|0;Wg(c,x[zb(e,b)>>2],j);fb=e+16|0;QU(a,c);fb=g+16|0}function Kp(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];TG(e+52|0,c,3);x[31721]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31721];x[31721]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;lV(b,e+4|0,x[e+52>>2]);x[31721]=0;V(19,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(20,e+40|0,e+28|0,e+52|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}b=a;a=e+40|0;Nh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Ch(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Ch(e+52|0);Q(c|0);p()}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;a:{b:{c:{if((c|0)==1){break c}x[31721]=0;W(1005,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break c}c=x[a+24>>2];b=oc(d+8|0,b);x[31721]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1011,c|0,d|0,1)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,10036,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function WE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;qf(a);ls(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Gb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=ks(rt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Gb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[bc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=bc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=jg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Cg(a,h,k);fb=b+16|0}function ut(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((go(i,a,b)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((go(l,i,b)|0)>=0){break e}if((go(l-f|0,i,b)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=qL(c,d);vt(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}pL(h,k);Sy(i,b,e,g)}fb=h+240|0}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;aS(a+946304|0);f=a+906300|0;g=Dj(f);d=e+48|0;Tb(d,0,160);d=cS(d);x[31721]=0;S(866,f|0,g|0,d|0);f=x[31721];x[31721]=0;a:{if((f|0)!=1){EA(d);d=Fe(e+28|0,b);x[31721]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(867,a|0,e+8|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;EA(d)}ub(b);Q(a|0);p()}function Zy(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];IL(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);IL(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87664>>2];i=B[d+87676>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87672>>2];d=5-a<<2;m=B[d+87664>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function QB(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!kc(c,x[a+4>>2])){w[c>>1]=0;Jf(c+2|0,b);f=d,g=Fk(wb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=wb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[oe(c,Fk(c,-1))>>1],w[f>>1]=g;Jf(c+2|0,b);XV(d+12|0);continue}else{Jf(a+14|0,Pd(x[a>>2],x[a+4>>2])-1&255);Jf(a+13|0,y[a+14|0]);Jf(a+16|0,Pd(x[a>>2],x[a+4>>2])-1&255);Jf(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}Jf(a+17|0,Pd(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function $w(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){Zh(a);break a}nm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=nm(b+8|0,x[d>>2],x[d+4>>2]);x[31721]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(169,e+40|0,b|0,c|0,g|0);c=x[31721];x[31721]=0;b:{if((c|0)!=1){he(d);fb=b+16|0;break b}a=N()|0;he(d);Q(a|0);p()}b=Jd(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;zp(a,e+8|0,e)}fb=e+48|0}function uo(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Kb(e+8|0,a+1074312|0,3);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Kb(e+8|0,a+1074312|0,3);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=rq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function _E(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((y[a|0]|y[a+1|0]<<8)!=26217){if((y[a|0]|y[a+1|0]<<8)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}c=a+110|0;b=a+2|0;while(1){if((b|0)==(c|0)){while(1){b=(e|0)==128;if(b){break a}c=a+e|0;d=v[c+113|0];if((d|0)<-2){break a}f=y[c+241|0];if(!f&(d|0)>=0|f>>>0>15){break a}e=e+1|0;if(y[c+369|0]<64){continue}break a}}c:{if((y[b|0]-1&255)>>>0>30){break c}d=d+1|0;if((d&255)>>>0<=40){break c}return 0}b=b+1|0;continue}}return b}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=fb-32|0;fb=f;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[31721]=0;e=U(153,g|0,e|0,8)|0;g=x[31721];x[31721]=0;if((g|0)==1){break c}if(e){x[31721]=0;S(915,f+4|0,b|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break e}x[31721]=0;O(916,a|0,f+4|0);e=x[31721];x[31721]=0;if((e|0)==1){break d}e=f+4|0;Fd(e);g=e;e=tr(x[a+4>>2]);ti(g,x[e>>2],x[e+4>>2]);if(x[f+4>>2]!=(d|0)){continue}}break}fb=f+32|0;break a}b=N()|0;break b}b=N()|0;Fd(f+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function Fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Kk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){aD(a,d,c);break a}b=Ab(a);b=UY(e+12|0,XC(a,Kk(x[a>>2],f)+d|0),Kk(x[a>>2],x[a+4>>2]),b);TY(b,d,c);c=fb-16|0;fb=c;d=zb(c+12|0,x[a+4>>2]);f=zb(c+8|0,x[a>>2]);g=zb(c+4|0,x[b+4>>2]);h=b,i=QY(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=c+16|0;SY(b)}fb=e+32|0;return}if(b>>>0<d>>>0){$C(a,e+D(b,6)|0)}}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38130>>1])+D(w[f-2>>1],w[e+38128>>1])|0)+D(w[f+2>>1],w[e+38132>>1])|0)+D(w[f+4>>1],w[e+38134>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function zj(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Bd(y[Dm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31721]=0;b=U(88,d|0,b|0,c|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Bm(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31721]=0;X(87);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Qb()}p()}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;kd(b,0);f=e+8|0;hk(f,1,a+33|0);d=e+20|0;Ac(d,f);ye(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Sb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function SR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=nc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){EE(a,b,h);break b}c=Ab(a);c=ig(f+12|0,Uf(a,nc(x[a>>2],d)+b|0),nc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=Bn(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){qo(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=g+16|0;Id(a,c);hg(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Xh(a,d+(b<<2)|0)}}AA(a);fb=e+16|0}function sQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Oz(a);c=Ld(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;au(a);return;case 3:v[a+4240|0]=c>=E(.5);au(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Jl(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[ak(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Nz(a)}C[a+4256>>3]=c;break;default:break a}}}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Lf(d+52|0);x[31721]=0;c=P(653,b|0,e|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(654,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31721]=0;S(188,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=hc(d+32|0,b);gd(e+8|0,c);ub(c);ub(b);Qk(a,e)}Fd(e);fb=d+80|0}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Rh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Jb(a);g=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;e=Ah(x[$c(c+4|0,c+12|0)>>2])+1|0}else{e=2147483631}og(g,e);e=x[c+4>>2];if(d){xg(e,f,d)}if((d|0)!=10){Db(f)}wd(a,e);mf(a,x[c+8>>2]);fb=c+16|0;break e}nf();p()}c=d}d=x[a>>2];Wd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function X0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=fl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Nr(c+4|0,fl(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Nr(c+4|0,d-e|0);break b}vF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}vF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;vT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;gc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=Ab(a);h=f+12|0;e=qB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=Gh(613566756);if(e>>>0<=d>>>0){e=rB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}cd();p()}c=yT(h,d,qB(x[a>>2],x[a+4>>2]),g);vT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;xT(a,c);wT(c);fb=f+32|0}function Bsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31721]=0;c=U(153,e|0,c|0,8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}if(c){x[31721]=0;O(411,d+4|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(412,a|0,d+4|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}c=d+4|0;Fd(c);e=c;c=tr(x[a+4>>2]);ti(e,x[c>>2],x[c+4>>2]);if((_b(x[d+4>>2])|0)!=1162757187){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Fd(d+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function Oqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Lf(d+52|0);x[31721]=0;e=P(525,b|0,c|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(526,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31721]=0;S(188,d+12|0,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;Fd(c);Q(a|0);p()}b=d+12|0;e=hc(d+32|0,b);gd(c+8|0,e);ub(e);ub(b);tY(a,c)}Fd(c);fb=d+80|0}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38130>>1])+D(v[f-1|0],w[e+38128>>1])|0)+D(v[f+1|0],w[e+38132>>1])|0)+D(v[f+2|0],w[e+38134>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function sW(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=vW(a+20|0)}return c}function W0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=fl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Nr(c+4|0,fl(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Nr(c+4|0,d-e|0);break b}uF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}uF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function zta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;kd(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function gN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=hq(a);d:{if(!e){if(fq(a)>>>0<=b>>>0){break d}a=qi(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=$b(8);x[31721]=0;b=P(37,d+4|0,6e3)|0;c=x[31721];x[31721]=0;e:{if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;ic(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function ij(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;Wf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=f+16|0}function Tc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+4>>2]=1213;x[b>>2]=a;x[b+8>>2]=0;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=zb(c+8|0,tf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){wd(a,1);b=x[x[b>>2]>>2];x[31721]=0;W(1214,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;wd(a,0);x[31721]=0;X(87);a=x[31721];x[31721]=0;c:{if((a|0)==1){a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){break c}T(0)|0;Qb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function XO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=x[a+24>>2];if(z[d+480188>>1]<=b>>>0){break a}x[31721]=0;O(1060,c+8|0,(d+(b<<5)|0)+480289|0);d=x[31721];x[31721]=0;if((d|0)!=1){d=x[a+24>>2];x[31721]=0;S(1061,c+20|0,d|0,c+8|0);d=x[31721];x[31721]=0;if((d|0)==1){break e}x[31721]=0;O(181,e|0,c+20|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}b=b+1|0;tb(c+20|0);tb(c+8|0);continue}break}b=N()|0;break b}b=N()|0;break c}b=N()|0;tb(c+20|0)}tb(c+8|0)}Qd(e);Q(b|0);p()}fb=c+32|0}function tW(a,b,c,d,e,f){b=y[(b&15)+25376|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}uc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);b:{d=Yc(x[b>>2],x[b+4>>2]);if(!d){break b}x[31721]=0;O(644,a|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31721]=0;JB(a,f,e,d);d=x[31721];x[31721]=0;if((d|0)!=1){break b}}a=N()|0;Wj(c+8|0);Q(a|0);p()}d=c+8|0;Md(d);Wj(d);fb=c+16|0;x[31721]=0;P(3,a+12|0,b+12|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;ld(a);Q(b|0);p()}}function Qpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-608|0;fb=f;b=fb-16|0;fb=b;d=f+8|0;DX(b+8|0,d);c=x[b+12>>2];nd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){fd(a,x[b+12>>2])}fb=b+16|0;c=(c|0)==(e|0);if(!c){CX(d)}b=-1;a:{if(!c){break a}b=0;if(!EX(f+8|0)){break a}b=-1;if(!hh(a,1024)){break a}b=0;d=fb-1024|0;fb=d;c=fb-16|0;fb=c;yC(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){fd(a,x[c+12>>2])}fb=c+16|0;if((e|0)==(g|0)){b=zC(d,0)>>>0<17}fb=d+1024|0}fb=f+608|0;return b|0}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31721]=0;c=U(153,e|0,c|0,8)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}if(c){x[31721]=0;O(684,d+4|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break e}x[31721]=0;O(685,a|0,d+4|0);c=x[31721];x[31721]=0;if((c|0)==1){break d}c=d+4|0;Fd(c);e=c;c=tr(x[a+4>>2]);ti(e,x[c>>2],x[c+4>>2]);if(x[d+4>>2]!=1413891155){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Fd(d+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function Dv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;i=fb-16|0;fb=i;b=fc(i+8|0,x[g+8>>2],x[g+12>>2]);e=fb-16|0;fb=e;d=121;x[e+12>>2]=121;c=x[b+4>>2];a:{if(!c){c=x[b>>2];break a}f=32-c|0;x[e+8>>2]=f;d=x[b>>2];j=x[d>>2];h=f;f=x[Gb(e+8|0,e+12|0)>>2];x[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=x[e+12>>2];c=d+4|0;x[b>>2]=c;d=j-f|0}h=c;c=d>>>5|0;qF(h,c);f=d&31;x[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=x[b>>2]+(c<<2)|0;x[h>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-f^-1)}fb=e+16|0;fb=i+16|0;fb=g+16|0;return a}function NA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;g=xu(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Kb(d+8|0,h,117);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}e=D(b,872)+a|0;i=e+1075648|0;c=x[i>>2];if(!c|!y[c+33|0]){break a}f=a;a=e+1074992|0;e=rq(f,x[a+88>>2],c);if(!e){break a}Kb(d+8|0,h,34);f=!Hb(x[x[d+8>>2]>>2],x[d+12>>2]);c=Zg(y[a+797|0]-w[a+770>>1]|0);b:{if(f|c-1<<24>>24<0){break b}a=x[a+656>>2];if(!a){break b}c=y[vb(a+108|0,c-1|0)|0]}ib[x[x[e>>2]+88>>2]](e,g,c&255,v[x[i>>2]+33|0],b)}fb=d+16|0}function _fa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Ck(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Ck(E(E(c>>>0)*E(1.1892070770263672)));e=Ck(E(E(d>>>0)*E(1.1892070770263672)));h=Ck(E(E(e>>>0)*E(1.1892070770263672)));f=Ck(E(E(c+e>>>0)*E(.11546666920185089)));g=Ck(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=xb(b,0),j=c-f|0,x[i>>2]=j;i=xb(b,1),j=e-f|0,x[i>>2]=j;i=xb(b,2),j=d-g|0,x[i>>2]=j;i=xb(b,3),j=h-g|0,x[i>>2]=j;i=xb(b,4),j=f,x[i>>2]=j;i=xb(b,5),j=g,x[i>>2]=j;FP(a);DP(a)}function JO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;a:{f=a+36|0;c=x[f>>2];d=x[a+40>>2];b:{if(Ib(c,d)){qc(b+12|0);break b}po(b,a);x[31721]=0;c=R(1064,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[b+12>>2]=c;lf(b);d=x[a+40>>2];c=x[a+36>>2]}c=(g=f,h=x[b+12>>2],i=Ib(c,d),i?g:h);a=x[a+8>>2];c:{if((a|0)==-1){g=b,h=wb(x[c>>2]),x[g>>2]=h;a=wb(x[c+4>>2]);while(1){c=x[b>>2];if(!Ib(c,a)){break c}e=e+C[c>>3];Wz(b);continue}}e=C[sf(x[c>>2],a)>>3]}xl(b+12|0);fb=b+16|0;return+e}a=N()|0;lf(b);Q(a|0);p()}function sS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}f=x[a+480208>>2]&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(g){if(e&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));Ee(d+12|0,0,256);x[a>>2]=x[d+12>>2]}fb=d+16|0}function nB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return xq(a,b)}return Kl(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Kl(xq(c,a),D(a,-100)+b|0)}return jB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return jB(xq(c,a),D(a,-1e4)+b|0)}return gB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return gB(xq(c,a),D(a,-1e6)+b|0)}return Au(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Au(xq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Au(Kl(c,a),D(a,-1e8)+b|0)}function tta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;kd(b,0);e=c+8|0;hk(e,1,a);d=c+20|0;Ac(d,e);ye(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Sb(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function Roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Lf(c+52|0);x[31721]=0;e=P(691,b|0,d|0)|0;f=x[31721];x[31721]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(692,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31721]=0;S(188,c+12|0,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;Fd(d);Q(a|0);p()}b=c+12|0;e=hc(c+32|0,b);gd(d+8|0,e);ub(e);ub(b);Qk(a,d)}Fd(d);fb=c+80|0}function _ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=of(e+20|0,1,0);a:{b:{while(1){f=Jb(d);SB(e+12|0,f,Bb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=mi(Bb(x[d+4>>2],y[d+11|0]));x[31721]=0;O(46,d|0,f|0);f=x[31721];x[31721]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31721]=0;O(47,d|0,b-c|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){x[31721]=0;O(48,a|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function L5(a){a=a|0;if(y[500488]){return x[125121]}if(!y[501296]){v[501296]=1}id(501008,5034);id(501020,5025);id(501032,10875);id(501044,10619);id(501056,5261);id(501068,11652);id(501080,5118);id(501092,5609);id(501104,8886);id(501116,8869);id(501128,8877);id(501140,8896);id(501152,10073);id(501164,13314);id(501176,8959);id(501188,7714);id(501200,5261);id(501212,9762);id(501224,10478);id(501236,10887);id(501248,9249);id(501260,6463);id(501272,5492);id(501284,13232);v[500488]=1;x[125121]=501008;return 501008}function H0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;a:{if(!OE(a,b+12|0)){break a}b:{if(NE(b+12|0)){if(fd(a,32)){break b}break a}c=0;if(!ME(b+12|0)){break a}}e=b+7|0;d=LE(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Gb(c+28|0,c+8|0)>>2];if(!hh(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;bk(f,e);g=fc(c+16|0,x[c+8>>2],d);nd(c,a,x[g>>2],x[g+4>>2]);bk(f,e);Tb(x[c+8>>2]+d|0,0,5-d|0);fd(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=KE(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=of(e+20|0,1,0);a:{b:{while(1){f=Jb(d);wN(e+12|0,f,Bb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=mi(Bb(x[d+4>>2],y[d+11|0]));x[31721]=0;O(46,d|0,f|0);f=x[31721];x[31721]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31721]=0;O(47,d|0,b-c|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){x[31721]=0;O(306,a|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=fb-16|0;fb=e;f=x[c+4>>2];h=x[c+8>>2];g=Tj(f,h);a:{if(g>>>0<=So(d)>>>0){i=h;j=x[d>>2];k=Rc(j,x[d+4>>2]);l=k>>>0>=g>>>0;if(!l){x[e+12>>2]=f;x[e+12>>2]=k+x[e+12>>2];i=x[e+12>>2]}f=Qi(f,i,j);if(!l){hv(d,i,h,g-Rc(x[d>>2],x[d+4>>2])|0);break a}Vq(d,f);break a}Ov(d);_k(d,Wl(d,g));hv(d,f,h,g)}fb=e+16|0}yc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Z2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(jh(a,x[b+8>>2],e)){Fx(b,c,d);return}a:{if(jh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function LU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function YG(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Lf(e+52|0);x[31721]=0;d=P(d|0,b|0,f|0)|0;g=x[31721];x[31721]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31721]=0;R(c|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31721]=0;S(188,e+12|0,b|0,_b(c)|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}a=N()|0;Fd(f);Q(a|0);p()}b=e+12|0;c=hc(e+32|0,b);gd(f+8|0,c);ub(c);ub(b);Qk(a,f)}Fd(f);fb=e+80|0}function Bpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ac(c+8|0,b,26);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function bK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[31596];x[31596]=0;Kd();a=$J(a,e+12|0,d);d=hb;d:{f=x[31596];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[31596]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}fb=e+16|0;return b}function Ym(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function gra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=ox(c+4|0,a);d=x[a+4>>2];x[31721]=0;O(505,d|0,b|0);b=x[31721];x[31721]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;gc(a);fb=c+16|0;break a}b=N()|0;gc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=Ab(a);c=vm(d+12|0,Ep(a,Rd(x[a>>2],x[a+4>>2])+1|0),Rd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31721]=0;O(505,e|0,b|0);b=x[31721];x[31721]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;nx(a,c);is(c);fb=d+32|0;break b}a=N()|0;is(c);Q(a|0);p()}}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{if((d|0)==1){break a}x[31721]=0;W(1076,c|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31721]=0;b=Ya(1077,d|0,E(e),b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31721]=0;V(991,10353,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(gt(a)){break c}}if(m){if(ft(a)){break c}}if(l){if(et(a)){break c}}if(k){if(dt(a)){break c}}if(j){if(ct(a)){break c}}if(i){if(bt(a)){break c}}if(h){if(Jh(a)){break c}}if(g){if(at(a)){break c}}if(f){if($s(a)){break c}}if(!e){break b}if(!_s(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function jT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=-1;a:{if(!(y[b+851|0]&2)){break a}d=x[a+480208>>2]&8192;b:{c:{f=x[b+656>>2];if(f){c=y[f+22|0];if(Cd(c)){g=b,h=Rh(c),v[g+838|0]=h;c=1}else{c=!d}d=y[f+21|0];if(Cd(d)){g=b,h=Rh(d),v[g+837|0]=h;break c}if(c){break c}break b}c=!d;x[b+776>>2]=0;x[b+780>>2]=0;break b}c=1;d=y[f+25|0];if((d|0)==255){break b}v[b+845|0]=d}d:{if(y[b+837|0]>=127){if(Ob(a+1074312|0,36)&c){break d}break a}if(!c){break a}}e=wq(a,b,1,256);if((e|0)<0){break a}e=y[b+837|0]>>>1|0}return e}function KH(a,b,c,d,e){var f=0,g=0,h=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Rd(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Dd(f,0);break e}x[31721]=0;P(d|0,h|0,c|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break b}f=Dd(x[b>>2],a)}x[31721]=0;O(e|0,g+4|0,f|0);f=x[31721];x[31721]=0;if((f|0)!=1){x[31721]=0;P(d|0,h|0,g+4|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break d}a=a+1|0;tb(g+4|0);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;kd(b,0);d=e+8|0;vD(d,a+1|0);c=e+20|0;Ac(c,d);ye(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,x[b+8>>2]);fb=e+32|0}function Wm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Yk(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}op(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Bh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function Sfa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=wg(22250);break b}x[31721]=0;c=P(37,b+8|0,a|0)|0;a=x[31721];x[31721]=0;c:{d:{if((a|0)!=1){x[31721]=0;O(990,b+20|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break d}d=b+20|0;a=wg(Jb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31721]=0;V(991,11015,0,0,0);c=x[31721];x[31721]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function SG(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=of(f+20|0,1,0);a:{b:{while(1){g=Jb(e);SB(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=mi(Bb(x[e+4>>2],y[e+11|0]));x[31721]=0;O(46,e|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31721]=0;O(47,e|0,b-c|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){x[31721]=0;O(d|0,a|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function IG(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=of(f+20|0,1,0);a:{b:{while(1){g=Jb(e);wN(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=mi(Bb(x[e+4>>2],y[e+11|0]));x[31721]=0;O(46,e|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31721]=0;O(47,e|0,b-c|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){x[31721]=0;O(d|0,a|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function vs(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=ZN(a);x[a+8>>2]=0;x[a>>2]=47676;x[31721]=0;i=R(858,104)|0;h=x[31721];x[31721]=0;a:{b:{c:{d:{if((h|0)!=1){x[31721]=0;d=R(1107,d|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=x[pe(g+12|0,g+8|0)>>2];x[31721]=0;b=ha(f|0,i|0,b|0,c|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}x[a+8>>2]=b;Uc(g+8|0);b=x[a+8>>2];Wd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(g+8|0)}Db(i)}Mm(a);Q(b|0);p()}function aH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=of(f+20|0,1,0);a:{b:{while(1){g=Jb(e);SB(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=mi(Bb(x[e+4>>2],y[e+11|0]));x[31721]=0;O(46,e|0,g|0);g=x[31721];x[31721]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31721]=0;O(47,e|0,b-c|0);b=x[31721];x[31721]=0;c:{if((b|0)!=1){x[31721]=0;O(d|0,a|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Rna(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;ur(f+12|0,c);x[31721]=0;c=f+24|0;O(600,c|0,d|0);d=x[31721];x[31721]=0;b:{c:{d:{if((d|0)==1){break d}x[31721]=0;c=f+36|0;O(600,c|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}gx(f+4|0,f+12|0);x[31721]=0;V(304,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}On(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;On(f+12|0)}Q(a|0);p()}}function fN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=hq(a);d:{if(!c){if(fq(a)>>>0<=b>>>0){break d}c=(y[qi(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=$b(8);x[31721]=0;b=P(37,d+4|0,6e3)|0;c=x[31721];x[31721]=0;e:{if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;ic(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function _1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;Dp(f+12|0,c);x[31721]=0;c=f+24|0;O(136,c|0,d|0);d=x[31721];x[31721]=0;b:{c:{d:{if((d|0)==1){break d}x[31721]=0;c=f+36|0;O(136,c|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}gx(f+4|0,f+12|0);x[31721]=0;V(95,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}On(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;On(f+12|0)}Q(a|0);p()}}function Jo(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26176|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{d:{if(f=zd(x[b+4>>2],y[b+11|0]),g=1,h=x[b+12>>2],h?f:g){Fb(a);break d}d=Bb(x[b+4>>2],y[b+11|0]);e=Qr(14289);bm(Tg(Tg(Jb(vz(c+20|0,d+e|0)),Jb(b),d)+d|0,14289,e)+e|0,1,0);x[31721]=0;O(129,c+8|0,b+12|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;S(2,a|0,c+20|0,c+8|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}tb(c+8|0);tb(c+20|0)}fb=c+32|0;return}b=N()|0;break a}b=N()|0;tb(c+8|0)}tb(c+20|0);Q(b|0);p()}function WO(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);de(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31721]=0;O(179,e|0,QL(d,b)|0);b=x[31721];x[31721]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((QL(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31721]=0;b=P(37,c+12|0,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;O(181,e|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Qd(e);Q(a|0);p()}function MU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=D(e,g);i=x[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(gt(a)){break b}}if(m){if(ft(a)){break b}}if(l){if(et(a)){break b}}if(k){if(dt(a)){break b}}if(j){if(ct(a)){break b}}if(i){if(bt(a)){break b}}if(h){if(Jh(a)){break b}}if(g){if(at(a)){break b}}if(f){if($s(a)){break b}}if(e){if(_s(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}
function wra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+12|0;f=Nb(e+8|0);x[31721]=0;d=R(205,b|0)|0;g=x[31721];x[31721]=0;a:{b:{if((g|0)==1){break b}x[31721]=0;S(172,e|0,b|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break b}d=x[e>>2];x[31721]=0;P(186,b|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;cc(f);Q(a|0);p()}Gn(c+4|0,e);x[31721]=0;S(479,a|0,x[c+4>>2],x[c+8>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Ic(c+12|0);fb=c+32|0;return}a=N()|0;Ic(c+12|0);Q(a|0);p()}function us(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=ZN(a);x[a+8>>2]=0;x[a>>2]=47676;x[31721]=0;h=R(858,104)|0;g=x[31721];x[31721]=0;a:{b:{c:{d:{if((g|0)!=1){x[31721]=0;c=R(1107,c|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=x[pe(f+12|0,f+8|0)>>2];x[31721]=0;b=ba(e|0,h|0,b|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}x[a+8>>2]=b;Uc(f+8|0);b=x[a+8>>2];Wd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(f+8|0)}Db(h)}Mm(a);Q(b|0);p()}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=Cf(a,c);Zd(e,x[a+36>>2]);h=a;a:{if(!f){Oc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];nl(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;wk(b,x[Gb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(nc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;kq(g,d+4|0);a=x[b>>2];i=xb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}cf(h,c);fb=e+16|0}function Ss(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((dp(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=ey(i+4|0,b,f);h=Jb(f);x[31721]=0;h=U(1237,a|0,h|0,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}Rb(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((dp(a,c,b)|0)!=(b|0)){break b}}VD(e);j=a}fb=i+16|0;return j|0}a=N()|0;Rb(f);Q(a|0);p()}function $M(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;d=P(37,d+8|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,d);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=Wi(C[Ug(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function IR(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!ge(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){jn(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Yk(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}fb=d+32|0;return f>>>0<3999}function yM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=DA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=DA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Bb(x[a+4>>2],y[a+11|0]);d=mn(a);f=Pd(b,c);a:{if(!f){break a}b:{if(!mJ(a,b)){if(d-e>>>0<f>>>0){_x(a,d,(e+f|0)-d|0,e,e,0)}d=Jb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}wd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=Yn(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31721]=0;U(1255,a|0,c|0,Bb(d,e)|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){Rb(b);break a}a=N()|0;Rb(b);Q(a|0);p()}wd(d,0);kg(a,e+f|0)}fb=g+16|0;return a|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;f=e+8|0;Zi(f,2,a+2|0);d=e+20|0;Ac(d,f);xc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;hR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);hR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=e+32|0}else{d=y[(a+c|0)+31|0];h=Zb(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function hX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=fc(c+8|0,c+24|0,8);e=x[d>>2];jc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Ub(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17486,9079,601,13222);p()}_(17465,9079,599,13222);p()}return d|0}function c7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Bb(x[a+4>>2],y[a+11|0]);d=Kc(a);f=Tj(b,c);a:{if(!f){break a}b:{if(!Az(a,b)){if(d-e>>>0<f>>>0){Om(a,d,(e+f|0)-d|0,e,e,0,0)}d=Jb(a)+e|0;while(1){if((b|0)==(c|0)){break b}ed(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=oi(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31721]=0;U(1248,a|0,c|0,Bb(d,e)|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}ed(d,0);kg(a,e+f|0)}fb=g+16|0;return a|0}function ex(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){b=fb-16|0;fb=b;a=YF(b+4|0,a);c=x[a+4>>2];x[31721]=0;W(167,c|0);c=x[31721];x[31721]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;gc(a);fb=b+16|0;break a}b=N()|0;gc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=Ab(a);b=WF(c+12|0,XF(a,Ur(x[a>>2],x[a+4>>2])+1|0),Ur(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31721]=0;W(167,d|0);d=x[31721];x[31721]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;VF(a,b);Tw(b);fb=c+32|0;break b}a=N()|0;Tw(b);Q(a|0);p()}}function Wf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function B0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;kd(b,0);e=d+8|0;hk(e,1,a+33|0);c=d+20|0;Ac(c,e);ye(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Sb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function Zo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;f=(y[vb(b,0)|0]&15)<<8|y[vb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=z[(e<<1)+31088>>1];if(f>>>0>=d>>>0){if(!e|(f|0)==(d|0)|(z[(e<<1)+31086>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=y[vb(b,2)|0];d=y[vb(b,0)|0];v[c+3|0]=0;v[c+1|0]=d&16|e>>>4;c=y[vb(b,2)|0];h=g,i=y[vb(b,3)|0],v[h+15|0]=i;be(a,c&15,g+15|0);fb=g+16|0}function WR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function kA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Vd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;kA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Vd(x[a>>2],c);Oi(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;kA(a,b|c,f,e)}fb=e+48|0}function era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ae(a);a:{if(d){b=dc(f);while(1){a=d;d=z[a+16>>1];if(Uo(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Uo(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=dc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){$Y(c,f,e+4|0);Xg(f,x[c+12>>2],b,x[c>>2]);a=ie(c);_Y(c);h=1}Wg(e+8|0,x[zb(c,a)>>2],h);fb=c+16|0;a=rd(x[e+8>>2]);fb=e+16|0;return a+4|0}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];fg(x[x[d>>2]-12>>2]+d|0,0);e=x[b>>2];d=x[e+8>>2];e=x[e+12>>2];g=e;if(d|e){h=x[a+36>>2];g=x[a+20>>2]+g|0;e=x[a+16>>2];d=d+e|0;e=di(f+32|0,d,d>>>0<e>>>0?g+1|0:g);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;Rm(h,f)}d=f+16|0;Zd(d,x[a+36>>2]);FB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=rl(d,vb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=f+48|0}function PQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ae(a);a:{if(d){b=dc(f);while(1){a=d;d=z[a+16>>1];if(Jq(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Jq(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=dc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){$Y(c,f,e+4|0);Xg(f,x[c+12>>2],b,x[c>>2]);a=ie(c);_Y(c);h=1}Wg(e+8|0,x[zb(c,a)>>2],h);fb=c+16|0;a=rd(x[e+8>>2]);fb=e+16|0;return a+4|0}function DF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=x[b+84>>2];if(c>>>0<=15){d=x[e>>2]}else{x[f+12>>2]=c-16;d=x[$c(e,f+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{if(!(!BF(d,c)|x[e>>2]!=x[c+12>>2])){e=1;d=x[b+84>>2];if((d|0)==x[c+16>>2]){break b}}e=0;d=x[b+84>>2];if((d|0)!=x[c+8>>2]){break a}}h=a,i=D((x[c>>2]-d|0)+(e?112:48)|0,bl(z[c+34>>1]))+g|0,x[h+4>>2]=i}fb=f+16|0}function Tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!tm(a,1084)){break a}Yl(a,1080);c=d+60|0;RX(a,c);f=QX(d+40|0);b=0;if(!PX(c,f)){break a}Yl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!OX(a,g)|!c){break b}qv(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];pg(vb(i,c),vb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=FC(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Wi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=Aua(zua(f,f>>31,d,j),hb,65536,0);n=i,o=Fc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;pM(a,c);fb=c+16|0}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Wi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=Aua(zua(f,f>>31,d,j),hb,65536,0);n=i,o=Fc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;vM(a,c);fb=c+16|0}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];fg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=di(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Rm(i,g)}e=g+16|0;Zd(e,x[a+36>>2]);LQ(d,x[a+36>>2],c);c=x[b>>2];b=rl(e,vb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=g+48|0}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];fg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=di(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Rm(i,g)}e=g+16|0;Zd(e,x[a+36>>2]);HQ(c,x[a+36>>2],d);c=x[b>>2];b=rl(e,vb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=g+48|0}function ym(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=mn(a);e=Pd(b,c);if(d>>>0<e>>>0){if(mJ(a,b)){break c}g=d;h=e-d|0;d=Bb(x[a+4>>2],y[a+11|0]);_x(a,g,h,d,0,d)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}wd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=Yn(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31721]=0;S(1360,a|0,c|0,Bb(e,d)|0);c=x[31721];x[31721]=0;if((c|0)!=1){Rb(b);break a}a=N()|0;Rb(b);Q(a|0);p()}wd(d,0);kg(a,e)}fb=f+16|0;return a|0}function xN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-Ot(d|1,e)|0,1233)>>>12|0;j=(i<<3)+124016|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=nB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=Bua(d,e,1410065408,2);f=zua(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=nB(b,c)}c=Bua(d,e,1e8,0);e=hb;b=Kl(b,c);c=zua(c,e,-1e8,0)+d|0;c=Au(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Rc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){d=wb(c);g=wb(x[x[a+20>>2]+8>>2]);xr(b+8|0,a+4228|0);f=wb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;Xl(c+24|0,d,g);Gk(c+16|0,x[c+24>>2],x[c+28>>2],f);d=FD(d,x[c+16>>2]);h=c,i=ED(f,x[c+20>>2]),x[h+12>>2]=i;Ud(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}Rz(a,a)}Xt(a);fb=b+16|0}function ew(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Bb(x[b+4>>2],c);a:{if(b>>>0<=10){Ke(a,b);ed(xg(a,d,b)+b|0,0);break a}e=a;a=Rh(y[a+11|0]);Np(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);c=bj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Wd(a,b);ed(xg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Np(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function ds(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Bb(x[b+4>>2],c);a:{if(b>>>0<=10){Ke(a,b);ed(Tg(a,d,b)+b|0,0);break a}e=a;a=Rh(y[a+11|0]);Eq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);c=bj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Wd(a,b);ed(Tg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Eq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function _O(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=Kc(a);e=Tj(b,c);if(d>>>0<e>>>0){if(Az(a,b)){break c}g=d;h=e-d|0;d=Bb(x[a+4>>2],y[a+11|0]);Om(a,g,h,d,0,d,0)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}ed(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=oi(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31721]=0;S(75,a|0,c|0,Bb(e,d)|0);c=x[31721];x[31721]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}ed(d,0);kg(a,e)}fb=f+16|0;return a|0}function UX(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!wf(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!wf(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function FH(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[31721]=0;W(1004,a|0);j=x[31721];x[31721]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31721]=0;ga(h|0,i+4|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}a=i+4|0;b=wg(Jb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31721]=0;V(991,g|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function k7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;IJ(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;Tp(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){TK(d+12|0,v[e|0]);e=e+1|0;continue}break}Qj(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ud(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function cw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((dp(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=of(i+4|0,b,f);g=Jb(f);x[31721]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31721];x[31721]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((dp(a,c,b)|0)!=(b|0)){break b}}VD(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function ZJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31596];x[31596]=0;Kd();a=ny(a,e+12|0,d);d=hb;g=x[31596];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31596]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function OG(a,b,c,d,e,f){var g=0;a:{g=fb-48|0;fb=g;Un(g+12|0,c);x[31721]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31721];x[31721]=0;b:{c:{d:{if((d|0)==1){break d}x[31721]=0;c=g+36|0;O(94,c|0,e|0);d=x[31721];x[31721]=0;if((d|0)==1){break d}gx(g+4|0,g+12|0);x[31721]=0;V(95,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}On(g+12|0);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;On(g+12|0)}Q(a|0);p()}}function Mta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=gg(d+4|0,c+16|0);f=Xc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[bc(b,0)|0]==43){break c}if(y[bc(b,0)|0]==45){break c}}x[31721]=0;U(307,b|0,f-c|0,e|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Zc(a,b);fb=d+16|0}function sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=om(d+4|0,c+16|0);f=Xc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[bc(b,0)|0]==43){break c}if(y[bc(b,0)|0]==45){break c}}x[31721]=0;U(49,b|0,f-c|0,e|0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Zc(a,b);fb=d+16|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=42524;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Tb(a+4248|0,0,48);x[31721]=0;X(856);c=x[31721];x[31721]=0;a:{if((c|0)==1){break a}e=a,f=bS(),x[e+4296>>2]=f;au(a);$t(a);x[31721]=0;O(949,a+44|0,2);c=x[31721];x[31721]=0;if((c|0)==1){break a}return a|0}c=N()|0;cc(b);Vf(a);Q(c|0);p()}function EH(a,b,c,d,e,f,g){var h=0,i=0;h=fb-16|0;fb=h;x[31721]=0;W(1004,a|0);i=x[31721];x[31721]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31721]=0;ja(g|0,h+4|0,i|0,b|0,c|0,d|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}a=h+4|0;b=wg(Jb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31721]=0;V(991,f|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function YS(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=tA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Xb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function WQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=nc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){bA(a,c,b);break a}e=Ab(a);d=ig(f+12|0,Uf(a,nc(x[a>>2],d)+c|0),nc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=Bn(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){xk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}ee(c);fb=g+16|0;Id(a,d);hg(d)}fb=f+32|0;return}if((c|0)!=128){Xh(a,d+512|0)}}function St(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Pf(f,b);x[31721]=0;S(11,c+20|0,0,f|0);b=x[31721];x[31721]=0;a:{b:{c:{if((b|0)!=1){x[31721]=0;O(970,e|0,c+20|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31721]=0;P(968,a|0,e|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function xR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Dl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Dl(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Dl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Dl(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;cn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31721]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=eg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31721]=0;S(736,b|0,d|0,Rc(e,a)>>>5|0);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;Ui(d);ub(b);break a}ub(b);cc(c+52|0);fb=c- -64|0;return}a=N()|0}cc(c+52|0);Q(a|0);p()}function koa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;cn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31721]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=eg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31721]=0;S(737,b|0,d|0,Rc(e,a)>>>2|0);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;sc(d);ub(b);break a}ub(b);cc(c+52|0);fb=c- -64|0;return}a=N()|0}cc(c+52|0);Q(a|0);p()}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;cn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31721]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=eg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31721]=0;S(738,b|0,d|0,Rc(e,a)>>>8|0);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;ev(d);ub(b);break a}ub(b);cc(c+52|0);fb=c- -64|0;return}a=N()|0}cc(c+52|0);Q(a|0);p()}function ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;cn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31721]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=eg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31721]=0;S(739,b|0,d|0,Rc(e,a)>>>4|0);a=x[31721];x[31721]=0;if((a|0)==1){a=N()|0;dn(d);ub(b);break a}ub(b);cc(c+52|0);fb=c- -64|0;return}a=N()|0}cc(c+52|0);Q(a|0);p()}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;kd(b,0);e=d+8|0;vD(e,a+1|0);c=d+20|0;Ac(c,e);ye(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,x[b+8>>2]);fb=d+32|0}function QK(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(fL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31721]=0;b=R(1190,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31721]=0;W(1191,a+b|0);a=x[31721];x[31721]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break a}}return}T(0)|0;Qb();p()}function J0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Dc(168);x[31721]=0;g=P(37,f+4|0,22250)|0;d=x[31721];x[31721]=0;a:{b:{c:{if((d|0)!=1){x[31721]=0;d=U(38,h|0,g|0,0)|0;i=x[31721];x[31721]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;el(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31721]=0;S(27,a|0,c|0,b|0);a=x[31721];x[31721]=0;if((a|0)!=1){Yb(c);fb=e+16|0;return}a=N()|0;Yb(c);Q(a|0);p()}function gm(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(fL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31721]=0;b=R(31,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31721]=0;O(24,a+b|0,1);a=x[31721];x[31721]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break a}}return}T(0)|0;Qb();p()}function Zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);h=wb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[tn(g+12|0)>>2];continue}break}fb=g+16|0;if(kc(d,wb(x[b+4>>2]))){Zh(a);return}fp(a,d)}function $H(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=ln(x[$c(i+4|0,i+12|0)>>2])+1|0}else{c=1073741807}Rj(j,c);c=x[i+4>>2];if(e){Vi(c,k,e)}if(g){Vi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Vi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}wd(a,c);mf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Wd(b,a);wd(c+(a<<2)|0,0);fb=i+16|0;return}nf();p()}function nT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Vj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=QA(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=dc(a);h=zh(c,Dc(28),Jg(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=dc(h),k=1,v[j+4|0]=k;fb=e+16|0;Xg(a,x[c+12>>2],g,x[c>>2]);b=ie(c);Zl(c);e=1}Wg(d+8|0,x[zb(c,b)>>2],e);fb=c+16|0;a=rd(x[d+8>>2]);fb=d+16|0;return a+8|0}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=z[a+30>>1];if(d){b=Zz(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!zd(x[c+4>>2],y[c+11|0])){ds(PQ(a,e+14|0),c);break a}b=_z(a,e+14|0);if(!Vg(b,Kf(a))){break a}c=fb-16|0;fb=c;b=x[zb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=Yg(zb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Ab(a);x[g>>2]=x[g>>2]-1;PU(x[dc(a)>>2],b);a=x[f>>2];fb=d+16|0;Ik(rd(b));Db(b);zb(c+12|0,a);fb=c+16|0}fb=e+16|0}function xua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!hh(a,7)){break b}c=0;if(!vE(a,18426)){break a}if(!hh(a,1)){break b}c=-1;if(!fd(a,yr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;xr(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){jE(f)}c=-1;if(!e){break a}c=0;if(!b0(y[d+9|0],y[d+10|0])){break a}c=te(a,b,a0(d+9|0),hb);break a}c=-1}fb=d+16|0;return c|0}function o9(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(sL(1,c+24|0)){st(x[31596],12779);p()}b=ue(c+16|0,x[c+24>>2],x[c+28>>2]);f=JA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=ue(e+8|0,zua(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=ue(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=ue(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function WJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31596];x[31596]=0;Kd();a=ny(a,e+12|0,d);d=hb;d:{g=x[31596];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[31596]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}fb=e+16|0;hb=a;return b}function paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Xl(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Cc(b,x[e>>2]);x[31721]=0;P(1153,b+12|0,c|0)|0;i=x[31721];x[31721]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}Qj(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ud(f+8|0,$z(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function GE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Yc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){xE(a,b);break a}c=Ab(a);c=ik(e+12|0,jk(a,Yc(x[a>>2],d)+b|0),Yc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=sp(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Jw(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);fj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){yn(a,d+(b<<1)|0)}}function xD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-20;fb=c+16|0;AD(x[c+12>>2],g-20|0);c=o_(d+12|0);o_(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function ita(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);x[31721]=0;W(347,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){gc(b);fb=e+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}b=d+8|0;Md(b);_g(b);fb=d+16|0;return a|0}a=N()|0;_g(d+8|0);Q(a|0);p()}function n9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Py(cb(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}fb=e+32|0;return g|0}function VF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-36;fb=c+16|0;Rw(x[c+12>>2],hj(g));c=UF(d+12|0);UF(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function N9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=x[b+292>>2];fg(x[x[e>>2]-12>>2]+e|0,0);Zd(g+16|0,x[b+292>>2]);f=di(g,-1,-1);e=x[g+24>>2];h=x[g+28>>2];a:{if(!Vn(e,h,x[f+8>>2],x[f+12>>2])){b:{if((c|0)!=(e|0)|h){break b}break a}}Ei(x[b+292>>2],c,0,0)}c=x[d+4>>2];e=x[d>>2];d=0;while(1){if(c){f=x[b+292>>2];h=qh(c);zj(f,d+e|0,h);f=x[x[b+292>>2]+4>>2];c=c-f|0;d=d+f|0;if((f|0)==(h|0)){continue}}break}ac(a,e,d);fb=g+32|0}function AU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-32;fb=c+16|0;GB(x[c+12>>2],HB(g));c=zU(d+12|0);zU(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function GG(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31721]=0;a=U(153,g|0,a|0,8)|0;g=x[31721];x[31721]=0;if((g|0)==1){break c}if(!a){break d}x[31721]=0;S(e|0,f+4|0,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;O(d|0,h|0,f+4|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}Fd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Fd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}fe(h);Q(a|0);p()}}function c2(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31721]=0;P(130,a|0,4945)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31721]=0;P(130,a|0,12608)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}}if(zd(x[a+4>>2],y[a+11|0])){x[31721]=0;P(130,a|0,10067)|0;c=x[31721];x[31721]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31721]=0;P(130,a|0,11127)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function Ut(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31590]){b=Ut(x[31590])}if(!x[31516]){break a}c=b|c;a=x[31516];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function Uj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Rc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){kX(a,b);break a}c=Ab(a);c=hn(e+12|0,Wl(a,Rc(x[a>>2],d)+b|0),Rc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=fC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){OW(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);gn(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Vq(a,b+d|0)}}function Jp(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31721]=0;a=U(153,g|0,a|0,e|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break c}if(!a){break d}x[31721]=0;O(d|0,f+4|0,b|0);a=x[31721];x[31721]=0;if((a|0)!=1){x[31721]=0;O(c|0,h|0,f+4|0);a=x[31721];x[31721]=0;if((a|0)==1){break e}Fd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Fd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}fe(h);Q(a|0);p()}}function pc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return pc(a,24)+(pc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=zt(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10077,13258,1632,6865);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-4096|0;fb=c;cn(a,b);a:while(1){if(Rc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[vb(g,b+h|0)|0]+d|0;i=vb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}av(c,cC(c),Ne(wb(g),f));e=e+1|0;continue a}else{d=y[vb(x[a>>2],b+f|0)|0]+d|0;i=vb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}fb=c+4096|0}function Hsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(378,a|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=vi(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){gc(e);fb=f+16|0}else{ej(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Md(b);Wj(b);fb=d+16|0;return a|0}a=N()|0;Wj(d+8|0);Q(a|0);p()}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=x[pe(e+24|0,e+28|0)>>2];x[31721]=0;f=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ba(998,a+8|0,e+8|0,c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){a=uz(a);b=tz(a+88|0);c=sz(a+92|0);d=rz(a+96|0);x[a>>2]=47756;x[b>>2]=47872;x[c>>2]=47952;x[d>>2]=47992;Uc(e+28|0);fb=e+32|0;return a|0}a=N()|0;Uc(e+28|0);Q(a|0);p()}function mR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Gb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Hd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function My(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124227]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31596]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function Yna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Wc(c+12|0,16,1,1,0);x[c+8>>2]=0;kd(a,0);vc(b);a:{b:{if(Dr(b,13822)){bd(b,12);if(!gp(b)){np(d,2)}bd(b,24);break b}if(ek(b,13709)){vc(b);x[c+8>>2]=4;e=1;break a}ed(d,8)}e=0}f=a,g=(hf(b)>>>0)/(D(y[d|0],Xq(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=ag(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Sk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Tb(d,0,x[Gb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function HY(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=nc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){TC(a,b);break a}c=Ab(a);c=ig(e+12|0,Uf(a,nc(x[a>>2],d)+b|0),nc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Bn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){xn(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);hg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Xh(a,d+(b<<2)|0)}}function ET(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Vj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=vB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=dc(a);g=zh(c,Dc(36),Jg(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=dc(g),k=1,v[j+4|0]=k;fb=b+16|0;Xg(a,x[c+12>>2],f,x[c>>2]);b=ie(c);JT(c);d=1}Wg(e+8|0,x[zb(c,b)>>2],d);fb=c+16|0;a=rd(x[e+8>>2]);fb=e+16|0;return a+8|0}function kfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31721]=0;W(1029,a|0);f=x[31721];x[31721]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31721]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11298,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;ew(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Jb(c)+Bb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Jb(c);$n(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(x[a+36>>2],y[a+43|0]);e=a,f=b+Jb(c)|0,x[e+44>>2]=f;RB(c,Kc(c));c=Jb(c);Dy(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){lt(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}lt(a,b)}}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Dc(56),x[h+8>>2]=i;c=qm(x[e+8>>2]);x[c>>2]=77456;g=zc(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=iM(g);x[d>>2]=77620;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Ln(e);Kn(b,zc(a),a);rm(e);fb=f+16|0}function nl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;ji(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;ji(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function ksa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;MZ(h,b);j=g,k=wb(x[g+4>>2]),x[j>>2]=k;h=ng(h);i=z[a+480190>>1];while(1){b=x[g>>2];if(!Ib(b,h)){Gv(g+4|0);break a}b=z[Yo(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Yg(g);continue}}fb=g+16|0}function xz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-48|0;fb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=fc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=ju(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=$b(8);x[31721]=0;b=P(37,b+20|0,8057)|0;c=x[31721];x[31721]=0;b:{if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;ic(a)}Q(c|0);p()}fb=b+48|0;return a|0}p()}function pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Gg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){KB(a,d,c);break c}b=Ab(a);b=Su(e+12|0,Iq(a,Gg(x[a>>2],f)+d|0),Gg(x[a>>2],x[a+4>>2]),b);x[31721]=0;S(790,b|0,d|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}AU(a,b);IB(b)}fb=e+32|0;break a}a=N()|0;IB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){BU(a,e+(b<<5)|0)}}function Fu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=xB(x[a+24>>2],y[a+32|0]);g=Lj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!_i(i,d&65535)){break c}e=x[a>>2];if(Rd(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Dd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!jC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function sU(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function Np(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Ah(x[$c(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}og(j,c);c=x[i+4>>2];if(e){xg(c,k,e)}if(g){xg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){xg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}wd(a,c);mf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Wd(b,a);ed(a+c|0,0);fb=i+16|0;return}nf();p()}function If(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=zua(b,c,h,i);h=hb;e=zua(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=zua(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=zua(f,0,b,0);h=hb;i=0;d=zua(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=zua(b,m,j,e)+h|0;e=hb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function Eq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Ah(x[$c(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}og(j,c);c=x[i+4>>2];if(e){Tg(c,k,e)}if(g){Tg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Tg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}wd(a,c);mf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Wd(b,a);ed(a+c|0,0);fb=i+16|0;return}nf();p()}function jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=jg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Cg(a,f,i);fb=b+16|0}function L_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=fl(a,7),v[f|0]=g;d=fl(a,1);e=fl(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;L_(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31721]=0;W(1029,a|0);e=x[31721];x[31721]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31721]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11443,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Tt(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=ae(a);d=dc(a);f=fb-16|0;fb=f;while(1){if(c){g=Du(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[zb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,ng(a))){if(!Du(b,rd(c))){break a}}c=ng(a)}if(!kc(c,ng(a))){b=x[zb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=Yg(zb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Ab(a);x[d>>2]=x[d>>2]-1;PU(x[dc(a)>>2],b);fb=c+16|0;Zm(rd(b));Db(b)}fb=e+16|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31721]=0;W(1029,a|0);e=x[31721];x[31721]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31721]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11479,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function XJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31596];x[31596]=0;Kd();a=ny(a,e+12|0,d);d=hb;g=x[31596];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31596]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function lH(a,b,c,d,e,f){var g=0,h=0;g=fb-256|0;fb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;Us(h|1,10616,f,x[b+4>>2]);f=Kd();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=mh(d,24,f,h,g)+d|0;f=pj(d,e,x[b+4>>2]);h=g+20|0;ad(h,x[b+28>>2]);x[31721]=0;ga(1235,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){Yb(g+20|0);a=Ss(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;Yb(g+20|0);Q(a|0);p()}return a}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=jg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Cg(a,f,i);fb=b+16|0}function ic(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{c=Ct(a);a=c;if(a>>>0<502704&a>>>0>=502192){b=c-4|0;e=x[125546];d=e;while(1){a=d;if(!(!a|(a|0)==502704)){if((XH(a)|0)==(b|0)){w[a+2>>1]=z[c-2>>1]+z[a+2>>1];break a}if((XH(b)|0)==(a|0)){d=c-2|0;w[d>>1]=z[a+2>>1]+z[d>>1];if(!f){x[125546]=b;w[b>>1]=z[a>>1];break a}g=f,h=Hx(b),w[g>>1]=h;break a}else{d=Ix(z[a>>1]);f=a;continue}}break}g=b,h=Hx(e),w[g>>1]=h;x[125546]=b;break a}Db(c)}}function rW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=xb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Kq(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[d+12>>2]=-1;if(bh(a,d+11|0)){x[d+4>>2]=y[d+11|0];f=x[Gb(d+4|0,d+12|0)>>2];c=fb+-64|0;fb=c;e=c+44|0;_f(e,a,f);g=x[c+44>>2];a=c+20|0;rg(a,3,Se(e),g);x[31721]=0;O(221,c+32|0,a|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){a=c+12|0;fc(a,b,11);b=a;a=c+32|0;km(b,a);tb(a);Ic(c+44|0);fb=c- -64|0;e=!f|(g|0)!=0;break a}a=N()|0;Ic(c+44|0);Q(a|0);p()}}fb=d+16|0;return e|0}function nH(a,b,c,d,e,f){var g=0,h=0;g=fb-112|0;fb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;Us(h|1,10616,f,x[b+4>>2]);f=Kd();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=mh(d,24,f,h,g)+d|0;f=pj(d,e,x[b+4>>2]);h=g+20|0;ad(h,x[b+28>>2]);x[31721]=0;ga(1232,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){Yb(g+20|0);a=cw(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;Yb(g+20|0);Q(a|0);p()}return a}function hF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8)!=26215|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}d=a+514|0;c=a+2|0;while(1){if((c|0)!=(d|0)){f=Ab(c);b=c;while(1){if((b|0)!=(f|0)){g=y[b|0];b=b+1|0;if(g>>>0>31){continue}break a}break}c=c+8|0;continue}break}d=a+772|0;b=a+516|0;c=-1;while(1){e=(b|0)==(d|0);if(e){break a}a=c;c=y[b|0]|y[b+1|0]<<8;a=(a|0)<(c|0);b=b+2|0;if(a){continue}break}}return e}function baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=qm(a);x[e>>2]=76956;d=zc(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=bM(d,cM(b));x[d>>2]=77120;c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31721]=0;W(1029,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31721]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,6695,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31721]=0;W(1029,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31721]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,6749,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Uqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Mf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){DE(a,c);break c}b=Ab(a);b=yD(d+12|0,zD(a,Mf(x[a>>2],e)+c|0),Mf(x[a>>2],x[a+4>>2]),b);x[31721]=0;O(524,b|0,c|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}xD(a,b);Lv(b)}fb=d+32|0;break a}a=N()|0;Lv(b);Q(a|0);p()}return}if(b>>>0<c>>>0){zE(a,d+D(b,20)|0)}}function Dr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);jc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(hd(c+24|0,b,7)){break b}Ub(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17486,9079,601,13222);p()}_(17465,9079,599,13222);p()}return d|0}function sg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Lc(41404,d+14|0)>>1];e=x[a>>2];c=Yc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){kp(a,b,f);break b}c=Ab(a);c=ik(e+12|0,jk(a,Yc(x[a>>2],g)+b|0),Yc(x[a>>2],x[a+4>>2]),c);$E(c,b,f);Id(a,c);fj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){yn(a,e+(b<<1)|0)}}fb=d+16|0}function dV(a,b,c,d){var e=0,f=0,g=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){e=c+1|0;f=11;break b}if((b&254)==16){e=c&15|b<<4|-128;f=14;break b}if((b|0)==18){break b}e=c;f=b;if(b>>>0>18){break a}}xf(a,f,e&255);b=y[a+3|0];c:{d:{if(!((d|0)!=4|(b|0)!=13)){b=y[a+5|0];if(b&3?(b|0)!=255:0){break d}v[a+5|0]=b+3>>>2;return 1}if((b&255)!=13){break c}}b=46;v[a+3|0]=46}g=1;if((d|0)==4|(b&255)!=17|y[a+5|0]!=32){break a}v[a+3|0]=16}return g}function u3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=Yn(f+20|0,b,c);x[31721]=0;e=U(1366,f+8|0,d|0,e|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){a=Jb(g);d=Jb(e);b=x[d>>2];c=x[a>>2];a:{if(!b|!c|(b|0)!=(c|0)){break a}while(1){b=x[d+4>>2];c=x[a+4>>2];if(!b|!c){break a}d=d+4|0;a=a+4|0;if((b|0)==(c|0)){continue}break}}Rb(e);Rb(g);fb=f+32|0;a=c-b|0;return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Rb(g);Q(a|0);p()}function te(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=gh(a);a:{b:{if(!b){i=e,j=gh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Jr(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function bu(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function K2(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31721]=0;m=a;a=0;a=NH(1101,m|a,b,c,d,a|e,f);b=x[31721];x[31721]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31721]=0;ga(987,8843,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}return a|0}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;lM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=D(x[a+16>>2],e+h|0);l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b+k<<2)+l|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function qO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=$b(8);x[31721]=0;b=P(37,h+4|0,8200)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Bl(a,b,4);c=iz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;ic(a)}Q(d|0)}p()}function iO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=$b(8);x[31721]=0;b=P(37,h+4|0,8200)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Bl(a,b,4);c=jz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;ic(a)}Q(d|0)}p()}function AL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function j3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=rc(c+8|0,16776);x[31721]=0;S(101,c+20|0,a|0,b|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Rd(d,x[c+24>>2])>>>0>b>>>0)){Qd(c+20|0);fb=c+32|0;return a|0}x[31721]=0;d=R(102,Dd(d,b)|0)|0;e=x[31721];x[31721]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Qd(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function Rt(a,b,c,d,e){var f=0,g=0;a:{if(!Bt(b)){break a}f=x[a+484344>>2];if(!Ge(f,x[a+484348>>2],b&65535)){break a}b=Vb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=jd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[qd(e+12|0,qd(e+8|0,e+4|0))>>2];b=Vi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function efa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31721]=0;W(1029,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31721]=0;ra(f|0,d|0,b|0,+c);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11678,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Wea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31721]=0;W(1029,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31721]=0;ra(f|0,d|0,b|0,+c);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11616,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Uea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31721]=0;W(1029,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31721]=0;ra(f|0,d|0,b|0,+c);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11066,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function H$(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){jQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;To(a);b=fb-32|0;fb=b;a:{b:{d=So(a);c=Rc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31721]=0;c=ba(958,b+12|0,c|0,c|0,Ab(a)|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){Id(a,c);gn(c);break c}Y(T(0)|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Qb();p()}}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;rM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=e+h|0;l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=x[(b<<2)+l>>2]+(k<<2)|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function x7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-208|0;fb=a;f=Kd();x[a>>2]=e;g=a+176|0;i=mh(g,20,f,9262,a);e=i+g|0;g=pj(g,e,x[c+4>>2]);ad(a+12|0,x[c+28>>2]);x[31721]=0;f=R(1219,x[a+12>>2])|0;h=x[31721];x[31721]=0;if((h|0)!=1){Yb(a+12|0);h=f;f=a+16|0;QJ(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Ss(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;Yb(a+12|0);Q(b|0);p()}function m9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[qd(e+12|0,qd(e+8|0,e+4|0))>>2];b=xg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;d=f+8|0;Te(d,2,a+6|0);e=f+20|0;Ac(e,d);xc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;gA(a+180|0,b+48|0,0);gA(a+228|0,b+88|0,2);gA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Tb(d,0,256)}fb=f+32|0}else{e=y[(a+c|0)+38|0];h=Zb(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function zL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){ec(a,21);return-1}if(x[a+1396>>2]<=9){vl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Fm(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){ec(a,21)}return c}_(7566,13258,1793,5750);p()}function tA(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+31856|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return zR(yo(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30512|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31728|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+31792|0]}function mH(a,b,c,d,e){var f=0,g=0,h=0;f=fb-144|0;fb=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;Us(g|1,10783,e,x[b+4>>2]);e=Kd();x[f>>2]=d;d=f+123|0;e=mh(d,13,e,g,f)+d|0;g=pj(d,e,x[b+4>>2]);h=f+4|0;ad(h,x[b+28>>2]);x[31721]=0;ga(1235,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){Yb(f+4|0);a=Ss(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;Yb(f+4|0);Q(a|0);p()}return a}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=43604;c=Nb(a+4256|0);b=a+4208|0;e=xb(b,0),f=1056964608,x[e>>2]=f;e=xb(b,1),f=1017370378,x[e>>2]=f;e=xb(b,2),f=1028670828,x[e>>2]=f;e=xb(b,3),f=1059760811,x[e>>2]=f;e=xb(b,4),f=1017370378,x[e>>2]=f;e=xb(b,5),f=1065353216,x[e>>2]=f;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;sc(c);Vf(a);Q(b|0);p()}function QT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(Ru(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=No(d+20|0);x[31721]=0;f=P(763,a|0,b|0)|0;g=x[31721];x[31721]=0;if((g|0)==1){break a}x[31721]=0;O(764,e|0,f|0);f=x[31721];x[31721]=0;if((f|0)==1){break a}x[e+4>>2]=b;VB(a,e);yf(e)}fn(d+12|0,x[a>>2]);Fw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;yf(e);Q(a|0);p()}function B1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Dc(32),x[j+8>>2]=k;e=qm(x[f+8>>2]);x[e>>2]=41416;h=zc(e);e=fb-16|0;fb=e;b=nm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Jn(h);x[b>>2]=41552;nm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;he(e);fb=e+16|0;b=a;a=Ln(f);Kn(b,zc(a),a);rm(f);fb=g+16|0}function Xy(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!xt(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}ec(a,32);return 0}_(15789,13258,1564,6036);p()}function bD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Im(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){bh(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Mg(a);Ub(a,b-4|0)}v[f|0]=c}function oH(a,b,c,d,e){var f=0,g=0,h=0;f=fb+-64|0;fb=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;Us(g|1,10783,e,x[b+4>>2]);e=Kd();x[f>>2]=d;d=f+43|0;e=mh(d,13,e,g,f)+d|0;g=pj(d,e,x[b+4>>2]);h=f+4|0;ad(h,x[b+28>>2]);x[31721]=0;ga(1232,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31721];x[31721]=0;a:{if((d|0)!=1){Yb(f+4|0);a=cw(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;Yb(f+4|0);Q(a|0);p()}return a}function Zoa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=Uv(a,127,b+15|0);x[31721]=0;v[b+14|0]=64;d=U(603,a+12|0,127,b+14|0)|0;c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){x[31721]=0;v[b+13|0]=0;P(683,a+24|0,b+13|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;cc(d)}cc(a);Q(b|0);p()}function Wsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Bb(x[a+4>>2],y[a+11|0]);f=Kc(a);a:{if(f-g>>>0>=b>>>0){f=Jb(a);if((c|0)==(g|0)){break a}i=c+f|0;Ri(i+b|0,i,g-c|0);break a}Om(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;kg(a,b);ed(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){ed(b,y[d|0]);b=b+1|0;d=x[je(h+12|0)>>2];continue}break}a=Ne(xd(a),c);fb=h+16|0;return a|0}function lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31721]=0;O(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11308,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31721]=0;O(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,12847,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31721]=0;O(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,12330,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31721]=0;O(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11152,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Rea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31721]=0;la(e|0,c|0,+b);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,15118,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function H7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-96|0;fb=a;f=Kd();x[a>>2]=e;g=a- -64|0;i=mh(g,20,f,9262,a);e=i+g|0;g=pj(g,e,x[c+4>>2]);ad(a+12|0,x[c+28>>2]);x[31721]=0;f=R(28,x[a+12>>2])|0;h=x[31721];x[31721]=0;if((h|0)!=1){Yb(a+12|0);h=f;f=a+16|0;UJ(h,a- -64|0,e,f);h=b;b=f+i|0;b=cw(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;Yb(a+12|0);Q(b|0);p()}function nda(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Jd(d+16|0);x[31721]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;S(1123,d+24|0,a|0,d|0);a=x[31721];x[31721]=0;a:{b:{if((a|0)!=1){a=x[pe(d+12|0,d+44|0)>>2];x[31721]=0;b=+pa(989,d+24|0,+b,a|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}ub(d+24|0);Uc(d+44|0);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Uc(d+44|0);Q(c|0);p()}function cfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31721]=0;la(e|0,c|0,+b);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11716,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31721]=0;O(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,9312,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31721]=0;d=+qa(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11634,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31721]=0;d=+qa(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11697,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function dU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31721]=0;O(806,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=Tu(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){gc(d);fb=e+16|0}else{Ol(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Md(b);TT(b);fb=c+16|0;return a}a=N()|0;TT(c+8|0);Q(a|0);p()}function afa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31721]=0;la(e|0,c|0,+b);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7777,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function _ea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31721]=0;la(e|0,c|0,+b);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7725,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);d=x[31721];x[31721]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31721]=0;d=+qa(e|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11086,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Bx(a,b,c){var d=0,e=0,f=0,g=0;e=Jb(a);a=Bb(x[a+4>>2],y[a+11|0]);d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=nu(c,(f-b|0)+1|0,g);if(!c){break c}if(!kx(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31721]=0;b=P(d|0,c|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,6722,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31721]=0;W(1029,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31721]=0;b=P(d|0,c|0,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,6773,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function ek(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=fc(c+8|0,c+28|0,4);jc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Ub(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17486,9079,601,13222);p()}_(17465,9079,599,13222);p()}return d|0}function YA(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}yk(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=uf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[qd(e+12|0,e+8|0)>>2];xg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function Z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Rc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Gb(e+28|0,e+24|0)>>2];f=Ne(wb(f),c);c=Ne(Ne(wb(x[b+12>>2]),c),g);b=x[d>>2];Pv(f,c,b);ac(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;ib[f|0](a,b,c,e+8|0)}fb=e+32|0}function ff(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Lp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(TH(a,b)&3){case 0:c=Lp(C[b>>3],C[b+8>>3]);break a;case 1:c=-Mp(C[b>>3],C[b+8>>3],1);break a;case 2:c=-Lp(C[b>>3],C[b+8>>3]);break a;default:break b}}c=Mp(C[b>>3],C[b+8>>3],1)}a=c;fb=b+16|0;return a}function dk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}uc(f+12|0,65535);sg(a,z[f+12>>1]);c=wb(x[a>>2]);x[f+4>>2]=c;h=wb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!bh(b,a)){ah(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Od(f+4|0)>>2];continue}}fb=f+16|0}function vna(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=UB(c+4|0,a);Im(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=ig(d+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),c);Im(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;Id(a,c);hg(c);fb=d+32|0}function bO(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function Mu(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(x[c>>2]);x[e+12>>2]=d;f=wb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=VT(b,C[d>>3]),C[g>>3]=h;d=x[Ju(e+12|0)>>2];continue}}}else{VT(b,C[Re(x[c>>2],0)>>3]);d=d+1|0;continue}break}Ul(a,c);fb=e+16|0}function tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=Cf(a,c);Zd(e,x[a+36>>2]);a:{b:{if(!c){Oc(e,a+32|0,5);d=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;yj(d+8|0,d+31|0);Km(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}YY(f,b,d)}f=c}cf(a,f);fb=e+16|0}function pO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=$b(8);x[31721]=0;b=P(37,f+4|0,8200)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Bl(a,b,2);c=iz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;ic(a)}Q(e|0)}p()}function jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Lo(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31721]=0;O(113,a|0,vh(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{while(1){if(vh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[bc(c+4|0,b)|0];x[31721]=0;O(114,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function hO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=$b(8);x[31721]=0;b=P(37,f+4|0,8200)|0;c=x[31721];x[31721]=0;if((c|0)==1){break c}mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Bl(a,b,2);c=jz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;ic(a)}Q(e|0)}p()}function XA(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}yk(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function CA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;UR(a+1074332|0,b);a=a+906300|0;f=Dj(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function AH(a,b,c,d,e,f,g,h,i){var j=0;x[31721]=0;W(1004,a|0);j=x[31721];x[31721]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31721]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,h|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function $R(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=wb(x[c>>2]);x[b+12>>2]=d;f=wb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}jQ(a,e);a=x[x[e>>2]+8>>2];x[31721]=0;W(a|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){continue}break}T(0)|0;Qb();p()}a=sc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Pe(b+12|0)>>2];continue}break}Db(a)}}function sx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Xk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31721]=0;O(113,a|0,vh(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{while(1){if(vh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[bc(c+4|0,b)|0];x[31721]=0;O(114,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function jo(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Xk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31721]=0;O(113,a|0,vh(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{b:{while(1){if(vh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[bc(c+4|0,b)|0];x[31721]=0;O(114,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function Kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31721]=0;S(1100,d|0,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,10321,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;d=-1;a:{if(!hh(a,1)){break a}e=yr(a);if((e-5&255)>>>0>=253){while(1){if((f|0)==127){d=1;break a}c=fb-16|0;fb=c;MD(c+8|0,b);g=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(g|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=(g|0)==(h|0);if(!c){rr(b)}if(!c){break a}f=f+1|0;if(eV(b,e)){continue}break}}d=0}fb=b+16|0;return d|0}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!hh(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=fc(b+8|0,b+24|0,8);nd(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){fd(a,8)}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!lk(a,c+8|0)){break a}b=0;if(!_b(x[c+12>>2])){break a}b=!(_b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function JH(a,b,c){a=Fb(a);x[31721]=0;O(c|0,a|0,4);c=x[31721];x[31721]=0;a:{b:{if((c|0)==1){break b}x[31721]=0;O(b|0,a|0,32);c=x[31721];x[31721]=0;if((c|0)==1){break b}x[31721]=0;O(b|0,a|0,10);c=x[31721];x[31721]=0;if((c|0)==1){break b}x[31721]=0;O(b|0,a|0,13);c=x[31721];x[31721]=0;if((c|0)==1){break b}x[31721]=0;O(b|0,a|0,9);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function vE(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);nd(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(hd(c+24|0,b,7)){break b}fd(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17486,9079,601,13222);p()}_(17465,9079,599,13222);p()}return d}function SM(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Pf(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31721]=0;O(96,a|0,vh(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{b:{while(1){if(vh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[bc(c+4|0,b)|0];x[31721]=0;O(98,a|0,d|0);d=x[31721];x[31721]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function wZ(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function hN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}b=$b(8);x[31721]=0;c=P(37,c+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=N()|0;ic(b)}Q(a|0)}p()}function Mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31721]=0;e=+oa(1096,d|0,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,5350,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function dfa(a){a=a|0;var b=0,c=0,d=0;x[31721]=0;W(1029,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31721]=0;c=+ia(d|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,11734,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function J2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31721]=0;a=Ha(1103,a|0,b|0,c|0,d|0)|0;b=x[31721];x[31721]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31721]=0;ga(987,11192,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}return a|0}function Ena(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Qf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Cn(a)>>>0>=c>>>0){g=x[a>>2];f=Yc(g,x[a+4>>2]);x[d+8>>2]=f;tv(g,x[Gb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){kp(a,c-f|0,e);break a}yn(a,x[a>>2]+(c<<1)|0);break a}JU(a);pC(a,jk(a,c));kp(a,c,e)}fb=d+16|0;fb=b+16|0}
function sY(a){var b=0;a:{if(hd(a,14255,3)|(y[a+3|0]-52&255)>>>0<252){break a}if(_b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if(_b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if(_b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=_b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function bfa(a){a=a|0;var b=0,c=0,d=0;x[31721]=0;W(1029,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31721]=0;c=+ia(d|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7794,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Rka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);x[31721]=0;W(811,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){e=fb-16|0;fb=e;d=vi(e+4|0,a,2304);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){gc(d);fb=e+16|0}else{Jw(b);b=b+2|0;x[d+4>>2]=b;continue}break}b=c+8|0;Md(b);Wj(b);fb=c+16|0;return a|0}a=N()|0;Wj(c+8|0);Q(a|0);p()}function $ea(a){a=a|0;var b=0,c=0,d=0;x[31721]=0;W(1029,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31721]=0;c=+ia(d|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7742,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Ti(a){var b=0,c=0;b=fb-16|0;fb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Mp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(TH(a,b)&3){case 0:a=Mp(C[b>>3],C[b+8>>3],1);break a;case 1:a=Lp(C[b>>3],C[b+8>>3]);break a;case 2:a=-Mp(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-Lp(C[b>>3],C[b+8>>3])}fb=b+16|0;return a}function h1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=hf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Uj(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(kc(c,a)){break a}le(d+8|0,c,a);jc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function jN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}b=$b(8);x[31721]=0;c=P(37,c+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;ic(b)}Q(a|0)}p()}function ez(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=eM(b,4096);dM(a,b-c|0);c=x[a+16>>2];b=fc(d+16|0,vb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function ota(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=Xd(a);b:{if(e>>>0>1){break b}c:{if(e){x[31721]=0;S(337,d+4|0,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+4|0;rn(b,a);cc(a);break c}a=T(28832)|0;if((gb|0)!=($(28832)|0)){break a}Y(a|0)|0;Z();break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}iw(a,b,c)}f=Rc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=d+16|0;return f|0}Q(a|0);p()}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=Ek(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[31721]=0;O(1129,a|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[31721]=0;V(1130,a|0,b|0,e|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}}a=N()|0;WM(c+8|0);Q(a|0);p()}a=c+8|0;Md(a);WM(a);fb=c+16|0}function $D(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(g0(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}yc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function zH(a,b,c,d,e,f,g){var h=0;x[31721]=0;W(1004,a|0);h=x[31721];x[31721]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31721]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,f|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Jb(c);c=Bb(x[c+4>>2],y[c+11|0]);a:{d=Bb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Kc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Jb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Ri(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Ri(h,f,c);b=c+d|0;kg(a,b);ed(b+e|0,0);break a}Eq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}Rl();p()}return a|0}function rV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function mra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);b:{f=b+c|0;c=Tj(b,f);if(c){x[31721]=0;O(348,a|0,c|0);e=x[31721];x[31721]=0;if((e|0)==1){break b}e=fb-16|0;fb=e;a=Vl(e+4|0,a,c);g=a,h=XY(b,f,x[a+4>>2]),x[g+4>>2]=h;gc(a);fb=e+16|0}a=d+8|0;Md(a);$i(a);fb=d+16|0;break a}a=N()|0;$i(d+8|0);Q(a|0);p()}}function VJ(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31596];x[31596]=0;Kd();d=fb-16|0;fb=d;sy(d,a,e+12|0,0);f=tG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31596];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31596]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31721]=0;O(1095,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,10900,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function AX(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function $sa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ac(c+8|0,b,15);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function rO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=$b(8);x[31721]=0;c=P(37,e+4|0,8200)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,1);c=iz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;ic(a)}Q(b|0)}p()}function jO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=$b(8);x[31721]=0;c=P(37,e+4|0,8200)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,1);c=jz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;ic(a)}Q(b|0)}p()}function Wqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ac(c+8|0,b,14);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function Fv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Fc(Aua(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Fc(Aua(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=Wi(dK(8192/+x[We(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return(a|0)>0?a:0}function sia(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31721]=0;O(290,b+4|0,8);b=x[31721];x[31721]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(124984)|0;if((gb|0)==($(124984)|0)){Y(b|0)|0;To(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function nj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(ph(a,f+12|0)){break b}h=tl(x[a>>2]);g=4;if(!Ff(x[d+8>>2],64,h)){break b}b=ll(d,h);while(1){c:{b=b-48|0;h=Cm(a);if(ph(h,f+12|0)|(e|0)<2){break c}g=tl(x[h>>2]);if(!Ff(x[d+8>>2],64,g)){break a}e=e-1|0;b=ll(d,g)+D(b,10)|0;continue}break}g=2;if(!ph(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function C3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Ff(x[d+8>>2],64,e)){break b}f=4;g=ll(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Ff(x[d+8>>2],64,e)){break a}f=f-1|0;g=ll(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function pfa(a){a=a|0;var b=0;x[31721]=0;W(1029,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31721]=0;V(991,5051,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function ZM(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;d=P(37,d+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,d);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=aC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=fh(x[b>>2],x[b+4>>2]);if(!d){break a}x[31721]=0;O(804,a|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31721]=0;WT(a,b,e,d);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;Ku(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);Ku(b);fb=c+16|0;return a|0}function Wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=nc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31721]=0;O(228,a|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31721]=0;to(a,b,e,d);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;_g(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=44224;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31721]=0;O(949,a+44|0,2);c=x[31721];x[31721]=0;if((c|0)!=1){return a|0}c=N()|0;sc(b);Vf(a);Q(c|0);p()}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=hC(a,b);x[31721]=0;c=P(687,a+12|0,b+12|0)|0;d=x[31721];x[31721]=0;b:{c:{if((d|0)!=1){x[31721]=0;P(688,a+24|0,b+24|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;cc(c)}cc(a);Q(b|0);p()}}function hC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=Rc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31721]=0;O(325,a|0,d|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31721]=0;hv(a,b,e,d);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;$i(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);$i(b);fb=c+16|0;return a|0}function cO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;c=fc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=ju(a,b,0);if(a+1>>>0>=3){a=$b(8);x[31721]=0;b=P(37,b+12|0,8057)|0;c=x[31721];x[31721]=0;b:{if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;ic(a)}Q(c|0);p()}fb=b+32|0;return a|0}p()}function Qn(a,b,c,d,e,f){var g=0;x[31721]=0;W(1004,a|0);g=x[31721];x[31721]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31721]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,e|0,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;oM(a,c);fb=c+16|0}function u0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=-1;a:{if(!hh(a,7)){break a}c=0;if(!vE(a,11774)){break a}c=fb-16|0;fb=c;f=d+5|0;vw(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){sE(f)}c=-1;if(!e){break a}c=0;if(!uE(y[d+6|0])){break a}c=te(a,b,tE(d+5|0),hb)}fb=d+16|0;return c|0}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;kM(a,c);fb=c+16|0}function r_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;b=wb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){ti(d+8|0,x[a>>2],x[a+4>>2]);if((_b(x[d+8>>2])|0)==(c|0)){f=d+8|0;fp(f,a);x[31721]=0;O(363,e|0,f|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[tn(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Pc(e);Q(a|0);p()}function TJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31596];x[31596]=0;Kd();d=fb-16|0;fb=d;sy(d,a,e+12|0,1);f=jx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31596];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31596]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;uM(a,c);fb=c+16|0}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;qM(a,c);fb=c+16|0}function rja(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Dc(2500);c=fb-2496|0;fb=c;oQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[tf(e+12|0,b)>>2];fb=e+16|0;return a|0}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[qd(f+12|0,f+8|0)>>2];Vi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function nx(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=zb(f+12|0,x[a+4>>2]);g=zb(f+8|0,x[a>>2]);e=zb(f+4|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[e>>2];x[c+12>>2]=d;while(1){e=x[c+8>>2];if(Pg(d,g)){js(lx(e),Pn(d));e=um(c+12|0);um(c+8|0);d=x[e>>2];continue}break}fb=c+16|0;x[b+4>>2]=e;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Lda(a,b){a=a|0;b=+b;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31721]=0;b=+Wa(1097,c|0,+b);c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7606,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function IK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=Cc(d+8|0,c);x[31721]=0;S(1193,d+20|0,b|0,e|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){x[31721]=0;a=P(1194,a|0,d+20|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}tb(d+20|0);tb(e);x[a>>2]=124256;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function LX(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,5);jc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(hd(c+24|0,b,5)){break b}Ub(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17486,9079,601,13222);p()}_(17465,9079,599,13222);p()}return d}function xx(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47636;h=Dc(80);x[31721]=0;d=R(1107,d|0)|0;i=x[31721];x[31721]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[pe(g+12|0,g+8|0)>>2];x[31721]=0;b=ha(f|0,h|0,b|0,c-b|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(h);Q(a|0);p()}function dia(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function ss(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47636;h=Dc(80);x[31721]=0;d=R(1107,d|0)|0;i=x[31721];x[31721]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[pe(g+12|0,g+8|0)>>2];x[31721]=0;b=ha(f|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(h);Q(a|0);p()}function pna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}f=a+480190|0;w[d>>1]=z[f>>1];w[d+14>>1]=c-1;c=z[Lc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(jC(x[b>>2],c)){break b}if(IR(a,c&65535)){e=Cc(d,22250);xc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[f>>1];if((e|0)!=(c|0)){break b}w[f>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function nea(a){a=a|0;var b=0,c=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31721]=0;b=R(1072,b|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7278,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function p9(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(sL(0,b+24|0)){st(x[31596],12742);p()}a=ue(b+16|0,x[b+24>>2],x[b+28>>2]);d=JA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=ou(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=ue(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=ue(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function nC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;b=wb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){ti(d+8|0,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){f=d+8|0;fp(f,a);x[31721]=0;O(363,e|0,f|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[tn(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Pc(e);Q(a|0);p()}function xea(a){a=a|0;var b=0,c=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31721]=0;c=+ia(1063,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31721]=0;V(991,7678,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function _x(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(1073741807-b>>>0>=c>>>0){i=Jb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=ln(x[$c(g+4|0,g+12|0)>>2])+1|0}else{c=1073741807}Rj(h,c);c=x[g+4>>2];if(e){Vi(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Vi(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}wd(a,c);mf(a,x[g+8>>2]);fb=g+16|0;return}nf();p()}function _5(a){a=a|0;if(y[500480]){return x[125119]}if(!y[501e3]){v[501e3]=1}td(500832,120136);td(500844,120164);td(500856,120192);td(500868,120224);td(500880,120264);td(500892,120300);td(500904,120328);td(500916,120364);td(500928,120380);td(500940,120396);td(500952,120412);td(500964,120428);td(500976,120444);td(500988,120460);v[500480]=1;x[125119]=500832;return 500832}function UZ(a){var b=0,c=0;a:{if(hd(a,15216,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Cb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Cb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Cb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Cb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Cb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function SA(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31721]=0;O(54,f|0,Xc(e,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{while(1){if(Xc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[bc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31721]=0;O(36,f|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Rb(f);Q(a|0);p()}function QP(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!uj(d,64,e)){break b}g=rk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!uj(d,64,e)){break a}f=f-1|0;g=rk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((vk(y[a+140|0])|0)!=1){break b}if((JM(a)|0)!=(b|0)){break b}d=a+120|0;Lt(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[18379];x[a+8>>2]=x[18378];x[a+12>>2]=e;e=x[18377];x[a>>2]=x[18376];x[a+4>>2]=e;ib[x[cq(a,vk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}IM(a,1,b)}fb=c+16|0}function Dsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;SZ(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){RZ(f)}c=-1;a:{if(!e){break a}c=0;if(!UZ(d+4|0)){break a}c=te(a,b,TZ(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function Aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Dc(64);x[31721]=0;e=R(881,c|0)|0;f=x[31721];x[31721]=0;a:{if((f|0)!=1){c=tf(d+8|0,e);e=x[c>>2];x[31721]=0;a=U(947,e|0,a|0,b|0)|0;b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}qc(d+12|0);break b}a=N()|0;Hg(c);break a}pe(d+12|0,c)}Hg(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function yH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=$b(8);x[31721]=0;c=P(37,f+4|0,8200)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,e);c=qH(a,c,e,d,76128,76900);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;ic(a)}Q(b|0)}p()}function xH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=$b(8);x[31721]=0;c=P(37,f+4|0,8200)|0;b=x[31721];x[31721]=0;if((b|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,e);c=qH(a,c,e,d,75300,76072);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;ic(a)}Q(b|0)}p()}function rN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=$b(8);x[31721]=0;c=P(37,c+4|0,7854)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Xe(65536/b),x[e+480244>>2]=f;pq(a);fb=c+16|0;return}d=N()|0;ic(a)}Q(d|0)}p()}function pN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=$b(8);x[31721]=0;c=P(37,c+4|0,7875)|0;d=x[31721];x[31721]=0;if((d|0)==1){break c}mc(a,c);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Xe(b*65536),x[e+480240>>2]=f;pq(a);fb=c+16|0;return}d=N()|0;ic(a)}Q(d|0)}p()}function o0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Pf(a,c);break e}e=d+8|0;Pf(e,c);x[31721]=0;S(126,d+20|0,b|0,e|0);b=x[31721];x[31721]=0;if((b|0)==1){break d}x[31721]=0;S(247,a|0,4,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function YU(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31721]=0;O(117,d|0,Xc(e,a)|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){a=xd(b);x[c+12>>2]=a;b=zf(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31721]=0;O(118,d|0,((a|0)==13?10:a)<<24>>24);a=x[31721];x[31721]=0;if((a|0)!=1){a=x[je(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function Om(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(2147483631-b>>>0>=c>>>0){j=Jb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Ah(x[$c(h+4|0,h+12|0)>>2])+1|0}else{c=2147483631}og(i,c);c=x[h+4>>2];if(e){xg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){xg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}wd(a,c);mf(a,x[h+8>>2]);fb=h+16|0;return}nf();p()}function Kz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Jl(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=YP(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function mj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(ii(a,f+12|0)){break b}g=4;h=sl(x[a>>2]);if(!uj(d,64,h)){break b}b=rk(d,h);while(1){c:{b=b-48|0;h=ao(a);if(ii(h,f+12|0)|(e|0)<2){break c}g=sl(x[h>>2]);if(!uj(d,64,g)){break a}e=e-1|0;b=rk(d,g)+D(b,10)|0;continue}break}g=2;if(!ii(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function rs(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47636;g=Dc(80);x[31721]=0;c=R(1107,c|0)|0;h=x[31721];x[31721]=0;a:{b:{if((h|0)!=1){x[f+8>>2]=c;c=x[pe(f+12|0,f+8|0)>>2];x[31721]=0;b=ba(e|0,g|0,b|0,c|0,d|0)|0;c=x[31721];x[31721]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(f+8|0);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Uc(f+8|0)}Db(g);Q(a|0);p()}function dN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;c=P(37,c+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function P4(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jb(b);b=fb-32|0;fb=b;a=ud(a,0);x[a>>2]=113248;d=uk(c);x[a+8>>2]=d;if(!d){a=Cc(b+8|0,c);x[31721]=0;S(1019,b+20|0,17522,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){x[31721]=0;W(1347,b+20|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=119624;return a|0}function Gm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+89104|0]}if(a>>>0<=511){return v[(a>>>5|0)+89104|0]+5|0}return v[(a>>>10|0)+89104|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+89104|0]+15|0}return v[(a>>>20|0)+89104|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+89104|0]+25|0}a=v[(a>>>30|0)+89104|0]+30|0}else{a=0}return a}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=qm(a);x[d>>2]=77876;a=bM(zc(d),_L(b));x[a>>2]=78208;x[31721]=0;P(344,a+24|0,65536)|0;c=x[31721];x[31721]=0;a:{if((c|0)!=1){c=a+36|0;Tb(c,0,192);e=a+228|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Tb(e,0,64);break a}b=N()|0;Dt(a);Q(b|0);p()}x[a+292>>2]=b;x[a>>2]=78020;return d|0}function Gta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;k$(c,a,b);xf(b,y[d+14|0],y[Hc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function om(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Pk(d)){Ke(c,d);break c}if(d>>>0>=2147483632){break b}og(e+8|0,Ah(d)+1|0);b=x[e+8>>2];wd(c,b);mf(c,x[e+12>>2]);Wd(c,d);c=b}Tg(c,f,d+1|0);fb=e+16|0;break a}nf();p()}return a|0}function h$(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=$b(16);b=fb-16|0;fb=b;if(!y[496944]){v[496944]=1}fc(b+8|0,1,126068);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31721]=0;a=Ca(1195,c|0,8943,a|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){da(a|0,94556,1196);p()}a=N()|0;ic(c);Q(a|0);p()}}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Pk(d)){Ke(c,d);break c}if(d>>>0>=2147483632){break b}og(e+8|0,Ah(d)+1|0);b=x[e+8>>2];wd(c,b);mf(c,x[e+12>>2]);Wd(c,d);c=b}xg(c,f,d+1|0);fb=e+16|0;break a}nf();p()}return a|0}function _M(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;c=P(37,c+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;ic(b)}Q(a|0)}p()}function Ts(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function Sp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Oq(d)){Ke(c,d);break c}if(d>>>0>=1073741808){break b}Rj(e+8|0,ln(d)+1|0);b=x[e+8>>2];wd(c,b);mf(c,x[e+12>>2]);Wd(c,d);c=b}Vi(c,f,d+1|0);fb=e+16|0;break a}nf();p()}return a|0}function YM(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;c=P(37,c+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;ic(b)}Q(a|0)}p()}function sra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=Cf(a,c);Zd(f,x[a+36>>2]);a:{if(!c){Oc(f,a+32|0,5);e=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31721]=0;ba(473,b|0,h|0,e|0,d|0)|0;b=x[31721];x[31721]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}cf(a,e);fb=f+16|0}function KQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Jk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}wk(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;kq(a,c+8|0);g=xb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function CR(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=Me(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=Me(a+902204|0,c&127)}ZS(a,e,b,f,d,c&255)}}function $3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+112096>>2];break b}e=(gt(a)|0)!=0;e=ft(a)?e|2:e;e=et(a)?e|4:e;e=dt(a)?e|8:e;e=ct(a)?e|16:e;e=bt(a)?e|32:e;e=Jh(a)?e|64:e;e=at(a)?e|128:e;e=$s(a)?e|256:e;x[d>>2]=e;if(!_s(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function RW(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=al(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function NW(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function Co(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function aR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Pd(c,b);a:{if(e>>>0<=Rg(a)>>>0){f=b;g=x[a>>2];h=nc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;KC(d+12|0,h);f=x[d+12>>2]}c=Qi(c,f,g);if(!i){to(a,f,b,e-nc(x[a>>2],x[a+4>>2])|0);break a}Xh(a,c);break a}br(a);im(a,Uf(a,e));to(a,c,b,e)}fb=d+16|0}return a}function $ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=43844;b=a+4208|0;e=xb(b,0),f=1060320051,x[e>>2]=f;e=xb(b,1),f=1041865114,x[e>>2]=f;e=xb(b,2),f=1065353216,x[e>>2]=f;e=xb(b,3),f=1049951732,x[e>>2]=f;e=xb(b,4),f=1049951732,x[e>>2]=f;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Vf(a);Q(b|0);p()}function spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;mX(c+8|0,d+12|0);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!oX(d+12|0)){break a}c=te(a,b,nX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(!c){break a}x[31721]=0;O(1165,a|0,c|0);e=x[31721];x[31721]=0;if((e|0)!=1){x[31721]=0;V(1166,a|0,b|0,Dd(b,c)|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;XL(d+8|0);Q(a|0);p()}b=d+8|0;Md(b);XL(b);fb=d+16|0;return a|0}function DO(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;a:{e=a+36|0;c=x[e>>2];d=x[a+40>>2];b:{if(Ib(c,d)){qc(b+12|0);break b}po(b,a);x[31721]=0;c=R(1064,b|0)|0;d=x[31721];x[31721]=0;if((d|0)==1){break a}x[b+12>>2]=c;lf(b);d=x[a+40>>2];c=x[a+36>>2]}if(!Ib(c,d)){e=x[b+12>>2];c=x[e>>2]}a=lj(c,x[e+4>>2]);xl(b+12|0);fb=b+16|0;return a|0}a=N()|0;lf(b);Q(a|0);p()}function ska(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;zS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;gc(c);fb=d+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Su(d+12|0,Iq(a,Gg(x[a>>2],x[a+4>>2])+1|0),Gg(x[a>>2],x[a+4>>2]),c);zS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;Id(a,c);uV(c);fb=d+32|0}function Yu(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;IV(d,a,a+1|0,a+2|0,a+3|0);IV(c,b,b+1|0,b+2|0,b+3|0);b=Xu(y[x[d>>2]],y[x[c>>2]]);a:{if(!Pj(b)){break a}b=y[x[d+4>>2]];a=y[x[c+4>>2]];b=(a|0)!=(b|0)?b<<24>>24<a<<24>>24?-1:1:0;if(!Pj(b)){break a}b=Xu(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Pj(b)){break a}b=Xu(y[x[d+12>>2]],y[x[c+12>>2]])}a=Cd(b);fb=c+32|0;return a}function uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31721]=0;O(50,d|0,Xc(e,c)|0);c=x[31721];x[31721]=0;if((c|0)!=1){a:{b:{while(1){if(Xc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[bc(b,a)|0];x[31721]=0;O(51,d|0,uf(uf(c))|0);c=x[31721];x[31721]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;RM(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;gc(c);fb=d+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=zJ(d+12|0,FJ(a,lj(x[a>>2],x[a+4>>2])+1|0),lj(x[a>>2],x[a+4>>2]),c);RM(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;uJ(a,c);pJ(c);fb=d+32|0}function Afa(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(iq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31721]=0;V(991,5078,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function _J(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31596];x[31596]=0;Kd();a=$J(a,e+12|0,d);d=hb;f=x[31596];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31596]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function Og(a,b){var c=0,d=0,e=0,f=0,g=0;e=Jb(a);d=Bb(x[a+4>>2],y[a+11|0]);c=gf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=gq(a,(f-c|0)+1|0,g);if(!a){break c}if(!Vp(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function DB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(2147483631-b>>>0>=c>>>0){h=Jb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Ah(x[$c(g+4|0,g+12|0)>>2])+1|0}else{c=2147483631}og(i,c);c=x[g+4>>2];if(e){Tg(c,h,e)}if((d|0)!=(e|0)){Tg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}wd(a,c);mf(a,x[g+8>>2]);fb=g+16|0;return}nf();p()}function ufa(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31721]=0;V(991,5660,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function OA(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;Vm(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!yd(a)){break a}Jj(a,b,0)}}function sN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=$b(8);x[31721]=0;c=P(37,c+4|0,9363)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function sH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=$b(8);x[31721]=0;c=P(37,d+4|0,10735)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Dc(223888);x[31721]=0;b=P(848,d|0,b+1074376|0)|0;e=x[31721];x[31721]=0;a:{if((e|0)!=1){b=x[tf(c+12|0,b)>>2];fb=c+16|0;break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31721]=0;W(610,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return a|0}c=N()|0;ze(b);OS(a+4|0);Q(c|0);p()}function p8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){yc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){yc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function Up(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ad(d+12|0,b);x[31721]=0;b=R(1220,x[d+12>>2])|0;e=x[31721];x[31721]=0;a:{if((e|0)==1){break a}x[31721]=0;e=R(1228,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break a}x[c>>2]=e;x[31721]=0;O(1229,a|0,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Yb(d+12|0);fb=d+16|0;return}a=N()|0;Yb(d+12|0);Q(a|0);p()}function Nga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=fQ(a,b,c,d,e^1);x[b>>2]=44456;a=b+4208|0;f=xb(a,0),g=1056964608,x[f>>2]=g;f=xb(a,1),g=1065353216,x[f>>2]=g;f=xb(a,2),g=1020054733,x[f>>2]=g;f=xb(a,3),g=1065353216,x[f>>2]=g;f=xb(a,4),g=1056964608,x[f>>2]=g;f=xb(a,5),g=1048406533,x[f>>2]=g;f=xb(a,6),g=1056964608,x[f>>2]=g;return b|0}function qQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=HD(b,c);a:{if(e>>>0<=So(a)>>>0){x[d+12>>2]=c;g=x[a>>2];f=Rc(g,x[a+4>>2]);h=f>>>0>=e>>>0;if(h){f=c}else{x[d+12>>2]=b;x_(d+12|0,f);f=x[d+12>>2]}b=Pv(b,f,g);if(!h){GD(a,x[d+12>>2],c,e-Rc(x[a>>2],x[a+4>>2])|0);break a}Vq(a,b);break a}Ov(a);_k(a,Wl(a,e));GD(a,b,c,e)}fb=d+16|0}function fsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;uZ(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){tZ(d)}c=-1;a:{if(!e){break a}c=0;if(!wZ(d)){break a}c=te(a,b,vZ(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function Xp(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ad(d+12|0,b);x[31721]=0;b=R(1203,x[d+12>>2])|0;e=x[31721];x[31721]=0;a:{if((e|0)==1){break a}x[31721]=0;e=R(1215,b|0)|0;f=x[31721];x[31721]=0;if((f|0)==1){break a}v[c|0]=e;x[31721]=0;O(1216,a|0,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Yb(d+12|0);fb=d+16|0;return}a=N()|0;Yb(d+12|0);Q(a|0);p()}function M5(a){a=a|0;if(y[500472]){return x[125117]}if(!y[500824]){v[500824]=1}id(500656,5240);id(500668,5247);id(500680,5213);id(500692,5221);id(500704,5204);id(500716,5254);id(500728,5231);id(500740,9758);id(500752,9964);id(500764,11294);id(500776,12930);id(500788,5503);id(500800,10797);id(500812,6622);v[500472]=1;x[125117]=500656;return 500656}function isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=th(d+4|0,a,1);CZ(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=Ab(a);d=ig(e+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),d);CZ(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;Id(a,d);hg(d);fb=e+32|0}function gR(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function _Z(a){var b=0,c=0;a:{if(hd(a,13907,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Cb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Cb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Cb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Cb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Cb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function Nta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=xd(b),x[f+12>>2]=g;c=Xc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[bc(b,0)|0]!=43){if(y[bc(b,0)|0]!=45){break b}}d=d+1|0;WU(e+12|0)}if(c>>>0>=d>>>0){break a}qE(b,x[zb(e+8|0,x[e+12>>2])>>2],d-Xc(x[b+4>>2],y[b+11|0])|0,48)}Zc(a,b);fb=e+16|0}function Lr(a,b,c){var d=0,e=0,f=0,g=0;a:{d=Bk(b,xd(a));b=Bk(c,b);if(Bb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){LT(a,d);break a}e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Bb(x[a+4>>2],y[a+11|0]);g=Jb(a);c=f-d|0;x[e+8>>2]=c;b=x[Gb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;Ri(d,b+d|0,c-b|0)}Hu(a,g,f-b|0)}fb=e+16|0;break a}Rl();p()}}function tN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=$b(8);x[31721]=0;c=P(37,c+4|0,5848)|0;a=x[31721];x[31721]=0;if((a|0)==1){break c}mc(b,c);x[31721]=0;S(100,b|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;ic(b)}Q(a|0)}p()}function Bo(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function tH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{b:{c:{if(b<g|b>f){a=$b(8);x[31721]=0;d=P(37,h+4|0,e|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}mc(a,d);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}e=N()|0;tb(d);break b}i=x[a+32>>2]+d|0,j=Xe(b*c),x[i>>2]=j;fb=h+16|0;return}e=N()|0;ic(a)}Q(e|0)}p()}function fw(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function Gx(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{e=x[b+1298404>>2];b=fb-32|0;fb=b;d=b+8|0;Pf(d,c);x[31721]=0;S(506,b+20|0,e|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){x[31721]=0;S(247,a|0,0,b+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Rb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function zfa(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31721]=0;V(991,8916,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function iF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){ej(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){bh(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d&65535}function hl(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;Lt(y[h+20|0]);g=fb-16|0;fb=g;x[g+12>>2]=f+8;e=fb-16|0;fb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[cq(e,vk(y[h+20|0]))>>2]](g+12|0,h);fb=e+16|0;fb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=f+16|0}function cM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Cu(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function Usa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;l_(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){k_(f)}c=-1;a:{if(!e){break a}c=0;if(!n_(d+14|0)){break a}c=te(a,b,m_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function Rf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Bb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}Ws(b,c);e=Jb(a);g=e+Bb(x[a+4>>2],y[a+11|0])|0;a=c-4|0;b:{while(1){c:{c=v[e|0];f=c-127|0;if(a>>>0<=b>>>0){break c}if((c|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;e=((g-e|0)>1)+e|0;continue}break}if((f&255)>>>0<130|c>>>0>x[a>>2]-1>>>0){break a}}x[d>>2]=4}}function $2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(jh(a,b,0)){break a}e=0;if(!b){break a}b=TA(b,124592,124640);e=0;if(!b){break a}Tb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function yI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=_I(a,c);x[a>>2]=113128;c=uk(Jb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31721]=0;S(1010,d+4|0,17983,b|0);b=x[31721];x[31721]=0;if((b|0)==1){break c}x[31721]=0;W(1347,d+4|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}b=N()|0;tb(d+4|0);break b}fb=d+16|0;return a|0}b=N()|0}Js(a);Q(b|0)}p()}function s0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;kE(e+8|0,c);c=y[d|0];x[31721]=0;O(246,e+20|0,c|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);x[31721]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;vg(e+8|0)}Q(a|0);p()}}function Rja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Fb(a+40|0);f=mg(a+52|0);Hf(c);w[a+28>>1]=65472;x[31721]=0;x[b+12>>2]=1065353216;O(885,c|0,b+12|0);g=x[31721];x[31721]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Hf(d);fb=b+16|0;return a|0}a=N()|0;bZ(f);tb(e);sc(d);sc(c);Q(a|0);p()}function xfa(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return wg(a)|0}Y(T(0)|0)|0;x[31721]=0;V(991,12243,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();return 0}return wg(22250)|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function M0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;YE(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){XE(f)}c=-1;a:{if(!e){break a}c=0;if(!_E(d+15|0)){break a}c=te(a,b,ZE(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function sG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function pT(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];be(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function nk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function iea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31721]=0;W(1004,a|0);f=x[31721];x[31721]=0;if((f|0)!=1){return Rt(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31721]=0;V(991,12486,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Zu(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);zua(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31721]=0;b=R(785,a|0)|0;c=x[31721];x[31721]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31721]=0;X(26);c=x[31721];x[31721]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Qb();p()}if(!b){break a}d=Tb(b,0,a)- -64|0}return d}function K1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Dc(24),x[h+8>>2]=i;b=qm(x[e+8>>2]);x[b>>2]=78536;iG(zc(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Ln(e);Kn(c,zc(b),b);rm(e);fb=g+16|0;Af(a,c);he(c);fb=f+16|0;fb=d+16|0}function zB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ef(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31721]=0;O(54,e|0,Xc(f,d)|0);d=x[31721];x[31721]=0;if((d|0)!=1){a:{while(1){if(Xc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[bc(b,a)|0]<<2)+c>>2];x[31721]=0;O(36,e|0,d|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Rb(e);Q(a|0);p()}function I6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=Ih(g+12|0,x[a+8>>2]);i=it(0,c,d-c|0,b?b:500188);Hh(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function Hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=xb(b,c);d=fb-16|0;fb=d;e=Pd(b,c);a:{if(e>>>0<=Rg(a)>>>0){f=c;g=x[a>>2];h=nc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;KC(d+12|0,h);f=x[d+12>>2]}b=Qi(b,f,g);if(!i){gY(a,f,c,e-nc(x[a>>2],x[a+4>>2])|0);break a}Xh(a,b);break a}br(a);im(a,Uf(a,e));gY(a,b,c,e)}fb=d+16|0}function u1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){ac(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;ac(e+24|0,x[d>>2],x[Gb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function tJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[dc(a)>>2]==1240;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=rv(e?0:h,f);if(g){if(!e){ie(a)}x[d+4>>2]=1207;e=Ae(d+8|0,g,d+4|0);a=qJ(a,e);Jc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}qy();p()}function haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];ez(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){ac(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Gb(e+12|0,e+8|0)>>2];kr(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];Pv(Ne(wb(x[b+4>>2]),c),Ne(Ne(wb(x[b+4>>2]),c),i),h);kr(a,d,g,0,f)}fb=e+16|0}function AK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Nk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Ut(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function uqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;ur(e+8|0,c);x[31721]=0;O(600,e+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);x[31721]=0;V(304,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;vg(e+8|0)}Q(a|0);p()}}function jF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Im(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){bh(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d}function IS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function pqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(!b){break a}x[31721]=0;O(593,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;O(594,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;WX(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);WX(b);fb=c+16|0;return a|0}function F8(a){a=a|0;a:{x[31721]=0;R(1198,499208)|0;a=x[31721];x[31721]=0;b:{if((a|0)==1){break b}x[31721]=0;R(1198,499544)|0;a=x[31721];x[31721]=0;if((a|0)==1){break b}x[31721]=0;R(1199,499292)|0;a=x[31721];x[31721]=0;if((a|0)==1){break b}x[31721]=0;R(1199,499628)|0;a=x[31721];x[31721]=0;if((a|0)==1){break b}break a}T(0)|0;Qb();p()}}function wsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;yZ(e+8|0,c);x[31721]=0;O(94,e+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);x[31721]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;vg(e+8|0)}Q(a|0);p()}}function wr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);g=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;ti(f+8|0,x[d>>2],x[d+4>>2]);h=_b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[tn(e+12|0)>>2];continue}break}fb=e+16|0;if(kc(d,wb(x[b+4>>2]))){Zh(a);return}fp(a,d)}function D0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(!b){break a}x[31721]=0;O(229,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[31721]=0;O(230,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){break a}}a=N()|0;CE(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);CE(b);fb=c+16|0;return a|0}function zha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;xr(b+8|0,a+4228|0);c=x[a+20>>2];d=wb(x[b+8>>2]);e=Vk(x[b+8>>2],x[b+12>>2]);x[31721]=0;S(973,c+4|0,d|0,e|0);c=x[31721];x[31721]=0;a:{if((c|0)==1){c=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(c|0)|0;To(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function vta(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!KD(a,b+20|0)){break a}c=0;if(!K_(b+20|0)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!fd(a,4)){break a}}c=-1;if(!lk(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}fb=b+32|0;return c|0}function iE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;mw(e+8|0,c);x[31721]=0;O(94,e+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);x[31721]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;vg(e+8|0)}Q(a|0);p()}}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31721]=0;O(926,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;ee(d);Q(a|0);p()}ee(d);fb=e+16|0}function Qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){cd();p()}if(b>>>0>=4925422){Xj();p()}c=Dc(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function M4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;Un(e+8|0,c);x[31721]=0;O(94,e+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);x[31721]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;vg(e+8|0)}Q(a|0);p()}}function Bq(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=wb(x[a>>2]);e=a;f=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=d;while(1){if(Ib(d,f)){b=b+C[d>>3];d=x[Ju(a+12|0)>>2];continue}break}fb=a+16|0;a=wb(x[e>>2]);x[c+12>>2]=a;b=-b;e=wb(x[e+4>>2]);while(1){if(Ib(a,e)){b=b+C[a>>3];C[a>>3]=b;a=x[Ju(c+12|0)>>2];continue}else{fb=c+16|0}break}}function Bja(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=fc(b,b+16|0,15);jc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(hd(b+16|0,8525,15)){break a}Ub(a,15);c=1}fb=b+32|0;return c|0}function kd(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;jn(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Cc(c+4|0,22250);ye(a+43|0,b);tb(b);NV(a);fb=c+16|0}function _c(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;el(b);f=tf(e+12|0,b);a:{d=a+8|0;b=x[d>>2];if(nc(b,x[a+12>>2])>>>0<=c>>>0){x[31721]=0;O(1294,d|0,c+1|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}b=x[d>>2]}a=xb(b,c);b=x[a>>2];if(b){sm(b);a=xb(x[d>>2],c)}g=a,h=ie(f),x[g>>2]=h;NI(f);fb=e+16|0;return}a=N()|0;NI(f);Q(a|0);p()}function jsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Rg(a)){d=x[a>>2];e=nc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Gb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){FZ(a,1-e|0,b);break a}Xh(a,x[a>>2]+4|0);break a}br(a);im(a,Uf(a,1));FZ(a,1,b)}fb=c+16|0}function eua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ac(c+8|0,b,10);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function P0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-784|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;fF(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){eF(f)}c=-1;a:{if(!e){break a}c=0;if(!hF(d+12|0)){break a}c=te(a,b,gF(y[d+527|0]),0)}fb=d+784|0;return c|0}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-32|0;fb=d;Ev(d+8|0,c);x[31721]=0;O(478,d+20|0,41660);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(d,d+8|0);x[31721]=0;V(95,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(d+8|0);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;vg(d+8|0)}Q(a|0);p()}}function UP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Fc(b,b>>31);x[a+4272>>2]=b;x[31721]=0;x[c+12>>2]=0;S(955,a+4256|0,b<<1,c+12|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){b=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function Mqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;qY(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){pY(f)}c=-1;a:{if(!e){break a}c=0;if(!sY(d+12|0)){break a}c=te(a,b,rY(d+12|0),hb)}fb=d- -64|0;return c|0}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=43344;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){Xt(a);return a|0}b=N()|0;sc(c);Vf(a);Q(b|0);p()}function e7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[dc(a)>>2]==1240;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=rv(e?0:h,f);if(g){if(!e){ie(a)}x[d+4>>2]=1207;e=Ae(d+8|0,g,d+4|0);a=qJ(a,e);Jc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}qy();p()}function Vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}uc(d+12|0,65535);sg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Hn(b,f)){xn(f)}w[c>>1]=x[d+8>>2];c=x[Od(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function K0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;c=fb-16|0;fb=c;f=d+10|0;RE(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){QE(f)}c=-1;a:{if(!e){break a}c=0;if(!TE(d+10|0)){break a}c=te(a,b,SE(y[d+45|0]),hb)}fb=d+48|0;return c|0}function tR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Gb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=yq(v[vb(a,f)|0]);h=yq(v[vb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function mP(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;a=Nb(a);x[31721]=0;W(994,b+4|0);c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){c=wb(x[b+4>>2]);d=wb(x[b+8>>2]);e=x[zb(b,a)>>2];x[31721]=0;S(995,c|0,d|0,e|0);c=x[31721];x[31721]=0;if((c|0)==1){break b}sc(b+4|0);fb=b+16|0;return}c=N()|0;break a}c=N()|0;sc(b+4|0)}Qd(a);Q(c|0);p()}function U8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(kc(b,-1)){$n(a,g,f-1|0,e);return Cy(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!kc(c,v[f-1|0])){break a}}$n(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function ws(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=x[pe(g+8|0,g+12|0)>>2];x[31721]=0;ha(f|0,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){a=uz(a);b=tz(a+88|0);c=sz(a+92|0);d=rz(a+96|0);x[a>>2]=47756;x[b>>2]=47872;x[c>>2]=47952;x[d>>2]=47992;Uc(g+12|0);fb=g+16|0;return a}a=N()|0;Uc(g+12|0);Q(a|0);p()}function qE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Bk(b,xd(a));a:{f=Bb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Kc(a);b:{if(e-f>>>0>=c>>>0){e=Jb(a);if((b|0)==(f|0)){break b}g=b+e|0;Ri(g+c|0,g,f-b|0);break b}Om(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}bm(b+e|0,c,d);b=c+f|0;kg(a,b);ed(b+e|0,0)}break a}Rl();p()}xd(a)}function ila(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=Cf(a,c);Zd(e+8|0,x[a+36>>2]);f=a;a:{if(!c){Oc(e+8|0,a+32|0,5);d=0;if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;GE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){yU(d,Zb(x[b>>2],a));a=a+1|0;continue}break}d=c}cf(f,d);fb=e+32|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;LW(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){KW(d)}c=-1;a:{if(!e){break a}c=0;if(!NW(d)){break a}c=te(a,b,MW(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=th(c+4|0,a,1);xk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=ig(d+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),c);xk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Id(a,c);hg(c);fb=d+32|0}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Lo(e,c);x[31721]=0;S(506,d+20|0,b|0,e|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;S(247,a|0,0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function yl(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=fb-32|0;fb=c;d=oc(c+24|0,x[a>>2]);e=x[f+12>>2];g=x[e>>2];e=x[e+4>>2];x[c+16>>2]=g;x[c+20>>2]=e;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=g;x[c+12>>2]=e;d=Nc(d,h,c+8|0);fb=c+32|0;if(!d){break a}b=a}fb=f+16|0;return b}a=a+8|0;continue}}function _$(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=vi(c+4|0,a,1);ck(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=ik(d+12|0,jk(a,Yc(x[a>>2],x[a+4>>2])+1|0),Yc(x[a>>2],x[a+4>>2]),c);ck(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Id(a,c);fj(c);fb=d+32|0}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31721]=0;V(991,13107,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Ksa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-208|0;fb=d;c=fb-16|0;fb=c;f=d+2|0;YZ(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){XZ(f)}c=-1;a:{if(!e){break a}c=0;if(!_Z(d+2|0)){break a}c=te(a,b,ZZ(d+2|0),hb)}fb=d+208|0;return c|0}function Kra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Rc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[Ab(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){rp(a,b,c);break a}d=Ab(a);d=hn(e+12|0,Wl(a,Rc(x[a>>2],f)+b|0),Rc(x[a>>2],x[a+4>>2]),d);OY(d,b,c);Id(a,d);gn(d)}fb=e+32|0;return}if(b>>>0<d>>>0){Vq(a,b+e|0)}}function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;qp(e,b,c);x[31721]=0;S(126,d+20|0,28,e|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function g3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(yd(e)){f=d+4|0;if(!zd(x[c+4>>2],y[c+11|0])){lP(c,18377);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31721]=0;P(844,c|0,f|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}tb(d+4|0)}Zc(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function Yn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Pd(b,c);if(f>>>0<1073741808){b:{if(Oq(f)){Ke(d,f);break b}Rj(e+8|0,ln(f)+1|0);g=x[e+8>>2];wd(d,g);mf(d,x[e+12>>2]);Wd(d,f);d=g}while(1){if((b|0)!=(c|0)){wd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}wd(d,0);fb=e+16|0;break a}nf();p()}return a|0}function Rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Lo(e,c);x[31721]=0;S(126,d+20|0,b|0,e|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Lo(e,c);x[31721]=0;O(14,d+20|0,e|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){x[31721]=0;S(847,a|0,b|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function y$(a,b,c,d){var e=0,f=0,g=0,h=0;e=Bb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Kc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Jb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Ri(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Ri(h,c,d);b=d+e|0;kg(a,b);ed(b+f|0,0);return a}Np(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}Rl();p()}function oi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Tj(b,c);if(f>>>0<2147483632){b:{if(Pk(f)){Ke(d,f);break b}og(e+8|0,Ah(f)+1|0);g=x[e+8>>2];wd(d,g);mf(d,x[e+12>>2]);Wd(d,f);d=g}while(1){if((b|0)!=(c|0)){ed(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}ed(d,0);fb=e+16|0;break a}nf();p()}return a|0}function kua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;S$(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){R$(f)}c=-1;a:{if(!d){break a}c=0;if(!U$(e+14|0)){break a}c=te(a,b,1024,0)}fb=e+1968|0;return c|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Pf(e,c);x[31721]=0;S(506,d+20|0,b|0,e|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Lj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(kc(x[a>>2],b)){a=0}else{b=Xi(b);e=Xi(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Vg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=$v(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[$v(c+12|0)>>2];continue}break}fb=c+16|0;a=XD(wb(x[a>>2]),b)}return a&65535}function Uja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!yd(x[a+1298300>>2])){d=x[a+24620>>2];e=fb-16|0;fb=e;b=Dc(536);x[31721]=0;d=P(880,b|0,d|0)|0;f=x[31721];x[31721]=0;a:{if((f|0)!=1){b=x[tf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(b);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;_R(b,ie(a));GA(a)}fb=c+16|0}function Pqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31721]=0;W(231,b|0);a=x[31721];x[31721]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;ee(c);Q(a|0);p()}ee(c);fb=d+16|0}function HF(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=_b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=(_b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function xX(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function wk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=nc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[Ab(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Qu(a,b);break a}c=Ab(a);c=ig(d+12|0,Uf(a,nc(x[a>>2],e)+b|0),nc(x[a>>2],x[a+4>>2]),c);SQ(c,b);Id(a,c);hg(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Xh(a,d+(b<<2)|0)}}function ts(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=x[pe(f+8|0,f+12|0)>>2];x[31721]=0;ba(e|0,a+8|0,b|0,c|0,d|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){a=uz(a);b=tz(a+88|0);c=sz(a+92|0);d=rz(a+96|0);x[a>>2]=47756;x[b>>2]=47872;x[c>>2]=47952;x[d>>2]=47992;Uc(f+12|0);fb=f+16|0;return a}a=N()|0;Uc(f+12|0);Q(a|0);p()}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;SC(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);SC(e,b);Tb(x[d+8>>2]+c|0,0,33-c|0);Ub(a,x[d+28>>2]);fb=d+32|0;return c|0}function lA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=Lu(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Ti(g)*Lu(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=aC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function qU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Jj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Qh(a+8|0,18,b+15|0);tv(a+26|0,18,27546);v[b+14|0]=255;Qh(a+62|0,256,b+14|0);wh(x[a>>2],x[a+4>>2],65535,261,1);wh(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function fM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){dM(a,65536);c=fc(b+16|0,vb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function U2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(jh(a,x[b+8>>2],e)){Fx(b,c,d);return}a:{if(!jh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function QR(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;OR(d,b+80|0);x[31721]=0;S(126,c+20|0,0,d|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;vX(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){uX(f)}c=-1;a:{if(!d){break a}c=0;if(!xX(e+2|0)){break a}c=te(a,b,256,0)}fb=e+128|0;return c|0}function qta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;d0(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){lE(f)}c=-1;a:{if(!d){break a}c=0;if(!B_(e+15|0)){break a}c=te(a,b,72,0)}fb=e+32|0;return c|0}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45488;b=a+4208|0;e=xb(b,0),f=1056880300,x[e>>2]=f;e=xb(b,1),f=1050733080,x[e>>2]=f;e=xb(b,2),f=1056964608,x[e>>2]=f;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Vf(a);Q(b|0);p()}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=45724;b=a+4208|0;e=xb(b,0),f=1065353216,x[e>>2]=f;e=xb(b,1),f=1065353216,x[e>>2]=f;e=xb(b,2),f=1051372203,x[e>>2]=f;e=xb(b,3),f=0,x[e>>2]=f;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Vf(a);Q(b|0);p()}function Sy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((go(a,f,b)|0)>=0){if((go(a,e,b)|0)>=0){break a}}j=f;f=(go(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}pL(g,h);fb=g+240|0}function DQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Tz(a);b=kk(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31721]=0;b=ba(953,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){Id(a,b);AQ(b);break b}Y(T(0)|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Qb();p()}function CQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Rg(a);b=nc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31721]=0;b=ba(954,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){Id(a,b);hg(b);break b}Y(T(0)|0)|0;x[31721]=0;X(26);a=x[31721];x[31721]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Qb();p()}function q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;ad(a,x[b+28>>2]);x[31721]=0;S(111,d+12|0,b|0,c|0);e=x[31721];x[31721]=0;a:{if((e|0)==1){break a}Yb(d+12|0);b=x[b+24>>2];if(b){x[31721]=0;S(112,d+8|0,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)==1){break a}Yb(d+8|0)}fb=d+16|0;return}b=N()|0;Yb(a);Q(b|0);p()}function ipa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=ow(c+4|0,a,1);gX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=yD(d+12|0,zD(a,Mf(x[a>>2],x[a+4>>2])+1|0),Mf(x[a>>2],x[a+4>>2]),c);gX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;xD(a,c);Lv(c);fb=d+32|0}function mla(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=WB(c+4|0,a,1);GB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Su(d+12|0,Iq(a,Gg(x[a>>2],x[a+4>>2])+1|0),Gg(x[a>>2],x[a+4>>2]),c);GB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;AU(a,c);IB(c);fb=d+32|0}function jM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;b=(b|0)>0|(b|0)>=0}ib[d|0](c,a,f,0)|0}return b|0}function Xsa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=ow(c+4|0,a,1);AD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=yD(d+12|0,zD(a,Mf(x[a>>2],x[a+4>>2])+1|0),Mf(x[a>>2],x[a+4>>2]),c);AD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;xD(a,c);Lv(c);fb=d+32|0}function TD(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=U_(c+4|0,a,1);T_(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=R_(d+12|0,S_(a,pr(x[a>>2],x[a+4>>2])+1|0),pr(x[a>>2],x[a+4>>2]),c);T_(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;Q_(a,c);P_(c);fb=d+32|0}function Rsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;d_(c+8|0,d+6|0);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!f_(d+6|0)){break a}c=te(a,b,e_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31721]=0;W(1004,a|0);d=x[31721];x[31721]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:985;return}Y(T(0)|0)|0;x[31721]=0;V(991,13137,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Kha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Pf(d,b);x[31721]=0;O(966,c+20|0,d|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;S(967,a|0,0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Kea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return E(VO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31721]=0;V(991,6229,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Jea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return E(UO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31721]=0;V(991,9377,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Iea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return E(TO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31721]=0;V(991,6272,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Hea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return E(SO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31721]=0;V(991,6174,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Gea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return E(RO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31721]=0;V(991,6130,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function xja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Lo(d,b);x[31721]=0;O(14,c+20|0,d|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;S(247,a|0,0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function tE(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=zua(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function soa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=ox(c+4|0,a);dC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=vm(d+12|0,Ep(a,Rd(x[a>>2],x[a+4>>2])+1|0),Rd(x[a>>2],x[a+4>>2]),c);dC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;jW(a,c);iW(c);fb=d+32|0}function fja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Xk(d,b);x[31721]=0;O(14,c+20|0,d|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;S(247,a|0,0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function c1(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Pf(d,b);x[31721]=0;S(126,c+20|0,22,d|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Rb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;UC(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);UC(e,b);Tb(x[d+8>>2]+c|0,0,4896-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function _z(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=ae(a);e=dc(a);f=fb-16|0;fb=f;while(1){if(c){g=Jq(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[zb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,ng(a))){if(!Jq(z[b>>1],z[rd(c)>>1])){break a}}c=ng(a)}a=x[zb(d+12|0,c)>>2];fb=d+16|0;return a}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=gg(d+8|0,b);x[31721]=0;S(843,d+20|0,b|0,c|0);e=x[31721];x[31721]=0;a:{b:{if((e|0)!=1){x[31721]=0;S(74,a|0,d+20|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function b1(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=YF(c+4|0,a);Rw(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;gc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=WF(d+12|0,XF(a,Ur(x[a>>2],x[a+4>>2])+1|0),Ur(x[a>>2],x[a+4>>2]),c);Rw(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;VF(a,c);Tw(c);fb=d+32|0}function XG(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;Dp(f+8|0,c);x[31721]=0;O(e|0,f+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(f,f+8|0);x[31721]=0;V(95,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;vg(f+8|0)}Q(a|0);p()}}function QG(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;p_(f+8|0,c);x[31721]=0;O(e|0,f+20|0,d|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){pk(f,f+8|0);x[31721]=0;V(95,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31721];x[31721]=0;if((a|0)==1){break c}vg(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;vg(f+8|0)}Q(a|0);p()}}function $ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}uc(d+12|0,65535);sg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}gw(b,d+10|0);e=c,f=Cb(z[d+10>>1]),w[e>>1]=f;c=x[Od(d+4|0)>>2];continue}}fb=d+16|0}function psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;GZ(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);GZ(e,b);Tb(x[d+8>>2]+c|0,0,102-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function pX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=zua(y[a+30|0],0,37,0);d=hb;b=zua(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function U1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=om(d+8|0,b);x[31721]=0;S(151,d+20|0,b|0,c|0);e=x[31721];x[31721]=0;a:{b:{if((e|0)!=1){x[31721]=0;S(4,a|0,d+20|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function Lsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Bb(x[a+4>>2],y[a+11|0]),x[f>>2]=g;e=x[Gb(d+12|0,d)>>2];x[d+4>>2]=e;a=Vp(Jb(a),b,x[Gb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}fb=d+16|0;return a|0}Rl();p()}function Bna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;fV(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);fV(e,b);Tb(x[d+8>>2]+c|0,0,263-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function dA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31721]=0;O(926,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;gc(d);Q(a|0);p()}gc(d);fb=e+16|0}function qZ(a){var b=0;a:{b:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1297108297){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function q7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=x[27987];x[g+24>>2]=x[27986];x[g+28>>2]=h;h=x[27985];x[g+16>>2]=x[27984];x[g+20>>2]=h;h=x[27983];x[g+8>>2]=x[27982];x[g+12>>2]=h;h=x[27981];x[g>>2]=x[27980];x[g+4>>2]=h;h=a;a=g+32|0;b=sk(h,b,c,d,e,f,g,a);fb=a;return b|0}function h2(a){a=a|0;var b=0,c=0;a:{b=fb-32|0;fb=b;c=b+8|0;Cc(c,13576);x[31721]=0;S(126,b+20|0,1,c|0);c=x[31721];x[31721]=0;b:{c:{if((c|0)!=1){x[31721]=0;O(12,a|0,b+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Rb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function Iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;Mv(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Mv(e,b);Tb(x[d+8>>2]+c|0,0,22-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function Gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;LC(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);LC(e,b);Tb(x[d+8>>2]+c|0,0,40-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function z0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;nw(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);nw(e,b);Tb(x[d+8>>2]+c|0,0,65-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function jea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return zO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31721]=0;V(991,6659,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function a4(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(gt(c)|0)!=0}if(b&2){a=(ft(c)|0)!=0|a}if(b&4){a=(et(c)|0)!=0|a}if(b&8){a=(dt(c)|0)!=0|a}if(b&16){a=(ct(c)|0)!=0|a}if(b&32){a=(bt(c)|0)!=0|a}if(b&64){a=(Jh(c)|0)!=0|a}if(b&128){a=(at(c)|0)!=0|a}if(b&256){a=($s(c)|0)!=0|a}if(b&512){a=(_s(c)|0)!=0|a}return a|0}function NP(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=ni(E(B[Av(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;uc(a+4224|0,b)}function Ida(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){eO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31721]=0;V(991,5784,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function VG(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Ac(f,c);x[31721]=0;S(d|0,e+20|0,b|0,f|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,e+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(e+20|0);tb(e+8|0);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Rb(e+20|0)}tb(e+8|0);Q(a|0);p()}}function JQ(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;lg(a,c+14|0);e=z[c+14>>1];wk(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;kq(a,c+8|0);f=xb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function Gsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;bk(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);bk(e,b);Tb(x[d+8>>2]+c|0,0,5-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function uQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31721]=0;x[c+12>>2]=0;S(955,a+4208|0,b<<1,c+12|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){b=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function mm(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=DS(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return CS(a,b,c,e);case 1:break b;default:break a}}f=CS(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=DS(x[a+720>>2],x[a+1272>>2],e)}return f}function jr(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=zb(d+12|0,c);g=zb(d+8|0,x[a>>2]);h=zb(d+4|0,x[b+4>>2]);i=b,j=$V(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Nv(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function j1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;Xk(d,b);x[31721]=0;O(14,c+20|0,d|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){x[31721]=0;O(15,a|0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Rb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Rb(c+20|0)}tb(c+8|0);Q(b|0);p()}function au(a){var b=0,c=0,d=0;b=zi(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=Yp(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=zi(d+c)*.5}else{b=0}C[a+4248>>3]=b}$t(a)}function _G(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Cc(e,b);x[31721]=0;S(126,d+20|0,c|0,e|0);b=x[31721];x[31721]=0;b:{c:{if((b|0)!=1){x[31721]=0;O(12,a|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break c}Rb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Rb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Zra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;dw(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){oZ(d)}c=-1;a:{if(!e){break a}c=0;if(!qZ(d)){break a}c=te(a,b,pZ(d),hb)}fb=d+192|0;return c|0}function BQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){Xj();p()}d=Dc(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function ria(a,b){a=a|0;b=b|0;var c=0;c=x[a+20>>2];b=x[c+4>>2];a:{if(!((Rc(b,x[c+8>>2])|0)!=8|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133)){c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}Rz(a,a)}bu(a)}function En(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-od((od(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-od(e+(od(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Tb(a,0,b<<3)}}function qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){cd();p()}c=Dc(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function Us(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function K6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;x[e>>2]=c;a=Yx(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}fb=f+16|0;return b|0}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;KY(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){WC(d)}c=-1;a:{if(!e){break a}c=0;if(!jV(d)){break a}c=te(a,b,iV(d),hb)}fb=d+80|0;return c|0}function uI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;Rb(b+520|0);Rb(b+508|0);Rb(b+496|0);d=b+460|0;c=Rb(b+484|0);while(1){c=Rb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=Rb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=Rb(c-12|0);if((d|0)!=(c|0)){continue}break}Hs(b);return a|0}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Cf(a,c);Zd(d,x[a+36>>2]);a:{b:{if(!c){Oc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Hi(f,b);break c;default:break d}}YY(f,b,e)}f=c}cf(a,f);fb=d+16|0}function hI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;tb(b+520|0);tb(b+508|0);tb(b+496|0);d=b+460|0;c=tb(b+484|0);while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=tb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}Hs(b);return a|0}function ZT(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Rs(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Ol(e,b,+n());return}a:{if(!vf(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Ol(a,b,vf(c)?NaN:c);return}b=Rs(b);g=Ti(c);Ol(a,b*ff(c),g*b)}function $u(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124209]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Ay(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Ay(a)}ie(b)}return a}function ey(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(Oq(b)){Ke(d,b);break b}Rj(f+8|0,ln(b)+1|0);e=x[f+8>>2];wd(d,e);mf(d,x[f+12>>2]);Wd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;rF(d,b,e+12|0);fb=e+16|0;wd((b<<2)+d|0,0);fb=f+16|0;break a}nf();p()}return a|0}function cV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){jp(e);break a}OD(b+8|0,Xb(Wi(Yp(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];be(e,d,b+7|0)}fb=b+16|0;b=c+4|0;DD(b,a+36|0,a+37|0);CD(b,e);fb=c+16|0}function ht(a,b,c,d){var e=0,f=0,g=0;e=fb-160|0;fb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Tb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1202;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31596]=61;break a}v[f|0]=0;a=kL(e,c,d,1178,1179)}fb=e+160|0;return a}function W$(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Pf(e,c);x[31721]=0;S(126,d+20|0,b|0,e|0);b=x[31721];x[31721]=0;a:{b:{if((b|0)!=1){x[31721]=0;O(12,a|0,d+20|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Rb(d+20|0);tb(d+8|0);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Rb(d+20|0)}tb(d+8|0);Q(c|0);p()}function rha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-3|0){case 0:c=ni(c);if(c==B[xb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(ni(E(c*E(4)))*E(.25))}d=xb(a+4208|0,b),e=c,B[d>>2]=e;Kz(a)}}function lea(a,b){a=a|0;b=b|0;var c=0;x[31721]=0;W(1004,a|0);c=x[31721];x[31721]=0;if((c|0)!=1){return BO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31721]=0;V(991,9801,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function bua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Kj(x[a>>2],x[a+4>>2])>>>0<=49){b=MB(c,x[a+12>>2]);x[31721]=0;O(294,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}Ql(b);_j(a,Kj(x[a>>2],x[a+4>>2])-1&255);b=Kj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Ql(b);Q(a|0);p()}function b_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function RD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=hf(b),x[g+28>>2]=h;c=f+8|0;_f(c,b,x[Gb(c,f+28|0)>>2]);b=Se(c);x[31721]=0;aa(239,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ic(f+8|0);fb=f+32|0;return}a=N()|0;Ic(f+8|0);Q(a|0);p()}function Lga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-1|0){case 0:c=ni(c);if(c==B[xb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(ni(E(c*E(4)))*E(.25))}d=xb(a+4208|0,b),e=c,B[d>>2]=e;Kz(a)}}function Aea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return MO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,12865,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function zea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return LO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,9330,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function sea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return Nf(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,7133,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function rea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return hq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,6822,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function qea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return FO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,6940,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function pea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return EO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,7008,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function oea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return fq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,7480,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function fea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return wO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,5816,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Eea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return QO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,8796,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Cea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return OO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,7165,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Bea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return NO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,5319,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function yea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return+KO(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31721]=0;V(991,15137,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function km(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Jb(b);e=c,f=Xc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;Qi(d,d+x[Gb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Xc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Nm(d+x[Gb(c+12|0,c+8|0)>>2]|0,a+d|0,78768);fb=c+16|0}function _q(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;TB(c,$U(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;TB(a,cC(a),b);fb=b+32|0}function Fea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return+zA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31721]=0;V(991,10149,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function nQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);tq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=hC(c+223848|0,b+223848|0);x[31721]=0;P(849,c+223860|0,b+223860|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){return c|0}b=N()|0;cc(a);Q(b|0);p()}function _F(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;Dw(d,b);x[31721]=0;S(11,c+20|0,1,d|0);b=x[31721];x[31721]=0;a:{if((b|0)!=1){x[31721]=0;O(12,a|0,c+20|0);a=x[31721];x[31721]=0;if((a|0)==1){b=N()|0;Rb(c+20|0);break a}Rb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function W2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(jh(a,x[b+8>>2],0)){Ex(b,c,d);return}e=x[a+12>>2];f=a+16|0;WH(x[f>>2],x[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){WH(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function rR(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;ve(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=fb-16|0;fb=c;e=Bb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Gb(c+12|0,c+8|0);a=kx(Jb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function Du(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;ve(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=fb-16|0;fb=c;e=Bb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Gb(c+12|0,c+8|0);a=Vp(Jb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function gf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function qW(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Cb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Cb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Cb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Cb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function ih(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);Wf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function hea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31721]=0;V(991,7642,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function cea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31721]=0;V(991,10930,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Y$(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=hf(a)}e=d+8|0;dw(e,b);f=fc(d+16|0,x[d+8>>2],c);jc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);dw(e,b);Tb(x[d+8>>2]+c|0,0,192-c|0);Ub(a,x[d+28>>2]);fb=d+32|0}function GK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=wt(a);x[a+32>>2]=b;x[a>>2]=94844;ad(d+12|0,x[a+4>>2]);x[31721]=0;b=R(1200,x[d+12>>2])|0;e=x[31721];x[31721]=0;if((e|0)!=1){Yb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=_n(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Yb(d+12|0);co(a);Q(b|0);p()}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=42284;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];F$(a+4260|0,80,150,80,255);x[31721]=0;O(949,a+44|0,2);c=x[31721];x[31721]=0;if((c|0)!=1){return a|0}c=N()|0;sc(b);Vf(a);Q(c|0);p()}function n0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}uc(d+12|0,65535);sg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}gw(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Od(d+4|0)>>2];continue}}fb=d+16|0}function iZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;d=c+44|0;_f(d,a,32);a=x[c+44>>2];e=c+20|0;rg(e,2,Se(d),a);x[31721]=0;O(221,c+32|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=c+12|0;An(a,b);b=a;a=c+32|0;km(b,a);tb(a);Ic(c+44|0);fb=c- -64|0;break a}a=N()|0;Ic(c+44|0);Q(a|0);p()}}function Wp(a,b){var c=0,d=0;c=fb-16|0;fb=c;ad(c+12|0,a);x[31721]=0;a=R(1219,x[c+12>>2])|0;d=x[31721];x[31721]=0;a:{b:{if((d|0)==1){break b}x[31721]=0;V(1230,a|0,111712,111738,b|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}Yb(c+12|0);fb=c+16|0;break a}a=N()|0;Yb(c+12|0);Q(a|0);p()}return b}function PV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=_b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=hr(f*+A[Gb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=_b(c),x[i+4>>2]=j;i=e,j=hr(f*+A[Gb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;Qj(a,h,Gb(b,g));fb=e+16|0}function t_(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function sy(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Fi(f,0,0);uK(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function fx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function RN(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47636;a=$b(8);x[31721]=0;b=P(37,b+4|0,12133)|0;c=x[31721];x[31721]=0;a:{b:{if((c|0)!=1){mc(a,b);x[31721]=0;S(100,a|0,48476,1008);a=x[31721];x[31721]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;ic(a)}Q(c|0)}p()}function EK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=SK(a);x[a+32>>2]=b;x[a>>2]=95212;ad(d+12|0,x[a+4>>2]);x[31721]=0;b=R(39,x[d+12>>2])|0;e=x[31721];x[31721]=0;if((e|0)!=1){Yb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=_n(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Yb(d+12|0);nt(a);Q(b|0);p()}function ZA(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}yk(a,b,b+700|0,c<<2,0)}}function PP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31721]=0;x[c+12>>2]=0;S(955,a+4208|0,b<<2,c+12|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){b=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function LM(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=gf(e);b:{c:{if((Bb(x[c+4>>2],y[c+11|0])|0)==(d|0)){x[31721]=0;d=U(373,c|0,e|0,d|0)|0;e=x[31721];x[31721]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}T(0)|0;Qb();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function EF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-od((od(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-od((od(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Dea(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return PO(x[a+24>>2])|0}Y(T(0)|0)|0;x[31721]=0;V(991,9766,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;qf(b);x[d+12>>2]=0;a:{if(!Jk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(ji(a,d+11|0)){Fp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function MZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=mg(a);b=b+236|0;e=gr(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31721]=0;S(405,c+4|0,a|0,c+14|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Gv(a);Q(b|0);p()}function kka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Bd(y[b+24|0])){a=mg(a);c=Xi(x[b>>2]);d=Kf(b);x[31721]=0;S(852,a|0,c|0,d|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}x[31721]=0;P(851,a+12|0,b+12|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;LS(a);Q(b|0);p()}function _A(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}yk(a,b,b+700|0,c,0)}}function JD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=hf(b),x[f+28>>2]=g;c=e+8|0;_f(c,b,x[Gb(c,e+28|0)>>2]);b=Se(c);x[31721]=0;V(346,a|0,b|0,x[e+8>>2],d|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ic(e+8|0);fb=e+32|0;return}a=N()|0;Ic(e+8|0);Q(a|0);p()}function eC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!ge(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}jn(b);b=Po(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Bh(b)){break a}if(x[a>>2]!=(d|0)){Rr(b+68|0)}yc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function TG(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31721]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){a=d+20|0;Nh(a,b);yb(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Ch(a);Q(b|0);p()}function JM(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;Lt(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;e=x[18375];x[a+8>>2]=x[18374];x[a+12>>2]=e;e=x[18373];x[a>>2]=x[18372];x[a+4>>2]=e;b=ib[x[cq(a,vk(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function mk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;po(c,a);if(x[b>>2]){ZY(b);a=x[b>>2];Ms(b);Db(a);e=Ab(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Ab(c);e=Ab(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;lf(c);fb=d+16|0}function Y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+28>>2]){break a}if((ib[x[b+32>>2]](x[b+24>>2],c,0,0)|0)<0){break a}c=x[d+4>>2];f=x[d>>2];while(1){if(!c){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,c)|0;if(!e){break a}g=e+g|0;c=c-e|0;f=f+e|0;continue}}ac(a,x[d>>2],g)}function OQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Rg(a)>>>0>=b>>>0){f=x[a>>2];e=nc(f,x[a+4>>2]);x[d+8>>2]=e;NQ(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){bA(a,b-e|0,c);break a}Xh(a,x[a>>2]+(b<<2)|0);break a}br(a);im(a,Uf(a,b));bA(a,b,c)}fb=d+16|0}function yfa(a){a=a|0;var b=0;x[31721]=0;W(1004,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31721]=0;V(991,5690,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function Zh(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Dc(16),x[g+8>>2]=h;b=qm(x[c+8>>2]);x[b>>2]=41176;g=Jn(zc(b)),h=41308,x[g>>2]=h;b=d+8|0;f=Ln(c);Kn(b,zc(f),f);rm(c);fb=e+16|0;Af(a,b);he(b);fb=d+16|0;x[a+8>>2]=0;Jd(a+12|0);return a}function Qea(a){a=a|0;var b=0;x[31721]=0;W(1029,a|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31721]=0;V(991,11974,a|0,0,0);a=x[31721];x[31721]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Qb();p()}function ux(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;_f(g,a,e);a=x[f+44>>2];e=f+20|0;rg(e,d,Se(g),a);x[31721]=0;O(221,f+32|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=f+12|0;fc(a,b,c);b=a;a=f+32|0;km(b,a);tb(a);Ic(f+44|0);fb=f- -64|0;break a}a=N()|0;Ic(f+44|0);Q(a|0);p()}}function Vm(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Nj(y[f+31|0])){break a}e=y[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=x[sd(a+906300|0,e)>>2];if(!e){break a}ib[x[x[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function Epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(644,a|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break a}kp(a,b,c)}b=d+8|0;Md(b);Wj(b);fb=d+16|0;return a|0}a=N()|0;Wj(d+8|0);Q(a|0);p()}function uha(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;Xt(a)}}function mZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(464,a|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break a}aD(a,b,c)}b=d+8|0;Md(b);cm(b);fb=d+16|0;return a|0}a=N()|0;cm(d+8|0);Q(a|0);p()}function jia(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;bu(a)}}function E0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(228,a|0,b|0);e=x[31721];x[31721]=0;if((e|0)==1){break a}EE(a,b,c)}b=d+8|0;Md(b);_g(b);fb=d+16|0;return a|0}a=N()|0;_g(d+8|0);Q(a|0);p()}function BP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;AP(a+60|0);AP(a+52|0);qq(a+49956|0);qq(a+58148|0);qq(a+66340|0);qq(a+74532|0);Tb(a+228|0,0,32768);Tb(a+32996|0,0,512);Tb(a+33508|0,0,16384)}function tu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=Ej(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=uh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function oj(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=Ih(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=ht(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Ed(d);x[h>>2]=a;if(!a){break a}f=ht(a,d,c,x[b+12>>2])}fb=b+16|0;Hh(g);fb=e+16|0;return f}function Tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(So(a)>>>0>=b>>>0){f=x[a>>2];e=Rc(f,x[a+4>>2]);x[d+8>>2]=e;Qh(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){rp(a,b-e|0,c);break a}Vq(a,x[a>>2]+b|0);break a}Ov(a);_k(a,Wl(a,b));rp(a,b,c)}fb=d+16|0}function Hp(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){Xj();p()}d=Dc(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=zc(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Cf(a,c);Zd(d,x[a+36>>2]);a:{b:{if(!c){Oc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Jk(f,b);break c}aN(f,b,e)}f=c}cf(a,f);fb=d+16|0}function r2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=yt(c);x[a>>2]=94304;x[d>>2]=94324;x[a+60>>2]=94364;x[a>>2]=94344;x[a+4>>2]=0;e=c;c=a+8|0;ho(e,c);x[a>>2]=94304;x[d>>2]=94324;x[31721]=0;P(110,c|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}a=N()|0;ul(d);Q(a|0);p()}function ni(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function nP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;oQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}
function Cs(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!Op(e+12|0,b,c)){break a}f=x[e+12>>2];b=Kx(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function vF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Yd(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function o7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;ad(g+8|0,x[d+28>>2]);x[31721]=0;b=R(1219,x[g+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(g+8|0);LJ(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Yb(g+8|0);Q(a|0);p()}function n7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;ad(g+8|0,x[d+28>>2]);x[31721]=0;b=R(1219,x[g+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(g+8|0);KJ(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Yb(g+8|0);Q(a|0);p()}function C1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31721]=0;V(170,e+8|0,b|0,e+28|0,e+24|0);c=x[31721];x[31721]=0;if((c|0)!=1){c=e+16|0;yp(c,x[e+8>>2],x[e+12>>2]);Af(a,c);he(c);he(e+8|0);he(b);fb=e+32|0;return}a=N()|0;he(b);Q(a|0);p()}function jY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Xe(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){uc(e+12|0,10);a=D(y[x[e+12>>2]+25152|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Xe(733.8401379310345/f*1e4);break a}a=Xe(f/.264*1e4)}fb=e+16|0;return a}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;QW(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){PW(e)}if(a){d=RW(b+14|0)}fb=b+160|0;return d|0}function Kta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;o$(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){n$(e)}if(a){d=p$(b+14|0)}fb=b+624|0;return d|0}function u7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;ad(g+8|0,x[d+28>>2]);x[31721]=0;b=R(28,x[g+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(g+8|0);OJ(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Yb(g+8|0);Q(a|0);p()}function t7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;ad(g+8|0,x[d+28>>2]);x[31721]=0;b=R(28,x[g+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(g+8|0);NJ(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Yb(g+8|0);Q(a|0);p()}function Ue(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;UE(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;qf(b);e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,1,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;yb(b,a);tb(a);Ic(d+28|0);fb=d+48|0;break a}a=N()|0;Ic(d+28|0);Q(a|0);p()}}function C$(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=vb(a,31),f=0,v[e|0]=f;d=Ii(a,Mo(a),0);v[c+15|0]=0;d=Tj(a,d);Nm(d+a|0,Mo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[vb(a,b)|0]>=32){if(y[vb(a,b)|0]!=127){break a}}e=vb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}fb=c+16|0}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+4|0;pW(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){oW(e)}if(a){d=qW(b+4|0)}fb=b+208|0;return d|0}function st(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=$b(16);if(!y[502177]){v[502177]=1}a=fc(c+8|0,a,126368);x[31721]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1180,d|0,c|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){da(a|0,124292,1181);p()}a=N()|0;ic(d);Q(a|0);p()}function fta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+10|0;Mv(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){t_(e)}if(a){d=u_(b+10|0)}fb=b+32|0;return d|0}function ara(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+11|0;bk(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){EY(e)}if(a){d=FY(b+11|0)}fb=b+16|0;return d|0}function Osa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+3|0;a_(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){$Z(e)}if(a){d=b_(b+3|0)}fb=b+160|0;return d|0}function gQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31721]=0;x[c+12>>2]=0;S(955,a+4208|0,D(b,254)|0,c+12|0);b=x[31721];x[31721]=0;a:{if((b|0)==1){b=T(124984)|0;if((gb|0)!=($(124984)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function cH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;uc(c,f);uc(c,65535);h=z[g+12>>1];sg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Gr(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function t$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=ZD(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[$c(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}cd();p()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=sV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31721]=0;O(788,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;ee(a);Q(b|0);p()}ee(a);fb=d+16|0}function S_(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=O_(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[$c(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}cd();p()}function Pna(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Rh(c);if((c|0)!=1){break b}}_x(a,d,1,d,d,0);c=d}d=x[a>>2];Wd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=(c<<2)+d|0;wd(a,b);wd(a+4|0,0)}function yna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31721]=0;O(228,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}Qu(a,b)}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}a=N()|0;_g(c+8|0);Q(a|0);p()}function sqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31721]=0;O(592,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}TC(a,b)}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}a=N()|0;_g(c+8|0);Q(a|0);p()}function pd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];jf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);jf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function dY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!ge(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}uc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Bh(a)){break a}yc(x[a+20>>2],x[b+20>>2],Sk(x[a>>2],z[a+34>>1]))}}function YL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;jf(e+24|0,b,c);b=Af(e+16|0,d);x[31721]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;eg(166,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31721];x[31721]=0;if((a|0)!=1){he(d);fb=e+32|0;return}a=N()|0;he(d);Q(a|0);p()}function J$(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function uF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Yd(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function o8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function hra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(nc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!yd(b)){break a}x[31721]=0;O(504,a|0,c+12|0);a=x[31721];x[31721]=0;d=b;if((a|0)!=1){break a}a=N()|0;Hg(c+12|0);Q(a|0);p()}Hg(c+12|0);fb=c+16|0;return d|0}function eo(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Bua(a,b,10,0);e=hb;a=zua(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function c0(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;qf(b);e=d+28|0;_f(e,a,c);a=x[d+28>>2];f=d+4|0;rg(f,3,Se(e),a);x[31721]=0;O(221,d+16|0,f|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=b;b=d+16|0;yb(e,b);tb(b);Ic(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Ic(d+28|0);Q(a|0);p()}function Ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=gJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31721]=0;W(601,b|0);e=x[31721];x[31721]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;gc(a);Q(b|0);p()}gc(a);fb=c+16|0}function Fp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Rh(c);if((c|0)!=10){break b}}Om(a,d,1,d,d,0,0);c=d}d=x[a>>2];Wd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,1,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;ye(b,a);tb(a);Ic(d+28|0);fb=d+48|0;break a}a=N()|0;Ic(d+28|0);Q(a|0);p()}}function i_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;uc(c,256);uc(c,65535);f=z[d+12>>1];sg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Gr(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Rh(c);if((c|0)!=10){break b}}DB(a,d,1,d,d,0);c=d}d=x[a>>2];Wd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function Rra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;Tk(b,a);tb(a);Ic(d+28|0);fb=d+48|0;break a}a=N()|0;Ic(d+28|0);Q(a|0);p()}}function De(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function DE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=ow(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31721]=0;W(231,b|0);e=x[31721];x[31721]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;gc(a);Q(b|0);p()}gc(a);fb=c+16|0}function uW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=wb(x[a>>2]);x[c+12>>2]=b;e=wb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Od(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function l$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;xc(b,a);tb(a);Ic(d+28|0);fb=d+48|0;break a}a=N()|0;Ic(d+28|0);Q(a|0);p()}}function Qha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6053,9014,88,7400);p()}fb=b+16|0;return a|0}function m7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;ad(a+8|0,x[d+28>>2]);x[31721]=0;b=R(1219,x[a+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(a+8|0);JJ(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Yb(a+8|0);Q(b|0);p()}function Yj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wb(x[b>>2]);f=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(V_(c,x[d>>2],x[d+4>>2])){break a}d=x[tn(e+12|0)>>2];continue}break}fb=e+16|0;if(kc(d,wb(x[b+4>>2]))){Zh(a);return}fp(a,d)}function Xt(a){var b=0,c=0,d=E(0);b=a+4232|0;c=y[b|0];if(c>>>0>=5){v[b|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-Ce(E(2),E(-E((b&255)+1|0))));break a}d=Ce(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function tF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}pp(d+8|0,a,e);Fw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}ac(a,x[c>>2],g)}function Qia(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31721]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;S(82,a|0,b|0,c+4|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ch(c+4|0);fb=c+32|0;return}a=N()|0;Ch(c+4|0);Q(a|0);p()}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;d=c+28|0;_f(d,a,32);a=x[c+28>>2];e=c+4|0;rg(e,1,Se(d),a);x[31721]=0;O(221,c+16|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=c+16|0;xc(b,a);tb(a);Ic(c+28|0);fb=c+48|0;break a}a=N()|0;Ic(c+28|0);Q(a|0);p()}}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=uf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Nk(b,1,c,x[a+32>>2])}return c|0}function s7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;ad(a+8|0,x[d+28>>2]);x[31721]=0;b=R(28,x[a+8>>2])|0;d=x[31721];x[31721]=0;if((d|0)!=1){Yb(a+8|0);MJ(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Yb(a+8|0);Q(b|0);p()}function eJ(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;d=qc(a+8|0),e=0,v[d+128|0]=e;Nd(b+8|0,x[zb(b+4|0,a)>>2]);x[31721]=0;O(1293,a|0,30);c=x[31721];x[31721]=0;if((c|0)!=1){Qu(a,30);c=b+8|0;Md(c);bJ(c);fb=b+16|0;return a}a=N()|0;bJ(b+8|0);Q(a|0);p()}function a$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[af(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[af(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function _L(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;fg(x[x[a>>2]-12>>2]+a|0,0);Zd(b+32|0,a);a=Ei(a,0,0,2);Zd(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];Rm(a,b);a=Cu(d,c);fb=b+48|0;return a}function Mp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function JE(a,b){var c=0,d=0;c=fb-16|0;fb=c;ad(c+12|0,a);x[31721]=0;a=R(28,x[c+12>>2])|0;d=x[31721];x[31721]=0;a:{if((d|0)==1){break a}x[31721]=0;a=P(29,a|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}Yb(c+12|0);fb=c+16|0;return a}a=N()|0;Yb(c+12|0);Q(a|0);p()}function B_(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function f0(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;e=d+28|0;_f(e,a,c);a=x[d+28>>2];f=d+4|0;rg(f,3,Se(e),a);x[31721]=0;O(221,d+16|0,f|0);e=x[31721];x[31721]=0;if((e|0)!=1){e=b;b=d+16|0;xc(e,b);tb(b);Ic(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Ic(d+28|0);Q(a|0);p()}function MG(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;qf(b);g=f+28|0;_f(g,a,d);a=x[f+28>>2];d=f+4|0;rg(d,e,Se(g),a);x[31721]=0;S(602,f+16|0,c|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=f+16|0;yb(b,a);tb(a);Ic(f+28|0);fb=f+48|0;break a}a=N()|0;Ic(f+28|0);Q(a|0);p()}}function gv(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Cb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function Uh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function KB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=WB(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31721]=0;O(788,b|0,c|0);f=x[31721];x[31721]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;gc(a);Q(b|0);p()}gc(a);fb=d+16|0}function jt(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Ly(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function V8(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){$n(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=uf(v[a|0])}return d|0}function eP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126892;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function xI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=ZI(a,c);x[a>>2]=113180;c=uk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,17922,b);x[31721]=0;W(1347,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function vl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=zt(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function nn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=qC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(Oq(c)){Ke(d,c);break b}Rj(e+8|0,ln(c)+1|0);f=x[e+8>>2];wd(d,f);mf(d,x[e+12>>2]);Wd(d,c);d=f}wd(Vi(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}nf();p()}return a|0}function X4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=aJ(a,c);x[a>>2]=111980;c=uk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,17860,b);x[31721]=0;W(1347,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function U4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=$I(a,c);x[a>>2]=112012;c=uk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,18041,b);x[31721]=0;W(1347,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function Gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=Yt(a+8|0,d);x[31721]=0;P(969,a+20|0,c|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=Yn(e+4|0,c,d);c=lK(0,Jb(b),0);x[31721]=0;a=U(1367,a|0,c|0,0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){lK(Jb(a),Jb(b),Bb(x[a+4>>2],y[a+11|0])+1|0);Rb(b);fb=e+16|0;return}a=N()|0;Rb(b);Q(a|0);p()}function pZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function Nn(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);Wf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function BC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;yC(d+8|0,e);f=x[d+12>>2];jc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Ub(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=zC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function $G(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{if(b){x[31721]=0;O(d|0,a|0,b|0);d=x[31721];x[31721]=0;if((d|0)==1){break a}rp(a,b,c)}b=e+8|0;Md(b);$i(b);fb=e+16|0;return a}a=N()|0;$i(e+8|0);Q(a|0);p()}function vB(a,b,c,d){var e=0,f=0,g=0;e=ae(a);a:{if(e){f=dc(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Nl(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Nl(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=dc(a);f=a}x[b>>2]=a;return f}function q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=oi(e+4|0,c,d);c=nK(0,Jb(b),0);x[31721]=0;a=U(545,a|0,c|0,0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){nK(Jb(a),Jb(b),Bb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function QA(a,b,c,d){var e=0,f=0,g=0;e=ae(a);a:{if(e){f=dc(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(vo(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!vo(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=dc(a);f=a}x[b>>2]=a;return f}function I1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[b+8>>2];a:{if(f>>>0<=c>>>0){c=x[d>>2];b=0;break a}x[e+12>>2]=f-c;x[e+8>>2]=x[d+4>>2];c=x[b+4>>2]+c|0;f=c;b=x[Gb(e+12|0,e+8|0)>>2];g=c+b|0;c=x[d>>2];Qi(f,g,c)}ac(a,c,b);fb=e+16|0}function Cq(a,b,c,d){var e=0,f=0,g=0;a:{e=Pl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Ak(g)){break a}f=Dd(a+318|0,e);e=oU(e);if(v[vb(f,10)|0]&1|d){wh(g,x[a+4>>2],b,e- -64|0,nU(c,y[vb(f,2)|0]))}if(d){break a}wh(x[a>>2],x[a+4>>2],b,e+67|0,nU(c,y[vb(f,3)|0]))}}function dra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qf(b);v[c+15|0]=0;a:{if(!ji(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(ji(a,c+14|0)){Fp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function QY(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;g=a;a=D((a-b|0)/-6|0,6)+c|0;PY(f+8|0,b,g,a);Ud(d+8|0,b,zb(f+4|0,Tq(c,a)));fb=f+16|0;a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Ud(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function Fh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31721]=0;x[g+4>>2]=x[g+4>>2]&e|d;S(c|0,a|0,b|0,g+4|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ch(g+4|0);fb=g+32|0;return}a=N()|0;Ch(g+4|0);Q(a|0);p()}function l8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function RG(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31721]=0;O(c|0,a|0,b|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}kX(a,b)}b=d+8|0;Md(b);$i(b);fb=d+16|0;return a}a=N()|0;$i(d+8|0);Q(a|0);p()}function PO(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Lj(Wb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[Zb(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return vn(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function rx(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31721]=0;x[f+4>>2]=x[f+4>>2]&e|d;S(c|0,a|0,b|0,f+4|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ch(f+4|0);fb=f+32|0;return}a=N()|0;Ch(f+4|0);Q(a|0);p()}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=Cf(a,c);Zd(d,x[a+36>>2]);a:{b:{if(!b){Oc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}FB(x[a+36>>2],e,c);f=1;g=b}cf(a,g);fb=d+16|0;return f|0}function pH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Dc(d),x[g+8>>2]=h;d=x[e+8>>2];x[31721]=0;P(c|0,d|0,b|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){b=a;a=Ln(e);Kn(b,zc(a),a);rm(e);fb=f+16|0;break a}a=N()|0;rm(e);Q(a|0);p()}}function cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;sx(e,c);c=d+16|0;x[c>>2]=b;Zc(c+4|0,e);x[31721]=0;O(1133,a+4|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ik(d+16|0);tb(d+4|0);fb=d+32|0;return}a=N()|0;Ik(d+16|0);tb(d+4|0);Q(a|0);p()}function UG(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;_f(f,a,d);a=x[e+28>>2];d=e+4|0;rg(d,c,Se(f),a);x[31721]=0;O(221,e+16|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=e+16|0;ye(b,a);tb(a);Ic(e+28|0);fb=e+48|0;break a}a=N()|0;Ic(e+28|0);Q(a|0);p()}}function Ly(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function c$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[af(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function D$(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;qf(b);e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;yb(b,a);tb(a);Ic(d+28|0);fb=d+48|0;return}a=N()|0;Ic(d+28|0);Q(a|0);p()}function zG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Cc(b+4|0,15621);a:{if(!Xc(x[a+4>>2],y[a+11|0])){break a}c=1;if((Og(a,14624)|0)!=-1){break a}if((Og(a,16804)|0)!=-1){break a}if((Og(a,13773)|0)!=-1){break a}c=(Og(a,13816)|0)!=-1}tb(a);fb=b+16|0;return c|0}function r3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=oi(a+20|0,b,c);x[31721]=0;c=U(1368,a+8|0,d|0,e|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){d=ki(Jb(b),Jb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function of(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Pk(b)){Ke(d,b);break b}og(e+8|0,Ah(b)+1|0);f=x[e+8>>2];wd(d,f);mf(d,x[e+12>>2]);Wd(d,b);d=f}ed(bm(d,b,c)+b|0,0);fb=e+16|0;break a}nf();p()}return a|0}function a1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!IF(a,c+12|0)){break a}d=0;if(!HF(c+12|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<_b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function OC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;oY(a,b);bd(a,_b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);nY(a,d);a:{b=_b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!bd(a,b)){break a}QC(a,c);return}Tb(c,0,80)}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function Fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=44960;b=a+4208|0;e=xb(b,0),f=1017370378,x[e>>2]=f;e=xb(b,1),f=0,x[e>>2]=f;x[31721]=0;O(949,a+44|0,2);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Vf(a);Q(b|0);p()}function ig(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Rj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function _9(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(!y[a+8|0]){Uj(a+12|0,x[a+4>>2]);le(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;ib[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}fb=b+32|0;return x[a+12>>2]}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=UI(a,0);x[a>>2]=118296;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31721]=0;O(1352,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}a=N()|0;Rb(f);Rb(e);Rb(d);tb(c);Q(a|0);p()}function x4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=TI(a,0);x[a>>2]=118400;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31721]=0;O(1353,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}a=N()|0;Rb(f);Rb(e);Rb(d);tb(c);Q(a|0);p()}function E4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=WI(a,0);x[a>>2]=118088;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31721]=0;O(1350,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=VI(a,0);x[a>>2]=118192;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31721]=0;O(1351,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function eK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;ji(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;ji(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function nE(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;_f(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,3,Se(e),a);x[31721]=0;O(221,d+16|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){a=d+16|0;Tk(b,a);tb(a);Ic(d+28|0);fb=d+48|0;return}a=N()|0;Ic(d+28|0);Q(a|0);p()}function lL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=lL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function US(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Gq(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function jra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(nc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;om(f,x[xb(c,d)>>2]+40|0);c=Wq(f,b);tb(f);if(!c){break a}g=x[xb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=Cf(a,c);Zd(e,x[a+36>>2]);a:{b:{if(!c){Oc(e,a+32|0,5);f=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}cf(a,g);fb=e+16|0}function _T(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;c=a;d=x[a>>2];f=Ek(d,x[a+4>>2]);a=wb(d);x[b+12>>2]=a;e=+(f>>>0);c=wb(x[c+4>>2]);while(1){if(Ib(a,c)){C[a>>3]=C[a>>3]/e;C[a+8>>3]=C[a+8>>3]/e;a=x[Lq(b+12|0)>>2];continue}else{fb=b+16|0}break}}function GV(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){gc(c);fb=d+16|0}else{DV(Tb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function AC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=wb(x[a>>2]);c=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Od(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function Vw(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ON(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=d,f=YN(c),x[e+8>>2]=f;c=x[pe(d+12|0,d+8|0)>>2];x[31721]=0;b=+pa(1122,a|0,+b,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){Uc(d+8|0);fb=d+16|0;return+b}a=N()|0;Uc(d+8|0);Q(a|0);p()}function Id(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=zb(c+12|0,x[a+4>>2]);e=zb(c+8|0,x[a>>2]);f=zb(c+4|0,x[b+4>>2]);g=b,h=$V(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),zc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Ica(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22250}c=Ed(gf(b)+1|0);x[a+4>>2]=c;if(!c){break a}yc(c,b,gf(b)+1|0)}return a|0}function Qb(){var a=0;a=x[31593];x[31721]=0;X(a|0);a=x[31721];x[31721]=0;a:{if((a|0)!=1){x[31721]=0;X(1369);a=x[31721];x[31721]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[31721]=0;X(1369);a=x[31721];x[31721]=0;if((a|0)!=1){break a}T(0)|0;Qb()}p()}function Lp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function jS(a,b){a=eS(a);eS(a+368680|0);if(b){dS(a,1);return}if(!y[495760]){jS(127056,1);v[495760]=1}Hk(258168,323704,a+131112|0);Hk(323704,389240,a+196648|0);Hk(389240,454776,a+262184|0);Hk(127080,258168,a+24|0);yc(a+327720|0,454776,40960)}function hn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}og(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function gT(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Gb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function Uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;ur(e,c);yj(d+12|0,e);x[31721]=0;V(304,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Pq(e,c);yj(d+12|0,e);x[31721]=0;V(304,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function $V(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;g=a;a=(b-a|0)+c|0;YV(f+8|0,b,g,a);Ud(d+8|0,b,zb(f+4|0,a));fb=f+16|0;a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Ud(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;yZ(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function nh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Bb(x[a+4>>2],d);a:{if((c|0)!=(Bb(x[b+4>>2],y[b+11|0])|0)){break a}a=Jb(a);b=Jb(b);if(!Cd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!Vp(a,b,c)}return e}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=Tu(e+4|0,a,d);f=x[d+4>>2];x[31721]=0;a=ba(1131,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){x[d+4>>2]=a;gc(d);fb=e+16|0;return}a=N()|0;gc(d);Q(a|0);p()}function VP(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function Hra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Ev(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Cra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Dp(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;kE(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function xW(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=vW(a+20|0)}return c}function vT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function vG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Un(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function se(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function _C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[31721]=0;d=R(205,b|0)|0;e=x[31721];x[31721]=0;b:{if((e|0)==1){break b}x[31721]=0;S(172,a|0,b|0,d|0);a=x[31721];x[31721]=0;if((a|0)==1){break b}break a}a=N()|0;cc(c);Q(a|0);p()}}function Wra(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=fc(b+8|0,b+28|0,3);jc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(hd(b+28|0,14728,3)){break a}Ub(a,3);d=1}fb=b+32|0;return d|0}function WG(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;uc(c,d);uc(c,65535);d=z[e+12>>1];sg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Gr(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function Una(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=fc(b+8|0,b+24|0,6);jc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(hd(b+24|0,3856,6)){break a}Ub(a,6);d=1}fb=b+32|0;return d|0}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=fv(e+4|0,a,d);f=x[d+4>>2];x[31721]=0;a=ba(1167,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){x[d+4>>2]=a;gc(d);fb=e+16|0;return}a=N()|0;gc(d);Q(a|0);p()}function HE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;mw(e,c);yj(d+12|0,e);x[31721]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31721];x[31721]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function oy(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;ji(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;ji(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function Yw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;jf(e+8|0,b,c);x[31721]=0;Ma(168,a|0,x[e+8>>2],x[e+12>>2]);b=x[31721];x[31721]=0;if((b|0)!=1){x[a+8>>2]=0;Af(a+12|0,d);he(d);fb=e+16|0;return a|0}a=N()|0;he(d);Q(a|0);p()}function EC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];jf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);jf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function cA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function a0(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function QS(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function fT(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function _u(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Cb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Cb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Cb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function Lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=Cf(a,c);Zd(d,x[a+36>>2]);a:{b:{if(!b){Oc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}FB(x[a+36>>2],e,c);f=b}cf(a,f);fb=d+16|0}function Fi(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function Cta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Pw(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function _U(a){var b=0,c=0,d=0;d=Mo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function FU(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=vi(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){gc(g);ir(b,f,h);fb=e+16|0}else{ck(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function oT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Vb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function _f(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31721]=0;S(172,a|0,b|0,c|0);c=x[31721];x[31721]=0;a:{if((c|0)!=1){a=x[a>>2];x[31721]=0;P(186,b|0,a|0)|0;a=x[31721];x[31721]=0;if((a|0)!=1){break a}}a=N()|0;cc(d);Q(a|0);p()}}function Sra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;UC(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,4896)}return a|0}function w_(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Vl(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){gc(g);ir(b,f,h);fb=e+16|0}else{wl(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function wY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=mn(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Vi(d+(e<<2)|0,b,c);b=c+e|0;kg(a,b);wd(d+(b<<2)|0,0);return a|0}$H(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function bpa(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!KD(a,b+20|0)){break a}c=0;if(!aX(b+20|0)){break a}c=-1;if(!lk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}a=x[b+12>>2];c=(a&2139062143)==(a|0)}fb=b+32|0;return c|0}function ZZ(a){var b=0,c=0,d=0,e=0;b=y[a+3|0];c=zua(b>>>0<3?48:64,0,Cb(y[a+196|0]|y[a+197|0]<<8),0);d=hb;e=c;c=zua(zua(Cb(y[a+198|0]|y[a+199|0]<<8),0,b>>>0<4?4:5,0),hb,Cb(y[a+200|0]|y[a+201|0]<<8),0);b=e+c|0;b=b+512|0;hb=0;return b}function Tf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31721]=0;V(1152,17403,9110,435,6381);a=x[31721];x[31721]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Qb();p()}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Nk(b,4,c,x[a+32>>2])}return c|0}function ZB(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=SV(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function RA(a,b,c){var d=0,e=0;d=ae(a);a:{if(d){e=dc(a);while(1){a=d;d=y[a+16|0];if(wo(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!wo(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=dc(a);e=a}x[b>>2]=a;return e}function Qqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;SC(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,33)}return a|0}function JR(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=ZB(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}yc(b+112|0,a,538);b=b+872|0;continue}}fb=c+544|0}function sua(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){ah(a+b|0);a=a+1|0;continue}break}break a}ac(c+8|0,b,120);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function F0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;nw(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,65)}return a|0}function zg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[xb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function cta(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){jp((a<<1)+b|0);a=a+1|0;continue}break}break a}Xv(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function VQ(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22280|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function Ni(a){var b=0,c=0,d=0,e=0;b=Xd(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Xd(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function yr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Ir(b+8|0,c+15|0);d=x[b+12>>2];nd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){fd(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function yD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}yE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function vm(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}DG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function vR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Fc(Aua(zua(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function PD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=Uk(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=dj(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Kg(a,d&65535,b)?d:-1)&65535}function mT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[$c(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=gC(c&255),x[e+44>>2]=f}fb=d+16|0}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;hU(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){zB(b)}return a|0}function Zpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Gh(178956970)>>>0<b>>>0){cd();p()}d=Dc(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function Sna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Gh(119304647)>>>0<b>>>0){cd();p()}d=Dc(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function Aua(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Bua(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function xV(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}wV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function pj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function mv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bX(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){cX(b)}return a|0}function jw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;vw(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){sE(b)}return a|0}function ik(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Iw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function Xr(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}ZF(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function UY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}RY(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function Su(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Fg(a+12|0,d);a:{if(!b){d=0;b=0;break a}tV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=zc(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function xta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Gh(715827882)>>>0<b>>>0){cd();p()}d=Dc(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function vka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){a=0;while(1){if((a|0)!=16){ah(a+b|0);a=a+1|0;continue}break}break a}MD(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function ku(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42268;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42120;break a;case 2:c=42116;break a;case 1:break b;case 0:break c}}c=42112;break a}c=42108}x[a>>2]=x[c>>2]}function _d(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Xra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;dr(c,er(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;ku(a+8|0,er(a));fb=c+16|0}
function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Dc(40),x[f+8>>2]=g;d=qm(x[c+8>>2]);x[d>>2]=78264;d=iM(zc(d));x[d+24>>2]=b;x[d>>2]=78412;b=a;a=Ln(c);Kn(b,zc(a),a);rm(c);fb=e+16|0}function TY(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Cv(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}ee(d);fb=e+16|0}function K_(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function lV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=xd(b);x[d+12>>2]=c;f=zf(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[je(d+12|0)>>2];continue}}Zc(a,b);fb=d+16|0}function Esa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Gh(2147483647)>>>0<b>>>0){cd();p()}d=Dc(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function Aq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[b-8>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-De(f*C[Re(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=xb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function vpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){ah(a+b|0);a=a+1|0;continue}break}break a}BD(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function rt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Kc(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);xg(d+e|0,b,c);b=c+e|0;kg(a,b);ed(b+d|0,0);return a|0}Np(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function hja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=-1;a:{if(!uG(a,c+8|0)){break a}d=0;if(!gR(c+8|0)|(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]?b:0)){break a}d=1}fb=c+32|0;return d|0}function bH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=X$(f+24|0,f+8|0);b=f+16|0;a=Qp(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function lv(a,b){var c=0,d=0,e=0;if(x[a>>2]){B$(a);c=x[a>>2];ZD(a);Db(c);d=Ab(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function Kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=nc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=qc(c+12|0);f=xb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function zW(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+31038>>1]-z[(c<<1)+31038>>1]|0)/5;a=y[Sb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function yx(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=Af(f+8|0,d);x[31721]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=eg(e,a,b,c,f);b=x[31721];x[31721]=0;if((b|0)!=1){he(d);fb=f+16|0;return a}a=N()|0;he(d);Q(a|0);p()}function wA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}yc(a+24604|0,b,40);ER(a,c)}function oha(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Kz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;SM(e,c);a=x[a+1298472>>2];x[31721]=0;S(389,a|0,b|0,e|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function JS(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Ab(a);c=dc(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=dc(b);x[b>>2]=c;x[c>>2]=0;e=Ab(b),f=0,x[e>>2]=f}return a}function zt(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!Xy(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=df(a)}return b}_(15746,13258,1578,5429);p()}function zda(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(zd(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(ke(b,47344)){break a}c=a+88|0;if(ke(b,47356)){break a}c=a+92|0;if(ke(b,47368)){break a}c=ke(b,47381)?a+96|0:0}}return c|0}function u_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if(_b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Cb(y[a+8|0]|y[a+9|0]<<8)}return b}function gta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Gh(1073741823)>>>0<=8191){cd();p()}c=Dc(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function bra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!lk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(zn(8978)|0)&e>>>0>255&e>>>0<260)){break a}c=te(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function ai(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ac(d+8|0,b,c);e=x[d+12>>2];jc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Ub(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Tb(b,0,c)}return a}function _W(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=zb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;kv(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];XW(a);Db(b)}fb=c+16|0}function KU(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=vi(e+4|0,a,d);a=x[f+4>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){ck(a,z[b>>1]);a=a+2|0;b=x[Od(d+12|0)>>2];continue}break}fb=d+16|0;x[f+4>>2]=a;gc(f);fb=e+16|0}function CS(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function AY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function wI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=uk(Jb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Jm(a,17604,b);x[31721]=0;W(1347,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return}p()}function tU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function lF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;bh(a,c+15|0);d=v[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11235,9079,324,14199);p()}return a}function fB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42192|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;_l(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function GD(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=Vl(e+4|0,a,d);a=x[f+4>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){wl(a,y[b|0]);a=a+1|0;b=x[je(d+12|0)>>2];continue}break}fb=d+16|0;x[f+4>>2]=a;gc(f);fb=e+16|0}function zua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function cr(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Sc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[Zb(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function vI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=uk(Jb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Jm(a,17645,b);x[31721]=0;W(1347,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return a}p()}function pL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;yc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;yc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function Vy(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!xt(a)){break a}if(!(v[a+1375|0]&1)){continue}break}ec(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function iga(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;a:{if(fr(a,10265)){c=b+4|0;Jm(c,18191,a);a=Jb(c);x[31721]=0;O(69,44,a|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;tb(b+4|0);Q(a|0);p()}fb=b+16|0;return}p()}function VT(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function FB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:yU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;fz(d+16|0,a,d+26|0,x[Gb(d+28|0,d+12|0)>>2]);ej(b,z[d+26>>1]);fb=d+32|0}function tq(a,b){a=yc(a,b,88);x[a+88>>2]=x[b+88>>2];yc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];yc(a+672|0,b+672|0,52);VA(a+724|0,b+724|0);VA(a+732|0,b+732|0);VA(a+740|0,b+740|0);yc(a+748|0,b+748|0,123);return a}function fo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function UU(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function rra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Cf(a,c);Zd(e,x[a+36>>2]);a:{if(!c){Oc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}fZ(x[a+36>>2],b,d,0);f=c}cf(a,f);fb=e+16|0}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=x[c+4>>2];f=x[c>>2];c=0;while(1){if(e){d=x[b+24>>2];g=qh(e);zj(d,c+f|0,g);d=x[x[b+24>>2]+4>>2];e=e-d|0;c=c+d|0;if((d|0)==(g|0)){continue}}break}ac(a,f,c)}function zT(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=zb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-7|0;continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];rB(a);Db(b)}fb=c+16|0}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Rg(a)>>>0<b>>>0){if(Gh(1073741823)>>>0<b>>>0){break a}d=Ab(a);e=a;a=ig(c+12|0,b,nc(x[a>>2],x[a+4>>2]),d);Id(e,a);hg(a)}fb=c+32|0;return}cd();p()}function wD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;g_(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){h_(b)}return a}function toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(gl(a)>>>0<b>>>0){if(Gh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=vm(c+12|0,b,Rd(x[a>>2],x[a+4>>2]),d);jW(e,a);iW(a)}fb=c+32|0;return}cd();p()}function qu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Pk(c)){Ke(a,c);break a}og(d+8|0,Ah(c)+1|0);e=x[d+8>>2];wd(a,e);mf(a,x[d+12>>2]);Wd(a,c);a=e}ed(xg(a,b,c)+c|0,0);fb=d+16|0;return}nf();p()}function oY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;qY(c+8|0,b);d=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){pY(b)}return a}function kY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Cn(a)>>>0<b>>>0){if(Gh(2147483647)>>>0<b>>>0){break a}d=Ab(a);e=a;a=ik(c+12|0,b,Yc(x[a>>2],x[a+4>>2]),d);Id(e,a);fj(a)}fb=c+32|0;return}cd();p()}function Zk(a){uc(a+16|0,x[a>>2]);uc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Mn(a)>>>0<b>>>0){if(Gh(536870911)>>>0<b>>>0){break a}d=Ab(a);e=a;a=Xr(c+12|0,b,fh(x[a>>2],x[a+4>>2]),d);Id(e,a);Wr(a)}fb=c+32|0;return}cd();p()}function Tm(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((nc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[xb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Cf(a,c);Zd(e,x[a+36>>2]);a:{if(!c){Oc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}LQ(d,x[a+36>>2],b);f=c}cf(a,f);fb=e+16|0}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(rB(a)>>>0<b>>>0){if(Gh(613566756)>>>0<b>>>0){break a}d=Ab(a);e=a;a=yT(c+12|0,b,qB(x[a>>2],x[a+4>>2]),d);xT(e,a);wT(a)}fb=c+32|0;return}cd();p()}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(gl(a)>>>0<b>>>0){if(Gh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=vm(c+12|0,b,Rd(x[a>>2],x[a+4>>2]),d);nx(e,a);is(a)}fb=c+32|0;return}cd();p()}function FF(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Pk(c)){Ke(a,c);break a}og(d+8|0,Ah(c)+1|0);e=x[d+8>>2];wd(a,e);mf(a,x[d+12>>2]);Wd(a,c);a=e}ed(Tg(a,b,c)+c|0,0);fb=d+16|0;return}nf();p()}function uA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;DR(a+24648|0);JR(a)}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Aj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function NK(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!bo(b)){break a}x[a>>2]=0}return a|0}function HM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;lz(f,b);while(1){if(d){b=x[f+4>>2];h=qh(d);zj(b,c+g|0,h);b=x[x[f+4>>2]+4>>2];d=d-b|0;g=b+g|0;if((b|0)==(h|0)){continue}}break}ac(a,c,g);fb=e+16|0}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;SM(d,b);a=x[a+1298472>>2];x[31721]=0;S(389,a|0,1,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(c+4|0);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function kJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Tp(d+24|0,a,b);Gk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=FD(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ud(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function jJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Tp(d+24|0,a,b);Gk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=$z(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ud(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Pv(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Xl(d+24|0,a,b);Gk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=FD(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ud(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Ex(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function zC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=gG(a);a:while(1){if((a|0)!=(e|0)){f=rd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[vb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function rA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=xw(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[yR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=kc(x[d>>2],x[d+4>>2])^1}return a}function SV(a){a=a*4294967296;if(F(a)<0x8000000000000000){hb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}hb=-2147483648;return 0}function zS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function moa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;cn(a,b);b=wb(x[a>>2]);x[c+12>>2]=b;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[je(c+12|0)>>2];continue}else{fb=c+16|0}break}}function lE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function av(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Xl(d+24|0,a,b);Gk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=ED(c,x[d+20>>2]),x[f+12>>2]=g;Ud(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function nd(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];jf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);jf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=mg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31721]=0;O(807,a|0,1);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;OT(d);ST(a);Q(b|0);p()}function Kpa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=fc(b+8|0,b+30|0,2);jc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Ub(a,2);d=1}fb=b+32|0;return d|0}function Gd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;bh(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11235,9079,324,14199);p()}return d}function Ai(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ac(d+8|0,b,c);e=x[d+12>>2];jc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Ub(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Tb(b,0,c)}}function vU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Jo(d);uU(x[c>>2])}b=b+1|0;continue}break}}function ala(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){ah(a+b|0);a=a+1|0;continue}break}break a}hU(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Hta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){ah(a+b|0);a=a+1|0;continue}break}break a}Xv(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function BO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Lj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[Zb(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function yga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Fc(Aua(zua(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;MP(a,e);b=x[a+12>>2];x[f+12>>2]=0;OQ(a,b,f+12|0);fb=f+16|0}function qw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){ah(a+b|0);a=a+1|0;continue}break}break a}wE(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function c3(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=Ct(a);if(ZH(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31721]=0;R(b|0,a|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}}ic(a)}return}T(0)|0;Qb();p()}function Sf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Tb(f,b&255,c?d:256);if(!c){while(1){Gf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Gf(a,f,d)}fb=f+256|0}function RF(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function uY(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;BD(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function re(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ed(b)}return c}function lo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(So(a)>>>0<b>>>0){if(Gh(-1)>>>0<b>>>0){break a}d=Ab(a);e=a;a=hn(c+12|0,b,Rc(x[a>>2],x[a+4>>2]),d);Id(e,a);gn(a)}fb=c+32|0;return}cd();p()}function j9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}oi(a,x[b+24>>2],d);break a}if(c&8){oi(a,x[b+12>>2],x[b+20>>2]);break a}Fb(a)}}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=Cf(a,c);Zd(d,x[a+36>>2]);a:{if(!c){Oc(d,a+32|0,5);e=0;if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break a}}jZ(x[a+36>>2],b,a);e=c}cf(a,e);fb=d+16|0}function Yh(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;cl(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=gg(d+4|0,b);x[31721]=0;V(1020,a|0,b|0,c|0,1);a=x[31721];x[31721]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Ina(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=Ru(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[$c(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}cd();p()}function AN(a,b){a=a|0;b=b|0;var c=0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47616;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22250}c=Ed(gf(b)+1|0);x[a+4>>2]=c;if(c){yc(c,b,gf(b)+1|0)}return a|0}function mi(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Gb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Gb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function IJ(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){pg(g+13|0,g+14|0)}h=c,i=(fa(b|0,Rc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function I$(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){ah(a+b|0);a=a+1|0;continue}break}break a}cl(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function o2(a,b){a=a|0;b=b|0;var c=0;a=wt(a);x[a>>2]=93624;c=Fb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[31721]=0;O(115,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);co(a);Q(b|0);p()}function Sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=gg(d+4|0,c);x[31721]=0;S(1006,a|0,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function Iha(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Rg(a)>>>0<=12){if(Gh(1073741823)>>>0<=12){break a}c=Ab(a);d=a;a=ig(b+12|0,13,nc(x[a>>2],x[a+4>>2]),c);Id(d,a);hg(a)}fb=b+32|0;return}cd();p()}function ul(a){a=a|0;var b=0;x[a>>2]=94820;x[31721]=0;O(116,a|0,0);b=x[31721];x[31721]=0;if((b|0)!=1){Yb(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Qb();p()}function sX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!Ge(d,x[a+4>>2],b)){break a}d=PD(a,x[dj(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=dj(c,b);bR(dj(c,d),a);c=d}return c|0}function gS(a,b,c){var d=0,e=0;d=Kc(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Tg(d+e|0,b,c);b=c+e|0;kg(a,b);ed(b+d|0,0);return a}Eq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a}function cJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(1073741823)>>>0<b>>>0){cd();p()}MI(c+8|0,Ls(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Bb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){Rl();p()}b=Jb(b);x[e+8>>2]=d-c;qu(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Q$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){xn((a<<2)+b|0);a=a+1|0;continue}break}break a}dE(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function E_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=443372356|y[a+4|0]!=32|(!y[a+46|0]|(y[a+45|0]-17&255)>>>0<240)){break a}if(!y[a+47|0]){break a}b=y[a+49|0]<101}return b}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Bb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){Rl();p()}b=Jb(b);x[e+8>>2]=d-c;FF(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function rw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){ah(a+b|0);a=a+1|0;continue}break}break a}ac(c+8|0,b,256);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ks(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(b){e=Kc(a);d=Bb(x[a+4>>2],y[a+11|0]);f=d+b|0;if(e-d>>>0<b>>>0){Om(a,e,f-e|0,d,d,0,0)}e=d;d=Jb(a);bm(e+d|0,b,c);kg(a,f);ed(d+f|0,0)}return a|0}function f_(a){var b=0,c=0,d=0;a:{if(hd(a,22239,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function YT(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function WT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Vr(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){C[a>>3]=C[b>>3];a=a+8|0;b=b+8|0;continue}break}x[d+4>>2]=a;gc(d);fb=e+16|0}function FZ(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{Wo(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function $d(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function xj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Bz(e,d,f,c,1);fb=d+16|0}function yW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;g_(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){h_(b)}return a}function wja(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!lk(a,b+8|0)){break a}c=0;if(!kR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!OE(a,b+4|0)){break a}c=jR(x[b+4>>2])}fb=b+16|0;return c|0}function uG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;rG(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fx(b)}return a}function to(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=th(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){qo(a,x[b>>2]);a=a+4|0;b=b+4|0;continue}break}x[d+4>>2]=a;gc(d);fb=e+16|0}function rr(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function lk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;cl(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){dl(b)}return a}function j$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Wv(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){UD(b)}return a}function fX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;bX(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){cX(b)}return a}function _pa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(1073741823)>>>0<b>>>0){cd();p()}sF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function UO(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function MX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Hn(b,a)|!c){break a}kh(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];pg(vb(b,a),vb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function MR(a){var b=0,c=0;a=a+906300|0;c=Dj(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function KD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;nr(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){J_(b)}return a}function JB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=vi(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){ck(a,z[b>>1]);a=a+2|0;b=b+2|0;continue}break}x[d+4>>2]=a;gc(d);fb=e+16|0}function IF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Pr(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rr(b)}return a}function F_(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Xv(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rv(b)}return a}function DW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Uw(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Vw(b)}return a}function w0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(214748364)>>>0<b>>>0){cd();p()}yE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function pia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;rT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function pC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(2147483647)>>>0<b>>>0){cd();p()}Iw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function im(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(1073741823)>>>0<b>>>0){cd();p()}Rj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function iL(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Jh(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}
function hv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Vl(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){wl(a,y[b|0]);a=a+1|0;b=b+1|0;continue}break}x[d+4>>2]=a;gc(d);fb=e+16|0}function gE(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function dR(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;PY(d+8|0,a,b,c);a=Tq(a,x[d+8>>2]);f=d,g=Tq(c,x[d+12>>2]),x[f+4>>2]=g;Ud(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function Pka(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Gh(2147483647)>>>0<=2303){cd();p()}Iw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function ND(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Xb(128/(D(x[We(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[af(c+7|0,c+6|0)|0];fb=c+16|0;return a|b<<4&240}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(357913941)>>>0<b>>>0){cd();p()}DG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;lg(a,d+14|0);e=z[d+14>>1];SR(b,e);c=0;while(1){if((c|0)==(e|0)){AA(b);fb=d+16|0}else{Jk(a,xb(x[b>>2],c));c=c+1|0;continue}break}}function gZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(715827882)>>>0<b>>>0){cd();p()}RY(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function XT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(536870911)>>>0<b>>>0){cd();p()}ZF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function UT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(268435455)>>>0<b>>>0){cd();p()}wV(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function Op(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=Xx(d+4|0,b,gf(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function LL(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function BS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Vr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{AS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function zI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=111960;d=a+8|0;while(1){b=x[a+8>>2];if(nc(b,x[a+12>>2])>>>0>c>>>0){b=x[xb(b,c)>>2];if(b){sm(b)}c=c+1|0;continue}break}tb(a+152|0);Wx(d);return a|0}function xA(a,b){var c=0;a=_V(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function QM(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Dc(1298480);x[31721]=0;c=R(1135,b|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){b=x[tf(a+12|0,c)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function Pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(nc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=RQ(a,b,c,d+12|0);fb=d+16|0;return a|0}function ke(a,b){var c=0;a:{c=gf(b);if((c|0)==(Bb(x[a+4>>2],y[a+11|0])|0)){x[31721]=0;a=U(373,a|0,b|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}T(0)|0;Qb();p()}function jk(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(2147483647);if(d>>>0<=b>>>0){a=Cn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function jc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;jf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);jf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function Uf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(1073741823);if(d>>>0<=b>>>0){a=Rg(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Jj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Pl(a,b);if((d|0)==255){break a}zk(a,b);Cq(a,b,0,0);if(!c){break a}e=Zb(a+26|0,d),f=65535,w[e>>1]=f;a=vb(a+62|0,b);v[a|0]=y[a|0]|128}}function zD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(214748364);if(d>>>0<=b>>>0){a=AE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function yV(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(268435455);if(d>>>0<=b>>>0){a=Uu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function oD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(Yp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;sT(c+8|0,127);a=$l(C[c+8>>3]);fb=c+16|0;return a}function Yr(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(536870911);if(d>>>0<=b>>>0){a=Mn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function XF(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(119304647);if(d>>>0<=b>>>0){a=Sw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function XC(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(715827882);if(d>>>0<=b>>>0){a=Sv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Iq(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(134217727);if(d>>>0<=b>>>0){a=Qo(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function FJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(178956970);if(d>>>0<=b>>>0){a=Ms(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Ep(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(357913941);if(d>>>0<=b>>>0){a=gl(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function xC(a,b){var c=0,d=0;c=fb-16|0;fb=c;CC(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function up(a,b){var c=0,d=0;c=fb-16|0;fb=c;tp(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function tx(a,b,c){var d=0;d=fb-16|0;fb=d;ac(d+8|0,b,c);b=x[d+12>>2];jc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Ub(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function sK(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function pB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+123760>>2]<=d>>>0)|0)){break a}}c=nB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function jX(a,b){var c=0,d=0;c=fb-16|0;fb=c;LC(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function iu(a){var b=0;x[31721]=0;a=R(858,a|0)|0;b=x[31721];x[31721]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31721]=0;X(26);b=x[31721];x[31721]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Qb();p()}function iV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function g0(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function fu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=qr(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){Cv(a,b);a=a+6|0;b=b+6|0;continue}break}x[d+4>>2]=a;gc(d);fb=e+16|0}function fE(a,b){var c=0,d=0;c=fb-16|0;fb=c;bk(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function eE(a,b){var c=0,d=0;c=fb-16|0;fb=c;xr(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function e0(a,b){var c=0,d=0;c=fb-16|0;fb=c;d0(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function bh(a,b){var c=0,d=0;c=fb-16|0;fb=c;Ir(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function __(a,b){var c=0,d=0;c=fb-16|0;fb=c;MD(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function _Q(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(82595524);if(d>>>0<=b>>>0){a=lu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Xz(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=ig(d+12|0,Uf(a,nc(x[a>>2],x[a+4>>2])+1|0),nc(x[a>>2],x[a+4>>2]),c);qo(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Id(a,c);hg(c);fb=d+32|0}function Ww(a,b){var c=0,d=0;c=fb-16|0;fb=c;Uw(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function SF(a,b){var c=0,d=0;c=fb-16|0;fb=c;rG(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function M_(a,b){var c=0,d=0;c=fb-16|0;fb=c;Wv(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function MY(a,b){var c=0,d=0;c=fb-16|0;fb=c;KY(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function JF(a,b){var c=0,d=0;c=fb-16|0;fb=c;Pr(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function IW(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Hn(a,b){var c=0,d=0;c=fb-16|0;fb=c;kh(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function H_(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xv(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function G_(a,b){var c=0,d=0;c=fb-16|0;fb=c;nr(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function FX(a,b){var c=0,d=0;c=fb-16|0;fb=c;qv(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Ub(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Ry(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Qg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function RL(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=hn(d+12|0,Wl(a,Rc(x[a>>2],x[a+4>>2])+1|0),Rc(x[a>>2],x[a+4>>2]),c);wl(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;Id(a,c);gn(c);fb=d+32|0}function EU(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=MB(b,x[a+12>>2]);x[31721]=0;O(787,a|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){Ql(c);fb=b+32|0;return}a=N()|0;Ql(c);Q(a|0);p()}function bV(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function Of(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=eA(c+12|0,a);x[31721]=0;S(202,a|0,b|0,d|0);a=x[31721];x[31721]=0;if((a|0)!=1){Fl(d);fb=c- -64|0;return}a=N()|0;Fl(d);Q(a|0);p()}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=St(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;yc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function ki(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function VY(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Vp(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function Ofa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=jP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function zk(a,b){var c=0,d=0,e=0;a:{c=Pl(a,b);if((c|0)==255){break a}if(Ak(x[a>>2])){break a}e=a+8|0;d=vb(e,c);v[d|0]=y[d|0]&223;d=Nu(c);c=vb(e,c);wh(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function w7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=tk(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function no(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!GM(y[a+20|0])){x[31721]=0;O(1142,b+15|0,a|0);c=x[31721];x[31721]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Qb();p()}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=x[18383];x[c+8>>2]=x[18382];x[c+12>>2]=d;d=x[18381];x[c>>2]=x[18380];x[c+4>>2]=d;ib[x[cq(c,vk(y[b+20|0]))>>2]](a,b);fb=c+16|0}function Pra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Qh(b,12,c);break a}nr(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ht(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Cw(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Cw(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function EG(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=vm(d+12|0,Ep(a,Rd(x[a>>2],x[a+4>>2])+1|0),Rd(x[a>>2],x[a+4>>2]),c);js(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;nx(a,c);is(c);fb=d+32|0}function zP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=zi(b-+(a|0))}else{b=0}return b}function p7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return sk(g,h,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function kp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=vi(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{ck(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function bA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{xk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Wl(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Gh(-1);if(d>>>0<=b>>>0){a=So(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[$c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Sh(a,b){var c=0;b=Tc(b);c=x[a+8>>2];if(nc(c,x[a+12>>2])>>>0>b>>>0){a=x[xb(c,b)>>2]!=0}else{a=0}if(!a){a=Ij($b(4));x[a>>2]=125440;da(a|0,125576,1192);p()}return x[xb(c,b)>>2]}function Jl(a){var b=0;a=ni(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function EE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{qo(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function vP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=uP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function rp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Vl(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{wl(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function Ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;HY(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){GY(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;s_(b,4,c);break a}kh(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Kr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){cd();p()}sF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=Ab(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function Hm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Tb(a- -64|0,0,48);return a}function wB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Ph(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function pu(a,b){var c=0;a=nS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function _k(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Gh(-1)>>>0<b>>>0){cd();p()}og(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;bG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){aG(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function It(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=xo(a);continue}break}return a}function E1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function iT(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function Wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ZV(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];ac(d+8|0,c,Oh(c,x[b+4>>2])<<8);pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function N1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Rc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Uj(c,a)}return!d|0}function zR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=xo(a);continue}break}return a}function r5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+112096>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Nz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=xo(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function Eh(a,b,c){a:{if(b>>>0<=c>>>0){a=$b(8);x[31721]=0;b=R(191,a|0)|0;c=x[31721];x[31721]=0;if((c|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24424,165);p()}function Cv(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function v7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return tk(g,h,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0)|0}function qga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Ld(c,E(0));d=a+4208|0;if((b|0)==12){c=E(ni(E(c*E(3)))/E(3));b=12}e=xb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function Ul(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function Gra(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;iZ(b,c);hZ(a,c);fb=c+32|0}function GT(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Nl(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[zb(e+12|0,d)>>2];fb=e+16|0;return a}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;ez(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function aD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=qr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){gc(a);fb=d+16|0}else{Cv(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function Xo(a){var b=0,c=0;b=x[31476];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[31476]=a;return b}x[31596]=48;return-1}function MS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Kc(a);d=Bb(x[a+4>>2],y[a+11|0]);e=d+1|0;if((c|0)==(d|0)){DB(a,c,e-c|0,c,c,0)}c=Jb(a);bm(c+d|0,1,b);kg(a,e);ed(c+e|0,0);return a|0}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Rc(a,b)>>>0){a=rl(e+4|0,vb(a,f),z[c+20>>1]);g=xy(d,a);Eb(a)}fb=e+16|0;return g|0}function D2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Cz(a,e,c,d,1);fb=e+16|0}function BG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function iq(a){var b=0;b=x[a+24>>2];x[31721]=0;W(859,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){Qd(a+68|0);lf(a+36|0);Al(a+32|0);sh(a+24|0);rh(a+4|0);return Uc(a)}T(0)|0;Qb();p()}function bta(a,b){a=a|0;b=b|0;if(!G_(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function VM(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Ik(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Uu(a);Db(b)}}function SX(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Ms(a);Db(b)}}function MH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];gl(a);Db(b)}}function E2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=bP(a,c,1);fb=c+16|0;gb=hb;return a|0}function poa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;b=-1;a:{if(!lk(a,c+8|0)){break a}b=0;if(!aW(c+8|0)){break a}b=-1;if(!hh(a,4)){break a}b=BW(a)>>>31|0}fb=c+16|0;return b|0}function m3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=kc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);fb=d+16|0;return a|0}function dX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;hb=0;return b}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];jA(a,d+8|0);b=x[Pe(d+12|0)>>2];continue}else{fb=d+16|0}break}}function mc(a,b){a=a|0;b=b|0;var c=0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47616;c=Ed(Xc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){yc(c,Jb(b),Xc(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function Q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=Kx(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function xE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=vi(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){gc(a);fb=c+16|0}else{Jw(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function kX(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Vl(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){gc(a);fb=c+16|0}else{OW(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function iw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Uj(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];ac(d+8|0,c,Rc(c,x[b+4>>2]));pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function eca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=cP(a,c,1);fb=c+16|0;return+e}function cka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(1);x[31721]=0;X(60);c=x[31721];x[31721]=0;if((c|0)!=1){b=x[tf(a+12|0,b)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function TC(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=th(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){gc(a);fb=c+16|0}else{xn(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Qu(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=th(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){gc(a);fb=c+16|0}else{gV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function OX(a,b){var c=0,d=0;c=fb-16|0;fb=c;qv(c+8|0,b);b=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Lg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Eh(x[d>>2],x[d+4>>2],a);return((Eh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Eh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function IE(a,b){var c=0,d=0;c=fb-16|0;fb=c;kh(c+8|0,b);b=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function p5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+112096>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function n_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(hd(a+44|0,18434,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function ji(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;yj(c+8|0,c+31|0);Km(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function pf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=A$(b,c),x[e+12>>2]=f;c=b;b=_D(d+4|0);Qi(c,c+b|0,a);e=vb(a,b),f=0,v[e|0]=f;C$(a);fb=d+16|0}function LG(a,b){var c=0,d=0,e=0;c=x[a>>2];if(x[c>>2]){e=x[c>>2];d=x[c+4>>2];while(1){if((d|0)!=(e|0)){d=d-b|0;continue}break}x[c+4>>2]=e;a=x[a>>2];b=x[a>>2];Ab(a);Db(b)}}function Eca(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=dP(a,c,1);fb=c+16|0;return a|0}function Dta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;cl(c+8|0,b);b=x[c+12>>2];jc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Ub(a,x[c+12>>2])}fb=c+16|0}function $E(a,b,c){var d=0;d=fb-16|0;fb=d;a=sp(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){ck(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0}function zx(a,b,c,d,e){var f=0;a:{f=iu(4332);if(f){x[31721]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function vsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}VR(d,9153,10891,171,42);qG(d,b,c)}fb=d+16|0}function q5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+112096>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function OY(a,b,c){var d=0;d=fb-16|0;fb=d;a=fC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){wl(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0}function LV(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-36|0;continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Sw(a);Db(b)}}function F1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function jka(a,b){a=a|0;b=b|0;var c=0;a=mg(a);c=Xi(x[b>>2]);b=Kf(b);x[31721]=0;S(853,a|0,c|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;NS(a);Q(b|0);p()}function jA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=th(c+4|0,a,1);qo(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0;return}Xz(a,b)}function hV(a,b,c,d){a=fc(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function aT(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function Em(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function nv(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Ez(a,d,c,1);fb=d+16|0}function Yq(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){VC(b);break a}kh(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Nja(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Cc(a+4|0,10265);x[31721]=0;W(64,b|0);c=x[31721];x[31721]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function ML(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function I4(a,b,c){a=a|0;b=b|0;c=c|0;a=YI(a,c);x[a>>2]=113420;b=Jb(b);x[31721]=0;O(1348,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Sx(a);Q(b|0);p()}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;aP(a,b,d,1);fb=d+16|0}function G4(a,b,c){a=a|0;b=b|0;c=c|0;a=XI(a,c);x[a>>2]=113460;b=Jb(b);x[31721]=0;O(1349,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Tx(a);Q(b|0);p()}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;bG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){aG(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function hd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function cda(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Dz(a,d,c,1);fb=d+16|0}function GH(a,b,c){var d=0;a:{if(!a){a=$b(8);x[31721]=0;c=R(c|0,a|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){break a}b=N()|0;ic(a);Q(b|0);p()}return}da(c|0,b|0,1008);p()}function DM(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Vl(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){gc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!yW(a,c)){break a}d=0;if(!xW(c)){break a}d=te(a,b,wW(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bb(x[b+4>>2],y[b+11|0]);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=Tg(Jb(vz(e,d+a|0)),Jb(b),d)+d|0;bm(Tg(b,Jb(c),a)+a|0,1,0)}function s1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ez(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function _h(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Qr(b);d=Kc(a);if(c>>>0<=d>>>0){Hu(a,Ri(Jb(a),b,c),c);break a}e=a;a=Bb(x[a+4>>2],y[a+11|0]);Eq(e,d,c-d|0,a,0,a,c,b)}}function PC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;HY(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){GY(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function Nv(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;YV(d+8|0,a,b,c);a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Ud(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function AW(a,b){var c=0;c=fb-32|0;fb=c;iX(c+24|0,a);ve(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Nc(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function s9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Py(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function aX(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function ZU(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function IU(a,b,c,d){var e=0;e=fb-32|0;fb=e;Xl(e+24|0,b,c);Gk(e+16|0,x[e+24>>2],x[e+28>>2],d);b=HU(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];Ud(a,b,e+12|0);fb=e+32|0}function G1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Asa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;xZ(a,6,c);break a}nr(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function $Y(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=dc(b);a=zh(a,Dc(32),Jg(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=dc(a),f=1,v[e+4|0]=f;fb=d+16|0}function upa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-80|0;fb=d;c=-1;a:{if(!j$(a,d+14|0)){break a}c=0;if(!qX(d+14|0)){break a}c=te(a,b,pX(d+14|0),hb)}fb=d+80|0;return c|0}function tT(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=fv(c+4|0,a,1);js(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;gc(a);fb=c+16|0;return}EG(a,b)}function kpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;xZ(a,4,c);break a}cl(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function iI(a,b,c){var d=0,e=0;d=mn(a);if(d>>>0>=c>>>0){e=b;b=c<<2;d=$h(Jb(a),e,b);kg(a,c);wd(b+d|0,0);return}e=a;a=Bb(x[a+4>>2],y[a+11|0]);$H(e,d,c-d|0,a,0,a,c,b)}function XK(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=uf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return uf(b)}function cpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Qh(a,5,c);break a}bk(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function DV(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;ZB(a+112|0,48e3);x[a+668>>2]=0;YB(a+724|0);YB(a+732|0);YB(a+740|0);Ig(a+788|0);return a}function t2(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=ox(c+4|0,a);js(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;gc(a);fb=c+16|0;return}EG(a,b)}function q_(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Qh(a,6,c);break a}BD(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function oda(a,b){a=a|0;b=b|0;var c=0;a=$b(8);x[31721]=0;b=P(1059,a|0,12097)|0;c=x[31721];x[31721]=0;if((c|0)!=1){da(b|0,125344,165);p()}b=N()|0;ic(a);Q(b|0);p()}function jm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Qh(a,4,c);break a}kh(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function _D(a){var b=0,c=0;a:{c=xb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=YD(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function S3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=jI(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function Oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=qh(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[ak(c+12|0,c+8|0,42272)>>2],x[d+36>>2]=e;lq(a);fb=c+16|0}function I8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=IK(a,e,b);x[a>>2]=94500;fb=e+16|0;return a|0}function Hq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function Dc(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Ed(a);if(b){break a}b=x[125545];if(b){ib[b|0]();continue}break}da(Pm($b(4))|0,124984,34);p()}return b|0}function rE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(bh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=c0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function qD(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Qf(b+14|0,4095);a=z[b+14>>1];c=pD(zi(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function l0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(bh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=f0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function cia(a){a=a|0;var b=0;b=fb-16|0;fb=b;rQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;qQ(a+4|0,wb(x[b+8>>2]),Vk(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function ar(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){pn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Ph(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;pn(a,b)}function XR(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){WR(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=WR(a);return a}function SQ(a,b){var c=0;c=fb-16|0;fb=c;a=Bn(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){gV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}ee(a);fb=c+16|0}function $q(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){pn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Ph(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;pn(a,b)}function xt(a){var b=0;a:{if((df(a)|0)!=79){break a}if((df(a)|0)!=103){break a}if((df(a)|0)!=103){break a}b=(df(a)|0)==83}if(!b){ec(a,30);return 0}return FL(a)}function ww(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;bF(a,c);break a}tp(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function pS(a,b){var c=0;c=fb-32|0;fb=c;a=ue(c+8|0,a,b);a=ou(c+16|0,x[a>>2],x[a+4>>2]);a=ue(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function ela(a,b){a=a|0;b=b|0;a=qc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31721]=0;O(793,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;Cj(a);Q(b|0);p()}function dM(a,b){var c=0,d=0;d=a+4|0;c=Rc(x[d>>2],x[a+8>>2]);a=x[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=mi(c);if(a>>>0<=b>>>0){break a}}b=eM(a,65536)}Uj(d,b)}}function aW(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=(_b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function Gia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Oc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){gy(a)}a=x[zb(b+12|0,wb(x[a+52>>2]))>>2];fb=b+16|0;return a|0}function Fia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Oc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){gy(a)}a=x[zb(b+12|0,wb(x[a+56>>2]))>>2];fb=b+16|0;return a|0}function BH(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function $h(a,b,c){var d=0;if(a>>>0<b>>>0){return yc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function on(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function RM(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function QF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31721]=0;S(172,a|0,b|0,c|0);a=x[31721];x[31721]=0;if((a|0)!=1){break a}a=N()|0;cc(d);Q(a|0);p()}}function Ld(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=Xf(a),B[d+4>>2]=e;a=B[Av(c+4|0,c+12|0,c+8|0)>>2];fb=c+16|0;return a}function Jk(a,b){var c=0;c=fb-32|0;fb=c;x[c+28>>2]=0;Rx(c+8|0,c+28|0);Km(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Im(b,x[c+28>>2]);fb=c+32|0;return(a|0)==4}function uC(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Ib(a,b)|(c|0)==z[a>>1])){a=x[Od(d+12|0)>>2];continue}break}fb=d+16|0;return a}function u8(a,b){a=a|0;b=b|0;var c=0,d=0;b=By(x[b>>2]);x[a+36>>2]=b;c=a,d=gh(b),x[c+44>>2]=d;c=a,d=_n(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Zn(5563);p()}}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function bS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=DA(126928);continue}break}x[b>>2]=d;xo(b);fb=a+16|0;return x[b>>2]}function aC(a){var b=0;a=De(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function Y5(a){a=a|0;if(y[500512]){return x[125127]}if(!y[501672]){v[501672]=1}td(501648,120996);td(501660,121008);v[500512]=1;x[125127]=501648;return 501648}function GP(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function B8(a,b){a=a|0;b=b|0;var c=0,d=0;b=lD(x[b>>2]);x[a+36>>2]=b;c=a,d=gh(b),x[c+44>>2]=d;c=a,d=_n(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Zn(5563);p()}}function m8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Ub(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!yW(a,d)){break a}c=0;if(!qV(d)){break a}c=te(a,b,pV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function Oe(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[dc(a)>>2];x[31721]=0;W(a|0,c|0);a=x[31721];x[31721]=0;if((a|0)==1){break a}}return}T(0)|0;Qb();p()}function EQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];jA(a,d+12|0);b=b+4|0;continue}break}}function CH(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function sla(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31721]=0;W(786,a|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a|0}b=N()|0;LB(a);Q(b|0);p()}function ru(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Av(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function K5(a){a=a|0;if(y[500504]){return x[125125]}if(!y[501640]){v[501640]=1}id(501616,13897);id(501628,13876);v[500504]=1;x[125125]=501616;return 501616}function vZ(a,b){var c=0;c=zua(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function jj(a,b,c,d,e){a:{e=iu(e);if(e){x[31721]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31721];x[31721]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function _y(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+82224>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function Mq(a,b){var c=0,d=0;a:{if(!a){break a}c=zua(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Ed(c);if(!(!a|!(y[a-4|0]&3))){Tb(a,0,c)}return a}function G$(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function Ci(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Bj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function $b(a){var b=0,c=0;x[31721]=0;b=cY(a+24|0);a=R(35,b|0)|0;c=x[31721];x[31721]=0;a:{if((c|0)!=1){if(!a){break a}return FR(Tb(a,0,b))}T(0)|0}Qb();p()}function n2(a,b,c){a=a|0;b=b|0;c=c|0;a=ms(a,x[b+28>>2]);FG(b+28|0,c);x[31721]=0;O(116,b|0,1);b=x[31721];x[31721]=0;if((b|0)==1){b=N()|0;Yb(a);Q(b|0);p()}}function fga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=lB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;HP(a);GP(a)}function JX(a,b,c,d){var e=0;e=fb-32|0;fb=e;Xl(e+24|0,b,c);Gk(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ud(a,b,e+12|0);fb=e+32|0}function H1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function io(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Ed(b)}return c}function eX(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function Yg(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Ph(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=BZ(c)}x[a>>2]=b;return a}function JW(a){var b=0;return(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16?b:((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}function rn(a,b){var c=0,d=0,e=0;Ov(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function i5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function aN(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;fz(d+16|0,a,d+24|0,x[Gb(d+28|0,d+12|0)>>2]);Im(b,x[d+24>>2]);fb=d+32|0}function _V(a,b){var c=0,d=0,e=0;br(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!F_(a,d)){break a}c=0;if(!sW(d)){break a}c=te(a,b,rW(d),hb)}fb=d- -64|0;return c|0}function tO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;SL(i,b,c,d,e,f,g);Zc(a,h+20|0);Zm(i);fb=h+32|0}function sta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!F_(a,d)){break a}c=0;if(!E_(d)){break a}c=te(a,b,D_(d),0)}fb=d- -64|0;return c|0}function rq(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Gj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[sd(a+906300|0,b-1|0)>>2]}return d}function ho(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Tb(a+32|0,0,40);aL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function bd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function YY(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;fz(d+16|0,a,d+27|0,x[Gb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function dJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function cT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Ao(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function Qw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Qh(a,3,c);break a}Pw(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function C_(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[c|0]=0;Qh(a,8,c);break a}cl(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=gg(a,b);x[31721]=0;P(73,a+12|0,c|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function tP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=Qt(Dc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47516;a=x[tf(d+12|0,c)>>2];fb=d+16|0;return a|0}function lh(a,b){var c=0;if(Cd(y[a+11|0])){c=x[a>>2];bj(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ke(b,0);wd(b,0)}function jI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Ih(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124227]>>2]?-1:a&57343}Hh(d);fb=c+16|0;return b}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!fX(a,d)){break a}c=0;if(!eX(d)){break a}c=te(a,b,dX(d),hb)}fb=d+96|0;return c|0}function Kw(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!fX(a,d)){break a}c=0;if(!JW(d)){break a}c=te(a,b,IW(d),hb)}fb=d+96|0;return c|0}function AG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Cc(b+4|0,15621);if(Xc(x[a+4>>2],y[a+11|0])){c=(Og(a,13898)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function $4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function zA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function r$(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Fd(b);continue}break}c=x[a>>2];if(c){zc(a);Db(c)}}function lS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=ue(c+8|0,zua(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function lK(a,b,c){var d=0,e=0,f=0,g=0;d=qC(b);if(d>>>0<c>>>0){mK(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=mK(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function is(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){hs(a);Db(c)}}function _2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(jh(a,x[b+8>>2],f)){Gx(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function YQ(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Fl(b);continue}break}c=x[a>>2];if(c){zc(a);Db(c)}}function WW(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;kv(b);continue}break}c=x[a>>2];if(c){zc(a);Db(c)}}function Tw(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Tr(b);continue}break}c=x[a>>2];if(c){zc(a);Db(c)}}function Lv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){zc(a);Db(c)}}function IB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Ql(b);continue}break}c=x[a>>2];if(c){hs(a);Db(c)}}function Gq(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function yX(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function qs(a,b,c,d){var e=0;e=$b(8);x[31721]=0;a=P(d|0,e|0,a|0)|0;d=x[31721];x[31721]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;ic(e);Q(a|0);p()}function mU(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function e_(a,b){var c=0;c=zua(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function cf(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Oc(c+8|0,a+32|0,5);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;tp(c+20|0,b);d=x[c+20>>2];tp(c+12|0,b);rl(a,d,x[c+16>>2]);fb=c+32|0}function RH(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function J_(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function H8(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function Dga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Ld(c,E(0));if((b|0)==1){d=1;c=ni(c)}e=xb(a+4208|0,d),f=c,B[e>>2]=f;NP(a)}}function CB(a,b,c){var d=0,e=0,f=0;d=Pl(a,b);if((d|0)!=255){e=Zb(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=vb(a,b),f=255,v[e|0]=f;e=vb(a,c),f=d,v[e|0]=f}}function uB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){Yg(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function sE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function jQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}if(c){x[c+8>>2]=x[b+8>>2]}a=x[b+8>>2];if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function gt(a){var b=0,c=0,d=0;if(!a){return 0}d=98944;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function gla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Ir(c+20|0,b);d=x[c+20>>2];Ir(c+12|0,b);rl(a,d,x[c+16>>2]);fb=c+32|0}function _i(a,b){var c=0;c=x[a>>2];if(Yc(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=Ge(x[a+484344>>2],x[a+484348>>2],z[Zb(c,b)>>1])}else{a=0}return a}function ZO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;SL(i,b,c,d,e,f,g);Zc(a,i);Zm(i);fb=h+32|0}function TF(a){a=a|0;var b=0;a=Fb(a);x[31721]=0;R(171,a+12|0)|0;b=x[31721];x[31721]=0;if((b|0)!=1){qc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function yP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=ff(31415.926535897932/b);c=Wi(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function vz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Pk(b)){bx(a);Ke(a,b);return a}c=Ah(b)+1|0;d=Dc(c);mf(a,c);wd(a,d);Wd(a,b);return a}nf();p()}function bq(a,b){var c=0;a:{if(!ML(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Zta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(bh(a,c+11|0)){x[c+4>>2]=y[c+11|0];D$(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function MQ(a){var b=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[Av(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;return a}function Ay(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Ly(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function r0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(bh(a,c+11|0)){x[c+4>>2]=y[c+11|0];nE(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function XS(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){wz(a,0,0,0,0,0,0,c,d);return}wz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function Nk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=$D(a,e,d);break a}a=$D(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function wm(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){zc(a);Db(b)}}function uL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function lg(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;w[c+30>>1]=0;pk(c+8|0,c+30|0);Km(c+20|0,a,x[c+8>>2],x[c+12>>2]);ej(b,z[c+30>>1]);fb=c+32|0}function eY(a){var b=0;if(!(hd(a,15004,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function PY(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=c-b|0;c=D((f|0)/6|0,6);g=e,h=$h(d,b,f)+c|0,x[g+12>>2]=h;Ud(a,b+c|0,e+12|0);fb=e+16|0}function KE(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Jm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gf(b);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=xg(Jb(vz(e,d+a|0)),b,d)+d|0;bm(xg(b,Jb(c),a)+a|0,1,0)}function FW(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Wc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Wc(a,b,c&2|1,0,d^1)}function Cpa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Mg(b);Mg(b);break a}a=dh(b);dh(b)}while(1){if(a){if(a&1){Ub(b,260)}a=a>>>1|0;continue}break}}function uV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){hs(a);Db(b)}}function k$(a,b,c){var d=0;d=fb-16|0;fb=d;jm(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);Zo(a,d+8|0,c);fb=d+16|0}function iW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){hs(a);Db(b)}}function Vf(a){a=a|0;var b=0;x[a>>2]=42760;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;mQ(a+44|0);return a|0}function Iu(a,b){var c=0,d=0;d=aj(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!Ge(a,b,d&65535)){continue}}break}return c&65535}function Fn(a,b){var c=0;a=Jn(a);x[a>>2]=78672;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function Bi(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function sO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;TL(h,b,c,d,e,f);Zc(a,g+20|0);Zm(h);fb=g+32|0}function SD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=fm(a,b),w[d+12>>1]=e;a=z[oe(c+14|0,c+12|0)>>1];fb=c+16|0;return a-1&65535}function yw(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=iF(a,1);break a}c=dh(a);Ub(a,b-2|0)}return c}function yb(a,b){var c=0;if(Cd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ke(b,0);ed(b,0);return a}function mp(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=jF(a,b);break a}c=Mg(a);Ub(a,b-4|0)}return c}function lf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=zb(d+12|0,a);c=x[b>>2];if(x[c>>2]){ZY(c);b=x[b>>2];c=x[b>>2];Ms(b);Db(c)}fb=d+16|0;return a}function TZ(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=_b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=x[$c(b+12|0,b+8|0)>>2];fb=b+16|0;hb=0;return a-216|0}function Le(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=121){Dq(12210);p()}e=d+8|0;Kb(e,a,b);Ef(e,c);fb=d+16|0;return a|0}function xO(a,b,c){var d=0,e=0;d=Kc(a);if(d>>>0>=c>>>0){Hu(a,Ri(Jb(a),b,c),c);return}e=a;a=Bb(x[a+4>>2],y[a+11|0]);Np(e,d,c-d|0,a,0,a,c,b)}function t5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function aL(a){var b=0,c=0;x[31721]=0;c=ca(1182)|0;b=x[31721];x[31721]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;el(a);return}T(0)|0;Qb();p()}function WH(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Dx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Kx(a,b){var c=0;c=fb-16|0;fb=c;b=Ih(c+12|0,b);a=a>>>0>=128?(a&-128)!=57216?-1:x[x[124227]>>2]?-1:a&255:a;Hh(b);fb=c+16|0;return a}function Hl(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[$c(a+20|0,b+12|0)>>2];fb=b+16|0;return D(a,c+d|0)}function zO(a,b){var c=0,d=0;a:{if(!Bt(b)){break a}c=x[a+484344>>2];if(!Ge(c,x[a+484348>>2],b&65535)){break a}d=x[Vb(c,b)+12>>2]}return d}function y_(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;Qw(b,a);a=y[vb(b,0)|0];d=y[vb(b,1)|0];b=y[vb(b,2)|0];fb=c+16|0;return a|d<<8|b<<16}function iC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Ab(b),d=0,x[c>>2]=d;return a}function gk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Sb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function gC(a){a=50-(D(y[(a>>>4|0)+29888|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Fc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function fk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Sb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function dd(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[We(b+8|0,qd(b+12|0,b+4|0))>>1];fb=b+16|0;return a}function bia(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];le(b,x[c+4>>2],x[c+8>>2]);pQ(a,fc(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function Hka(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function kH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function W3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=ty(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function U3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=uy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function tS(a,b,c,d){var e=0;e=a+1074376|0;$A(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=su(x[a+480180>>2])}uo(a,b,e,c)}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=jx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function fd(a,b){var c=0,d=0,e=0;c=hh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function YO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;TL(h,b,c,d,e,f);Zc(a,h);Zm(h);fb=g+32|0}function QX(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function FC(a){var b=0;b=Cb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Cb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function tua(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){wn(b)}v[a|0]=1}return a|0}function ou(a,b,c){var d=0;d=fb-16|0;fb=d;b=ue(d+8|0,zua(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function lka(a,b){a=a|0;b=b|0;a=UA(a);x[31721]=0;O(850,a|0,b|0);b=x[31721];x[31721]=0;if((b|0)==1){b=N()|0;uq(a);Q(b|0);p()}return a|0}function lW(a){var b=0,c=0;c=fb-16|0;fb=c;b=zb(c+12|0,a);a=x[b>>2];if(x[a>>2]){fW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];gl(a);Db(b)}fb=c+16|0}function gn(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function Vha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Sc(c&255))){sQ(a,8,E(0))}a=Aj(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Ro(a){var b=0,c=0;c=fb-16|0;fb=c;b=zb(c+12|0,a);a=x[b>>2];if(x[a>>2]){xY(a,x[a>>2]);a=x[b>>2];b=x[a>>2];yY(a);Db(b)}fb=c+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Rt(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42176|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Rt(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42128|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function G3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=kK(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function E3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=jK(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function ft(a){return a>>>0<=254?(a+1&127)>>>0>32:(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}function Y8(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){RK(b)}v[a|0]=1}return a|0}function Jca(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function ti(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function jH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function TX(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[We(b+8|0,qd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function Sga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Ld(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=ni(c)}B[d>>2]=c;QP(a)}}function Kka(a,b){a=a|0;b=b|0;a=eE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function uS(a,b,c,d){var e=0;e=a+1074376|0;aB(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=su(x[a+480180>>2])}uo(a,b,e,c)}function tt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function li(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Mc(c,d,(b>>31&a)+b|0)>>2]}function Zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=121){Dq(12175);p()}d=c+8|0;Kb(d,a,b);Ef(d,0);fb=c+16|0;return a|0}function Hy(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return uf(v[b|0])|0}function Aj(a){var b=0,c=0;b=lm(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[sd(x[a+16>>2]+906300|0,b)>>2]}return c}function vt(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function pka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Dq(12210);p()}d=c+8|0;Kb(d,a,b);Vo(d);fb=c+16|0;return a|0}function l9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=uf(v[a|0])}else{a=-1}return a|0}function zY(a,b){var c=0;c=fb-16|0;fb=c;a=th(c+4|0,a,1);Wo(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0}function tL(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14218,13258,1180,5734);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Zg(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[We(b+8|0,qd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function xB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Kj(c,x[a+484364>>2])>>>0<=b>>>0){return Wb(c,y[a+484376|0])}return Sj(c,b)}function k5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function jC(a,b){var c=0;c=fb-16|0;fb=c;a=fc(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Hb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function he(a){var b=0;a=x[a+4>>2];if(a){if(sm(a)){a:{b=a+8|0;if(x[b>>2]){if((Xw(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function dH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Jr(d+8|0,d);fb=d+16|0;return x[a>>2]}function bT(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Ao(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function _8(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function YN(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=Qt(Dc(8));x[c+4>>2]=a;x[c>>2]=48464;a=x[tf(b+12|0,c)>>2];fb=b+16|0;return a|0}function Wy(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}yc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function Wq(a,b){var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if((c|0)==(Bb(x[b+4>>2],y[b+11|0])|0)){a=kx(Jb(a),Jb(b),c)}else{a=1}return!a}function PM(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=AM(Dc(8));x[c+4>>2]=a;x[c>>2]=73544;a=x[tf(b+12|0,c)>>2];fb=b+16|0;return a|0}function NJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Zs(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function NG(a,b,c,d){a=Nb(a);x[31721]=0;S(d|0,a|0,b|0,c|0);b=x[31721];x[31721]=0;if((b|0)!=1){return a}b=N()|0;sc(a);Q(b|0);p()}function KJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Vs(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function xU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Wd(b,a)}if(c){Wd(c,a)}if(d){Wd(d,a)}if(e){Wd(e,a)}}function hr(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function hS(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Vv(b);a=x[a>>2];b=x[a>>2];O_(a);Db(b)}fb=c+16|0}function fe(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){B$(b);a=x[a>>2];b=x[a>>2];ZD(a);Db(b)}fb=c+16|0}function ev(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){vV(b);a=x[a>>2];b=x[a>>2];XB(a);Db(b)}fb=c+16|0}function eW(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){kW(b);a=x[a>>2];b=x[a>>2];gl(a);Db(b)}fb=c+16|0}function b5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function _t(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Uz(b);a=x[a>>2];b=x[a>>2];Tz(a);Db(b)}fb=c+16|0}function ZR(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){mu(b);a=x[a>>2];b=x[a>>2];lu(a);Db(b)}fb=c+16|0}function Ui(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){HX(b);a=x[a>>2];b=x[a>>2];Qo(a);Db(b)}fb=c+16|0}function TR(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Ap(b);a=x[a>>2];b=x[a>>2];Sw(a);Db(b)}fb=c+16|0}function ST(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){NT(b);a=x[a>>2];b=x[a>>2];gl(a);Db(b)}fb=c+16|0}function PF(a,b){var c=0;c=x[b+4>>2];if(c){ac(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!kc(c,b)){le(a,c,b);return}Jd(a)}function LB(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){DU(b);a=x[a>>2];b=x[a>>2];Qo(a);Db(b)}fb=c+16|0}function KG(a,b,c){a=ni(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function Gk(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=c-b|0;if((b|0)!=(c|0)){$h(d,b,f)}x[e+12>>2]=d+f;Ud(a,b+f|0,e+12|0);fb=e+16|0}function $t(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function wG(a){a=a|0;var b=0;a=Fb(a);x[31721]=0;O(133,a|0,13724);b=x[31721];x[31721]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function YV(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=$h(d,f,b)+b|0,x[g+12>>2]=h;Ud(a,c,e+12|0);fb=e+16|0}function Y2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(jh(a,x[b+8>>2],0)){Ex(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function Jx(a,b){var c=0,d=0,e=0,f=0;c=gf(b);d=Dc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=yc(zc(d),b,c+1|0),x[e>>2]=f}function Cr(a,b){return Rq(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function qT(a){dB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=mg(a);mg(a+12|0);v[a+24|0]=1}function lY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((fm(x[a>>2],x[a+4>>2])|0)!=65535){_$(a,c+14|0)}fb=c+16|0}function Yl(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Qc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function OJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Zs(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function LJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Vs(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Cl(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;iA(a,c,d)}function Ag(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Ho(a,d)}function uia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=xh(E(Ld(c,E(0))*E(255))),v[d|0]=e;bu(a)}}function Zq(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function LP(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=sc(b-24|0);if((c|0)!=(b|0)){continue}break}return Vf(a)|0}function Bha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=xh(E(Ld(c,E(0))*E(127))),v[d|0]=e;Xt(a)}}function pR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function oC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function nu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(kc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function cp(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function HG(a,b){x[a>>2]=b;aL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function wp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function me(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function bt(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+103600|0]<<5)+103600|0]>>>(a&7)&1}else{a=a>>>0<196606}return a}function Ee(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function vW(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function mh(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=Ih(f+8|0,c);a=ht(a,b,d,x[f+12>>2]);Hh(c);fb=f+16|0;return a}function ZE(a,b){var c=0;c=zua(b&255,0,1536,0);b=hb;a=zua(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function RX(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!hh(a,4)){VC(b);break a}kh(c+8|0,b);EC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function OU(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){LU(a,1);LU(a,0)}}function OK(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function NV(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function NU(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){MU(a,1);MU(a,0)}}function gY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a=th(e+4|0,a,d);f=a,g=XY(b,c,x[a+4>>2]),x[f+4>>2]=g;gc(a);fb=e+16|0}function xZ(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function w2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function qX(a){var b=0;if(!(hd(a,13865,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function df(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function TS(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Xb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function Ska(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=tf(b+12|0,Tb(Dc(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Pt(a){a=a|0;var b=0;x[a>>2]=47676;Wd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Mm(a)|0}function Pfa(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=oc(b+8|0,a);a=Gz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function NE(a){var b=0;b=0;a:{if(hd(a,14188,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function Lu(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function Ii(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function x8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=By(x[b>>2]);x[a+36>>2]=b;c=a,d=_n(b),v[c+44|0]=d}function jga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Ld(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;HP(a)}}function eha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Ld(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;WP(a)}}function bga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Ld(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;FP(a)}}function Zga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Ld(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;SP(a)}}function Th(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42208|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function RJ(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=Ih(d+8|0,b);a=rK(a,9262,x[d+12>>2]);Hh(b);fb=d+16|0;return a}function PG(a,b,c){a=De(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function E8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=lD(x[b>>2]);x[a+36>>2]=b;c=a,d=_n(b),v[c+44|0]=d}function mK(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function g8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function VU(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function Pl(a,b){a=a+62|0;if(v[vb(a,b)|0]<0){return 255}if(y[vb(a,b)|0]!=255){a=y[vb(a,b)|0]&127}else{a=255}return a}function Bh(a){var b=0;jn(a);b=Zu(x[a>>2],bl(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Sk(x[a>>2],z[a+34>>1])}function B$(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Fd(b);continue}break}x[a+4>>2]=c}function Ap(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Tr(b);continue}break}x[a+4>>2]=c}function wK(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function qh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Gb(b+12|0,b+8|0)>>2];fb=b+16|0;return a}function cR(a){var b=0,c=0,d=0;if(x[a>>2]){Y_(a);b=x[a>>2];Sv(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function br(a){var b=0,c=0,d=0;if(x[a>>2]){Hf(a);b=x[a>>2];Rg(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function JU(a){var b=0,c=0,d=0;if(x[a>>2]){gj(a);b=x[a>>2];Cn(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function IT(a){var b=0,c=0,d=0;if(x[a>>2]){nG(a);b=x[a>>2];Mn(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Gh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function yc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function rL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function UL(a,b){var c=0;c=fb-16|0;fb=c;a=Vl(c+4|0,a,1);wl(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;gc(a);fb=c+16|0}function F$(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function zm(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}pg(a,b);a=a+1|0;continue}}}function uR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=tR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Ws(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}wc(a,b);a=a+4|0;continue}}}function TK(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!kc(XK(c,b),-1)){break a}x[a>>2]=0}return a|0}function RP(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function PR(a,b){var c=0;c=fb-16|0;fb=c;a=UB(c+4|0,a);qo(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;gc(a);fb=c+16|0}function Gl(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=wg(a?a:22250),x[d>>2]=e}}function $S(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function ml(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a)+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)>>2];fb=b+16|0;return a}function OP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function mJ(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=(Bb(x[a+4>>2],y[a+11|0])<<2)+c>>>0>=b>>>0}else{a=0}return a}function iy(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function KA(a,b){var c=0;c=fb-16|0;fb=c;a=ue(c+8|0,Aua(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Il(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function zn(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function kW(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;continue}break}x[a+4>>2]=c}function jh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!ki(x[a+4>>2],x[b+4>>2])}function em(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function eH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=xb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function UQ(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function Tv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Ee(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function Ef(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function yR(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function p3(){if(y[500380]){return x[125094]}ms(500372,x[vH()>>2]);v[500380]=1;x[125094]=500372;return 500372}function nS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function kq(a,b){var c=0;c=fb-32|0;fb=c;kh(c+16|0,b);Km(c+24|0,a,x[c+16>>2],x[c+20>>2]);kh(c+8|0,b);fb=c+32|0}function Qv(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Lc(b+14|0,b+12|0)|0];fb=b+16|0;return a}function Ll(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;fc(a,b,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Fk(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function Cx(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Dx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function uU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27408|0]>>>z[a+68>>1]}function ZK(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return uf(v[b|0])}function MJ(a,b,c,d,e){b=nj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function JJ(a,b,c,d,e){b=mj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Fta(a,b){a=a|0;b=b|0;var c=0;b=fb-80|0;fb=b;c=-1;if(j$(a,b+14|0)){c=i$(b+14|0)}fb=b+80|0;return c|0}function zf(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a)+Bb(x[a+4>>2],y[a+11|0])|0)>>2];fb=b+16|0;return a}function vfa(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){st(x[31596],12710);p()}fb=a+16|0;return x[a+12>>2]}function ui(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Gb(b+12|0,b+8|0)|0];fb=b+16|0;return a}function eA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function Zda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return AH(a,b,c,d,e,f,g,12977,1086)|0}function XU(a,b){a=a|0;b=b|0;var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){ks(a,b-c|0,0);return}LT(a,b)}function Sda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return AH(a,b,c,d,e,f,g,13045,1093)|0}function Nl(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Pj(a)){a=HT(b,d)}return Cd(a)}function Jqa(a,b){a=a|0;b=b|0;if(!uY(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function IX(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function IL(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function yu(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=xo(a);continue}break}return a}function xw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function wW(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function hua(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(lk(a,b+8|0)){c=N$(b+8|0)}fb=b+16|0;return c|0}function Mpa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(KD(a,b+4|0)){c=yX(b+4|0)}fb=b+16|0;return c|0}function Az(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=Bb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function Aqa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(lk(a,b+8|0)){c=eY(b+8|0)}fb=b+16|0;return c|0}function sl(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function iua(a){a=a|0;var b=0;b=x[a+76>>2];if(kc(-1,b)){b=JE(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function i$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function QH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return xz(g|a,b,c,d,a|e,f)|0}function Ob(a,b){var c=0;c=fb-16|0;fb=c;CF(c+8|0,a,b);a=Hb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function Bs(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Dx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function BN(a,b){a=a|0;b=b|0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47616;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function BI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function zE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function rT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function mda(a){a=a|0;var b=0;b=fb-16|0;fb=b;ve(b+8|0,a);a=Gz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function fW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;eW(c);continue}break}x[a+4>>2]=b}function bz(a,b,c){b=(D(D($y(a),az(a,b)),125)>>>0)/(PL(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function YR(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Fl(c);continue}break}x[a+4>>2]=b}function Wca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return qO(x[a+4>>2],b,c,d,e,f,g)|0}function Tca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return iO(x[a+4>>2],b,c,d,e,f,g)|0}function Pb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function MT(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;yf(c);continue}break}x[a+4>>2]=b}function E$(a,b){a=nm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];nm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function CU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Ql(c);continue}break}x[a+4>>2]=b}function Ax(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function sj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function sT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function fJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=Ih(b+12|0,a);c=x[x[124227]>>2];Hh(a);fb=b+16|0;return c?4:1}function Pu(a,b){b=zua(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Fc(Aua(b,a,1e6,0),hb)}function gp(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Hn(a,b+12|0)){c=_b(x[b+12>>2])}fb=b+16|0;return c|0}function Rk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(up(a,b+14|0)){c=Cb(z[b+14>>1])}fb=b+16|0;return c|0}function yZ(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cb(b&65535),w[d+14>>1]=e;Ev(a,c+14|0);fb=c+16|0}function k1(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=-1;if(lk(a,b+8|0)){c=RF(b+8|0)}fb=b+16|0;return c|0}function jV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=hd(a,18291,17)}else{a=1}return!a}function iS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Ec(a+60|0,0);x[a+64>>2]=0;return a}function Tb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function R1(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=-1;if(uG(a,b+8|0)){c=sG(b+8|0)}fb=b+32|0;return c|0}function Ov(a){var b=0,c=0;if(x[a>>2]){To(a);Db(x[a>>2]);b=Ab(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function Jv(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Nm(b,b+22|0,78768);x[a+20>>2]=0;kd(a,0);return a|0}function ID(a,b){if(b>>>0<=126){Ue(((b<<5)+a|0)+480280|0);Ko((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function yf(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,a)>>2];c=x[a>>2];if(c){Ab(a);Db(c)}fb=b+16|0}function wH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Cc(d+4|0,c);a=mc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function mqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=up(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function mV(a){fe(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function mC(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=(VY(a,b,x[c>>2],d)|0)!=0}else{a=1}return a}function jE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function eS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function dl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function cZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){bZ(c+52|0);tb(c+40|0);sc(c+16|0);sc(c+4|0);Db(c)}}function Xha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Aj(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function V0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;An(c+8|0,b);qp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function U0(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Ec(a+8|0,0);Kr(a,127);tF(a,127,y[b|0]);return a|0}function Cg(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function C9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;mE(c+8|0,b);qp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function oF(a,b,c,d,e,f,g){a=zb(a,b);zb(a+4|0,c);zb(a+8|0,d);zb(a+12|0,e);zb(a+16|0,f);zb(a+20|0,g)}function bi(a,b,c){var d=0;d=x[a+4>>2];while(1){if((b|0)!=(d|0)){d=d-c|0;continue}break}x[a+4>>2]=b}function Zc(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];bx(b);return a}function Xx(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Ih(f+12|0,e);a=it(a,b,c,d);Hh(e);fb=f+16|0;return a}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;a=Aj(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function PT(a,b,c){var d=0;d=fb-16|0;fb=d;a=x[zb(d+12|0,GT(b,c,ae(a),dc(a)))>>2];fb=d+16|0;return a}function MI(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=XX(c)}x[a+4>>2]=c;x[a>>2]=b}function KR(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22250}else{a=22250}return a}function Di(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Ih(f+12|0,e);a=gK(a,b,c,d);Hh(e);fb=f+16|0;return a}function Ada(a,b){a=a|0;b=b|0;var c=0;b=Jb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}Vt(b,a)}function zw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=bh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function vJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=rc(c+4|0,b);Zc(d,a);tb(a);fb=c+16|0}function cra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Hn(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function aw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Cc(c+4|0,b);Zc(d,a);tb(a);fb=c+16|0}function aea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return FH(a,b,c,d,e,f,10648,1083)|0}function Qaa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=x[tf(b+12|0,Ul(Dc(12),a))>>2];fb=b+16|0;return a|0}function QQ(a,b){var c=0;c=fb-16|0;fb=c;a=ue(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Pea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return FH(a,b,c,d,e,f,10693,1056)|0}function Os(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Kd(){var a=0;if(y[500356]){return x[125088]}a=uk(14271);v[500356]=1;x[125088]=a;return a}function BJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function uD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[c_(c+12|0,0-b|0)>>2];fb=c+16|0;return a}function qua(a,b){a=a|0;b=b|0;if(!fE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function h9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function g9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function fz(a,b,c,d){var e=0;e=fb-16|0;fb=e;ac(e+8|0,c,d);HM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function f9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function e9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function d9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Mz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Km(a,b,c,d){var e=0;e=fb-16|0;fb=e;jf(e+8|0,c,d);HM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function rX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function bca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ZO(a,x[b+4>>2],c,d,e,f,g)}function a2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;AI(d,b);Nh(a,d);tb(d);fb=c+16|0}function Z$(a,b){a=a|0;b=b|0;if(!fE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function Yba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;tO(a,x[b+4>>2],c,d,e,f,g)}function S2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(jh(a,x[b+8>>2],f)){Gx(b,c,d,e)}}function Q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function Mw(a,b){a=KF(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];KF(a+12|0,x[b+12>>2],x[b+16>>2])}function Hja(a,b){a=a|0;b=b|0;Ni(a);Ni(a);a:{if(b>>>0>=60){Ub(a,4);break a}Ni(a)}return Ni(a)|0}function vx(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function vL(a){var b=0;b=+((a&2097151)>>>0);return E(nk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function rD(a){var b=0,c=0;b=fb-16|0;fb=b;if(up(a,b+14|0)){c=we(w[b+14>>1])}fb=b+16|0;return c}function p$(a){var b=0;if(!(hd(a,24676,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function hK(a){var b=0;b=x[124227];if(a){x[124227]=(a|0)==-1?500164:a}return(b|0)==500164?-1:b}function b$(a,b){return(Xb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Xb((D(a&15,b)>>>0)/15|0,1,15))&255}function Xd(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=bh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function Uba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;YO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Tba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;sO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function BW(a){var b=0,c=0;b=fb-16|0;fb=b;if(IE(a,b+12|0)){c=_b(x[b+12>>2])}fb=b+16|0;return c}function cW(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function at(a){return y[(a>>>3&31|y[(a>>>8|0)+107504|0]<<5)+107504|0]>>>(a&7)&1&a>>>0<=131071}function Xba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Rt(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function Wpa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=Zh(b+12|0);bY(c,a,0,0);ub(a);fb=b+32|0}function Nm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Nc(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=VY(a,b,x[c>>2],d)}else{a=1}return!a}function Mm(a){a=a|0;var b=0;x[a>>2]=47636;b=x[a+4>>2];if(b){Db(iq(b))}x[a+4>>2]=0;return a|0}function Js(a){a=a|0;var b=0;x[a>>2]=112044;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function FY(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function qC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function a9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function Ne(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[pU(c+12|0,b)>>2];fb=c+16|0;return a}function HU(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[GU(c+12|0,b)>>2];fb=c+16|0;return a}function wpa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Yh(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function wN(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=uN(d);b=b+1|0}jU(a,b,c,d,e)}function tD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;ku(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function r4(a,b){a=a|0;b=b|0;a=ud(a,0);wI(a+8|0,b);x[a>>2]=117076;x[a>>2]=117360;return a|0}function p4(a,b){a=a|0;b=b|0;a=ud(a,0);wI(a+8|0,b);x[a>>2]=117232;x[a>>2]=117476;return a|0}function nF(a,b){if((a&4088)>>>0>=520){b=Cw(0-Cua(b^1230262859,25)|0,4)^1247037516}return b}function dh(a){var b=0;b=fb-16|0;fb=b;a=up(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function cB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function bg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){ID(a,c);b=b+1|0;continue}break}}function _I(a,b){a=ud(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=112044;x[a+8>>2]=112096;return a}function Yx(a,b,c){var d=0;d=fb-16|0;fb=d;c=Ih(d+12|0,c);a=My(a,b);Hh(c);fb=d+16|0;return a}function Yfa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;wz(a,b,c,d,e,0,0,f,g)}function N$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function BE(a){var b=0;b=x[a>>2];if(x[b>>2]){zE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];AE(a);Db(b)}}function xm(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[xb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Zw(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22260>>2]}else{b=9742}rc(a,b)}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function YK(a){var b=0;b=x[a>>2];if(b){if(!kc(ZK(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function MP(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function KF(a,b,c){var d=0;d=fb-16|0;fb=d;b=nm(d+8|0,b,c);kG(b,a);he(b);fb=d+16|0;return a}function Ah(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function wy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=ht(a,b,c,d);fb=e+16|0;return a}function m2(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);ms(a,x[b+4>>2]);FG(b+4|0,c)}function iU(a,b,c){while(1){if((b|0)!=(c|0)){gU(a,y[b|0]);b=b+1|0;continue}break}return a}function eq(a){a=a|0;var b=0;x[a>>2]=47616;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function dx(){var a=0,b=0;a=fb-16|0;fb=a;b=tf(a+12|0,Nb(Dc(12)));fb=a+16|0;return x[b>>2]}function aA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function V_(a,b,c){var d=0;d=fb-16|0;fb=d;ti(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function SE(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function Qr(a){var b=0;while(1){if(!kc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function Dl(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function Cua(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function ln(a){var b=0;if(a>>>0>=2){b=cY(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function iX(a,b){var c=0;c=fb-16|0;fb=c;An(c+8|0,b);WY(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function fS(a){var b=0;b=a+4e4|0;while(1){b=EA(b-160|0);if((b|0)!=(a|0)){continue}break}}function an(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,(b<<1)+a|0)>>2];fb=c+16|0;return a}function Yv(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,D(b,6)+a|0)>>2];fb=c+16|0;return a}function XI(a,b){a=ud(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=113336;Fb(a+16|0);return a}function SI(a,b){a=ud(a,b);b=a+8|0;x[b>>2]=121028;x[a>>2]=116012;x[b>>2]=116060;return a}function RI(a,b){a=ud(a,b);b=a+8|0;x[b>>2]=121064;x[a>>2]=116276;x[b>>2]=116324;return a}function Lt(a){if(GM(a)){a=$b(4);x[a>>2]=0;a=Ij(a);x[a>>2]=124508;da(a|0,124544,34);p()}}function HS(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function GB(a,b){a=Ul(a,b);Zc(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function $ha(a,b){a=a|0;b=b|0;a=Aj(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function w1(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function sq(a,b,c){a=Hl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function sm(a){var b=0;b=Xw(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function qK(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=rK(a,11188,b);fb=c+16|0;return a}function hD(a){var b=0;b=aV(a);while(1){if((a|0)!=(b|0)){C$(a);a=a+32|0;continue}break}}function fs(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=uN(d);b=b+1|0}pB(a,b,c,d)}function fC(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function bm(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Qh(a,b,d+15|0);fb=d+16|0;return a}function PK(a){var b=0;b=x[a>>2];if(b){if(!bo(sl(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Oea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return EH(a,b,c,d,e,12533,1057)|0}function Ig(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Av(a,b,c){var d=E(0);d=B[a>>2];if(!zv(d,B[b>>2])){b=zv(B[c>>2],d)?c:a}return b}function $da(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return EH(a,b,c,d,e,12433,1084)|0}function xc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;An(d,a);km(d,b);fb=c+16|0;return a}function pV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function nU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function lG(a,b){var c=0;c=fb-16|0;fb=c;b=Af(c+8|0,b);kG(b,a);he(b);fb=c+16|0;return a}function kE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;mw(a,c+15|0);fb=c+16|0}function Yda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zH(a,b,c,d,e,9626,1087)|0}function Vt(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;kP(18442,b);Ut(125920);fb=b+16|0}function Rda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zH(a,b,c,d,e,9698,1094)|0}function O$(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24624|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function F5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function $1(){var a=0;a:{if(BG(19988993)){break a}if(AG()){break a}a=zG()^1}return a|0}function z5(a){a=a|0;a=501296;while(1){a=tb(a-12|0);if((a|0)!=501008){continue}break}}function y5(a){a=a|0;a=500824;while(1){a=tb(a-12|0);if((a|0)!=500656){continue}break}}function xv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;tv(a+236|0,128,c+14|0);fb=c+16|0}function wu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){sA(a,b,0);sA(a,b,1);sA(a,b,2)}}function w9(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function v9(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function qJ(a,b){var c=0,d=0;Oe(a,ie(b));b=dc(b);c=dc(a),d=x[b>>2],x[c>>2]=d;return a}function oK(a){return(a|0)!=0&(a|0)!=121468&(a|0)!=121492&(a|0)!=500080&(a|0)!=500104}function iv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function g5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+97920>>2]}return b<<24>>24}function e5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96384>>2]}return b<<24>>24}function Qi(a,b,c){var d=0;d=fb-16|0;fb=d;JX(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function P5(a){a=a|0;a=501672;while(1){a=Rb(a-12|0);if((a|0)!=501648){continue}break}}function OI(a){var b=0;b=x[a>>2];if(x[b>>2]){Hf(b);a=x[a>>2];Vx(Ls(a),x[a>>2],Rg(a))}}function O5(a){a=a|0;a=501600;while(1){a=Rb(a-12|0);if((a|0)!=501312){continue}break}}function N7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nH(b,c,d,e,f,1)|0}function L7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nH(b,c,d,e,f,0)|0}function D7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return lH(b,c,d,e,f,1)|0}function B7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return lH(b,c,d,e,f,0)|0}function A5(a){a=a|0;a=501640;while(1){a=tb(a-12|0);if((a|0)!=501616){continue}break}}function xo(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function tia(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function hf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function dC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function ak(a,b,c){var d=0;d=x[a>>2];if(!Kq(d,x[b>>2])){b=Kq(x[c>>2],d)?c:a}return b}function Zx(a){a=a|0;x[a>>2]=113248;if(x[a+8>>2]!=(Kd()|0)){pl(x[a+8>>2])}return a|0}function Xca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return pO(x[a+4>>2],b,c,d,e)|0}function Ug(a,b,c){var d=0;d=C[a>>3];if(!kV(d,C[b>>3])){b=kV(C[c>>3],d)?c:a}return b}function Uca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hO(x[a+4>>2],b,c,d,e)|0}function R3(a,b,c){a=a|0;b=b|0;c=c|0;a=Kx(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function N5(a){a=a|0;a=501e3;while(1){a=Rb(a-12|0);if((a|0)!=500832){continue}break}}function Mg(a){var b=0;b=fb-16|0;fb=b;a=Hn(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function Lfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hP(a,b,c,d,0,0,0,0,e)|0}function HV(a,b,c,d,e,f){a=zb(a,b);zb(a+4|0,c);zb(a+8|0,d);zb(a+12|0,e);zb(a+16|0,f)}function Ge(a,b,c){if(vn(a,b,c)){a=dj(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function Aha(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function z$(a,b,c){a=a|0;b=b|0;c=c|0;return y$(a,b,Jb(c),Bb(x[c+4>>2],y[c+11|0]))|0}function yF(a){var b=0;b=x[a>>2];if(x[b>>2]){gj(b);a=x[a>>2];b=x[a>>2];Cn(a);Db(b)}}function qR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[dc(a)+4|0]){Eb(b+16|0)}Db(b)}}function oG(a){var b=0;b=x[a>>2];if(x[b>>2]){nG(b);a=x[a>>2];b=x[a>>2];Mn(a);Db(b)}}function lia(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];bu(a);uQ(a)}function de(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48600;Ud(a,48496,b+12|0);fb=b+16|0}function az(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+81121|0]<<1}function am(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Xe(zi(b)*+(c>>>0)),x[d+24>>2]=e}function _Y(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[dc(a)+4|0]){Ik(b+16|0)}Db(b)}}function Zp(a){a=a|0;x[a+56>>2]=94160;x[a>>2]=94140;mt(a+4|0);ul(a+56|0);return a|0}function Z_(a){var b=0;b=x[a>>2];if(x[b>>2]){Y_(b);a=x[a>>2];b=x[a>>2];Sv(a);Db(b)}}function Vk(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,a+b|0)>>2];fb=c+16|0;return a}function VV(a){var b=0;b=x[a>>2];if(x[b>>2]){AV(b);a=x[a>>2];b=x[a>>2];Uu(a);Db(b)}}function Pga(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];QP(a);PP(a)}function JT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[dc(a)+4|0]){KT(b+16|0)}Db(b)}}function J6(a){a=a|0;Rp(x[a+8>>2]);a=x[a+8>>2];if(!a){return 1}return(fJ(a)|0)==1|0}function GQ(a){var b=0;b=x[a>>2];if(x[b>>2]){Hf(b);a=x[a>>2];b=x[a>>2];Rg(a);Db(b)}}function DA(a){var b=0;b=fb-16|0;fb=b;zb(b+12|0,a+116|0);a=XR(a);fb=b+16|0;return a}function Bf(a){a=a|0;x[a+60>>2]=94324;x[a>>2]=94304;mt(a+8|0);ul(a+60|0);return a|0}function Af(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function yL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function _S(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function Vu(a,b){a=Cb(a&65535);b=Cb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Ip(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function Gp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function B6(){var a=0,b=0,c=0;a=ud(501728,1);x[a>>2]=113248;b=a,c=Kd(),x[b+8>>2]=c}function xs(a,b,c,d){if(b>>>0>=d>>>0){Xj();p()}c=Dc(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function xda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ws(a,b,c,d,e,1109)|0}function xd(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a))>>2];fb=b+16|0;return a}function wda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ws(a,b,c,d,e,1111)|0}function vda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ws(a,b,c,d,e,1113)|0}function tv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function rF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function qfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ws(a,b,c,d,e,1002)|0}function qV(a){if((y[a+14|0]-53&255)>>>0>=252){a=hd(a,15601,14)}else{a=1}return!a}function ng(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,dc(a))>>2];fb=b+16|0;return a}function kP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;kL(125920,a,b,0,0);fb=c+16|0}function bM(a,b){a=Jn(a);v[a+8|0]=0;x[a+4>>2]=b;x[a>>2]=77356;Nb(a+12|0);return a}function Xi(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,wb(a))>>2];fb=b+16|0;return a}function Po(a,b){a=yc(a,b,34);w[a+34>>1]=z[b+34>>1];yc(a+36|0,b+36|0,68);return a}function Pca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IH(a,b,c,d,e,1124)|0}function NQ(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Kf(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,ng(a))>>2];fb=b+16|0;return a}function zX(a){var b=0;while(1){if((b|0)!=512){ah(a+b|0);b=b+1|0;continue}break}}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function s5(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+112096>>2]&b)!=0&c>>>0<=127}function iM(a){a=Jn(a);x[a>>2]=77820;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function gP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IH(a,b,c,d,e,1003)|0}function _N(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return vs(a,b,c,d,e,1108)|0}function XN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return vs(a,b,c,d,e,1110)|0}function WN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return vs(a,b,c,d,e,1112)|0}function VN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return vs(a,b,c,d,e,1028)|0}function Qk(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;hc(a+8|0,b+8|0)}function NN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xx(a,b,c,d,e,1109)|0}function MN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ss(a,b,c,d,e,1109)|0}function LN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xx(a,b,c,d,e,1111)|0}function KN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ss(a,b,c,d,e,1111)|0}function JN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xx(a,b,c,d,e,1113)|0}function IN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ss(a,b,c,d,e,1113)|0}function HN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ss(a,b,c,d,e,1002)|0}function yra(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,wY(b,Jb(c),Bb(x[c+4>>2],y[c+11|0])))}function xba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return eN(a-88|0,b,c,d,e)|0}function wx(a,b,c,d){if(b>>>0>=d>>>0){Xj();p()}c=Dc(b<<c);x[a+4>>2]=b;x[a>>2]=c}function wi(a){return(kk(x[a>>2],x[a+4>>2])|0)!=(0-kk(x[a+12>>2],x[a+16>>2])|0)}function s_(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function qx(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function mg(a){var b=0,c=0;qc(a+4|0);Ec(a+8|0,0);b=a,c=dc(a),x[b>>2]=c;return a}function gU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27548>>2]}function gH(a,b){x[a>>2]=b;Rb(a+52|0);Rb(a+40|0);Rb(a+28|0);tb(a+16|0);return a}function fH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function Xl(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;Ud(a,b,d+12|0);fb=d+16|0}function X5(a){a=a|0;if(!y[500608]){nn(500596,113564);v[500608]=1}return 500596}function V5(a){a=a|0;if(!y[500640]){nn(500628,113648);v[500640]=1}return 500628}function Tp(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;Qj(a,b,d+12|0);fb=d+16|0}function T5(a){a=a|0;if(!y[500544]){nn(500532,113492);v[500544]=1}return 500532}function Rb(a){var b=0;if(Cd(y[a+11|0])){b=x[a>>2];bj(x[a+8>>2]);Db(b)}return a}function R5(a){a=a|0;if(!y[500576]){nn(500564,113528);v[500576]=1}return 500564}function OR(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;rC(d,1,b);Ac(a,d);fb=c+16|0}function EI(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function B2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function $f(a){var b=0;b=vb(a,2);return y[vb(a,1)|0]<<8|y[b|0]<<16|y[vb(a,0)|0]}function xca(a,b){a=a|0;b=b|0;a=x[a+4>>2];return yO(x[a+24>>2],B[a+48>>2],b)|0}function v_(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){UL(a,b);return}RL(a,b)}function u2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function nA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){PR(a,b);return}Xz(a,b)}function hw(a,b){return Xe(zi((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function h3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[502176]){v[502176]=1}fc(a,c,126364)}function g4(a,b){a=a|0;b=b|0;a=Ij(a);x[a>>2]=125036;Jx(a+4|0,Jb(b));return a|0}function VC(a){var b=0;while(1){if((b|0)!=4){ah(a+b|0);b=b+1|0;continue}break}}function T9(a){a=a|0;a=x[a+24>>2];return $L(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function Oo(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function J5(a){a=a|0;if(!y[500592]){Cc(500580,13617);v[500592]=1}return 500580}function Iw(a,b){var c=0;if((b|0)<0){Xj();p()}c=Dc(b<<1);x[a+4>>2]=b;x[a>>2]=c}function C5(a){a=a|0;if(!y[500560]){Cc(500548,13766);v[500560]=1}return 500548}function ye(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Ew(d,a);km(d,b);fb=c+16|0}function wb(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,a)>>2];fb=b+16|0;return a}function vj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function qf(a){if(Cd(y[a+11|0])){ed(x[a>>2],0);Wd(a,0);return}ed(a,0);Ke(a,0)}function jB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Kl(Kl(c,a),D(a,-100)+b|0)}function iB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function hba(a,b){a=a|0;b=b|0;wn(x[a+4>>2]);MF(OF(x[a+4>>2],b));wn(x[a+4>>2])}function gB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return jB(Kl(c,a),D(a,-1e4)+b|0)}function Zz(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function Yz(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function YI(a,b){a=ud(a,b);w[a+8>>1]=11310;x[a>>2]=113296;Fb(a+12|0);return a}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,12934,1088)|0}function X2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(jh(a,x[b+8>>2],0)){Ex(b,c,d)}}function Vj(a){var b=0;b=fb-16|0;fb=b;a=x[tf(b+12|0,a)>>2];fb=b+16|0;return a}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,13008,1090)|0}function Tk(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;mE(d,a);km(d,b);fb=c+16|0}function Rga(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function RR(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Ab(a)>>2]){PR(a,b);return}Xz(a,b)}function H5(a){a=a|0;if(!y[500624]){Cc(500612,9253);v[500624]=1}return 500612}function Ej(a){if(Ob(a+1074312|0,7)){a=qn(x[a+480180>>2])^1}else{a=0}return a}function E5(a){a=a|0;if(!y[500528]){Cc(500516,5265);v[500528]=1}return 500516}function BT(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Au(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return gB(Kl(c,a),D(a,-1e6)+b|0)}function ce(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Ub(b,c);$w(a,b,d,c)}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,9420,1085)|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,9581,1089)|0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,9659,1091)|0}function UJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qn(a,b,c,d,9451,1092)|0}function Se(a){var b=0;b=fb-16|0;fb=b;Gn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function QJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function DS(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function o5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+97920>>2]}return b|0}function m5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96384>>2]}return b|0}function eU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);YT(a,b,0,0,b+-1,0)}function eQ(a){a=a|0;x[a>>2]=44732;sc(a+4276|0);sc(a+4264|0);return Vf(a)|0}function bC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function Vl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function PL(a,b){a=a^-1;return x[(b&12)+81124>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function P7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return oH(b,c,d,e,1)|0}function MK(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function M7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return oH(b,c,d,e,0)|0}function J8(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){JK(a,c);return}Cc(a,7920)}function F7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mH(b,c,d,e,1)|0}function Dh(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function C7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mH(b,c,d,e,0)|0}function BZ(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function l3(a,b,c){a=a|0;b=b|0;c=c|0;return kc(a,x[b+4>>2])&x[b>>2]==(c|0)}function eG(a,b){a=a|0;b=b|0;a=Ij(a);x[a>>2]=125036;Jx(a+4|0,b);return a|0}function di(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return oO(x[a+4>>2],b,c,d)|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lO(x[a+4>>2],b,c,d)|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nO(x[a+4>>2],b,c,d)|0}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kO(x[a+4>>2],b,c,d)|0}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rO(x[a+4>>2],b,c,d)|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return jO(x[a+4>>2],b,c,d)|0}function Nha(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function Dk(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(nV(a)?b:a)&65535}function zra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=mp(a,b),x[d>>2]=e}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=yw(a,b),w[d>>1]=e}function uj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function sc(a){var b=0;b=fb-16|0;fb=b;GQ(zb(b+12|0,a));fb=b+16|0;return a}function qF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function lz(a,b){var c=0,d=0;c=zb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function gd(a,b){a=lG(a,b);x[a+8>>2]=x[b+8>>2];lG(a+12|0,b+12|0);return a}function dp(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function dG(a,b){a=Af(a,b);x[a+8>>2]=x[b+8>>2];Af(a+12|0,b+12|0);return a}function cc(a){var b=0;b=fb-16|0;fb=b;aZ(zb(b+12|0,a));fb=b+16|0;return a}function Wc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function OF(a,b){a=a|0;b=b|0;return aF(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))|0}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function KX(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function Jb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Cd(y[a+11|0]),d?b:c}function zy(a,b){var c=0;c=yt(a+4|0);x[a>>2]=94952;x[c>>2]=94972;ho(c,b)}function yy(a,b){var c=0;c=BK(a+4|0);x[a>>2]=95320;x[c>>2]=95340;ho(c,b)}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ts(a,b,c,d,1119)|0}
function dL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;di(a,-1,-1)}function Im(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function wU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ts(a,b,c,d,1115)|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ts(a,b,c,d,1117)|0}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ts(a,b,c,d,1121)|0}function oc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=gf(b),x[c+4>>2]=d;return a}function oU(a){if(a>>>0<=8){return y[a+27536|0]}return y[a+27527|0]|256}function oN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function nK(a,b,c){var d=0;d=c;c=gf(b);if(d>>>0>c>>>0){bO(a,b)}return c}function Wta(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function W_(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function Ty(a){return((Kh(a)+(Kh(a)<<8)|0)+(Kh(a)<<16)|0)+(Kh(a)<<24)|0}function Q2(a){a=a|0;if(!a){return 0}return(TA(a,124592,124736)|0)!=0|0}function Pp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return uH(a,b,c,d,1003)|0}function OD(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return uH(a,b,c,d,1124)|0}function Kc(a){if(Cd(y[a+11|0])){a=bj(x[a+8>>2])-1|0}else{a=10}return a}function Goa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;OG(a,b,c,d,e,136)}function $P(a){a=a|0;return E(E(E(B[xb(a+4208|0,5)>>2]*E(198))+E(-99)))}function zq(a,b){if(b){zq(a,x[b>>2]);zq(a,x[b+4>>2]);KT(b+16|0);Db(b)}}function xqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yx(a,b,c,d,589)|0}function oB(a,b){if(b){oB(a,x[b>>2]);oB(a,x[b+4>>2]);Zm(b+16|0);Db(b)}}function mn(a){if(Cd(y[a+11|0])){a=bj(x[a+8>>2])-1|0}else{a=1}return a}function mA(a,b){if(b){mA(a,x[b>>2]);mA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function et(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function ei(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function bsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;OG(a,b,c,d,e,94)}function ZC(a,b){if(b){ZC(a,x[b>>2]);ZC(a,x[b+4>>2]);Ik(b+16|0);Db(b)}}function YC(a,b){if(b){YC(a,x[b>>2]);YC(a,x[b+4>>2]);Ik(b+16|0);Db(b)}}function Xu(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Xj(){var a=0;a=Pm($b(4));x[a>>2]=124920;da(a|0,124996,34);p()}function VA(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function UN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return us(a,b,c,d,1114)|0}function TN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return us(a,b,c,d,1116)|0}function Sr(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function SN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return us(a,b,c,d,1118)|0}function QN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return us(a,b,c,d,1120)|0}function MB(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function GN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1115)|0}function Fx(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function FN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1117)|0}function EN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1119)|0}function DN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1121)|0}function y2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function ax(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yx(a,b,c,d,166)|0}function aZ(a){var b=0;b=x[a>>2];if(x[b>>2]){To(b);Db(x[x[a>>2]>>2])}}function VR(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function Ux(a){a=a|0;if(x[a+8>>2]!=(Kd()|0)){pl(x[a+8>>2])}return a|0}function RT(a,b,c){if(Ge(a,b,c)){a=x[Vb(a,c)+12>>2]}else{a=1}return a}function NM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){no(c+120|0);Db(c)}}function IV(a,b,c,d,e){a=zb(a,b);zb(a+4|0,c);zb(a+8|0,d);zb(a+12|0,e)}function A_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yx(a,b,c,d,342)|0}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function tY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];hc(a+8|0,b+8|0)}function h8(a){a=a|0;var b=0;b=x[125096]+1|0;x[125096]=b;x[a+4>>2]=b}function P6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gg(a,f)}function O6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Sp(a,f)}function oO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yH(a,b,c,d,4)|0}function nO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yH(a,b,c,d,2)|0}function lO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return xH(a,b,c,d,4)|0}function kO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return xH(a,b,c,d,2)|0}function X$(a,b){return Qp(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function NH(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function Mc(a,b,c){if(nc(a,b)>>>0<=c>>>0){sw();p()}return(c<<2)+a|0}function Jr(a,b){return Bw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Hk(a,b,c){var d=0;d=fb-16|0;fb=d;JX(d+8|0,a,b,c);fb=d+16|0}function Gr(a,b,c){if(Yc(a,b)>>>0<=c>>>0){sw();p()}return(c<<1)+a|0}function GS(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function EY(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function Am(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function wga(a,b){a=a|0;b=b|0;if(!x[31721]){x[31721]=a;x[31722]=b}}function og(a,b){a=a|0;b=b|0;var c=0;c=Dc(b);x[a+4>>2]=b;x[a>>2]=c}function md(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function j5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function f4(a,b){a=a|0;b=b|0;a=xI(a,b,1);x[a>>2]=121196;return a|0}function ega(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,983,86224)|0}function Vx(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function Rj(a,b){a=a|0;b=b|0;var c=0;c=XX(b);x[a+4>>2]=b;x[a>>2]=c}function QU(a,b){var c=0,d=0;c=zb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function M3(a,b){a=a|0;b=b|0;a=yI(a,b,1);x[a>>2]=121100;return a|0}function zp(a,b,c){a=Af(a,b);x[a+8>>2]=0;Af(a+12|0,c);he(c);he(b)}function zh(a,b,c){a=zb(a,b);DZ(a+4|0,x[c>>2],x[c+4>>2]);return a}function yia(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,948,4268)|0}function xga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,980,5048)|0}function x1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function tm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function rk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function qL(a,b){a=oL(a-1|0);if(!a){a=oL(b);a=a?a+32|0:0}return a}function nla(a,b){a=a|0;b=b|0;a=Hv(a,b);x[a>>2]=125244;return a|0}function mga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,982,4276)|0}function mN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function ko(a,b){if(A[a+4>>2]<A[Ab(a)>>2]){UL(a,b);return}RL(a,b)}function jha(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,975,4280)|0}function ip(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function iia(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,956,4304)|0}function bY(a,b,c,d){a=Fe(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function aha(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,976,4276)|0}function _j(a,b){if(Gg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,977,4268)|0}function PH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cO(a,b,c,d)|0}function Msa(a,b){a=a|0;b=b|0;a=Hv(a,b);x[a>>2]=125192;return a|0}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,979,4228)|0}function Fs(a){a=a|0;x[a>>2]=113128;pl(x[a+16>>2]);return Js(a)|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,972,4236)|0}function ze(a){var b=0;b=fb-16|0;fb=b;oG(zb(b+12|0,a));fb=b+16|0}function y1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function mW(a){var b=0;b=fb-16|0;fb=b;gW(zb(b+12|0,a));fb=b+16|0}function ld(a){var b=0;b=fb-16|0;fb=b;yF(zb(b+12|0,a));fb=b+16|0}function kz(a){var b=0;b=fb-16|0;fb=b;VM(zb(b+12|0,a));fb=b+16|0}function iG(a,b,c){a=Jn(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78672}function dn(a){var b=0;b=fb-16|0;fb=b;VV(zb(b+12|0,a));fb=b+16|0}function aca(a,b){a=a|0;b=b|0;return E(VO(x[x[a+4>>2]+24>>2],b))}function _ba(a,b){a=a|0;b=b|0;return E(RO(x[x[a+4>>2]+24>>2],b))}function ZX(a){var b=0;b=fb-16|0;fb=b;SX(zb(b+12|0,a));fb=b+16|0}function Wx(a){var b=0;b=fb-16|0;fb=b;OI(zb(b+12|0,a));fb=b+16|0}function Wfa(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Wba(a,b){a=a|0;b=b|0;return E(TO(x[x[a+4>>2]+24>>2],b))}function WV(a){var b=0;b=fb-16|0;fb=b;LV(zb(b+12|0,a));fb=b+16|0}function Vba(a,b){a=a|0;b=b|0;return E(SO(x[x[a+4>>2]+24>>2],b))}function Rp(a){var b=0;b=fb-16|0;fb=b;Hh(Ih(b+12|0,a));fb=b+16|0}function RV(a){var b=0;b=fb-16|0;fb=b;EV(zb(b+12|0,a));fb=b+16|0}function Qq(a,b,c){a=Cb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function Qp(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function Qd(a){var b=0;b=fb-16|0;fb=b;MH(zb(b+12|0,a));fb=b+16|0}function Pc(a){var b=0;b=fb-16|0;fb=b;BE(zb(b+12|0,a));fb=b+16|0}function Ok(a){var b=0;b=fb-16|0;fb=b;Z_(zb(b+12|0,a));fb=b+16|0}function IP(a){return E(E(B[xb(a+4208|0,11)>>2]*E(19980))+E(20))}function IA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function HZ(a,b){a=a|0;b=b|0;a=Hv(a,b);x[a>>2]=125056;return a|0}function $ba(a,b){a=a|0;b=b|0;return E(UO(x[x[a+4>>2]+24>>2],b))}function wg(a){var b=0;b=Mq(gf(a)+1|0,1);if(b){bO(b,a)}return b}function vo(a,b,c,d){a=Xu(a,c);if(Pj(a)){a=HT(b,d)}return Cd(a)}function usa(a,b){a=a|0;b=b|0;a=AZ(a,b);if(!a){zZ(b)}return a|0}function py(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function mx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function kt(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function hm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function hca(a,b){a=a|0;b=b|0;return zO(x[x[a+4>>2]+24>>2],b)|0}function gq(a,b,c){if(!b){return 0}return St(a,uf(c<<24>>24),b)}function Uc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){cu(b)}return a}function UM(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Ot(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function Mka(a,b){a=a|0;b=b|0;a=BY(a,b);if(!a){AY(b)}return a|0}function JP(a){return E(E(B[xb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function H6(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return fJ(a)|0}function Bw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function As(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function yi(a,b){a=a|0;b=b|0;a=Yh(a,b);if(!a){dl(b)}return a|0}function uT(a,b){a=a|0;b=b|0;a=__(a,b);if(!a){rr(b)}return a|0}function tha(a,b,c){a=a|0;b=b|0;c=c|0;return zx(a,b,c,0,974)|0}function mr(a,b){a=a|0;b=b|0;a=H_(a,b);if(!a){Rv(b)}return a|0}function kS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function hh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function fD(a,b){a=a|0;b=b|0;a=MY(a,b);if(!a){WC(b)}return a|0}function f7(a,b){a=a|0;b=b|0;ES(a,Hy(x[b>>2])<<24>>24,x[b>>2])}function bs(a,b){a=a|0;b=b|0;a=SF(a,b);if(!a){fx(b)}return a|0}function ZP(a){a=a|0;return Ck(E(B[xb(a+4208|0,4)>>2]*E(4)))|0}function Rw(a,b){a=Zc(a,b);hc(a+12|0,b+12|0);pe(a+32|0,b+32|0)}function Ow(a,b){a=a|0;b=b|0;a=JF(a,b);if(!a){Rr(b)}return a|0}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;return zx(a,b,c,0,978)|0}function Nr(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function LR(a,b){return b>>>0>=4e3?22250:((b<<5)+a|0)+946304|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;return zx(a,b,c,1,978)|0}function GW(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function GR(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Er(a,b){a=a|0;b=b|0;a=Hn(a,b);if(!a){xn(b)}return a|0}function Bp(a,b){a=a|0;b=b|0;a=Ww(a,b);if(!a){Vw(b)}return a|0}function A$(a,b){if(!b){return-1}b=gq(a,b,0);return b?b-a|0:-1}function $o(a,b){a=a|0;b=b|0;a=G_(a,b);if(!a){J_(b)}return a|0}function $ca(a,b,c){a=a|0;b=b|0;c=c|0;return+gO(x[a+4>>2],b,c)}function $$(a,b){a=a|0;b=b|0;a=eE(a,b);if(!a){jE(b)}return a|0}function pG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(cc(c))}}function nm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){el(c)}return a}function kha(a){a=a|0;return E(E(B[xb(a+4208|0,6)>>2]*E(20)))}function eM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function dba(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];gg(a+4|0,b+4|0)}function aka(a){a=a|0;a=Hv(a,22250);x[a>>2]=125136;return a|0}function _b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function _R(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Cj(c))}}function Zl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){dc(a);Db(b)}}function ZH(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function Ysa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;QG(a,b,c,d,366)}function XX(a){if(a>>>0>=1073741824){Xj();p()}return Dc(a<<2)}function Uha(a){a=a|0;a=Aj(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function Lra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;QG(a,b,c,d,478)}function Ita(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;XG(a,b,c,d,136)}function Ff(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function D_(a){return(y[a+47|0]+y[a+45|0]|0)+(y[a+46|0]<<5)|0}function wc(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function wR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function qm(a){a=jG(a,0);x[a+8>>2]=0;x[a>>2]=121336;return a}function qN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function q1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(a,x[d>>2],0)}function oL(a){var b=0,c=0,d=0;return b=yua(a),c=0,d=a,d?b:c}function mt(a){a=a|0;x[a>>2]=93624;tb(a+32|0);return co(a)|0}function kj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function eh(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function cS(a){x[a>>2]=0;Nb(a+4|0);Tb(a+16|0,0,144);return a}function bI(a){a=a|0;x[a>>2]=112012;pl(x[a+8>>2]);return a|0}function aI(a){a=a|0;x[a>>2]=111980;pl(x[a+8>>2]);return a|0}function _P(a){a=a|0;return E(E(B[xb(a+4208|0,2)>>2]*E(10)))}function ZL(a){a=a|0;x[a>>2]=78208;cc(a+24|0);return Dt(a)|0}function Oz(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Nra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;XG(a,b,c,d,94)}function Is(a){a=a|0;x[a>>2]=113180;pl(x[a+8>>2]);return a|0}function Iga(a){a=a|0;return E(E(B[xb(a+4208|0,6)>>2]*E(4)))}function Hv(a,b){a=Ij(a);x[a>>2]=125016;Jx(a+4|0,b);return a}function $X(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function zja(a,b,c){a=a|0;b=b|0;c=c|0;return NG(a,b,c,65)|0}function z2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function xl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(lf(b))}}function vu(a,b){if(b){vu(a,x[b>>2]);vu(a,x[b+4>>2]);Db(b)}}function uu(a,b){if(b){uu(a,x[b>>2]);uu(a,x[b+4>>2]);Db(b)}}function ro(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function or(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function nD(a,b){if(b){nD(a,x[b>>2]);nD(a,x[b+4>>2]);Db(b)}}function n5(a,b,c){a=a|0;b=b|0;c=c|0;return kH(b,c,97920)|0}function mD(a,b){if(b){mD(a,x[b>>2]);mD(a,x[b+4>>2]);Db(b)}}function l5(a,b,c){a=a|0;b=b|0;c=c|0;return kH(b,c,96384)|0}function kba(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,y$(c,0,b,gf(b)))}function jz(a,b,c,d,e,f){return rH(a,b,c,d,e,f,73604,74400)}function iz(a,b,c,d,e,f){return rH(a,b,c,d,e,f,74480,75244)}function f5(a,b,c){a=a|0;b=b|0;c=c|0;return jH(b,c,97920)|0}function dqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;MG(a,b,c,d,3)}function c5(a,b,c){a=a|0;b=b|0;c=c|0;return jH(b,c,96384)|0}function _aa(a){a=a|0;yz(a,2,100);_j(x[a+24>>2]+484360|0,0)}function _B(a,b){if(b){_B(a,x[b>>2]);_B(a,x[b+4>>2]);Db(b)}}function Z0(a){a=a|0;a=fG(a,13422);x[a>>2]=24444;return a|0}function Xw(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function XM(a,b){a=a|0;b=+b;tH(a,b,1e4,1074420,9363,512,32)}function V$(a,b,c){a=a|0;b=b|0;c=c|0;return $G(a,b,c,265)|0}function Uv(a,b,c){a=a|0;b=b|0;c=c|0;return $G(a,b,c,325)|0}function OS(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(WA(b))}}function Ny(a,b){return rt(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function ME(a){return!hd(a,14184,3)&(y[a+3|0]-10&255)>>>0<5}function MC(a,b){if(b){MC(a,x[b>>2]);MC(a,x[b+4>>2]);Db(b)}}function Lw(a,b){return gS(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function Jpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;MG(a,b,c,d,2)}function Ih(a,b){var c=0,d=0;c=a,d=hK(b),x[c>>2]=d;return a}function Ds(a,b){var c=0,d=0;c=a,d=uk(b),x[c>>2]=d;return a}function CM(a,b){a=a|0;b=b|0;return Tj(x[b>>2],x[b+4>>2])|0}function BM(a,b){a=a|0;b=b|0;return Pd(x[b>>2],x[b+4>>2])|0}function $B(a,b){if(b){$B(a,x[b>>2]);$B(a,x[b+4>>2]);Db(b)}}function qp(a,b,c){a=a|0;b=b|0;c=c|0;oi(a,b,Ii(b,b+c|0,0))}function nz(a){return(Jb(a)+Bb(x[a+4>>2],y[a+11|0])|0)-1|0}function ir(a,b,c){if((a|0)!=(b|0)){b=b-a|0;$h(c-b|0,a,b)}}function iA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function a5(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Vo(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function OH(a,b,c){b=La(1013,a|0,b|0,c|0)|0;hb=gb;return b}function L1(a){a=a|0;a=fG(a,8704);x[a>>2]=28852;return a|0}function I3(a){a=a|0;a=HZ(a,7956);x[a>>2]=40248;return a|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function FO(a){return Lj(Wb(x[a+484360>>2],y[a+484376|0]))}function $n(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function yq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function yA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function wea(a,b){a=a|0;b=b|0;return Rn(a,b,11782,1065)|0}function vra(a,b,c){a=a|0;b=b|0;c=c|0;oi(a,b,Rc(b,c)+b|0)}function v$(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function uea(a,b){a=a|0;b=b|0;return HH(a,b,13394,1066)|0}function sF(a,b){var c=0;c=Dc(b<<2);x[a+4>>2]=b;x[a>>2]=c}function nN(a,b){a=a|0;b=+b;tH(a,b,256,1074456,11752,1,0)}function mea(a,b){a=a|0;b=b|0;return Rn(a,b,11817,1073)|0}function kg(a,b){if(Cd(y[a+11|0])){Wd(a,b);return}Ke(a,b)}function kea(a,b){a=a|0;b=b|0;return Rn(a,b,11847,1075)|0}function hg(a){var b=0;OP(a);b=x[a>>2];if(b){Iz(a);Db(b)}}function dea(a,b){a=a|0;b=b|0;return Rn(a,b,11943,1078)|0}function bea(a,b){a=a|0;b=b|0;return Rn(a,b,11911,1079)|0}function aK(a,b,c){a=a|0;b=b|0;c=c|0;qu(a,b,c);return a|0}function Yy(a,b){return x[((a>>>24^b)<<2)+495776>>2]^a<<8}function Tx(a){a=a|0;x[a>>2]=113336;tb(a+16|0);return a|0}function Sx(a){a=a|0;x[a>>2]=113296;tb(a+12|0);return a|0}function No(a){x[a>>2]=0;x[a+4>>2]=0;Ec(a+8|0,0);return a}function Nea(a,b){a=a|0;b=b|0;return Rn(a,b,11879,1058)|0}function MM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){cu(c)}}function Fc(a,b){return bH(a,b,2147483647,-2147483648,-1)}function EL(a){while(1){if((zt(a)|0)!=-1){continue}break}}function Dy(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function yB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function y9(a,b,c){a=a|0;b=b|0;c=c|0;return Ed(D(b,c))|0}function xn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function wv(a){sc(a+88|0);sc(a+68|0);sc(a+48|0);return a}function wj(a){return df(a)|df(a)<<8|df(a)<<16|df(a)<<24}function pg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function mha(a){a=a|0;return B[xb(a+4208|0,3)>>2]<E(1)|0}function dla(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function cL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;di(a,-1,-1)}function _w(a){a=a|0;x[a>>2]=125036;VH(a+4|0);return a|0}function WZ(a){a=a|0;x[a>>2]=125016;VH(a+4|0);return a|0}function VB(a,b){wc(a,b);wc(a+4|0,b+4|0);wc(Ab(a),Ab(b))}function M1(a,b,c){a=a|0;b=b|0;c=c|0;$w(a,b,x[b+8>>2],c)}function Lh(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function Kga(a){a=a|0;return B[xb(a+4208|0,1)>>2]<E(1)|0}function Kfa(a,b){a=a|0;b=b|0;return HH(a,b,6432,1006)|0}function KS(a,b){a=JS(a,b);JS(a+12|0,b+12|0);v[a+24|0]=1}function FG(a,b){el(x[b>>2]);sm(x[a>>2]);x[a>>2]=x[b>>2]}function Dt(a){a=a|0;x[a>>2]=77356;cc(a+12|0);return a|0}function CD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function Aga(a){a=a|0;NP(a);v[a+4202|0]=1;x[a+4224>>2]=0}function zka(a,b,c){a=a|0;b=b|0;c=c|0;KH(a,b,c,844,845)}function tja(a,b,c){a=a|0;b=b|0;c=c|0;GG(a,b,c,916,915)}function sD(a){a=a&255;return Sc(a)^1|(a-49&255)>>>0<36}function nt(a){a=a|0;x[a>>2]=93560;Yb(a+4|0);return a|0}function jR(a){return(a|0)==1179012417|(a|0)==538987841}function hM(a){a=a|0;x[a>>2]=77820;cc(a+4|0);return a|0}function fda(a,b,c){a=a|0;b=b|0;c=c|0;yz(x[a+4>>2],b,c)}function eg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function co(a){a=a|0;x[a>>2]=93496;Yb(a+4|0);return a|0}function cK(a,b,c){a=zb(a,b);zb(a+4|0,x[c>>2]);return a}function cG(a){a=a|0;x[a>>2]=41552;he(a+4|0);return a|0}function VH(a){a=Pn(x[a>>2]);if((Xw(a+8|0)|0)<0){Db(a)}}function Qj(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function OL(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;qc(a+8|0);return a}function NI(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){sm(b)}}function Ln(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function Kl(a,b){b=(b<<1)+123808|0;return Qi(b,b+2|0,a)}function Jt(a){a=a|0;x[a>>2]=48684;kz(a+4|0);return a|0}function Hd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;HO(a,x[b+4>>2],c)}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;GG(a,b,c,840,839)}function EO(a){return Iu(x[a+484344>>2],x[a+484348>>2])}function AT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function wna(a,b){a=a|0;b=b|0;if(!jX(a,b)){Tb(b,0,40)}}function vha(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4228|0,7)}function uua(a,b){a=a|0;b=b|0;Fh(a,b,263,1025,-1284,2)}function ura(a,b){a=a|0;b=b|0;return Cc(a,b?b:22250)|0}function ud(a,b){a=jG(a,b-1|0);x[a>>2]=113704;return a}function pca(a,b){a=a|0;b=b|0;return BO(x[a+4>>2],b)|0}function oh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function oaa(a,b){a=a|0;b=b|0;tT(x[a>>2],b);return a|0}function nR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function n8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;oi(a,c,d)}function mna(a,b){a=a|0;b=b|0;Fh(a,b,590,1058,-1332,3)}function kia(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4260|0,8)}function k8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Yn(a,c,d)}function hi(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function gi(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function f6(){ud(501960,1);LI(501968);x[125490]=117076}function eda(a,b){a=a|0;b=b|0;eO(x[x[a+4>>2]+24>>2],b)}function dka(a){a=a|0;Cj(126916);Cj(126908);tb(126896)}function d6(){ud(501976,1);LI(501984);x[125494]=117232}function asa(a,b){a=a|0;b=b|0;Fh(a,b,419,1042,-1332,2)}function aq(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function _6(a,b){a=a|0;b=b|0;fc(a,OK(x[b>>2]),x[b>>2])}function Xb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Vta(a,b){a=a|0;b=b|0;Fh(a,b,298,1058,-1332,2)}function VK(a){a=a|0;return ot(x[x[a>>2]-12>>2]+a|0)|0}function P8(a){a=a|0;return Zp(x[x[a>>2]-12>>2]+a|0)|0}function N8(a){a=a|0;return Bf(x[x[a>>2]-12>>2]+a|0)|0}function Loa(a,b){a=a|0;b=b|0;Fh(a,b,263,1042,-1332,2)}function Kh(a){var b=0;b=zt(a);x[a+1396>>2]=0;return b}function HT(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Bm(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function $y(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function $K(a){a=a|0;return pt(x[x[a>>2]-12>>2]+a|0)|0}function zca(a){a=a|0;return EO(x[x[a+4>>2]+24>>2])|0}function yp(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){el(c)}}function yda(a,b){a=a|0;b=b|0;Fh(a,b,82,1025,-1284,2)}function yN(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function wca(a){a=a|0;return wO(x[x[a+4>>2]+24>>2])|0}function tca(a){a=a|0;return QO(x[x[a+4>>2]+24>>2])|0}function tb(a){if(Cd(y[a+11|0])){Db(x[a>>2])}return a}function sv(a,b){a=a|0;b=b|0;Fh(a,b,591,1058,-1332,2)}function sca(a){a=a|0;return MO(x[x[a+4>>2]+24>>2])|0}function rj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function rca(a){a=a|0;return LO(x[x[a+4>>2]+24>>2])|0}function rc(a,b){a=a|0;b=b|0;FF(a,b,Qr(b));return a|0}function qj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function pda(a,b){a=a|0;b=b|0;Fh(a,b,83,1025,-1284,2)}function mQ(a){sc(a+36|0);sc(a+24|0);_t(a+12|0);_t(a)}function ll(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function kca(a){a=a|0;return hq(x[x[a+4>>2]+24>>2])|0}function gh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function fR(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function eT(a,b,c,d){return dd(Ao(a,b,c,d,0)-32768|0)}function eR(a,b){return(b>>>0>46?63:v[a+b|0])<<24>>24}function cg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function Zba(a){a=a|0;return OO(x[x[a+4>>2]+24>>2])|0}function WA(a){uq(a+223860|0);cc(a+223848|0);return a}function W1(a,b,c){a=a|0;b=b|0;c=c|0;KH(a,b,c,77,150)}function T3(a,b){a=a|0;b=b|0;return jI(b,x[a+8>>2])|0}function Sha(a){a=a|0;v[a+4202|0]=1;$t(a);Nz(a);nQ(a)}function Qda(a,b){a=a|0;b=b|0;Fh(a,b,82,1025,-1284,4)}function LD(a,b){a=Fe(a,b);Tb(a+20|0,0,1040);return a}function JC(a,b){a=a|0;b=b|0;Fh(a,b,590,1058,-1332,2)}function H3(a,b){a=a|0;b=b|0;return kK(b&255)<<24>>24}function Fca(a){a=a|0;return FO(x[x[a+4>>2]+24>>2])|0}function F3(a,b){a=a|0;b=b|0;return jK(b&255)<<24>>24}function Dra(a,b){a=a|0;b=b|0;Fh(a,b,82,1042,-1332,2)}function Dda(a,b){a=a|0;b=b|0;Fh(a,b,13,1025,-1284,2)}function Dca(a){a=a|0;return NO(x[x[a+4>>2]+24>>2])|0}function Cca(a){a=a|0;return fq(x[x[a+4>>2]+24>>2])|0}function Cc(a,b){a=a|0;b=b|0;qu(a,b,gf(b));return a|0}function Bqa(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,z$(c,0,b))}function Aca(a){a=a|0;return Nf(x[x[a+4>>2]+24>>2])|0}function $r(a,b){a=hc(a,b);Tb(a+20|0,0,1040);return a}function $e(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function $J(a,b,c){a=fK(a,b,c,0,-2147483648);return a}function zs(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function zba(a,b,c){a=a|0;b=b|0;c=c|0;gN(a-88|0,b,c)}function zJ(a,b,c,d){return Hp(a,b,c,d,24,178956971)}function yua(a){if(a){return 31-G(a-1^a)|0}return 32}function wQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function ve(a,b){fc(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function s$(a,b,c,d){return Hp(a,b,c,d,28,153391690)}function nX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function lha(a){a=a|0;return E(B[xb(a+4208|0,1)>>2])}function lda(a){a=a|0;return Gz(x[a>>2],x[a+4>>2])|0}function kr(a,b,c,d,e){fc(a,b+d|0,(e|0)==-1?c-d|0:e)}function jG(a,b){x[a+4>>2]=b;x[a>>2]=124488;return a}function hu(a){a=a|0;a=Zh(a);x[a+20>>2]=0;return a|0}function dm(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function be(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function WF(a,b,c,d){return Hp(a,b,c,d,36,119304648)}function Vn(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function V4(a,b){a=a|0;b=b|0;Fh(a,b,13,1058,-1332,2)}function R_(a,b,c,d){return Hp(a,b,c,d,40,107374183)}function PB(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function Nw(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function Jga(a){a=a|0;return E(B[xb(a+4208|0,3)>>2])}function Br(a,b,c){if(b){_O(a+36|0,b,Ii(b,b+c|0,0))}}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;iN(a-88|0,b,c)}function BF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function yba(a,b){a=a|0;b=b|0;return fN(a-88|0,b)|0}function yT(a,b,c,d){return Hp(a,b,c,d,7,613566757)}function xpa(a,b){a=a|0;b=b|0;return ai(a,b,1030)|0}function vN(a){a=a|0;a=x[a+4>>2];return(a?a:5011)|0}function rsa(a,b,c){a=a|0;b=b|0;c=c|0;JZ(a,c,b,0,0)}function rba(a,b,c){a=a|0;b=b|0;c=+c;$M(a-92|0,b,c)}function pp(a,b,c){fc(a,(c>>>3&536870908)+b|0,c&31)}function pm(a){a=a|0;a=zc(a);ib[x[x[a>>2]>>2]](a)|0}function pba(a,b,c){a=a|0;b=b|0;c=+c;ZM(a-92|0,b,c)}function pF(a){return nL(a,E(2524354896707238e-44))}function opa(a,b){a=a|0;b=b|0;return tx(a,b,1100)|0}function nua(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a,b,c,264)}function mo(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function mca(a){a=a|0;return+KO(x[x[a+4>>2]+24>>2])}function m1(a,b){a=a|0;b=b|0;return aF(a,b,gf(b))|0}function ie(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function hx(a,b){a=a|0;b=b|0;return gS(a,b,Qr(b))|0}function hsa(a,b){a=a|0;b=b|0;return ns(a,b,1188)|0}function dua(a,b){a=a|0;b=b|0;rx(a,b,263,274,-1332)}function dda(a,b){a=a|0;b=+b;return+fO(x[a+4>>2],b)}function dca(a){a=a|0;return+zA(x[x[a+4>>2]+24>>2])}function cU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function aqa(a,b,c){a=a|0;b=b|0;c=c|0;ps(a,b,c,598)}function aQ(a){a=a|0;return E(B[xb(a+4208|0,0)>>2])}function YB(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;VG(a,b,c,506)}function Vpa(a,b,c){a=a|0;b=b|0;c=c|0;aH(a,b,c,306)}function Vp(a,b,c){if(!c){return 0}return hd(a,b,c)}function Upa(a,b,c){a=a|0;b=b|0;c=c|0;IG(a,b,c,306)}function Soa(a,b){a=a|0;b=b|0;return ns(a,b,1184)|0}function Rta(a,b,c){a=a|0;b=b|0;c=c|0;ps(a,b,c,301)}function Ota(a,b,c){a=a|0;b=b|0;c=c|0;SG(a,b,c,306)}function Oj(a){if(!a){return 0}return x[a+44>>2]!=0}function Oaa(a,b){a=a|0;b=b|0;return ns(a,b,1187)|0}function Mna(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,hx(b,c))}function JA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function Gj(a){if(!a){return 0}return Nj(y[a+31|0])}function GF(a){return nL(a,E(15845632502852868e13))}function Fqa(a,b,c){a=a|0;b=b|0;c=c|0;WG(a,b,c,256)}function Dba(a,b,c){a=a|0;b=b|0;c=+c;kN(a-88|0,b,c)}function CF(a,b,c){fc(a,(c>>>3&536870908)+b|0,1<<c)}function C2(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function B9(a,b,c){a=a|0;b=b|0;c=c|0;ps(a,b,c,1170)}function Aba(a,b){a=a|0;b=b|0;return hN(a-88|0,b)|0}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a,b,c,420)}function $pa(a,b,c){a=a|0;b=b|0;c=c|0;ps(a,b,c,599)}function wqa(a,b){a=a|0;b=b|0;return ai(a,b,422)|0}function ssa(a,b){a=a|0;b=b|0;return ai(a,b,308)|0}function sr(a,b,c){a=a|0;b=b|0;c=c|0;VG(a,b,c,126)}function rqa(a,b){a=a|0;b=b|0;return ai(a,b,826)|0}function pja(a,b){a=a|0;b=b|0;return ai(a,b,225)|0}function pga(a,b){a=a|0;b=b|0;return E(xm(a,b,12))}function p2(a,b){a=a|0;b=b|0;return ns(a,b,1186)|0}function mua(a,b,c){a=a|0;b=b|0;c=c|0;aH(a,b,c,48)}function mja(a,b){a=a|0;b=b|0;return ai(a,b,326)|0}function iba(a){a=a|0;x[a>>2]=48464;return Qt(a)|0}function iY(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,Ny(b,c))}function hta(a,b){a=a|0;b=b|0;return RG(a,b,348)|0}function hG(a,b,c){a=a|0;b=b|0;c=c|0;Zc(a,Lw(b,c))}function gda(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a,b,c,84)}function fG(a,b){a=eG(a,b);x[a>>2]=125296;return a}function cca(a,b,c){a=a|0;b=b|0;c=c|0;IG(a,b,c,48)}function al(a,b){return(a&65535)>>>0<(b&65535)>>>0}function aJ(a,b){a=ud(a,b);x[a>>2]=115060;return a}function ZI(a,b){a=ud(a,b);x[a>>2]=113760;return a}function Xm(a){Fj(a+724|0);Fj(a+732|0);Fj(a+740|0)}function WI(a,b){a=ud(a,b);x[a>>2]=117592;return a}function VI(a,b){a=ud(a,b);x[a>>2]=117740;return a}function UI(a,b){a=ud(a,b);x[a>>2]=117856;return a}function TI(a,b){a=ud(a,b);x[a>>2]=117972;return a}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a,b,c,85)}function QI(a,b){a=ud(a,b);x[a>>2]=119160;return a}function Py(a){if(!a){return 0}x[31596]=a;return-1}function PI(a,b){a=ud(a,b);x[a>>2]=119280;return a}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;SG(a,b,c,48)}function $I(a,b){a=ud(a,b);x[a>>2]=115092;return a}function zsa(a,b){a=a|0;b=b|0;if(!AZ(a,b)){zZ(b)}}function ysa(a,b){a=a|0;b=b|0;return ai(a,b,78)|0}function yY(a){return(x[Ab(a)>>2]-x[a>>2]|0)/33|0}function xK(a){return(Jh(a)|0)!=0|(a|32)-97>>>0<6}function vq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function ue(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function sja(a,b){a=a|0;b=b|0;return ai(a,b,73)|0}function sZ(a){if(!(a&255)){return 1}return Sc(a)}function qha(a,b){a=a|0;b=b|0;return E(xm(a,b,6))}function qba(a,b){a=a|0;b=b|0;return+_M(a-92|0,b)}function ph(a,b){a=a|0;b=b|0;return YK(a)^YK(b)^1}function oqa(a,b){a=a|0;b=b|0;return ai(a,b,41)|0}function oba(a,b){a=a|0;b=b|0;return+YM(a-92|0,b)}function o1(a,b){a=a|0;b=b|0;rx(a,b,13,257,-1284)}function nZ(a,b){a=a|0;b=b|0;return RG(a,b,325)|0}function lu(a){return(x[Ab(a)>>2]-x[a>>2]|0)/52|0}function kja(a,b){a=a|0;b=b|0;return ai(a,b,60)|0}function kR(a,b){return(a|0)==1179011410&b>>>0>80}function ii(a,b){a=a|0;b=b|0;return PK(a)^PK(b)^1}function hga(a,b){a=a|0;b=b|0;return E(xm(a,b,2))}function gl(a){return(x[Ab(a)>>2]-x[a>>2]|0)/12|0}function fc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function epa(a,b){a=a|0;b=b|0;return ai(a,b,71)|0}function dha(a,b){a=a|0;b=b|0;return E(xm(a,b,5))}function d5(a,b){a=a|0;b=b|0;rx(a,b,13,290,-1332)}function aga(a,b){a=a|0;b=b|0;return E(xm(a,b,3))}function _m(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function ZN(a){x[a+4>>2]=0;x[a>>2]=47636;return a}function ZD(a){return(x[Ab(a)>>2]-x[a>>2]|0)/28|0}function Yqa(a,b){a=a|0;b=b|0;return ai(a,b,91)|0}function Yga(a,b){a=a|0;b=b|0;return E(xm(a,b,4))}function XW(a){return(x[Ab(a)>>2]-x[a>>2]|0)/56|0}function Tqa(a,b){a=a|0;b=b|0;if(!BY(a,b)){AY(b)}}function TE(a){return!hd(a,24528,25)&y[a+34|0]<65}function Sw(a){return(x[Ab(a)>>2]-x[a>>2]|0)/36|0}function SH(a){return(a<<1)+16777216>>>0<16777217}function Ol(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function O_(a){return(x[Ab(a)>>2]-x[a>>2]|0)/40|0}function N0(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a,b,c,18)}function Ms(a){return(x[Ab(a)>>2]-x[a>>2]|0)/24|0}function Gpa(a,b){a=a|0;b=b|0;if(!eE(a,b)){jE(b)}}function Cga(a,b){a=a|0;b=b|0;return E(xm(a,b,1))}function Cba(a,b){a=a|0;b=b|0;return+jN(a-88|0,b)}function Aja(a,b){a=a|0;b=b|0;if(!SF(a,b)){fx(b)}}function AE(a){return(x[Ab(a)>>2]-x[a>>2]|0)/20|0}function $s(a){return a-48>>>0<10|(a|32)-97>>>0<6}function vM(a,b){a=a|0;b=b|0;hl(a,b,74440,74448)}function uM(a,b){a=a|0;b=b|0;hl(a,b,74456,74464)}function tQ(a){a=a|0;cc(a+4208|0);return Vf(a)|0}function rM(a,b){a=a|0;b=b|0;hl(a,b,75260,75268)}function rB(a){return(x[Ab(a)>>2]-x[a>>2]|0)/7|0}function qM(a,b){a=a|0;b=b|0;hl(a,b,75276,75284)}function pz(a,b){x[a>>2]=x[b>>2];Zc(a+4|0,b+4|0)}function pw(a,b){a=a|0;b=b|0;if(!Ww(a,b)){Vw(b)}}function pM(a,b){a=a|0;b=b|0;hl(a,b,76088,76096)}function oM(a,b){a=a|0;b=b|0;hl(a,b,76104,76112)}function lM(a,b){a=a|0;b=b|0;hl(a,b,76916,76924)}function kM(a,b){a=a|0;b=b|0;hl(a,b,76932,76940)}function k0(a,b){a=a|0;b=b|0;if(!e0(a,b)){lE(b)}}function jd(a,b,c,d){return Vc(a,D(Nf(b),c)+d|0)}function gw(a,b){a=a|0;b=b|0;if(!up(a,b)){jp(b)}}function g$(a,b){a=M_(a,b);if(!a){UD(b)}return a}function du(a){a=a|0;sc(a+4208|0);return Vf(a)|0}function ci(a,b,c){return Fa(1018,a|0,b|0,c|0)|0}function c_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function bx(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function bp(a,b){a=a|0;b=b|0;if(!Yh(a,b)){dl(b)}}function _l(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function XP(a){a=a|0;sc(a+4256|0);return Vf(a)|0}function Sv(a){return(x[Ab(a)>>2]-x[a>>2]|0)/6|0}function QD(a,b){a=a|0;b=b|0;if(!__(a,b)){rr(b)}}function QC(a,b){a=a|0;b=b|0;if(!MY(a,b)){WC(b)}}function OE(a,b){a=IE(a,b);if(!a){xn(b)}return a}function Kn(a,b,c){a=Jd(a);x[a+4>>2]=c;x[a>>2]=b}function KZ(a,b){a=a|0;b=b|0;if(!JF(a,b)){Rr(b)}}function I_(a,b){a=a|0;b=b|0;if(!H_(a,b)){Rv(b)}}function GU(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function ES(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function EB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function Cda(a){a=a|0;return wH(a,47576,12589)|0}function y4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500288))}function w4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500296))}function vea(a,b,c){a=a|0;b=b|0;c=c|0;xO(a,b,c)}function u4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500240))}function s4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500248))}function qpa(a,b){a=a|0;b=b|0;Jp(a,b,652,651,8)}function qd(a,b){return Kq(x[b>>2],x[a>>2])?b:a}function q4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500256))}function oua(a,b,c){a=a|0;b=b|0;c=c|0;W$(a,b,c)}function oe(a,b){return al(z[a>>1],z[b>>1])?b:a}function o4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500264))}function nga(a){a=a|0;KP(a);Hz(a);v[a+4202|0]=1}function n4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500336))}function m4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500344))}function gca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function gL(a,b){if(!a){return 0}return My(a,b)}function fua(a,b){a=a|0;b=b|0;Jp(a,b,300,299,8)}function eL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function dta(a,b){a=a|0;b=b|0;Jp(a,b,365,364,8)}function dB(a){if(y[a+24|0]){PS(a);v[a+24|0]=0}}function bha(a){a=a|0;v[a+4202|0]=1;UP(a);WP(a)}function b0(a,b){return(b&255)==2&(a&255)>>>0<3}function _qa(a,b){a=a|0;b=b|0;Jp(a,b,523,522,6)}function _oa(a,b){a=a|0;b=b|0;Jp(a,b,685,684,8)}function _n(a){return ib[x[x[a>>2]+28>>2]](a)|0}function YX(a){var b=0;b=x[a>>2];je(a);return b}function Wga(a){a=a|0;v[a+4202|0]=1;SP(a);RP(a)}function We(a,b){return Kq(x[a>>2],x[b>>2])?b:a}function W4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500192))}function Vaa(a,b){a=a|0;b=b|0;Zc(a,aO(b,18251))}function T4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500200))}function S4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500396))}function S0(a,b){a=a|0;b=b|0;Fp(a,b);return a|0}function R4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500388))}function Qm(a,b){return zv(B[b>>2],B[a>>2])?b:a}function Q4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500404))}function O4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500412))}function N4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500420))}function Lz(a,b){return zv(B[a>>2],B[b>>2])?b:a}function Lk(a){return ib[x[x[a>>2]+36>>2]](a)|0}function Lc(a,b){return al(z[b>>1],z[a>>1])?b:a}function LI(a){var b=0,c=0;b=a,c=Kd(),x[b>>2]=c}function L4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500436))}function K4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500428))}function J4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500444))}function H4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500452))}function Gb(a,b){return Rq(x[b>>2],x[a>>2])?b:a}function F4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500460))}function D4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500272))}function Bv(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function Bda(a){a=a|0;return wH(a,47596,8191)|0}function A4(a,b){a=a|0;b=b|0;_c(a,b,Tc(500280))}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;ce(a,b,c)}function $c(a,b){return Rq(x[a>>2],x[b>>2])?b:a}function ys(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function yka(a,b){a=a|0;b=b|0;return Ny(a,b)|0}function tea(a){a=a|0;return DH(a,6626,1070)|0}function qi(a,b){return(D(b,104)+a|0)+484380|0}function ppa(a,b){a=a|0;b=b|0;return jX(a,b)|0}function n3(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,c,b)}function lm(a){return(a>>>0<=127?-1:a^128)&255}function lZ(a,b,c){a=a|0;b=b|0;c=c|0;c0(a,b,c)}function kf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function kU(a){zB(a);Tb(a+27|0,0,255);return a}function iP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function fca(a){a=a|0;return x[x[a+4>>2]+8>>2]}function f$(a,b,c){a=a|0;b=b|0;c=c|0;f0(a,b,c)}function caa(a){a=a|0;x[a>>2]=77456;return a|0}function cE(a,b,c){a=a|0;b=b|0;c=c|0;D$(a,b,c)}function Zia(a,b){a=a|0;b=b|0;AA(aR(a+24|0,b))}function Yi(a,b){return y[a+b|0]!=63&b>>>0<=46}function Sn(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function Pm(a){a=Ij(a);x[a>>2]=124900;return a}function P3(a,b,c){a=a|0;b=b|0;c=c|0;iI(a,b,c)}function Nu(a){return(a>>>0<9?a:a-9|256)&65535}function Lea(a){a=a|0;return DH(a,7109,1062)|0}function Kv(a,b){return y[a+b|0]!=63&b>>>0<=15}function Jg(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Jda(a,b){a=a|0;b=b|0;return Lw(a,b)|0}function Gf(a,b,c){if(!(y[a|0]&32)){$D(b,c,a)}}function Ft(a,b){return(a&255)>>>0<(b&255)>>>0}function Bg(a,b,c){a=Aua(a,b,c,c>>31);return a}function yt(a){a=DL(a);x[a>>2]=94792;return a}function xi(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function vca(a,b){a=a|0;b=b|0;vO(a,x[b+4>>2])}function uca(a,b){a=a|0;b=b|0;XO(a,x[b+4>>2])}function uc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function r1(a){a=a|0;x[a>>2]=41416;return a|0}function p1(a){a=a|0;x[a>>2]=41176;return a|0}function osa(a,b){a=a|0;b=b|0;ux(a,b,17,3,16)}function oca(a,b){a=a|0;b=b|0;AO(a,x[b+4>>2])}function ny(a,b,c){a=fK(a,b,c,-1,-1);return a}function nca(a,b){a=a|0;b=b|0;uO(a,x[b+4>>2])}function nW(a){return Xe(443250/+(a>>>0)*1e4)}function m_(a){a=(a&65535)-98|0;hb=0;return a}function laa(a,b){a=a|0;b=b|0;pH(a,b,1160,52)}function lP(a,b){a=a|0;b=b|0;return aO(a,b)|0}function ida(a,b){a=a|0;b=b|0;zz(x[a+4>>2],b)}function ica(a,b){a=a|0;b=b|0;IO(a,x[b+4>>2])}function iaa(a){a=a|0;fM(a);return x[a+16>>2]}function iJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function h0(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function en(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function d$(a){v[a+12|0]=y[a+12|0]|2;return a}function cua(a,b){a=a|0;b=b|0;ux(a,b,44,2,44)}function b2(a,b){a=a|0;b=b|0;return hx(a,b)|0}function af(a,b){return Ft(y[a|0],y[b|0])?b:a}function _K(a){a=a|0;Iy(x[x[a>>2]-12>>2]+a|0)}function Yt(a,b){a=a|0;b=b|0;return gg(a,b)|0}function X9(a){a=a|0;x[a>>2]=76956;return a|0}function Vsa(a,b){a=a|0;b=b|0;YG(a,b,369,368)}function V9(a,b){a=a|0;b=b|0;pH(a,b,1164,308)}function UK(a){a=a|0;Gy(x[x[a>>2]-12>>2]+a|0)}function Tz(a){return x[Ab(a)>>2]-x[a>>2]>>11}function Sb(a,b){return Ft(y[b|0],y[a|0])?b:a}function R9(a){a=a|0;x[a>>2]=78264;return a|0}function Qt(a){a=a|0;x[a>>2]=48444;return a|0}function Qf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function O8(a){a=a|0;LK(x[x[a>>2]-12>>2]+a|0)}function MW(a){a=zua(a&65535,0,80,0);return a}function M9(a){a=a|0;x[a>>2]=77876;return a|0}function M8(a){a=a|0;KK(x[x[a>>2]-12>>2]+a|0)}function Lta(a,b){a=a|0;b=b|0;YG(a,b,309,308)}function Jd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function D1(a){a=a|0;x[a>>2]=78536;return a|0}function Bca(a,b){a=a|0;b=b|0;CO(a,x[b+4>>2])}function BK(a){a=DL(a);x[a>>2]=95184;return a}function z6(a){a=a|0;_c(a,501744,Tc(500420))}function yca(a){a=a|0;return DO(x[a+4>>2])|0}function y6(a){a=a|0;_c(a,501752,Tc(500436))}function xp(a,b,c,d){a=Aua(a,b,c,d);return a}function x6(a){a=a|0;_c(a,501760,Tc(500428))}function w6(a){a=a|0;_c(a,501768,Tc(500444))}function vk(a){a=a&255;return(a|0)==255?-1:a}function v6(a){a=a|0;_c(a,501776,Tc(500452))}function u9(a){a=a|0;return Ba(x[a+60>>2])|0}function u6(a){a=a|0;_c(a,501800,Tc(500460))}function t6(a){a=a|0;_c(a,501832,Tc(500208))}function s6(a){a=a|0;_c(a,501840,Tc(500216))}function r6(a){a=a|0;_c(a,501848,Tc(500224))}function q6(a){a=a|0;_c(a,501856,Tc(500232))}function p6(a){a=a|0;_c(a,501864,Tc(500272))}function o6(a){a=a|0;_c(a,501872,Tc(500280))}function n6(a){a=a|0;_c(a,501880,Tc(500288))}function m6(a){a=a|0;_c(a,501888,Tc(500296))}function lca(a){a=a|0;return PO(x[a+4>>2])|0}function l6(a){a=a|0;_c(a,501896,Tc(500304))}function k6(a){a=a|0;_c(a,501904,Tc(500312))}function jaa(a){a=a|0;fM(a);return x[a+4>>2]}function j6(a){a=a|0;_c(a,501912,Tc(500320))}function i6(a){a=a|0;_c(a,501920,Tc(500328))}function hY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function h6(a){a=a|0;_c(a,501928,Tc(500240))}function g6(a){a=a|0;_c(a,501944,Tc(500248))}function e6(a){a=a|0;_c(a,501960,Tc(500256))}function c6(a){a=a|0;_c(a,501976,Tc(500264))}function b6(a){a=a|0;_c(a,501992,Tc(500336))}function _e(a,b,c,d){ac(a,jd(b,c,d,0),Nf(c))}function _H(a,b,c){a=a|0;b=b|0;c=c|0;JK(a,c)}function XB(a){return x[Ab(a)>>2]-x[a>>2]>>8}function WY(a,b,c){fc(a,b,Ii(b,b+c|0,0)-b|0)}function Uu(a){return x[Ab(a)>>2]-x[a>>2]>>4}function UA(a){v[a+24|0]=0;v[a|0]=0;return a}function Tq(a,b){return D((b-a|0)/6|0,6)+a|0}function Rg(a){return x[Ab(a)>>2]-x[a>>2]>>2}function Qo(a){return x[Ab(a)>>2]-x[a>>2]>>5}function Pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Ph(a){return x[x[a+8>>2]>>2]==(a|0)}function Mn(a){return x[Ab(a)>>2]-x[a>>2]>>3}function Jz(a){return E(E(a*E(7900))+E(100))}function Iz(a){return x[zc(a)>>2]-x[a>>2]>>2}function G6(a){a=a|0;_c(a,501680,Tc(500192))}function F6(a){a=a|0;_c(a,501688,Tc(500200))}function E6(a){a=a|0;_c(a,501696,Tc(500396))}function D6(a){a=a|0;_c(a,501712,Tc(500388))}function Cn(a){return x[Ab(a)>>2]-x[a>>2]>>1}function Ck(a){return KG(a,E(4294967296),-1)}function C6(a){a=a|0;_c(a,501720,Tc(500404))}function Bb(a,b){if(!Cd(b)){a=Rh(b)}return a}function A6(a){a=a|0;_c(a,501728,Tc(500412))}function vn(a,b,c){return aj(a,b)>>>0>c>>>0}function qy(){da(Pm($b(4))|0,124984,34);p()}function pU(a,b){x[a>>2]=x[a>>2]+b;return a}function oia(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function mB(a){v[a+4|0]=0;v[a|0]=0;return a}function cu(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function ao(a){a=a|0;OK(x[a>>2]);return a|0}function a6(a){a=a|0;_c(a,502e3,Tc(500344))}function X3(a,b){a=a|0;b=b|0;return ty(b)|0}function Wo(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function V3(a,b){a=a|0;b=b|0;return uy(b)|0}function So(a){return x[Ab(a)>>2]-x[a>>2]|0}function Sl(a,b){return Jq(z[a>>1],z[b>>1])}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a)}function LO(a){return A[a+1074420>>2]/1e4|0}function Ki(a,b){a=a|0;b=b|0;return E(E(0))}function Jq(a,b){return a<<16>>16<b<<16>>16}function Jf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Dw(a,b){if(b){Cc(a,b);return}Fb(a)}function Cm(a){a=a|0;Hy(x[a>>2]);return a|0}function zU(a){x[a>>2]=x[a>>2]-32;return a}function wba(a,b){a=a|0;b=b|0;dN(a-88|0,b)}function voa(a,b){a=a|0;b=b|0;UG(a,b,2,31)}function um(a){x[a>>2]=x[a>>2]-12;return a}function tn(a){x[a>>2]=x[a>>2]+28;return a}function tba(a,b){a=a|0;b=b|0;cN(a-92|0,b)}function sba(a,b){a=a|0;b=b|0;bN(a-92|0,b)}function ry(a){a=a|0;return Sh(a,500452)|0}function rf(a,b,c){a=zua(c,0,a,b);return a}function qz(a){x[a>>2]=x[a>>2]-16;return a}function o_(a){x[a>>2]=x[a>>2]-20;return a}function nL(a,b){return E(mx(a?E(-b):b)*b)}function lD(a){a=a|0;return Sh(a,500412)|0}function kw(a){a=a|0;return Sh(a,500396)|0}function kv(a){yf(a+24|0);cc(a+12|0);cc(a)}function kn(a){x[a>>2]=x[a>>2]+52;return a}function kl(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function jy(a){a=a|0;return Sh(a,500460)|0}function jn(a){NB(x[a+20>>2]);x[a+20>>2]=0}function jl(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function jca(a){a=a|0;return+JO(x[a+4>>2])}function id(a,b){a=a|0;b=b|0;xO(a,b,gf(b))}function i9(a){a=a|0;return Sh(a,500208)|0}function h4(a){a=a|0;qs(a,165,125344,1194)}function fI(a){a=a|0;return gH(a,118400)|0}function eI(a){a=a|0;return gH(a,118296)|0}function dI(a){a=a|0;return fH(a,118192)|0}function cv(a){x[a>>2]=x[a>>2]+32;return a}function cI(a){a=a|0;return fH(a,118088)|0}function b9(a){a=a|0;return Sh(a,500224)|0}function _v(a){x[a>>2]=x[a>>2]-28;return a}function Zn(a){a=a|0;qs(a,165,125344,1059)}function Yta(a,b){a=a|0;b=b|0;ew(a+36|0,b)}function Yf(a){x[a>>2]=x[a>>2]+20;return a}function XQ(a){x[a>>2]=x[a>>2]-52;return a}function VW(a){x[a>>2]=x[a>>2]-56;return a}function Uq(a){x[a>>2]=x[a>>2]+12;return a}function UV(a,b,c,d){fc(a,b,(d|0)==-1?c:d)}function UF(a){x[a>>2]=x[a>>2]-36;return a}function Tr(a){as(a+32|0);ub(a+12|0);tb(a)}function Qja(a,b){a=a|0;b=b|0;ds(a+40|0,b)}function Ns(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function Lq(a){x[a>>2]=x[a>>2]+16;return a}function Lba(a,b){a=a|0;b=b|0;tN(a-88|0,b)}function Kba(a,b){a=a|0;b=b|0;sN(a-88|0,b)}function J1(a){a=a|0;return x[a+4>>2]!=0|0}function Fl(a){tb(a+36|0);sc(a+24|0);Ok(a)}function FS(a,b){return dH(a,b,2147483647)}function Ey(a){a=a|0;return Sh(a,500388)|0}function Eg(a){return E(F(a))==E(Infinity)}function CP(a){return E(E(a*E(96))+E(-96))}function By(a){a=a|0;return Sh(a,500404)|0}function Bt(a){return(a|0)<=65535&(a|0)>=0}function yta(a,b){a=a|0;b=b|0;UG(a,b,3,8)}function yJ(a,b){a=a|0;b=b|0;Sp(a,b+40|0)}function xq(a,b){v[a|0]=b+48;return a+1|0}function xg(a,b,c){Qi(b,b+c|0,a);return a}function xJ(a,b){a=a|0;b=b|0;Sp(a,b+52|0)}function x5(a,b){a=a|0;b=b|0;nn(a,113368)}function wha(a){a=a|0;v[a+4202|0]=1;gQ(a)}function we(a){return Cb(a&65535)<<16>>16}function w5(a,b){a=a|0;b=b|0;nn(a,113388)}function vba(a){a=a|0;return dq(a-92|0)|0}function tl(a){a=a|0;return ZK(a)<<24>>24}function sga(a){a=a|0;return x[a+4260>>2]}function qg(a){x[a>>2]=x[a>>2]+6;return a}function pt(a){a=a|0;ul(a+8|0);return a|0}function ot(a){a=a|0;ul(a+4|0);return a|0}function nba(a){a=a|0;return dq(a-96|0)|0}function msa(a,b){a=a|0;b=b|0;Ai(a,b,282)}function ms(a,b){x[a>>2]=b;el(b);return a}function lba(a,b){a=a|0;b=+b;XM(a-96|0,b)}function kB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function je(a){x[a>>2]=x[a>>2]+1;return a}function dz(a,b,c){fc(a,(c<<12)+b|0,4096)}function dq(a){a=a|0;iq(a+8|0);return a|0}function cz(a,b){a=a|0;b=b|0;gg(a,b+36|0)}function cN(a,b){a=a|0;b=b|0;sH(a,b,2048)}function by(a,b){a=a|0;b=b|0;gg(a,b+12|0)}function bN(a,b){a=a|0;b=b|0;sH(a,b,4096)}function Tta(a,b){a=a|0;b=b|0;Ai(a,b,136)}function Tg(a,b,c){Hk(b,b+c|0,a);return a}function Sm(a){return E(F(a))<E(Infinity)}function Pe(a){x[a>>2]=x[a>>2]+4;return a}function Ou(a){Nm(a,Mo(a),78768);return a}function Od(a){x[a>>2]=x[a>>2]+2;return a}function Nba(a){a=a|0;return dq(a-88|0)|0}function Lf(a){a=a|0;Zh(a+8|0);return a|0}function LH(a){a=Da(a|0)|0;hb=gb;return a}function KO(a){return+A[a+1074420>>2]/1e4}function Ju(a){x[a>>2]=x[a>>2]+8;return a}function Jba(a,b){a=a|0;b=+b;rN(a-88|0,b)}function Hba(a,b){a=a|0;b=+b;pN(a-88|0,b)}function Fpa(a,b){a=a|0;b=b|0;Ai(a,b,274)}function Fba(a,b){a=a|0;b=+b;nN(a-88|0,b)}function FQ(a){x[a>>2]=x[a>>2]-4;return a}function EJ(a,b){a=a|0;b=b|0;gg(a,b+24|0)}function E9(a,b){a=a|0;b=b|0;om(a,b+12|0)}function DP(a){a=a|0;Tb(a+4296|0,0,81928)}function DJ(a,b){a=a|0;b=b|0;gg(a,b+48|0)}function Apa(a,b){a=a|0;b=b|0;Ai(a,b,106)}function AJ(a,b){a=a|0;b=b|0;Sp(a,b+28|0)}function $x(a,b){a=a|0;b=b|0;gg(a,b+16|0)}function $v(a){x[a>>2]=x[a>>2]-2;return a}function ypa(a,b){a=a|0;b=b|0;Ai(a,b,72)}function v5(a,b){a=a|0;b=b|0;Cc(a,11280)}function u5(a,b){a=a|0;b=b|0;Cc(a,11397)}function tw(a,b,c,d,e){cH(a,b,c,d,e,128)}function ql(a){return(a|0)==32|a-9>>>0<5}function nsa(a,b){a=a|0;b=b|0;Br(a,b,17)}function nia(a){a=a|0;return y[a+4201|0]}function nY(a,b){a=a|0;b=b|0;Ai(a,b,284)}function mia(a){a=a|0;return y[a+4202|0]}function mf(a,b){x[a+8>>2]=b|-2147483648}function lt(a,b){x[a+24>>2]=x[a+24>>2]+b}function kK(a){return a-97>>>0<26?a&95:a}function kG(a,b){wc(a,b);wc(a+4|0,b+4|0)}function jg(a,b){a=Aua(0,a,b,0);return a}function jK(a){return a-65>>>0<26?a|32:a}function go(a,b,c){return ib[c|0](a,b)|0}function ge(a,b){return(b|0)!=0&(a|0)!=0}function gc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function ej(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function bl(a){return D(Dn(a),Yd(a))&255}function aua(a,b){a=a|0;b=b|0;_G(a,b,28)}function _sa(a,b){a=a|0;b=b|0;Ai(a,b,34)}function Ufa(a){a=a|0;return(a|0)==277|0}function Hx(a){return a-502192>>>2&65535}function Fr(a,b,c,d,e){cH(a,b,c,d,e,256)}function Fj(a){w[a+4>>1]=65535;x[a>>2]=0}function Eqa(a,b){a=a|0;b=b|0;Ai(a,b,42)}function DZ(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function yS(a,b){return(Pl(a,b)|0)!=255}function wX(a,b){a=a|0;b=b|0;return b|0}function w$(a,b){x[a>>2]=x[a>>2]+(b<<1)}function tI(a){a=a|0;return rd(a-8|0)|0}function sI(a){a=a|0;return Qx(a-8|0)|0}function rm(a){a=x[a+8>>2];if(a){Db(a)}}function ri(a){return(a&65535)>>>0<3999}function rI(a){a=a|0;return Px(a-8|0)|0}function qI(a){a=a|0;return Ox(a-8|0)|0}function pD(a){return PG(a,65535,65535)}function p0(a,b){a=a|0;b=b|0;Br(a,b,11)}function oI(a){a=a|0;return Nx(a-8|0)|0}function nI(a){a=a|0;return Mx(a-8|0)|0}function mS(a,b,c,d){return Qp(a,b,c,d)}function mI(a){a=a|0;return Lx(a-8|0)|0}function lB(a,b,c){return a<b?b:a>c?c:a}function hZ(a,b){a=a|0;b=b|0;Br(a,b,32)}function fY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function d3(a){a=a|0;if(a){ZH(Ct(a),1)}}function cga(a){a=a|0;return-2013527448}function _s(a){return(a|0)==32|(a|0)==9}function XH(a){return(z[a+2>>1]<<2)+a|0}function Wg(a,b,c){v[a+4|0]=c;x[a>>2]=b}function VO(a,b){return CH(a,b,1075834)}function TO(a,b){return BH(a,b,1075834)}function T$(a,b){return(a&255)==(b&255)}function Sqa(a,b){a=a|0;b=b|0;nE(a,b,8)}function SW(a,b,c,d){return en(c,d,a,b)}function SO(a,b){return BH(a,b,1075835)}function RO(a,b){return CH(a,b,1075835)}function Qy(a){return(q(a),j(2))>>>20|0}function L$(a,b){a=a|0;b=b|0;Ai(a,b,50)}function Iv(a,b,c){return a<b?b:a>c?c:a}function Iba(a){a=a|0;return+qN(a-88|0)}function Hj(a,b){return bB(a&255,b&255)}function HJ(a,b){a=a|0;b=b|0;of(a,1,45)}function Gba(a){a=a|0;return+oN(a-88|0)}function GJ(a,b){a=a|0;b=b|0;ey(a,1,45)}function Eba(a){a=a|0;return+mN(a-88|0)}function Cb(a){return(a<<8|a>>>8)&65535}function CK(a){x[a+4>>2]=x[a+4>>2]|8192}function C0(a,b){a=a|0;b=b|0;Ai(a,b,59)}function yj(a,b){x[a+4>>2]=1;x[a>>2]=b}function yQ(a){a=a|0;return 1869112133}function xh(a){return KG(a,E(255),255)}function wJ(a){a=a|0;return x[a+64>>2]}function v1(a){a=a|0;return x[a+16>>2]}function tga(a){a=a|0;return-275227023}function sha(a){a=a|0;return-270114148}function rP(a,b,c){return NG(a,b,c,70)}function pk(a,b){x[a+4>>2]=2;x[a>>2]=b}function ow(a,b,c){return Gp(a,b,c,20)}function lna(a){a=a|0;HW(a);return a|0}function le(a,b,c){mo(a,b,Rc(b,c)+b|0)}function lX(a,b){a=a|0;b=b|0;_G(a,b,4)}function l4(a,b){a=a|0;b=b|0;iH(a,b,0)}function kga(a){a=a|0;return 302837129}function k4(a,b){a=a|0;b=b|0;iH(a,b,1)}function j4(a,b){a=a|0;b=b|0;hH(a,b,0)}function j2(a,b){a=a|0;b=b|0;ks(a,1,b)}function i4(a,b){a=a|0;b=b|0;hH(a,b,1)}function gx(a,b){x[a+4>>2]=3;x[a>>2]=b}function gha(a){a=a|0;return-285139079}function gJ(a,b,c){return Gp(a,b,c,24)}function fv(a,b,c){return Gp(a,b,c,12)}function fia(a){a=a|0;return 542066252}function ee(a){x[x[a+8>>2]>>2]=x[a>>2]}function eaa(a){a=a|0;return y[a+40|0]}function ay(a){a=a|0;return x[a+12>>2]}function _ga(a){a=a|0;return-284078960}function Xfa(a,b){a=a|0;b=b|0;return 3}function Vfa(a,b){a=a|0;b=b|0;return 2}function U_(a,b,c){return Gp(a,b,c,40)}function Tga(a){a=a|0;return-281111764}function Td(a,b){return Jb(a)+(b<<2)|0}function Rx(a,b){x[a+4>>2]=4;x[a>>2]=b}function Ps(a){a=a|0;return 2147483647}function Mga(a){a=a|0;return-271958638}function KM(a){return a?(a|0)==2?3:2:1}function Ij(a){x[a>>2]=125596;return a}function Hu(a,b,c){kg(a,c);ed(b+c|0,0)}function Ega(a){a=a|0;return-620920304}function Cu(a,b){return bH(a,b,-1,0,0)}function CZ(a,b,c){_l(a,b&65535,c&255)}function CJ(a){a=a|0;return x[a+60>>2]}function z8(a){a=a|0;return zK(a,1)|0}function yE(a,b){xs(a,b,20,214748365)}function xka(a,b){a=a|0;b=b|0;ur(a,b)}function xP(a){return Wi(zP(a)*32768)}function wM(a){x[a>>2]=74424;return a}function vi(a,b,c){return Ip(a,b,c,1)}function uz(a){x[a>>2]=48280;return a}function tz(a){x[a>>2]=48304;return a}function th(a,b,c){return Ip(a,b,c,2)}function t8(a){a=a|0;return yK(a,0)|0}function sz(a){x[a>>2]=48384;return a}function sp(a,b,c){return vx(a,b,c,1)}function sV(a,b,c){return vx(a,b,c,5)}function sP(a,b){a=a|0;b=b|0;return 0}function s8(a){a=a|0;return yK(a,1)|0}function rz(a){x[a>>2]=48424;return a}function qt(a,b){a=a|0;b=b|0;return-1}function qr(a,b,c){return Gp(a,b,c,6)}function qn(a){return(a&740327453)!=0}function oka(a,b){a=a|0;b=b|0;aU(a,b)}function nka(a,b){a=a|0;b=b|0;MS(a,b)}function nV(a){return(a&65535)==65534}function lT(a,b){return(0-b|0)!=(a|0)}function il(a){a=x[a>>2];if(a){pl(a)}}function iR(a,b){Wc(a,b&4?16:8,1,0,0)}function fP(a){a=a|0;GH(a,47440,1007)}function dt(a){return(uy(a)|0)!=(a|0)}function ct(a){return(ty(a)|0)!=(a|0)}function cla(a,b){a=a|0;b=b|0;Ub(a,b)}function ap(a,b){w[a+8>>1]=b;return a}function aj(a,b){return Uk(a,b)&65535}function aO(a,b){return rt(a,b,gf(b))}function aG(a,b,c){ac(a,b,fh(b,c)<<3)}function _r(a){a=a|0;return x[a+4>>2]}function _X(a){HL(a);He(x[a+80>>2],a)}function Zr(a){a=a|0;return x[a+8>>2]}function WB(a,b,c){return Ip(a,b,c,5)}function Vr(a,b,c){return Ip(a,b,c,3)}function Vi(a,b,c){NC(b,c,a);return a}function Ve(a,b){x[a+4>>2]=b;return a}function UH(a){a=E(a-a);return E(a/a)}function Tu(a,b,c){return Ip(a,b,c,4)}function Tl(a,b){return v[a|0]<v[b|0]}function Qz(a,b){a=a|0;b=b|0;return 1}function QO(a){return z[a+1074448>>1]}function Pta(a,b){a=a|0;b=b|0;Ny(a,b)}function Nj(a){return(a-1&255)>>>0<17}function NO(a){return x[a+1074424>>2]}function NC(a,b,c){Hk(a,(b<<2)+a|0,c)}function MO(a){return x[a+1074416>>2]}function Jn(a){x[a>>2]=77408;return a}function Jha(a,b){a=a|0;b=b|0;VE(a,b)}function Hh(a){a=x[a>>2];if(a){hK(a)}}function Gi(a,b,c){Zc(Zc(a,b)+12|0,c)}function GY(a,b,c){ac(a,b,nc(b,c)<<2)}function Fz(a){a=a|0;GH(a,47496,1009)}function EW(a){return(a|0)>=120?120:a}function DL(a){x[a>>2]=94820;return a}function DG(a,b){xs(a,b,12,357913942)}function Bn(a,b,c){return vx(a,b,c,2)}function AM(a){x[a>>2]=48764;return a}function A8(a){a=a|0;return zK(a,0)|0}function zga(a){a=a|0;x[a+4224>>2]=0}function yh(a){lf(a+52|0);cc(a+40|0)}function xQ(a,b,c){a=a|0;b=b|0;c=c|0}function wV(a,b){wx(a,b,4,268435456)}function wO(a){return x[a+480272>>2]}function vf(a){return F(a)==Infinity}function vC(a,b){if(!FX(a,b)){AX(b)}}function ur(a,b){a=a|0;b=b|0;Pf(a,b)}function uka(a){a=a|0;return gh(a)|0}function tV(a,b){wx(a,b,5,134217728)}function sd(a,b){return D(b,160)+a|0}function s2(a,b){a=a|0;b=b|0;sx(a,b)}function mta(a){a=a|0;return y_(a)|0}function k2(a,b){a=a|0;b=b|0;ls(a,b)}function hq(a){return z[a+480192>>1]}function fq(a){return z[a+480190>>1]}function el(a){x[a+4>>2]=x[a+4>>2]+1}function dy(a){a=a|0;return v[a+8|0]}function d2(a,b){a=a|0;b=b|0;Dp(a,b)}function cy(a){a=a|0;return v[a+9|0]}function ZQ(a,b){xs(a,b,52,82595525)}function ZF(a,b){wx(a,b,3,536870912)}function Y3(a,b){a=a|0;b=b|0;Lw(a,b)}function Xk(a,b){a=a|0;b=b|0;om(a,b)}function VS(a){return(a+5&255)>>>0<2}function VE(a,b){a=a|0;b=b|0;NZ(a,b)}function Uy(a){return!hd(a,125912,6)}function Un(a,b){a=a|0;b=b|0;Xk(a,b)}function TV(a,b){return D(b,872)+a|0}function TQ(a,b){return Fk(a,b-a>>2)}function T1(a,b){a=a|0;b=b|0;Un(a,b)}function Ssa(a){a=a|0;return Dc(a)|0}function SB(a,b,c,d,e){jU(a,b,c,d,e)}function Ru(a){return x[Ab(a)>>2]<<5}function RY(a,b){xs(a,b,6,715827883)}function RB(a,b){a=a|0;b=b|0;XU(a,b)}function Pf(a,b){a=a|0;b=b|0;gg(a,b)}function OO(a){return z[a+480214>>1]}function Nf(a){return z[a+480188>>1]}function Kja(a){a=a|0;return Ni(a)|0}function Ix(a){return(a<<2)+502192|0}function Isa(a){a=a|0;return rD(a)|0}function Hr(a,b){a=a|0;b=b|0;Qw(a,b)}function H9(a,b){a=a|0;b=b|0;Yt(a,b)}function DD(a,b,c){zb(zb(a,b)+4|0,c)}function CW(a){return(a&255)>>>0<129}function AP(a){x[a>>2]=0;x[a+4>>2]=0}function $j(a,b){a=a|0;b=b|0;m$(a,b)}function $9(a){a=a|0;return y[a+8|0]}function zb(a,b){x[a>>2]=b;return a}function yv(a,b){return(b-a|0)/33|0}function wF(a){a=a|0;return dh(a)|0}function vr(a,b){return(b-a|0)/28|0}function uw(a,b){w[a>>1]=b;return a}function uq(a){if(y[a+24|0]){PS(a)}}function su(a){return!(a&204473357)}function sf(a,b){return D(b,24)+a|0}function rl(a,b,c){return aK(a,b,c)}function qca(a,b){a=a|0;b=b|0;GO(a)}function pr(a,b){return(b-a|0)/40|0}function pe(a,b){return Ec(a,ie(b))}function n1(a){a=a|0;TF(Tb(a,0,36))}function m$(a,b){h$(a,x[a+16>>2]|b)}function lj(a,b){return(b-a|0)/24|0}function l1(a){a=a|0;return Zh(a)|0}function kx(a,b,c){return hd(a,b,c)}function kc(a,b){return(a|0)==(b|0)}function kF(a){a=a|0;return Xd(a)|0}function kC(a,b){return D(b,56)+a|0}function jv(a,b){return(b-a|0)/56|0}function hW(a){if(!y[a+4|0]){gW(a)}}function hA(a,b){return D(b,28)+a|0}function gD(a,b,c){return St(a,b,c)}function fm(a,b){return em(Yc(a,b))}function dv(a,b){return D(b,36)+a|0}function dj(a,b){return D(b,52)+a|0}function cm(a){if(!y[a+4|0]){Z_(a)}}function bJ(a){if(!y[a+4|0]){OI(a)}}function _g(a){if(!y[a+4|0]){GQ(a)}}function Xq(a){return(a&255)==1?1:2}function XY(a,b,c){return Qi(a,b,c)}function XL(a){if(!y[a+4|0]){MH(a)}}function Wj(a){if(!y[a+4|0]){yF(a)}}function Wb(a,b){return Me(a,b&255)}function WX(a){if(!y[a+4|0]){SX(a)}}function WM(a){if(!y[a+4|0]){VM(a)}}function WK(a){a=a|0;return ul(a)|0}function W8(a){a=a|0;return sl(a)|0}function Ur(a,b){return(b-a|0)/36|0}function Uk(a,b){return(b-a|0)/52|0}function Uia(a){a=a|0;Br(a,22250,1)}function TT(a){if(!y[a+4|0]){VV(a)}}function Rq(a,b){return a>>>0<b>>>0}function Ri(a,b,c){return $h(a,b,c)}function Rd(a,b){return(b-a|0)/12|0}function Rba(a,b){a=a|0;b=b|0;WO(a)}function Qx(a){a=a|0;return a+184|0}function Px(a){a=a|0;return a+472|0}function Pg(a,b){return(a|0)!=(b|0)}function P1(a){a=a|0;return Mg(a)|0}function Ox(a){a=a|0;return a+496|0}function Nx(a){a=a|0;return a+508|0}function N6(a){a=a|0;return Zx(a)|0}function Mx(a){a=a|0;return a+520|0}function Mf(a,b){return(b-a|0)/20|0}function MV(a){if(!y[a+4|0]){LV(a)}}function M$(a){a=a|0;return Nw(a)|0}function Lx(a){a=a|0;return a+532|0}function Ku(a){if(!y[a+4|0]){oG(a)}}function Kj(a,b){return Gg(a,b)&255}function HK(a){a=a|0;return _w(a)|0}function HC(a,b){return Ne(a,0-b|0)}function Gw(a){v[a+2|0]=0;w[a>>1]=0}function FV(a){if(!y[a+4|0]){EV(a)}}function El(a){return W_(a,251,255)}function ED(a,b){return Ne(a,b-a|0)}function Dd(a,b){return D(b,12)+a|0}function DY(a,b){return D(b,33)+a|0}function CE(a){if(!y[a+4|0]){BE(a)}}function Aka(a){a=a|0;JH(a,118,117)}function Ae(a,b,c){return cK(a,b,c)}function $l(a){return PG(a,255,255)}function $i(a){if(!y[a+4|0]){aZ(a)}}function $g(a,b){return D(b,20)+a|0}function zl(a,b){return(a+b|0)-1|0}function x9(a,b){a=a|0;b=b|0;Db(b)}function u$(a,b){return Vl(a,b,28)}function sJ(a){return Sh(a,500280)}function rd(a){a=a|0;return a+16|0}function rJ(a){return Sh(a,500272)}function qB(a,b){return(b-a|0)/7|0}function ox(a,b){return Vl(a,b,12)}function oo(a,b){x[a+1298472>>2]=b}function ol(a){return(a&255)>>>0>1}function oJ(a){return Sh(a,500296)}function nJ(a){return Sh(a,500288)}function ky(a,b){return!(b>>>31|0)}function kI(a){C[(fb-16|0)+8>>3]=a}function jp(a){v[a|0]=0;v[a+1|0]=0}function gu(a,b){return(a-b|0)/6|0}function gF(a){return(a&255)+704|0}function fi(a,b){a=a|0;b=b|0;Fb(a)}function bj(a){return a&2147483647}function Yoa(a){a=a|0;lY(a,65535)}
function YF(a,b){return Vl(a,b,36)}function WS(a){ze(a+8|0);OS(a+4|0)}function Vc(a,b){return D(b,6)+a|0}function Sk(a,b){return D(bl(b),a)}function Or(a,b){return(b<<11)+a|0}function Kq(a,b){return(a|0)<(b|0)}function Kk(a,b){return(b-a|0)/6|0}function Ji(a){a=a|0;v[a+4202|0]=0}function Ho(a,b){return(b<<13)+a|0}function GM(a){return(vk(a)|0)==-1}function FM(a,b){a=a|0;b=b|0;cc(b)}function EM(a,b){a=a|0;b=b|0;Um(b)}function Cy(a){return kc(a,-1)?0:a}function Cd(a){return(a&128)>>>7|0}function Bc(a,b){return dH(a,b,-1)}function BY(a,b){return tx(a,b,18)}function AZ(a,b){return tx(a,b,56)}function $p(a,b){v[a|0]=b;return a}function zF(a){return(a&16)>>>4|0}function yo(a){return a+1074328|0}function xb(a,b){return(b<<2)+a|0}function wt(a){return HG(a,93496)}function sn(a){x[a>>2]=2;return a}function qc(a){x[a>>2]=0;return a}function oz(a,b){return pR(a,b)^1}function k3(a){a=a|0;return 13206}function jta(a){a=a|0;dg(a,3872)}
function i3(a){a=a|0;return 10286}function fr(a,b){return ke(a,b)^1}function eO(a,b){x[a+480272>>2]=b}function e$(a){qs(a,17,125224,33)}function bqa(a){a=a|0;dg(a,16824)}function bn(a,b){return(b<<8)+a|0}function bc(a,b){return Jb(a)+b|0}function ae(a){return x[dc(a)>>2]}function Zb(a,b){return(b<<1)+a|0}function Yja(a){a=a|0;sg(a,Lj(a))}function Xs(a,b){return cK(a,0,b)}function Xf(a){return a!=a?E(0):a}function Wz(a){x[a>>2]=x[a>>2]+24}function WL(a){return a+1298412|0}function Vh(a){x[a>>2]=1;return a}function Vd(a,b){return(b<<4)+a|0}function UB(a,b){return Vl(a,b,4)}function Sc(a){return W_(a,1,120)}function SK(a){return HG(a,93560)}function Re(a,b){return(b<<3)+a|0}function O2(a){a=a|0;return 13092}function NB(a){if(a){Db(a+-64|0)}}function N2(a){a=a|0;return 10809}function Mra(a){a=a|0;dg(a,16221)}function Me(a,b){return(b<<5)+a|0}function LE(a){return a>>>0>8?5:4}function L8(a){a=a|0;return 10406}function Jh(a){return a-48>>>0<10}function Ib(a,b){return kc(a,b)^1}function EA(a){cc(a+4|0);return a}function Dx(a,b){return x[a+b>>2]}function Dq(a){qs(a,17,125276,52)}function DT(a,b){return Vl(a,b,8)}function $k(a){w[a>>1]=0;return a}function zN(a){a=a|0;eq(a);Db(a)}function vua(a){a=a|0;dg(a,4358)}function vqa(a){a=a|0;aw(a,3863)}function uba(a){a=a|0;Nt(a-92|0)}function tqa(a){a=a|0;aw(a,4887)}function rg(a,b,c,d){$e(a,c,d,b)}function o3(a){a=a|0;return 6920}function mba(a){a=a|0;Nt(a-96|0)}function mY(a,b){yc(a,b+4|0,256)}function lw(a,b,c,d){pB(a,b,c,d)}function kQ(a){return(a&8)>>>3|0}function jf(a,b,c){mo(a,b,b+c|0)}function f3(a){a=a|0;return 6901}function dF(a,b,c,d){$w(a,b,c,d)}function cqa(a){a=a|0;dg(a,3985)}function bv(a){v[a|0]=0;return a}function Zv(a,b,c){WG(a,b,c,128)}function X1(a){a=a|0;dg(a,16851)}function V1(a){a=a|0;JH(a,51,50)}function UE(a){Nm(a,Cp(a),78768)}function PN(a){a=a|0;Pt(a);Db(a)}function P2(a){a=a|0;return 9845}function Mba(a){a=a|0;Nt(a-88|0)}function M2(a){a=a|0;return 5720}function Ira(a){a=a|0;dg(a,4484)}function Hoa(a){a=a|0;dg(a,4165)}function Fg(a,b){zb(qc(a)+4|0,b)}function FK(a){x[a+72>>2]=499208}function Era(a){a=a|0;dg(a,4378)}function DK(a){x[a+72>>2]=499292}function Cw(a,b){return Cua(a,b)}function CN(a){a=a|0;Mm(a);Db(a)}function AF(a){return(a&2)>>>1|0}function zu(a){OT(a+12|0);ST(a)}function zd(a,b){return!Bb(a,b)}function xy(a,b){return nh(a,b)}function wo(a,b){return Ft(a,b)}function wf(a,b){return bh(a,b)}function vh(a,b){return Xc(a,b)}function vA(a){w[a+480214>>1]=0}function uga(a){a=a|0;Db(LP(a))}function ug(a){tb(a+20|0);tb(a)}function ub(a){he(a+12|0);he(a)}function uJ(a,b){os(a,b,24,-24)}function uE(a){return(a&255)==1}function tj(a,b){return a>>>b&1}function tf(a,b){return Ec(a,b)}function si(a,b,c){$e(a,c,20,b)}function sB(a,b){return Yc(a,b)}function rga(a){a=a|0;return 13}function rC(a,b,c){$e(a,c,64,b)}function pl(a){if(oK(a)){Db(a)}}function mF(a,b){return iF(a,b)}function kk(a,b){return b-a>>11}function jW(a,b){os(a,b,12,-12)}function hk(a,b,c){$e(a,c,13,b)}function hha(a){a=a|0;Db(XP(a))}function hc(a,b){return dG(a,b)}function gia(a){a=a|0;Db(tQ(a))}function cq(a,b){return xb(a,b)}function bE(a,b,c){$e(a,c,30,b)}function aaa(a){a=a|0;Db(Dt(a))}function Zm(a){tb(a+12|0);tb(a)}function Zi(a,b,c){$e(a,c,28,b)}function Ys(a,b){return Rd(a,b)}function YD(a,b){return Rq(a,b)}function Y1(a){a=a|0;dg(a,4532)}function Xe(a){return hr(De(a))}function Xc(a,b){return Bb(a,b)}function XD(a,b){return ep(b,a)}function Wk(a,b,c){$e(a,c,22,b)}function Wi(a){return on(De(a))}function Wh(a,b){return xw(a,b)}function W5(a){a=a|0;Rb(500596)}function Vg(a,b){return Ib(a,b)}function Vb(a,b){return dj(a,b)}function Uo(a,b){return al(a,b)}function U5(a){a=a|0;Rb(500628)}function Tj(a,b){return Rc(a,b)}function Te(a,b,c){$e(a,c,32,b)}function Sj(a,b){return Me(a,b)}function Sg(a){return VS(a&255)}function S5(a){a=a|0;Rb(500532)}function Qs(a){a=a|0;return 127}function Ql(a){tb(a+12|0);ld(a)}function Q_(a,b){os(a,b,40,-40)}function QZ(a,b,c){$e(a,c,24,b)}function QL(a,b){return fh(a,b)}function Q5(a){a=a|0;Rb(500564)}function Pi(a,b){return(a|b)!=0}function Pd(a,b){return nc(a,b)}function PS(a){NS(a+12|0);LS(a)}function Oc(a,b,c){fc(a,b,1<<c)}function Mk(a,b,c){$e(a,c,12,b)}function Ls(a){return Ab(a+8|0)}function Kaa(a){a=a|0;Db(Jt(a))}function Je(a){a=a|0;return a|0}function I5(a){a=a|0;tb(500580)}function Hb(a,b){return(a&b)!=0}function HD(a,b){return Bk(b,a)}function Gc(a,b){return Or(a,b)}function G5(a){a=a|0;tb(500612)}function Fe(a,b){return E$(a,b)}function FD(a,b){return ED(a,b)}function Ec(a,b){return zb(a,b)}function Dg(a){return Si(a)?0:a}function D5(a){a=a|0;tb(500516)}function Cj(a){yA(a,0);return a}function CG(a,b){return Zc(a,b)}function Bd(a){return(a&255)!=0}function B5(a){a=a|0;tb(500548)}function Aw(a,b){return jF(a,b)}function AR(a,b){return yR(a,b)}function $z(a,b){return TQ(a,b)}function z3(a){a=a|0;Db(dI(a))}function z1(a){a=a|0;Db(cG(a))}function y3(a){a=a|0;Db(cI(a))}function vv(a,b){return a-b>>2}function v3(a){a=a|0;Db(bI(a))}function td(a,b){iI(a,b,qC(b))}function s3(a){a=a|0;Db(aI(a))}function q$(a){return Ax(a,28)}function nc(a,b){return b-a>>2}function mO(a,b){JG(a,b,22250)}function lx(a){return Ax(a,12)}function lN(a,b){JG(a,b,13602)}function lI(a){a=a|0;Db(Is(a))}function hJ(a){a=a|0;Db(Zx(a))}function h5(a){a=a|0;Db(Js(a))}function gM(a){a=a|0;Db(hM(a))}function gI(a){a=a|0;Db(Fs(a))}function gG(a){return a+1024|0}function fha(a){a=a|0;return 6}function fh(a,b){return b-a>>3}function fL(){return(db()|0)>0}function ep(a,b){return a-b>>1}function eia(a){a=a|0;return 9}function ec(a,b){x[a+100>>2]=b}function dQ(a){a=a|0;Db(eQ(a))}function d4(a){a=a|0;Db(uI(a))}function cC(a){return a+4096|0}function bo(a){return(a|0)==-1}function bB(a,b){return a<<8|b}function aV(a){return a+4896|0}function _4(a){a=a|0;Db(zI(a))}function Zt(a){return a>>>27^a}function ZW(a,b){ux(a,b,5,3,4)}function Yd(a){return a&64?2:1}function Yc(a,b){return b-a>>1}function Wt(a){a=a|0;Db(Vf(a))}function Tn(a){a=a|0;Db(WZ(a))}function TM(a){return Ax(a,16)}function Sz(a){a=a|0;Db(du(a))}function R8(a){a=a|0;Db(mt(a))}function Pk(a){return a>>>0<11}function P9(a){a=a|0;Db(ZL(a))}function Oh(a,b){return b-a>>8}function Nt(a){a=a|0;Db(dq(a))}function NY(a,b){mo(a,b,rd(b))}function LT(a,b){Hu(a,Jb(a),b)}function LK(a){a=a|0;Db(Zp(a))}function Ky(a){a=a|0;Db(ul(a))}function Ks(a){a=a|0;Db(Ux(a))}function KK(a){a=a|0;Db(Bf(a))}function KI(a){a=a|0;Db(Tx(a))}function K3(a){a=a|0;Db(hI(a))}function Jy(a){a=a|0;Db(co(a))}function JI(a){a=a|0;Db(Sx(a))}function Iy(a){a=a|0;Db(pt(a))}function In(a){a=a|0;Db(_w(a))}function He(a,b){if(!a){Db(b)}}function Gy(a){a=a|0;Db(ot(a))}function Gg(a,b){return b-a>>5}function Fy(a){a=a|0;Db(nt(a))}function Ek(a,b){return b-a>>4}function B3(a){a=a|0;Db(fI(a))}function A3(a){a=a|0;Db(eI(a))}function $N(a){a=a|0;Db(eq(a))}function zQ(a,b){bi(a,b,2048)}function yd(a){return(a|0)!=0}function yC(a,b){ac(a,b,1024)}function xT(a,b){os(a,b,7,-7)}function wC(a){return a+128|0}function vb(a,b){return a+b|0}function uy(a){return iK(a,0)}function ty(a){return iK(a,1)}function so(a){a=a|0;return 4}function qk(a){return(a&5)!=0}function qP(){return 19988993}function oR(a,b,c){Ol(a,b,-c)}function mX(a,b){ac(a,b,1108)}function lp(a){return a>>>0<5}function lc(a){a=a|0;return 0}function j_(a,b){$e(a,b,40,2)}function hp(a,b){yb(a+12|0,b)}function hQ(a){a=a|0;return 3}function gr(a){return a+256|0}function cQ(a){a=a|0;return 7}function bL(a){a=a|0;return-1}function Ze(a,b){w[a+28>>1]=b}function UC(a,b){ac(a,b,4896)}function TP(a){a=a|0;return 5}function S$(a,b){ac(a,b,1954)}function Rc(a,b){return b-a|0}function Pj(a){return!(a&255)}function P$(a,b){$e(a,b,13,1)}function Oq(a){return a>>>0<2}function Mt(a,b){x[a+32>>2]=b}function Mr(a,b){$e(a,b,26,3)}function Io(a,b){x[a+36>>2]=b}function Ie(a){a=a|0;return 2}function IY(a){cp(Tb(a,0,40))}function Fb(a){bx(a);return a}function Dn(a){return a&1?2:1}function Dj(a){return a+4e4|0}function Bk(a,b){return a-b|0}function Be(a){a=a|0;return 1}function Ak(a){return yd(a)^1}function $W(a,b){$e(a,b,33,1)}function $U(a){return a+512|0}function $L(a){return qk(a)^1}function zc(a){return a+12|0}function xG(a,b,c){ef(a,c,b)}function wP(a){return a+48|0}function vX(a,b){ac(a,b,126)}function vV(a){CV(a,x[a>>2])}function vD(a,b){$e(a,b,8,2)}function uZ(a,b){ac(a,b,576)}function tr(a){return a-28|0}function tB(a){v[a+6152|0]=0}function rZ(a,b){ac(a,b,674)}function qA(a,b){v[a+34|0]=b}function pn(a,b){x[a+8>>2]=b}function pW(a,b){ac(a,b,204)}function pA(a,b){v[a+32|0]=b}function oq(a,b){B[a+8>>2]=b}function od(a,b){return a>>b}function oE(a,b,c){bf(a,c,b)}function oA(a,b){v[a+35|0]=b}function o$(a,b){ac(a,b,610)}function nq(a,b){B[a+4>>2]=b}function nG(a){mG(a,x[a>>2])}function mu(a){YR(a,x[a>>2])}function mq(a,b){v[a+33|0]=b}function kZ(a){return a+36|0}function hj(a){return a-36|0}function gj(a){xF(a,x[a>>2])}function fp(a,b){Fe(a,b+8|0)}function fV(a,b){ac(a,b,263)}function fF(a,b){ac(a,b,772)}function fA(a,b){yA(a,ie(b))}function dw(a,b){ac(a,b,192)}function d_(a,b){ac(a,b,218)}function dE(a,b){ac(a,b,512)}function cx(a,b){pG(a,ie(b))}function cY(a){return a+3&-4}function cF(a,b){$e(a,b,8,3)}function cD(a,b,c){be(a,b,c)}function ac(a,b,c){fc(a,b,c)}function a_(a,b){ac(a,b,157)}function ZY(a){lJ(a,x[a>>2])}function Yo(a){return a+14|0}function Y_(a){X_(a,x[a>>2])}function YZ(a,b){ac(a,b,206)}function YW(a){return a-56|0}function YE(a,b){ac(a,b,497)}function X8(a){a=a|0;m$(a,1)}function Wd(a,b){x[a+4>>2]=b}function Vv(a){N_(a,x[a>>2])}function VL(a){return a-40|0}function Uz(a){zQ(a,x[a>>2])}function Ud(a,b,c){Qj(a,b,c)}function To(a){LY(a,x[a>>2])}function Sq(a,b){return a<<b}function SZ(a,b){ac(a,b,236)}function Qh(a,b,c){s_(a,b,c)}function Qe(a,b){a=a|0;b=b|0}function QW(a,b){ac(a,b,146)}function QV(a,b){yc(a,b,128)}function Pn(a){return a-12|0}function OZ(a){return a+10|0}function Nq(a,b,c){pp(a,b,c)}function NT(a){MT(a,x[a>>2])}function Mo(a){return a+32|0}function LW(a,b){ac(a,b,608)}function Ke(a,b){v[a+11|0]=b}function Kb(a,b,c){CF(a,b,c)}function JY(a,b){ac(a,b,128)}function Hf(a){vQ(a,x[a>>2])}function HX(a){GX(a,x[a>>2])}function HB(a){return a-32|0}function GZ(a,b){ac(a,b,102)}function FR(a){return a+24|0}function DX(a,b){ac(a,b,600)}function DU(a){CU(a,x[a>>2])}function Ct(a){return a-24|0}function Cp(a){return a+20|0}function CV(a,b){bi(a,b,256)}function CT(a,b,c){ue(a,b,c)}function CC(a,b){ac(a,b,130)}function AV(a){zV(a,x[a>>2])}function AS(a,b,c){DZ(a,b,c)}function zv(a,b){return a<b}function zV(a,b){bi(a,b,16)}function xY(a,b){bi(a,b,33)}function x$(a){return a-2|0}function wE(a,b){ac(a,b,32)}function vw(a,b){ac(a,b,11)}function uf(a){return a&255}function uN(a){return 0-a|0}function tg(a,b){v[a+3|0]=b}function rG(a,b){ac(a,b,24)}function qv(a,b){ac(a,b,30)}function qq(a){Tb(a,0,8192)}function qY(a,b){ac(a,b,52)}function pi(a){return a-4|0}function pP(){return 458754}function nw(a,b){ac(a,b,65)}function nr(a,b){ac(a,b,12)}function np(a,b){v[a+1|0]=b}function nf(){e$(11034);p()}function mE(a,b){fc(a,b,20)}function l_(a,b){ac(a,b,98)}function lJ(a,b){bi(a,b,24)}function kda(a){a=a|0;mP(a)}function kV(a,b){return a<b}function hU(a,b){ac(a,b,27)}function g_(a,b){ac(a,b,48)}function eu(a){Tb(a,0,2048)}function dc(a){return a+4|0}function d0(a,b){ac(a,b,17)}function cj(a){return a+3|0}function bw(a,b){ZG(a,b,64)}function bX(a,b){ac(a,b,96)}function aE(a,b){ZG(a,b,32)}function Ye(a){return a+2|0}function Xv(a,b){ac(a,b,64)}function Wv(a,b){ac(a,b,66)}function VD(a){x[a+12>>2]=0}function Uw(a,b){ac(a,b,20)}function T_(a,b){yc(a,b,40)}function SC(a,b){ac(a,b,33)}function Rl(){Dq(11034);p()}function Rh(a){return a&127}function RE(a,b){ac(a,b,38)}function R$(a){Tb(a,0,1954)}function Pr(a,b){ac(a,b,36)}function PZ(a){return a+6|0}function PE(a,b){Ai(a,b,37)}function N_(a,b){bi(a,b,40)}function Mv(a,b){ac(a,b,22)}function MD(a,b){ac(a,b,16)}function LC(a,b){ac(a,b,40)}function KY(a,b){ac(a,b,80)}function Hc(a){return a+1|0}function GX(a,b){bi(a,b,32)}function FA(a){Tb(a,0,4096)}function Ew(a,b){fc(a,b,22)}function An(a,b){fc(a,b,32)}function Ab(a){return a+8|0}function xr(a,b){ac(a,b,7)}function xk(a,b){B[a>>2]=b}function xF(a,b){bi(a,b,2)}function wfa(){return fb|0}function wd(a,b){x[a>>2]=b}function vc(a){x[a+8>>2]=0}function vQ(a,b){bi(a,b,4)}function v0(a){a=a|0;Zh(a)}function uv(a){MC(a,ae(a))}function uX(a){Tb(a,0,126)}function tp(a,b){ac(a,b,2)}function tc(a){a=a|0;Db(a)}function tZ(a){Tb(a,0,576)}function tC(a){Tb(a,0,130)}function sw(){Dq(7718);p()}function sR(a){mA(a,ae(a))}function oZ(a){Tb(a,0,192)}function oW(a){Tb(a,0,204)}function n$(a){Tb(a,0,610)}function mG(a,b){bi(a,b,8)}function kh(a,b){ac(a,b,4)}function fn(a,b){pp(a,b,0)}function es(a){a=a|0;gs(a)}function eea(a){a=a|0;fb=a}function eF(a){Tb(a,0,772)}function dZ(a){YC(a,ae(a))}function cl(a,b){ac(a,b,8)}function cd(){e$(7718);p()}function bk(a,b){ac(a,b,5)}function bZ(a){ZC(a,ae(a))}function bQ(a,b){NQ(a,3,b)}function bF(a,b){Qh(a,2,b)}function Yb(a){sm(x[a>>2])}function X_(a,b){bi(a,b,6)}function XZ(a){Tb(a,0,206)}function XE(a){Tb(a,0,497)}function Si(a){return a!=a}function RZ(a){Tb(a,0,236)}function Pw(a,b){ac(a,b,3)}function PW(a){Tb(a,0,146)}function Oba(a){a=a|0;gb=a}function OT(a){zq(a,ae(a))}function NS(a){uu(a,ae(a))}function Ml(a){oB(a,ae(a))}function LY(a,b){bi(a,b,1)}function LS(a){vu(a,ae(a))}function KW(a){Tb(a,0,608)}function KV(a){_B(a,ae(a))}function JV(a){$B(a,ae(a))}function Ir(a,b){ac(a,b,1)}function Hs(a){pl(x[a>>2])}function Gv(a){mD(a,ae(a))}function EZ(a){nD(a,ae(a))}function CX(a){Tb(a,0,600)}function BV(a){Tb(a,0,256)}function BD(a,b){ac(a,b,6)}function $Z(a){Tb(a,0,157)}function zZ(a){Tb(a,0,56)}function vp(a){return a&1}function vY(a){Tb(a,0,33)}function pY(a){Tb(a,0,52)}function k_(a){Tb(a,0,98)}function h_(a){Tb(a,0,48)}function ed(a,b){v[a|0]=b}function dO(){return 2048}function cX(a){Tb(a,0,96)}function WC(a){Tb(a,0,80)}function UD(a){Tb(a,0,66)}function Rv(a){Tb(a,0,64)}function Rr(a){Tb(a,0,36)}function QE(a){Tb(a,0,38)}function Md(a){v[a+4|0]=1}function Ch(a){tb(a+16|0)}function AQ(a){wm(a,2048)}function yn(a,b){xF(a,b)}function yU(a,b){lg(a,b)}function x_(a,b){pU(a,b)}function wl(a,b){$p(a,b)}function qo(a,b){zb(a,b)}function lU(a,b){Dh(a,b)}function js(a,b){CG(a,b)}function gX(a,b){Fe(a,b)}function fg(a,b){h$(a,b)}function ck(a,b){uw(a,b)}function bW(a,b){Ul(a,b)}function ad(a,b){ms(a,b)}function Xh(a,b){vQ(a,b)}function WD(a,b){Qk(a,b)}function Vz(a,b){pe(a,b)}function Vq(a,b){LY(a,b)}function RC(a,b){tY(a,b)}function Nh(a,b){Lo(a,b)}function Ng(a){a=a|0;p()}function Nd(a,b){Jg(a,b)}function Lo(a,b){Zc(a,b)}function KT(a){ze(a+8|0)}function KC(a,b){fY(a,b)}function Ik(a){tb(a+4|0)}function Ic(a){cc(a+8|0)}function Hi(a,b){ji(a,b)}function Gn(a,b){PF(a,b)}function Fd(a){ub(a+8|0)}function Eu(a,b){IR(a,b)}function EV(a){LG(a,872)}function BU(a,b){CU(a,b)}function AD(a,b){hc(a,b)}function $Q(a,b){YR(a,b)}function $F(a,b){mG(a,b)}function $C(a,b){X_(a,b)}function vg(a){qx(a,24)}function pJ(a){wm(a,24)}function pI(a){qx(a,48)}function op(a){eH(a,11)}function ah(a){v[a|0]=0}function _o(a){eH(a,16)}function Vja(){ua();p()}function P_(a){wm(a,40)}function On(a){qx(a,36)}function wT(a){wm(a,7)}function sh(a){OM(a,0)}function rh(a){MM(a,0)}function gW(a){LG(a,9)}function fj(a){wm(a,2)}function b3(){YH();p()}function as(a){pG(a,0)}function YH(){va();p()}function Wr(a){wm(a,8)}function SY(a){wm(a,6)}function Jc(a){Oe(a,0)}function Hg(a){cZ(a,0)}function HA(a){$R(a,0)}function GA(a){_R(a,0)}function DR(a){dS(a,0)}function Al(a){NM(a,0)}function sC(a){qg(a)}function hs(a){zc(a)}function gV(a){qc(a)}function dW(a){Nb(a)}function XV(a){Pe(a)}function WU(a){je(a)}function Um(a){sc(a)}function OW(a){bv(a)}function Jw(a){$k(a)}function FT(a){No(a)}function Eb(a){tb(a)}function Df(a){a=a|0}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,rc,hG,om,A1,_F,o1,m1,j1,OF,MF,ne,R0,N0,VE,J0,HZ,WZ,Jna,Dna,sna,tua,iua,cw,$j,Wta,Z,rsa,kw,hm,TK,gh,dp,Msa,Je,e3,Pna,Cc,Z4,lD,Uj,Zq,nn,yra,JZ,oi,XU,RB,uma,Rla,aU,Xka,nla,og,gka,Rj,dka,cka,Vja,Tja,Nja,jA,zja,rja,iga,Iia,EQ,p9,o9,st,EQ,vfa,_O,gg,Mea,vea,Qda,Jda,Dda,yda,uda,pda,gda,Qca,cca,Mca,Hy,ua,Mb,F5,d5,V4,M4,B4,Un,b4,oka,Y3,nka,I3,da,a3,L2,A2,t2,s2,r2,vH,q2,p2,o2,n2,m2,k2,j2,l2,H8,ls,Fp,og,i2,AG,zG,h2,ix,g2,yG,Pf,f2,d2,b2,es,ds,_h,dg,_1,Dp,a2,$1,Z1,e2,Y1,vG,X1,vG,c2,wG,W1,V1,U1,T1,S1,bd,Mb,P1,Bp,O1,gh,N1,pd,M1,fl,pd,ax,L1,_w,Yw,n1,K1,C1,B1,l1,h1,e1,d1,Nw,TF,c1,b1,Ija,Jja,tT,Gja,Hja,nA,hu,Ub,Kja,ce,QF,_0,Z0,wF,X0,W0,wF,kF,zw,S0,Kg,kF,ww,Via,dja,Uia,hf,vka,Y0,_f,lua,uka,wta,HE,GE,F0,E0,FE,D0,ag,C0,B0,Ac,pw,A0,z0,y0,Of,x0,im,w0,DE,v0,s0,rE,r0,q0,p0,iw,o0,WE,qE,n0,m0,l0,k0,j0,kE,pE,$$,Ad,ew,vua,uua,iE,hE,sua,rua,qua,pw,pua,_$,oua,jw,nua,mua,_k,fua,wr,eua,Lb,Zf,dg,dua,cE,cua,id,Rk,bua,aua,$ta,M$,L$,kd,_ta,gp,Zta,Yta,Xta,I$,H$,Uj,aw,Vta,Uta,mla,Tta,ch,Sta,Rta,Lta,Zj,Ota,Nta,Mta,Qta,Pta,Pf,z$,Yh,Lf,Ita,Hta,Gta,Dta,Zj,Yj,Cta,Bta,Ata,RD,f$,QD,zta,yta,xta,_k,L_,I_,tta,ota,A_,lo,nta,sg,l$,mta,iw,lta,kta,JD,jta,z_,Yw,ita,hta,v_,VZ,gta,_k,dta,wr,dk,cta,bta,L$,ata,$sa,_sa,r_,q_,jm,Zsa,Ysa,Xsa,Vsa,Zj,p_,Wsa,Yh,Lf,PD,Psa,sr,Lsa,z_,Hsa,Gsa,Fsa,Esa,Bsa,wr,Asa,zsa,bp,r_,ysa,xsa,dg,wsa,vsa,usa,tsa,ssa,MZ,qsa,psa,aK,LZ,osa,nsa,Z$,KZ,msa,lsa,ksa,tla,jsa,IZ,isa,IZ,Isa,gsa,Zj,hsa,Yh,Lf,ek,bsa,asa,$ra,_ra,Xra,Wra,Vra,Ura,Tra,bp,Sra,Rra,Qra,fD,T0,Pra,Ora,Nra,Mra,Lra,nZ,Kra,Q0,Jra,Ira,Hra,Gra,mZ,Fra,csa,Era,Dra,dg,Cra,TD,Bra,dsa,Ara,zra,xra,bD,bD,lZ,wra,vra,jZ,bD,gZ,ura,K8,tra,sra,rra,qra,pra,ora,nra,fZ,pd,Yq,cra,Ev,mra,Gia,Fia,Eia,Dia,Cia,Bia,lra,kra,lg,jra,ira,hra,gra,hG,lla,jla,Sia,bja,cja,fra,eZ,era,dra,Sja,zia,Xk,yG,hla,pla,gla,fla,_qa,Zqa,Yqa,Xqa,Wqa,Vqa,Uqa,Tqa,Sqa,Rqa,Qqa,Oqa,Nqa,Pqa,uY,Lf,nY,QC,Kqa,PC,Jqa,Iqa,Hqa,Gqa,OC,Fqa,zw,FE,Eqa,lY,kY,Dqa,Er,Cqa,of,Bqa,iY,bp,gw,bp,KZ,Hr,dg,HE,bp,lo,yqa,xqa,wqa,vqa,JC,sv,uqa,tqa,sqa,rqa,qqa,pqa,oqa,nqa,mqa,lqa,kqa,jqa,iqa,hqa,gqa,_C,fqa,eqa,dqa,dg,iZ,hZ,iD,cqa,bqa,iE,Yw,aqa,$pa,_pa,Zpa,Ypa,Ska,Rka,Qka,Upa,Vpa,ur,Wpa,Xpa,Uv,MX,Rpa,tka,Wka,Gu,ska,rka,nT,Bu,hT,qka,ZS,qU,pka,AB,Jj,yi,Kpa,Jpa,mr,Spa,Bv,Gpa,V$,Fpa,Epa,sX,Yq,Dpa,Cpa,qw,Bpa,eZ,Apa,zpa,lr,ypa,xpa,wpa,vpa,pC,qpa,nC,ppa,opa,lX,qp,npa,Zj,Yh,Lf,yi,kpa,jpa,ipa,hpa,PC,epa,dpa,lr,cpa,im,eja,$oa,_oa,Yj,hX,nC,jw,Zoa,lX,Yoa,Xoa,Woa,mv,Voa,mv,Uoa,tm,U0,Roa,Zj,Toa,hC,UW,hv,Soa,Yh,Lf,mr,Ooa,Loa,QC,Koa,Hoa,Goa,HW,qw,fD,Foa,iE,dg,woa,voa,pw,uoa,toa,soa,roa,Jv,qoa,gp,noa,moa,loa,koa,joa,ioa,cn,ZV,hoa,goa,foa,eoa,doa,coa,boa,aoa,$na,_na,Zna,Yna,Xna,PC,Wna,Vna,Una,Bv,Tna,Sna,Rna,wr,Hka,Bp,M$,Oka,Nka,wr,Mka,yi,Bp,Lka,Kka,Jka,Qna,GV,Mna,Lna,Kna,Ina,Hna,Kr,Ena,Cna,Bna,Ana,zna,yna,xna,wna,vna,una,tna,j3,AI,rna,dg,qna,pna,Tka,ula,Ssa,EU,rla,qla,JB,ola,kla,ila,rU,bla,dla,cla,ala,Xd,$ka,fU,_ka,Zka,Yka,XT,WT,UT,Go,QT,Vka,Uka,Pka,$o,Fka,Yj,uT,bs,Fja,Eja,Dja,wka,Cja,V0,Bja,Ow,bs,$$,Aja,uT,Dka,yja,Ika,Zj,Yh,Lf,Gka,Zj,Yh,Lf,Eka,Zj,Yh,Lf,Bka,yka,xka,Je,pE,mka,lka,kka,jka,ika,hka,sla,lna,EP,fka,Dc,bka,Yia,aka,R1,k1,a1,g1,_ja,Zja,$0,i1,Q1,f1,SR,Yja,Xja,Wja,RR,QR,CA,Uja,ela,Rja,Qja,Pja,Oja,WQ,Qia,fja,hx,MS,_F,qG,nA,RR,Lja,Xk,ks,Dr,Aka,Cka,uja,tja,Yj,sja,nC,qja,pja,oja,mr,nja,yi,mja,lja,kja,jja,ija,Zj,Yh,Lf,vja,aja,$ia,_ia,Zia,ji,Lm,Xia,Wia,fu,to,Tia,Oia,Nia,Mia,Lia,Kia,RQ,Ria,lq,PQ,nl,ji,lg,Hia,Aia,c9,Jia,Pia,xia,wia,Qha,via,wk,BQ,ig,OQ,hia,Rha,hn,Lha,xja,Kha,Iha,Hha,Gha,nA,Jha,qe,Yt,Yt,Fha,Eha,Cha,qQ,fQ,iha,$ga,Uga,Nga,Fga,vga,yga,lga,dga,tP,Vt,Zfa,Yfa,maa,naa,oP,Rfa,mP,lP,Mja,paa,Nfa,tP,Mfa,Xaa,Laa,_aa,gP,YL,fP,Fz,Jfa,Cda,eq,Bda,Jm,dP,Uaa,bP,Taa,cP,Saa,aP,aK,kba,Efa,Vaa,Ez,iY,Dz,Cz,Bz,sfa,qfa,fP,Fz,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,ZO,YO,XO,eG,C9,$aa,WO,JO,Qaa,IO,HO,jba,F9,G9,GO,L9,DO,CO,cz,AO,Fz,yO,vO,uO,po,E9,D9,tO,sO,rO,qO,pO,oO,nO,lO,kO,jO,iO,hO,zz,gO,fO,NR,pv,yz,xz,Hda,cO,Gda,Fda,Eda,YN,xda,gP,wda,Rca,vda,Pca,tda,Oca,sda,Nca,rda,Lca,qda,Kca,nda,W9,YL,Pq,zka,sx,cs,UT,fba,eba,dba,bba,Zaa,eka,Waa,Oaa,Raa,j9,b9,a9,Paa,im,_k,_k,Maa,$ja,Yaa,gba,aba,Zw,_,oaa,QM,PM,xz,jM,laa,kaa,baa,aM,V9,U9,Q9,K9,J9,I9,H9,B9,A9,z9,HR,mna,y9,x9,w9,v9,r9,q9,IK,HK,p3,i9,h9,g9,f9,e9,d9,Y8,gh,X8,Je,g3,g4,I8,HK,F8,wn,RK,By,q8,p8,ry,hi,gi,Zs,Db,qy,ph,tl,py,Cm,h8,g8,rj,oh,UJ,qj,Ey,jy,hi,gi,Vs,ii,W8,hm,ao,rj,oh,QJ,qj,O7,J7,NK,E7,kt,dp,z7,Ss,Df,h7,Zn,g7,f7,e7,tJ,c7,rt,a7,$6,uj,_6,tJ,Y6,wY,W6,V6,S6,R6,G6,F6,E6,D6,C6,B6,A6,z6,y6,x6,w6,v6,u6,t6,s6,r6,q6,p6,o6,n6,m6,l6,k6,j6,i6,h6,g6,f6,e6,d6,c6,b6,a6,cJ,$5,N5,O5,P5,W5,U5,S5,Q5,y5,z5,A5,I5,G5,D5,B5,Y4,X4,W4,U4,T4,yI,S4,xI,R4,Q4,P4,O4,N4,L4,K4,J4,I4,H4,G4,F4,E4,D4,C4,A4,z4,y4,x4,w4,v4,u4,t4,s4,r4,q4,p4,o4,n4,m4,h4,w3,x3,l4,k4,j4,i4,ym,Sp,M3,L3,f4,e4,P3,O3,N3,rk,D3,C3,Yn,ey,oi,YH,In,_r,kna,jna,ina,hna,gna,fna,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Uma,Tma,Sma,Rma,Qma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,tma,sma,rma,qma,pma,oma,nma,mma,lma,kma,jma,ima,hma,gma,fma,ema,dma,cma,bma,ama,$la,_la,Zla,Yla,Xla,Wla,Vla,Ula,Tla,Sla,Qla,Pla,Ola,Nla,Mla,Lla,Kla,Jla,Ila,Hla,Gla,Fla,Ela,Dla,Cla,Bla,Ala,zla,yla,xla,wla,vla,In,Gna,Fna,Zra,Yra,Joa,Ioa,Coa,Boa,Mqa,Lqa,upa,tpa,ara,$qa,hua,gua,Usa,Tsa,u0,t0,xua,wua,mpa,lpa,Noa,Moa,Ona,Nna,Fta,Eta,vta,uta,K0,I0,H0,G0,bpa,apa,Qoa,Poa,Ipa,Hpa,bra,h0,Osa,Nsa,fsa,esa,Kta,Jta,fta,eta,gpa,fpa,wja,hja,gja,Dsa,Csa,Ksa,Jsa,Mpa,Lpa,poa,ooa,spa,rpa,Rsa,Qsa,Eoa,Doa,yoa,xoa,qta,pta,Aoa,zoa,Tpa,Opa,Npa,M0,L0,P0,O0,kua,jua,Aqa,zqa,sta,rta,Qpa,Ppa,ona,nna,Tn,_r,p1,tc,pm,sP,tc,Je,tc,lc,Be,Be,lc,lc,q1,F1,E1,r1,tc,pm,tc,cG,z1,y1,Be,x1,w1,v1,u1,t1,s1,du,Sz,cu,yQ,lc,Df,lc,lc,lc,Qe,so,uia,tia,sia,ria,qia,Ki,Qz,Qz,Pz,xQ,Pz,wQ,Pz,wQ,Df,h0,pia,oia,nia,mia,lia,Ji,uQ,Nha,lc,lc,Be,Oz,Ie,Ie,Be,kia,jia,Qe,Df,Qe,Df,tQ,gia,fia,lc,Df,lc,lc,lc,Qe,eia,sQ,dia,cia,bia,aia,Ki,$ha,_ha,Zha,Yha,Xha,Wha,Vha,Uha,Tha,Sha,Ji,nQ,lc,lc,Be,Ie,Ie,Be,rQ,pQ,Vf,Ng,b3,Pha,Rz,Oha,lc,Mha,xQ,tha,jha,aha,Vga,Oga,Gga,xga,mga,ega,Hga,yia,iia,Dha,du,Sz,yQ,lc,Df,lc,lc,lc,Qe,hQ,Bha,Aha,zha,yha,xha,Ki,wha,Ji,gQ,lc,lc,Be,Ie,Ie,Be,vha,uha,XP,hha,gha,lc,Df,lc,lc,lc,Qe,fha,eha,dha,cha,Ki,bha,Ji,UP,lc,lc,Be,Ie,Ie,Wt,_ga,lc,Df,lc,lc,lc,Qe,TP,Zga,Yga,Xga,Ki,Wga,Ji,RP,lc,lc,Be,Ie,Ie,du,Sz,Tga,lc,Df,lc,lc,lc,Qe,TP,Sga,Rga,Qga,Ki,Pga,Ji,PP,lc,lc,Be,Ie,Ie,eQ,dQ,Mga,lc,Df,lc,lc,lc,Qe,cQ,Lga,qha,pha,Ki,oha,Ji,nha,lc,lc,Be,Ie,Ie,Qe,Df,aQ,Kga,Jga,$P,Iga,_P,ZP,dQ,sha,cQ,rha,aQ,mha,lha,$P,kha,_P,ZP,Wt,Ega,lc,Df,lc,lc,lc,Qe,Ie,Dga,Cga,Bga,Ki,Aga,Ji,zga,lc,lc,Be,Ie,Ie,LP,uga,tga,lc,Df,lc,lc,sga,Qe,rga,qga,pga,oga,Ki,nga,Ji,Hz,lc,lc,Be,Ie,Ie,Qe,Df,Wt,kga,lc,Df,lc,lc,lc,Qe,hQ,jga,hga,gga,Ki,fga,Ji,GP,lc,lc,Be,Ie,Ie,Wt,cga,lc,Df,lc,lc,lc,Qe,so,bga,aga,$fa,Ki,_fa,Ji,DP,lc,lc,Be,Ie,Ie,Qt,tc,Ada,$N,vN,$N,zN,Mm,CN,Pt,PN,dq,Nt,Qba,Pba,tN,sN,rN,qN,pN,oN,nN,mN,kN,jN,iN,hN,gN,fN,eN,dN,cN,bN,$M,_M,ZM,YM,XM,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,Je,Ng,Je,Ng,Je,Ng,Je,Ng,Ng,iba,tc,hba,Jt,Kaa,cba,Je,Ng,Je,tc,Jaa,Iaa,Ng,CM,BM,CM,BM,Qe,Kt,Qe,Kt,FM,EM,FM,EM,tc,Naa,Je,tc,Haa,Gaa,tc,vM,uM,Ng,Daa,sM,Caa,sM,Faa,tM,Eaa,tM,tc,Baa,Aaa,tc,rM,qM,Gt,Gt,Gt,Gt,zaa,hz,hz,hz,tc,yaa,xaa,tc,pM,oM,uaa,mM,taa,mM,waa,nM,vaa,nM,tc,saa,raa,tc,lM,kM,Et,Et,Et,Et,qaa,gz,gz,gz,X9,tc,pm,tc,Dt,aaa,Be,Be,$9,_9,_r,Z9,Y9,Ng,Ng,caa,tc,pm,tc,hM,gM,Be,lc,Be,jaa,iaa,haa,gaa,faa,eaa,daa,Ng,M9,tc,pm,tc,ZL,P9,O9,N9,Ng,R9,tc,pm,tc,gM,T9,S9,D1,tc,pm,tc,tc,J1,Be,Be,_r,Zr,I1,H1,G1,Qe,Kt,Qe,Kt,u9,t9,s9,co,Jy,Qe,eL,dL,cL,lc,lc,m9,bL,l9,qt,k9,qt,nt,Fy,Qe,eL,dL,cL,lc,lc,$8,bL,_8,qt,Z8,qt,mt,R8,S8,Q8,V8,U8,T8,Zp,LK,P8,O8,ot,Gy,VK,UK,Bf,KK,N8,M8,pt,Iy,$K,_K,Je,tc,L8,n3,m3,l3,J8,In,n9,lc,G8,Jy,u8,t8,s8,r8,WK,Ky,ul,Ky,Jy,x8,AK,w8,v8,Fy,B8,A8,z8,y8,pt,Iy,$K,_K,WK,Ky,Fy,E8,AK,D8,C8,ot,Gy,VK,UK,zI,_4,cu,aI,s3,r3,q3,m8,bI,v3,u3,t3,j8,Js,h5,g5,f5,e5,c5,wX,b5,a5,$4,Fs,gI,H3,G3,F3,E3,Is,lI,a4,$3,_3,Z3,X3,W3,V3,U3,T3,S3,R3,Q3,Zx,hJ,M6,L6,K6,J6,lc,I6,H6,Sx,JI,dy,cy,by,v5,u5,Tx,KI,Zr,ay,$x,x5,w5,JI,KI,Je,tc,tc,s5,r5,q5,p5,o5,n5,m5,l5,wX,k5,j5,i5,tc,BI,BI,Pp,Be,Be,t5,Be,tc,FI,DI,Pp,lc,lc,CI,so,tc,FI,DI,Pp,lc,lc,CI,so,tc,II,HI,Pp,lc,lc,GI,so,tc,II,HI,Pp,lc,lc,GI,so,Je,tc,o8,n8,Je,tc,l8,k8,tc,i8,f8,e8,d8,YJ,YJ,c8,b8,a8,$7,_7,tc,Z7,Y7,X7,W7,PJ,PJ,V7,U7,T7,S7,R7,tc,Q7,P7,N7,M7,L7,K7,I7,H7,tc,G7,F7,D7,C7,B7,A7,y7,x7,Je,tc,Ie,w7,v7,u7,t7,s7,r7,M5,L5,K5,J5,H5,E5,C5,Je,tc,Ie,q7,p7,o7,n7,m7,l7,_5,Z5,Y5,X5,V5,T5,R5,hI,K3,J3,rd,Qx,Px,Ox,Nx,Mx,Lx,tI,sI,rI,qI,oI,nI,mI,uI,d4,c4,rd,Qx,Px,Ox,Nx,Mx,Lx,tI,sI,rI,qI,oI,nI,mI,Ux,Ks,k7,Ux,Ks,j7,Ks,Ks,tc,Qs,Qs,fi,fi,fi,HJ,lc,ei,ei,tc,Qs,Qs,fi,fi,fi,HJ,lc,ei,ei,tc,Ps,Ps,fi,fi,fi,GJ,lc,ei,ei,tc,Ps,Ps,fi,fi,fi,GJ,lc,ei,ei,cI,y3,dy,cy,by,EJ,cz,DJ,CJ,BJ,Os,dI,z3,dy,cy,by,EJ,cz,DJ,CJ,BJ,Os,eI,A3,Zr,ay,$x,AJ,yJ,xJ,wJ,Os,vJ,fI,B3,Zr,ay,$x,AJ,yJ,xJ,wJ,Os,vJ,tc,i7,d7,tc,b7,Z6,tc,X6,U6,tc,T6,Q6,tc,iJ,P6,Qe,tc,iJ,O6,Qe,tc,tc,Je,tc,N6,hJ,Je,tc,Je,tc,Je,tc,Je,tc,gI,lI,Je,Ng,tc,o3,tc,k3,_H,tc,i3,h3,_H,In,Ng,tc,f3,va,Je,tc,Df,Df,$2,T2,V2,W2,tc,O2,tc,N2,Tn,In,Tn,Tn,Tn,Tn,In,tc,M2,tc,S2,U2,X2,tc,_2,Z2,Y2,tc,P2]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":i0,"wa":pP,"xa":pP,"ya":qP,"za":qP,"Aa":tc,"Ba":Sfa,"Ca":oP,"Da":Qfa,"Ea":Pfa,"Fa":Vt,"Ga":Qe,"Ha":Ufa,"Ia":Tfa,"Ja":Xfa,"Ka":Qz,"La":Vfa,"Ma":sP,"Na":Wfa,"Oa":Je,"Pa":vP,"Qa":uP,"Ra":vP,"Sa":dO,"Ta":K2,"Ua":J2,"Va":I2,"Wa":Ofa,"Xa":jP,"Ya":Lfa,"Za":hP,"_a":Afa,"$a":Nda,"ab":Oda,"bb":yfa,"cb":xfa,"db":ufa,"eb":zfa,"fb":Pda,"gb":cea,"hb":Ida,"ib":fea,"jb":xea,"kb":Lda,"lb":hea,"mb":Mda,"nb":gea,"ob":Kda,"pb":Tda,"qb":Rda,"rb":Sda,"sb":_da,"tb":Yda,"ub":Zda,"vb":Uda,"wb":Vda,"xb":Wda,"yb":Xda,"zb":tea,"Ab":uea,"Bb":Fea,"Cb":Aea,"Db":zea,"Eb":yea,"Fb":Eea,"Gb":Dea,"Hb":Bea,"Ib":Cea,"Jb":Jea,"Kb":Kea,"Lb":Gea,"Mb":Iea,"Nb":Hea,"Ob":nea,"Pb":sea,"Qb":qea,"Rb":pea,"Sb":rea,"Tb":oea,"Ub":bea,"Vb":Nea,"Wb":mea,"Xb":kea,"Yb":wea,"Zb":dea,"_b":lea,"$b":jea,"ac":iea,"bc":Oea,"cc":$da,"dc":Pea,"ec":aea,"fc":Lea,"gc":Kfa,"hc":Ifa,"ic":H2,"jc":Hfa,"kc":Gfa,"lc":Ffa,"mc":Dfa,"nc":G2,"oc":Cfa,"pc":Bfa,"qc":tfa,"rc":rfa,"sc":pfa,"tc":Qea,"uc":ofa,"vc":mc,"wc":vN,"xc":eq,"yc":AN,"zc":BN,"Ac":Ica,"Bc":Jca,"Cc":zN,"Dc":kda,"Ec":mda,"Fc":lda,"Gc":ON,"Hc":ON,"Ic":dO,"Jc":QH,"Kc":QH,"Lc":PH,"Mc":PH,"Nc":F2,"Oc":DN,"Pc":GN,"Qc":NN,"Rc":MN,"Sc":EN,"Tc":JN,"Uc":IN,"Vc":FN,"Wc":LN,"Xc":KN,"Yc":HN,"Zc":Mm,"_c":CN,"$c":ida,"ad":fca,"bd":eda,"cd":wca,"dd":jca,"ed":dda,"fd":gca,"gd":$ca,"hd":xca,"id":fda,"jd":Vca,"kd":Uca,"ld":Tca,"md":Yca,"nd":Xca,"od":Wca,"pd":Zca,"qd":ada,"rd":_ca,"sd":bda,"td":qca,"ud":Gca,"vd":dca,"wd":sca,"xd":rca,"yd":mca,"zd":tca,"Ad":lca,"Bd":Dca,"Cd":Zba,"Dd":$ba,"Ed":aca,"Fd":_ba,"Gd":Wba,"Hd":Vba,"Id":yca,"Jd":Aca,"Kd":Fca,"Ld":zca,"Md":kca,"Nd":Cca,"Od":nca,"Pd":uca,"Qd":Bca,"Rd":oca,"Sd":ica,"Td":vca,"Ud":pca,"Vd":hca,"Wd":Xba,"Xd":Uba,"Yd":Tba,"Zd":bca,"_d":Yba,"$d":Rba,"ae":Sba,"be":Eca,"ce":E2,"de":eca,"ee":Hca,"fe":Sca,"ge":hda,"he":D2,"ie":cda,"je":jda,"ke":QN,"le":SN,"me":TN,"ne":UN,"oe":WN,"pe":XN,"qe":_N,"re":VN,"se":Pt,"te":PN,"ue":RN,"ve":oda,"we":zda,"xe":mc,"ye":AN,"ze":BN,"Ae":eq,"Be":DN,"Ce":GN,"De":NN,"Ee":MN,"Fe":EN,"Ge":JN,"He":IN,"Ie":FN,"Je":LN,"Ke":KN,"Le":HN,"Me":Mm,"Ne":QN,"Oe":SN,"Pe":TN,"Qe":UN,"Re":WN,"Se":XN,"Te":_N,"Ue":VN,"Ve":Pt,"We":RN,"Xe":ib,"Ye":wga,"Ze":Oba,"_e":wfa,"$e":eea,"af":c3,"bf":d3,"cf":R2,"df":Q2,"ef":C2,"ff":B2,"gf":y2,"hf":u2,"jf":z2,"kf":y2,"lf":x2,"mf":v2,"nf":w2,"of":v2,"pf":u2,"qf":u2}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


